tinyMCE.addI18n('es.advanced',{
style_select:"Estilos",
font_size:"Tama\u00F1o",
fontdefault:"Fuente",
block:"Formato",
paragraph:"P\u00E1rrafo",
div:"Div",
address:"Direcci\u00F3n",
pre:"Preformateado",
h1:"Encabezado 1",
h2:"Encabezado 2",
h3:"Encabezado 3",
h4:"Encabezado 4",
h5:"Encabezado 5",
h6:"Encabezado 6",
blockquote:"Cita",
code:"C\u00F3digo",
samp:"Ejemplo de c\u00F3digo",
dt:"T\u00E9rmino de definici\u00F3n",
dd:"Descripci\u00F3n de definici\u00F3n",
bold_desc:"Negrita (Ctrl+B)",
italic_desc:"Cursiva (Ctrl+I)",
underline_desc:"Subrayado (Ctrl+U)",
striketrough_desc:"Tachado",
justifyleft_desc:"Alinear a la izquierda",
justifycenter_desc:"Alinear al centro",
justifyright_desc:"Alinear a la derecha",
justifyfull_desc:"Justificar",
bullist_desc:"Lista desordenada",
numlist_desc:"Lista ordenada",
outdent_desc:"Reducir sangr\u00EDa",
indent_desc:"Aumentar sangr\u00EDa",
undo_desc:"Deshacer (Ctrl+Z)",
redo_desc:"Rehacer (Ctrl+Y)",
link_desc:"Insertar/editar hiperv\u00EDnculo",
unlink_desc:"Quitar hiperv\u00EDnculo",
image_desc:"Insertar/editar imagen",
cleanup_desc:"Limpiar c\u00F3digo basura",
code_desc:"Editar c\u00F3digo HTML",
sub_desc:"Sub\u00EDndice",
sup_desc:"Super\u00EDndice",
hr_desc:"Insertar regla horizontal",
removeformat_desc:"Limpiar formato",
custom1_desc:"Su descripci\u00F3n personal aqu\u00ED",
forecolor_desc:"Elegir color del texto",
backcolor_desc:"Elegir color de fondo",
charmap_desc:"Insertar caracteres personalizados",
visualaid_desc:"Mostrar/ocultar l\u00EDnea de gu\u00EDa/elementos invisibles",
anchor_desc:"Insertar/editar ancla",
cut_desc:"Cortar",
copy_desc:"Copiar",
paste_desc:"Pegar",
image_props_desc:"Propiedades de imagen",
newdocument_desc:"Nuevo documento",
help_desc:"Ayuda",
blockquote_desc:"Cita",
clipboard_msg:"Copiar/Cortar/Pegar no se encuentra disponible en Mozilla y Firefox.\n \u00BFQuiere m\u00E1s informaci\u00F3n sobre este tema?",
path:"Ruta",
newdocument:" \u00BFSeguro que desea limpiar todo el contenido?",
toolbar_focus:"Ir a los botones de herramientas - Alt+Q, Ir al editor - Alt-Z, Ir a la ruta del elemento - Alt-X",
more_colors:"M\u00E1s colores"
});