tinyMCE.addI18n('az.advanced_dlg',{
about_title:"TinyMCE haqda",
about_general:"Proqram haqq\u0131nda",
about_help:"K\u00F6m\u0259k",
about_license:"Lisenziya",
about_plugins:"Plaginl\u0259r",
about_plugin:"Plaginl\u0259r",
about_author:"M\u00FC\u0259llif",
about_version:"Versiya",
about_loaded:"Y\u00FCkl\u0259nil\u0259n plaginl\u0259r",
anchor_title:"L\u00F6bv\u0259r \u0259lav\u0259/redakt\u0259 et",
anchor_name:"L\u00F6vb\u0259r ad\u0131",
code_title:"HTML-m\u0259nb\u0259 redaktoru",
code_wordwrap:"S\u00F6zl\u0259rin s\u0259tr\u0259 ke\u00E7idi",
colorpicker_title:"R\u0259ngi se\u00E7",
colorpicker_picker_tab:"Se\u00E7im",
colorpicker_picker_title:"R\u0259ng se\u00E7imi",
colorpicker_palette_tab:"Palitra",
colorpicker_palette_title:"Palitra r\u0259ngl\u0259ri",
colorpicker_named_tab:"Adland\u0131r\u0131lm\u0131\u015F",
colorpicker_named_title:"Adland\u0131r\u0131lm\u0131\u015F r\u0259ngl\u0259r",
colorpicker_color:"R\u0259ng:",
colorpicker_name:"Ad\u0131:",
charmap_title:"X\u00FCsusi simvol se\u00E7in",
image_title:"\u015E\u0259kli \u0259lav\u0259/redakt\u0259 et",
image_src:"\u015E\u0259klin \u00FCnvan\u0131",
image_alt:"\u015E\u0259klin t\u0259sviri",
image_list:"\u015E\u0259kil siyah\u0131s\u0131",
image_border:"S\u0259rh\u0259d",
image_dimensions:"\u00D6l\u00E7\u00FCl\u0259r",
image_vspace:"\u015Eaquli f\u0259za",
image_hspace:"\u00DCf\u00FCqi f\u0259za",
image_align:"Tarazla\u015Fd\u0131r",
image_align_baseline:"Bazis liniyas\u0131 \u00FCzr\u0259",
image_align_top:"Yuxar\u0131 il\u0259",
image_align_middle:"M\u0259rk\u0259z il\u0259",
image_align_bottom:"A\u015Fa\u011F\u0131 il\u0259",
image_align_texttop:"M\u0259tn yuxar\u0131s\u0131 il\u0259",
image_align_textbottom:"M\u0259tn a\u015Fa\u011F\u0131s\u0131 \u00FCzr\u0259",
image_align_left:"Sola",
image_align_right:"Sa\u011Fa",
link_title:"Ke\u00E7idi \u0259lav\u0259/redakt\u0259 et",
link_url:"Ke\u00E7id \u00FCnvan\u0131",
link_target:"H\u0259d\u0259f",
link_target_same:"Ke\u00E7idi h\u0259min p\u0259nc\u0259r\u0259d\u0259 a\u00E7",
link_target_blank:"Ke\u00E7idi yeni p\u0259nc\u0259r\u0259d\u0259 a\u00E7",
link_titlefield:"Ad\u0131",
link_is_email:"Daxil edil\u0259n \u00FCnvan e-po\u00E7ta b\u0259nz\u0259yir. mailto: prefiksini \u0259lav\u0259 etm\u0259k ist\u0259yirsiniz?",
link_is_external:"Daxil edil\u0259n \u00FCnvan xarici ke\u00E7id\u0259 b\u0259nz\u0259yir. http:// prefiksini \u0259lav\u0259 etm\u0259k ist\u0259yirsiniz?",
link_list:"Ke\u00E7idl\u0259r siyah\u0131s\u0131"
});