tinyMCE.addI18n('ca.advimage_dlg',{
tab_general:"General",
tab_appearance:"Aparen\u00E7a",
tab_advanced:"Avan\u00E7at",
general:"General",
title:"T\u00EDtol",
preview:"Previsualitzaci\u00F3",
constrain_proportions:"Mant\u00E9 la proporci\u00F3",
langdir:"Direcci\u00F3 de l\'idioma",
langcode:"Codi de l\'idioma",
long_desc:"Enlla\u00E7 a la descripci\u00F3 llarga",
style:"Estil",
classes:"Classes",
ltr:"D\'esquerra a dreta",
rtl:"De dreta a esquerra",
id:"Id",
map:"Mapa de la imatge",
swap_image:"Canvia imatge",
alt_image:"Imatge alternativa",
mouseover:"quan el ratol\u00ED arriba",
mouseout:"quan el ratol\u00ED marxa",
misc:"Miscel\u00B7l\u00E0nia",
example_img:"Aparen\u00E7a imatge previsualitzada",
missing_alt:"Esteu segur que voleu continuar sense incloure una descripci\u00F3 de la imatge? La imatge pot no ser accessible a usuaris amb discapacitats, o a aquells que utilitzin navegadors de text o que naveguin amb les imatges desactivades.",
dialog_title:"Insereix/edita imatge",
src:"URL de la imatge",
alt:"Descripci\u00F3 de la imatge",
list:"Llista de la imatge",
border:"Vora",
dimensions:"Dimensions",
vspace:"Espai vertical",
hspace:"Espai horitzontal",
align:"Alineaci\u00F3",
align_baseline:"L\u00EDnia de base",
align_top:"Superior",
align_middle:"Mitjan lloc",
align_bottom:"Inferior",
align_texttop:"Dalt del text",
align_textbottom:"Baix del text",
align_left:"A l\'esquerra",
align_right:"A la dreta",
image_list:"Llista d\'imatges"
});