tinyMCE.addI18n('sq.media_dlg',{
title:"Fut / edito media",
general:"T\u00EB P\u00EBrgjithshme",
advanced:"T\u00EB Avancuara",
file:"Skedari/URL",
list:"Lista",
size:"P\u00EBrmasat",
preview:"Paraqitje",
constrain_proportions:"Ruaj raportet",
type:"Tipi",
id:"Id",
name:"Emri",
class_name:"Klasa",
vspace:"Hap\u00EBsira-V",
hspace:"Hap\u00EBsira-H",
play:"Luaj automatikisht",
loop:"Lak",
menu:"Shfaq menu",
quality:"Cil\u00EBsia",
scale:"Shkalla",
align:"Drejtimi",
salign:"Drejtimi S",
wmode:"WMode",
bgcolor:"Fusha",
base:"Baza",
flashvars:"Flashvars",
liveconnect:"SWLiveConnect",
autohref:"AutoHREF",
cache:"Cache",
hidden:"Fshehur",
controller:"Kontrollues",
kioskmode:"M\u00EBnyra Kiosk",
playeveryframe:"Luaj \u00E7do kuader",
targetcache:"Cache sh\u00EBnjestr\u00EBn",
correction:"Pa rregullime",
enablejavascript:"Aktivizo JavaScript",
starttime:"Koha e nisjes",
endtime:"Koha e p\u00EBrfundimit",
href:"Href",
qtsrcchokespeed:"Choke speed",
target:"Sh\u00EBnjestra",
volume:"Volumi",
autostart:"Nisje automatike",
enabled:"Aktivizuar",
fullscreen:"Pamje e plot\u00EB",
invokeurls:"Th\u00EBrrit URL",
mute:"Mbyll z\u00EBrin",
stretchtofit:"Zmadho me p\u00EBrshtatje",
windowlessvideo:"Video pa dritare",
balance:"Balanci",
baseurl:"URL baz\u00EB",
captioningid:"Id e titullit",
currentmarker:"Sh\u00EBnjuesi aktual",
currentposition:"Pozicioni aktual",
defaultframe:"Kuadri fillestar",
playcount:"Numri i luajtjeve",
rate:"Raporti",
uimode:"M\u00EBnyra UI",
flash_options:"Opsionet e Flash",
qt_options:"Opsionet e Quicktime",
wmp_options:"Opsionet e Windows media player",
rmp_options:"Opsionet e Real media player",
shockwave_options:"Opsionet e Shockwave",
autogotourl:"Shko n\u00EB URL automatikisht",
center:"Qend\u00EBr",
imagestatus:"Statusi fotos",
maintainaspect:"Ruaj raportet",
nojava:"Pa Java",
prefetch:"Para ngarko",
shuffle:"Shuffle",
console:"Konsola",
numloop:"Numri lak\u00EBve",
controls:"Kontrollet",
scriptcallbacks:"Script Callbacks",
swstretchstyle:"Stili i zmadhimit",
swstretchhalign:"Zmadho Drejtim-H",
swstretchvalign:"Zmadho Drejtim-V",
sound:"Z\u00EBri",
progress:"Progresi",
qtsrc:"QT Src",
qt_stream_warn:"Risurset rtsp duhet t\u00EB shtohen n\u00EB fush\u00EBn QT Src n\u00EB opsionet e avancuara.\nDuhet t\u00EB shtoni gjithashtu nj\u00EB version jo stream n\u00EB fush\u00EBn src..",
align_top:"Krye",
align_right:"Djathtas",
align_bottom:"Fund",
align_left:"Majtas",
align_center:"Qend\u00EBr",
align_top_left:"Krye-majtas",
align_top_right:"Krye-djathtas",
align_bottom_left:"Fund-majtas",
align_bottom_right:"Fund-djathtas",
flv_options:"Opsionet e videos Flash",
flv_scalemode:"M\u00EBnyra e shkall\u00EBs",
flv_buffer:"Buffer",
flv_startimage:"Foto fillestare",
flv_starttime:"Foto p\u00EBrfundimtare",
flv_defaultvolume:"Volumi fillestar",
flv_hiddengui:"GUI e fshehur",
flv_autostart:"Nis automatikisht",
flv_loop:"Lak",
flv_showscalemodes:"Trego shkall\u00EBt",
flv_smoothvideo:"Video pa ngecje",
flv_jscallback:"JS Callback"
});