tinyMCE.addI18n({cy:{
common:{
edit_confirm:"Ydych chi eisiau defnyddio'r modd WYSIWYG ar gyfer y textarea yma?",
apply:"Gosod",
insert:"Mewnosod",
update:"Diweddaru",
cancel:"Diddymu",
close:"Cau",
browse:"Pori",
class_name:"Dosbarth",
not_set:"-- Nid wedi osod --",
clipboard_msg:"Nid yw Cop\u00EFo/Torri/Gludo ar gael mewn Mozilla a Firefox.\nYdych chi eisiau mwy o wybodaeth am y mater yma?",
clipboard_no_support:"Dim wedi'i gynnal gan eich porwr, defnyddiwch Currently not supported by your browser, use keyboard shortcuts instead.",
popup_blocked:"Rydym wedi sylwi fod eich popup-blocker wedi analluogi ffenest sy'n darparu swyddogaeth cymhwysiad. Bydd rhaid i chi analluogi blocio popups ar gyfer y safle yma i ddefnyddio'r offeryn yma.",
invalid_data:"Gwall: Gwerthau allilys wedi mewnbynnu, mae'r gwerthau yma wedi eu marcio mewn coch.",
more_colors:"Mwy o liwiau"
},
contextmenu:{
align:"Aliniad",
left:"Chwith",
center:"Canol",
right:"De",
full:"Llawn"
},
insertdatetime:{
date_fmt:"%Y-%m-%d",
time_fmt:"%H:%M:%S",
insertdate_desc:"Mewnosod dyddiad",
inserttime_desc:"Mewnosod amser",
months_long:"Ionawr,Chwefror,Mawrth,Ebrill,Mai,Mehefin,Goffennaf,Awst,Medi,Hydref,Tachwedd,Rhagfyr",
months_short:"Ion,Chw,Maw,Ebr,Mai,Meh,Gor,Aws,Med,Hyd,Tac,Rha",
day_long:"Sul,Llun,Mawrth,Mercher,Iau,Gwener,Sadwrn,Sul",
day_short:"Sul,Llu,Maw,Mer,Iau,Gwe,Sad,Sul"
},
print:{
print_desc:"Argraffu"
},
preview:{
preview_desc:"Rhagolygu"
},
directionality:{
ltr_desc:"Cyfeiriad chwith i'r dde",
rtl_desc:"Cyfeiriad de i'r chwith"
},
layer:{
insertlayer_desc:"Mewnosod haen newydd",
forward_desc:"Symud ymlaen",
backward_desc:"Symud n\u00F4l",
absolute_desc:"Toglu lleoli absoliwt",
content:"Haen newydd..."
},
save:{
save_desc:"Cadw",
cancel_desc:"Cadw pob newidiad"
},
nonbreaking:{
nonbreaking_desc:"Mewnosod n\u00F4d bwlch do-doriad"
},
iespell:{
iespell_desc:"Rhedeg gwirio sillafu",
download:"ieSpell dim wedi'i canfod. A ydych eisiau ei gosod rwan?"
},
advhr:{
advhr_desc:"Mesurydd llorweddol"
},
emotions:{
emotions_desc:"Emosiwn"
},
searchreplace:{
search_desc:"Canfod",
replace_desc:"Canfod/Amnewid"
},
advimage:{
image_desc:"Mewnosod/golygu delwedd"
},
advlink:{
link_desc:"Mewnosod/Golygu cyswllt"
},
xhtmlxtras:{
cite_desc:"Dyfyniad",
abbr_desc:"Talfyriad",
acronym_desc:"Acronym",
del_desc:"Dilead",
ins_desc:"Mewnosodiad",
attribs_desc:"Mewnosod/Golygu Priodoleddau"
},
style:{
desc:"Golygu Arddull CSS"
},
paste:{
paste_text_desc:"Gludo fel Testun Plaen",
paste_word_desc:"Gludo o Word",
selectall_desc:"Dewis Pobpeth",
plaintext_mode_sticky:"Gludo rwan mewn modd testun plaen. Cliciwch eto i doglu n\u00F4l i fodd gludo normal. Byddwch yn cael eich dychwelyd i fodd gludo normal ar \u00F4l gludo rhywbeth.",
plaintext_mode:"Gludo rwan mewn modd testun plaen. Cliciwch eto i doglu n\u00F4l i fodd gludo normal."
},
paste_dlg:{
text_title:"Defnyddiwch CTRL+V ar eich bysellfwrdd i ludo'r testun i fewn i'r ffenest.",
text_linebreaks:"Cadw toriadau llinell",
word_title:"Defnyddiwch CTRL+V ar eich bysellfwrdd i ludo'r testun i fewn i'r ffenest."
},
table:{
desc:"Mewnosod tabl newydd",
row_before_desc:"Mewnosod rhes cyn",
row_after_desc:"Mewnosod rhes ar \u00F4l",
delete_row_desc:"Dileu rhes",
col_before_desc:"Mewnosod colofn cyn",
col_after_desc:"Mewnosod colofn ar \u00F4l",
delete_col_desc:"Tynnu colofn",
split_cells_desc:"Hollti celloedd tabl cyfuniedig",
merge_cells_desc:"Cyfuno celloedd tabl",
row_desc:"Priodweddau rhes tabl",
cell_desc:"Priodweddau cell tabl",
props_desc:"Priodweddau tabl",
paste_row_before_desc:"Gludo rhes tabl cyn",
paste_row_after_desc:"Gludo rhes tabl ar \u00F4l",
cut_row_desc:"Torri rhes tabl",
copy_row_desc:"Cop\u00EFo rhes tabl",
del:"Dileu tabl",
row:"Rhes",
col:"Colofn",
cell:"Cell"
},
autosave:{
unload_msg:"Bydd eich newidiadau yn cael eu colli os byddwch yn llywio i ffwrdd o'r tudalen yma.",
restore_content:"Adfer cynnwys awto-cadwedig.",
warning_message:"Os adferwch chi'r cynnwys cadwedig, byddwch yn colli'r holl cynnwys sydd yn bresennol yn y golygydd.\n\nA ydych chi'n si\u0175r eich bod eisiau adfer y cynnwys cadwedig?."
},
fullscreen:{
desc:"Toglu modd sgrin llawn"
},
media:{
desc:"Mewnosod / golygu cyfrwng planedig",
edit:"Golygu cyfrwng planedig"
},
fullpage:{
desc:"Priodweddau dogfen"
},
template:{
desc:"Mewnosod cynnwys templed rhagosodol"
},
visualchars:{
desc:"Nodau rheolaeth ymlaen/i ffwrdd."
},
spellchecker:{
desc:"Toglu cywiriadau",
menu:"Gosodiadau cywiriadau",
ignore_word:"Anwybyddu gair",
ignore_words:"Anwybyddu pob un",
langs:"Ieithoedd",
wait:"Aroswch, os gwelwch yn dda...",
sug:"Awgrymiadau",
no_sug:"Dim awgrymiadau",
no_mpell:"Dim camsillafiadau wedi'i canfod."
},
pagebreak:{
desc:"Mewnosod toriad tudalen."
},
advlist:{
types:"Mathau",
def:"Rhagosodedig",
lower_alpha:"Alffa is",
lower_greek:"Groegaiddd is",
lower_roman:"Rhufeinig is",
upper_alpha:"Alffa uwch",
upper_roman:"Rhufeinig uwch",
circle:"Cylch",
disc:"Disg",
square:"Sgw\u00E2r"
}}});