tinyMCE.addI18n('fr.advlink_dlg',{
title:"Ins\u00E9rer / \u00E9diter un lien",
url:"URL du lien",
target:"Cible",
titlefield:"Titre",
is_email:"L'URL que vous avez saisie semble \u00EAtre une adresse e-mail, souhaitez-vous ajouter le pr\u00E9fixe \u00AB mailto: \u00BB ?",
is_external:"L'URL que vous avez saisie semble \u00EAtre une adresse web externe. Souhaitez-vous ajouter le pr\u00E9fixe \u00AB http:// \u00BB ?",
list:"Liste de liens",
general_tab:"G\u00E9n\u00E9ral",
popup_tab:"Popup",
events_tab:"\u00C9v\u00E8nements",
advanced_tab:"Avanc\u00E9",
general_props:"Propri\u00E9t\u00E9s g\u00E9n\u00E9rales",
popup_props:"Propri\u00E9t\u00E9s de la popup",
event_props:"\u00C9v\u00E8nements",
advanced_props:"Propri\u00E9t\u00E9s avanc\u00E9es",
popup_opts:"Options",
anchor_names:"Ancres",
target_same:"Ouvrir dans cette fen\u00EAtre / dans ce cadre",
target_parent:"Ouvrir dans la fen\u00EAtre / le cadre parent",
target_top:"Ouvrir dans le cadre principal (remplace tous les cadres)",
target_blank:"Ouvrir dans une nouvelle fen\u00EAtre",
popup:"Popup Javascript",
popup_url:"URL de la popup",
popup_name:"Nom de la fen\u00EAtre",
popup_return:"Ins\u00E9rer 'return false'",
popup_scrollbars:"Afficher les ascenseurs",
popup_statusbar:"Afficher la barre d'\u00E9tat",
popup_toolbar:"Afficher la barre d'outils",
popup_menubar:"Afficher la barre de menu",
popup_location:"Afficher la barre d'adresse",
popup_resizable:"Autoriser le redimensionnement de la fen\u00EAtre",
popup_dependent:"D\u00E9pendante (seulement sous Mozilla/Firefox)",
popup_size:"Taille",
popup_position:"Position (X/Y)",
id:"Id",
style:"Style",
classes:"Classes",
target_name:"Nom de la cible",
langdir:"Sens de lecture",
target_langcode:"Langue de la cible",
langcode:"Code de la langue",
encoding:"Encodage de la cible",
mime:"Type MIME de la cible",
rel:"Relation de la page \u00E0 la cible",
rev:"Relation de la cible \u00E0 la page",
tabindex:"Tabindex",
accesskey:"Touche d'acc\u00E8s rapide",
ltr:"Gauche \u00E0 droite",
rtl:"Droite \u00E0 gauche",
link_list:"Liste des liens"
});