tinyMCE.addI18n('cy.table_dlg',{
general_tab:"Cyffredinol",
advanced_tab:"Uwch",
general_props:"Priodweddau cyffredinol",
advanced_props:"Priodweddau uwch",
rowtype:"Rhes mewn rhan tabl",
title:"Mewnosod/Golygu tabl",
width:"Lled",
height:"Uchder",
cols:"Colofnau",
rows:"Rhesi",
cellspacing:"Bylchiad celloedd",
cellpadding:"Padio celloedd",
border:"Border",
align:"Aliniad",
align_default:"Rhagosodedig",
align_left:"Chwith",
align_right:"De",
align_middle:"Canol",
row_title:"Priodweddau rhes tabl",
cell_title:"Priodweddau cell tabl",
cell_type:"Math cell",
valign:"Aliniad ferigol",
align_top:"Pen",
align_bottom:"Gwaelod",
bordercolor:"Lliw border",
bgcolor:"Lliw cefndir",
merge_cells_title:"Cyfuno celloedd tabl",
id:"Id",
style:"Arddull",
langdir:"Cyfeiriad iaith",
langcode:"Cod iaith",
mime:"Math MIME targed",
ltr:"Chwith i'r dde",
rtl:"De i'r chwith",
bgimage:"Delwedd cefndir",
summary:"Crynodeb",
td:"Data",
th:"Pennyn",
cell_cell:"Diweddaru cell cyfredol",
cell_row:"Diweddaru pob cell yn y rhes",
cell_all:"Diweddaru pob cell yn y tabl",
row_row:"Diweddaru rhes cyfredol",
row_odd:"Diweddaru rhesi odrif yn y tabl",
row_even:"Diweddaru rhesi eilrif yn y tabl",
row_all:"Diweddaru pob rhes yn y tabl",
thead:"Pen Tabl",
tbody:"Corff Tabl",
tfoot:"Troed Tabl",
scope:"Cwmpas",
rowgroup:"Gr\u0175p Rhesi",
colgroup:"Gr\u0175p Colofnau",
col_limit:"Rydych wedi mynd tu twnt i'r nifer uchafswm {$cols} o golofnau.",
row_limit:"Rydych wedi mynd tu twnt i'r nifer uchafswm {$rows} o rhesi.",
cell_limit:"Rydych wedi mynd tu twnt i'r nifer uchafswm {$cells} o celloedd.",
missing_scope:"A ydych chi'n si\u0175r eich bod eisiau parhau heb penodi cwmpas i'r cell pennyn yma? Hebddo fo, efallai fydd o'n anodd i rhai ddefnyddwyr gyda anableddau i ddeallt y cynnwys neu'r data yn y tabl.",
caption:"Egluryn tabl",
frame:"Ffr\u00E2m",
frame_none:"none",
frame_groups:"groups",
frame_rows:"rows",
frame_cols:"cols",
frame_all:"all",
rules:"Rheolau",
rules_void:"void",
rules_above:"above",
rules_below:"o dan",
rules_hsides:"hsides",
rules_lhs:"lhs",
rules_rhs:"rhs",
rules_vsides:"vsides",
rules_box:"box",
rules_border:"border"
});