tinyMCE.addI18n('vi.table_dlg',{
general_tab:"Chung",
advanced_tab:"N\u00E2ng cao",
general_props:"Thu\u1ED9c t\u00EDnh chung",
advanced_props:"Thu\u1ED9c t\u00EDnh n\u00E2ng cao",
rowtype:"H\u00E0ng trong t\u1EEBng ph\u1EA7n b\u1EA3ng",
title:"Ch\u00E8n/S\u1EEDa b\u1EA3ng",
width:"Chi\u1EC1u r\u1ED9ng",
height:"Chi\u1EC1u cao",
cols:"C\u1ED9t",
rows:"H\u00E0ng",
cellspacing:"Kho\u1EA3ng c\u00E1ch \u00F4",
cellpadding:"Kho\u1EA3ng l\u00F3t \u00F4",
border:"Vi\u1EC1n",
align:"Canh l\u1EC1",
align_default:"M\u1EB7c \u0111\u1ECBnh",
align_left:"Tr\u00E1i",
align_right:"Ph\u1EA3i",
align_middle:"Gi\u1EEFa",
row_title:"Thu\u1ED9c t\u00EDnh h\u00E0ng",
cell_title:"Thu\u1ED9c t\u00EDnh \u00F4",
cell_type:"Lo\u1EA1i \u00F4",
valign:"Canh l\u1EC1 d\u1ECDc",
align_top:"Tr\u00EAn",
align_bottom:"D\u01B0\u1EDBi",
bordercolor:"M\u00E0u vi\u1EC1n",
bgcolor:"M\u00E0u n\u1EC1n",
merge_cells_title:"K\u1EBFt h\u1EE3p c\u00E1c \u00F4 c\u1EE7a b\u1EA3ng",
id:"Id",
style:"Ki\u1EC3u d\u00E1ng",
langdir:"H\u01B0\u1EDBng ng\u00F4n ng\u1EEF",
langcode:"M\u00E3 ng\u00F4n ng\u1EEF",
mime:"Ki\u1EC3u MIME \u0111\u00EDch",
ltr:"Tr\u00E1i qua ph\u1EA3i",
rtl:"Ph\u1EA3i qua tr\u00E1i",
bgimage:"\u1EA2nh n\u1EC1n",
summary:"T\u00F3m l\u01B0\u1EE3c",
td:"D\u1EEF li\u1EC7u",
th:"\u0110\u1EA7u \u0111\u1EC1",
cell_cell:"C\u1EADp nh\u1EADt \u00F4 hi\u1EC7n th\u1EDDi",
cell_row:"C\u1EADp nh\u1EA5t t\u1EA5t c\u00E1c \u00F4 trong h\u00E0ng",
cell_all:"C\u1EADp nh\u1EA5t t\u1EA5t c\u00E1c \u00F4 trong b\u1EA3ng",
row_row:"C\u1EADp nh\u1EADt h\u00E0ng hi\u1EC7n th\u1EDDi",
row_odd:"C\u1EADp nh\u1EADt h\u00E0ng l\u1EBB trong b\u1EA3ng",
row_even:"C\u1EADp nh\u1EADt h\u00E0ng ch\u1EB5n trong b\u1EA3ng",
row_all:"C\u1EADp nh\u1EADt t\u1EA5t h\u00E0ng trong b\u1EA3ng",
thead:"\u0110\u1EA7u b\u1EA3ng",
tbody:"Th\u00E2n b\u1EA3n",
tfoot:"Ch\u00E2n b\u1EA3ng",
scope:"Ph\u1EA1m vi",
rowgroup:"Nh\u00F3m h\u00E0ng",
colgroup:"Nh\u00F3m c\u1ED9t",
col_limit:"B\u1EA1n \u0111\u00E3 v\u01B0\u1EE3t qu\u00E1 s\u1ED1 t\u1ED1i \u0111a c\u1ED9t c\u1EE7a {$cols}.",
row_limit:"B\u1EA1n \u0111\u00E3 v\u01B0\u1EE3t qu\u00E1 s\u1ED1 t\u1ED1i \u0111a h\u00E0ng c\u1EE7a {$rows}.",
cell_limit:"B\u1EA1n \u0111\u00E3 v\u01B0\u1EE3t qu\u00E1 s\u1ED1 t\u1ED1i \u0111a \u00F4 c\u1EE7a {$cells}.",
missing_scope:"B\u1EA1n c\u00F3 ch\u1EAFc ch\u1EAFn mu\u1ED1n ti\u1EBFp th\u1EE5c  v\u1EDBi vi\u1EC7c kh\u00F4ng ch\u1EC9 \u0111\u1ECBnh ph\u1EA1m vi cho \u00F4 ti\u00EAu \u0111\u1EC1 c\u1EE7a b\u1EA3ng n\u00E0y. Kh\u00F4ng c\u00F3 n\u00F3, \u0111i\u1EC1u n\u00E0y c\u00F3 th\u1EC3 kh\u00F3 kh\u0103n cho m\u1ED9t s\u1ED1 ng\u01B0\u1EDDi d\u00F9ng khuy\u1EBFt t\u1EADt \u0111\u1EC3 hi\u1EC3u n\u1ED9i dung ho\u1EB7c d\u1EEF li\u1EC7u hi\u1EC3n th\u1ECB c\u1EE7a b\u1EA3ng.",
caption:"Ch\u00FA t\u00EDch b\u1EA3ng",
frame:"Khung",
frame_none:"kh\u00F4ng",
frame_groups:"nh\u00F3m",
frame_rows:"h\u00E0ng",
frame_cols:"c\u1ED9t",
frame_all:"t\u1EA5t",
rules:"Th\u01B0\u1EDBc",
rules_void:"tr\u1ED1ng kh\u00F4ng",
rules_above:"tr\u00EAn",
rules_below:"d\u01B0\u1EDBi",
rules_hsides:"hsides",
rules_lhs:"lhs",
rules_rhs:"rhs",
rules_vsides:"vsides",
rules_box:"box",
rules_border:"vi\u1EC1n"
});