tinyMCE.addI18n('da.table_dlg',{
general_tab:"Generelt",
advanced_tab:"Avanceret",
general_props:"Generelle egenskaber",
advanced_props:"Avancerede egenskaber",
rowtype:"Row in table part",
title:"Inds\u00E6t/rediger tabel",
width:"Bredde",
height:"H\u00F8jde",
cols:"Kolonner",
rows:"R\u00E6kker",
cellspacing:"Afstand mellem celler",
cellpadding:"Afstand til celleindhold",
border:"Kant",
align:"Justering",
align_default:"Standard",
align_left:"Venstre",
align_right:"H\u00F8jre",
align_middle:"Centreret",
row_title:"R\u00E6kkeegenskaber",
cell_title:"Celleegenskaber",
cell_type:"Celletype",
valign:"Vertikal justering",
align_top:"Top",
align_bottom:"Bund",
bordercolor:"Kantfarve",
bgcolor:"Baggrundsfarve",
merge_cells_title:"Flet celler",
id:"Id",
style:"Style",
langdir:"Sprogretning",
langcode:"Sprogkode",
mime:"Destinations-MIME-type",
ltr:"Venstre mod h\u00F8jre",
rtl:"H\u00F8jre mod venstre",
bgimage:"Baggrundsbillede",
summary:"Beskrivelse",
td:"Data",
th:"Hoved",
cell_cell:"Opdater aktuelle celle",
cell_row:"Opdater alle celler i r\u00E6kken",
cell_all:"Opdater alle celler i tabellen",
row_row:"Opdater aktuelle celle",
row_odd:"Opdater ulige r\u00E6kker",
row_even:"Opdater lige r\u00E6kker",
row_all:"Opdater alle r\u00E6kker",
thead:"Tabelhoved",
tbody:"Tabelkrop",
tfoot:"Tabelfod",
scope:"Forklaring",
rowgroup:"R\u00E6kkegruppe",
colgroup:"Kolonnegruppe",
col_limit:"Du har overskredet antallet af tilladte kolonner p\u00E5 {$cols}.",
row_limit:"Du har overskredet antallet af tilladte r\u00E6kker p\u00E5 {$rows}.",
cell_limit:"Du har overskredet antallet af tilladte celler p\u00E5 {$cells}.",
missing_scope:"Er du sikker p\u00E5, du vil forts\u00E6tte uden at angive forklaring for denne overskriftscelle? Uden forklaring vil v\u00E6re sv\u00E6rt for f.ek.s blinde at l\u00E6se og forst\u00E5 indholdet i tabellen.",
caption:"Tabeloverskrift",
frame:"Ramme",
frame_none:"ingen",
frame_groups:"grupper",
frame_rows:"r\u00E6kker",
frame_cols:"kolonner",
frame_all:"alle",
rules:"Regler",
rules_void:"void",
rules_above:"over",
rules_below:"under",
rules_hsides:"hsides",
rules_lhs:"lhs",
rules_rhs:"rhs",
rules_vsides:"vsides",
rules_box:"boks",
rules_border:"kant"
});