tinyMCE.addI18n('gl.xhtmlxtras_dlg',{
attribute_label_title:"T\u00EDtulo",
attribute_label_id:"ID",
attribute_label_class:"Clase",
attribute_label_style:"Estilo",
attribute_label_cite:"Cita",
attribute_label_datetime:"Data/Hora",
attribute_label_langdir:"Direcci\u00F3n de texto",
attribute_option_ltr:"Esquerda a dereita",
attribute_option_rtl:"Dereita a esquerda",
attribute_label_langcode:"Lenguaxe",
attribute_label_tabindex:"Orde de tabulaci\u00F3n",
attribute_label_accesskey:"Tecla de acceso",
attribute_events_tab:"Eventos",
attribute_attrib_tab:"Atributos",
general_tab:"Xeral",
attrib_tab:"Atributos",
events_tab:"Eventos",
fieldset_general_tab:"Configuraci\u00F3n xeral",
fieldset_attrib_tab:"Atributos",
fieldset_events_tab:"Evento",
title_ins_element:"Insertar",
title_del_element:"Borrar",
title_acronym_element:"Acr\u00F3nimo",
title_abbr_element:"Abreviatura",
title_cite_element:"Cita",
remove:"Suprimir",
insert_date:"Insertar data/hora actuais",
option_ltr:"Esquerda a dereita",
option_rtl:"Dereita a esquerda",
attribs_title:"Insertar/Editar atributos"
});