tinyMCE.addI18n('vi.advanced',{
style_select:"Ki\u1EC3u",
font_size:"K\u00EDch th\u01B0\u1EDBc font",
fontdefault:"T\u00EAn font ch\u1EEF",
block:"\u0110\u1ECBnh d\u1EA1ng",
paragraph:"\u0110o\u1EA1n",
div:"Th\u1EBB",
address:"Th\u1EBB \u0110\u1ECBa ch\u1EC9",
pre:"Th\u1EBB Ti\u1EC1n \u0111\u1ECBnh d\u1EA1ng",
h1:"Th\u1EBB Heading 1",
h2:"Th\u1EBB Heading 2",
h3:"Th\u1EBB Heading 3",
h4:"Th\u1EBB Heading 4",
h5:"Th\u1EBB Heading 5",
h6:"Th\u1EBB Heading 6",
blockquote:"Th\u1EBB Tr\u00EDch d\u1EABn",
code:"Th\u1EBB M\u00E3",
samp:"Th\u1EBB M\u00E3 v\u00ED d\u1EE5",
dt:"Th\u1EBB \u0110i\u1EC1u kho\u1EA3n \u0111\u1ECBnh ngh\u0129a ",
dd:"Th\u1EBB M\u00F4 t\u1EA3 \u0111\u1ECBnh ngh\u0129a",
bold_desc:"Ch\u1EEF \u0111\u1EADm (Ctrl+B)",
italic_desc:"Ch\u1EEF nghi\u00EAng (Ctrl+I)",
underline_desc:"G\u1EA1ch ch\u00E2n (Ctrl+U)",
striketrough_desc:"G\u1EA1ch ngang",
justifyleft_desc:"Canh l\u1EC1 tr\u00E1i",
justifycenter_desc:"Canh gi\u1EEFa",
justifyright_desc:"Canh l\u1EC1 ph\u1EA3i",
justifyfull_desc:"Canh l\u1EC1 \u0111\u1EC1u",
bullist_desc:"Danh s\u00E1ch",
numlist_desc:"Danh s\u00E1ch c\u00F3 ch\u1EC9 s\u1ED1",
outdent_desc:"V\u1EC1 \u0111\u1EA7u d\u00F2ng",
indent_desc:"Th\u1EE5t \u0111\u1EA7u d\u00F2ng",
undo_desc:"Tr\u1EDF v\u1EC1 (Ctrl+Z)",
redo_desc:"Ti\u1EBFn t\u1EDBi (Ctrl+Y)",
link_desc:"Th\u00EAm/S\u1EEDa Li\u00EAn k\u1EBFt",
unlink_desc:"X\u00F3a Li\u00EAn k\u1EBFt",
image_desc:"Ch\u00E8n/s\u1EEDa \u1EA3nh",
cleanup_desc:"D\u1ECDn d\u1EB9p m\u00E3 l\u1ED9n x\u1ED9n",
code_desc:"S\u1EEDa m\u00E3 HTML",
sub_desc:"Ch\u1EC9 s\u1ED1 d\u01B0\u1EDBi d\u00F2ng",
sup_desc:"Ch\u1EC9 s\u1ED1 b\u00EAn tr\u00EAn",
hr_desc:"Ch\u00E8n th\u01B0\u1EDBc ngang",
removeformat_desc:"Lo\u1EA1i b\u1ECF \u0111\u1ECBnh d\u1EA1ng",
custom1_desc:"M\u00F4 t\u1EA3 t\u00F9y bi\u1EBFn c\u1EE7a b\u1EA1n \u1EDF \u0111\u00E2y",
forecolor_desc:"Ch\u1ECDn m\u00E0u ch\u1EEF",
backcolor_desc:"Ch\u1ECDn m\u00E0u n\u1EC1n",
charmap_desc:"Ch\u00E8n k\u00FD t\u1EF1 t\u00F9y bi\u1EBFn",
visualaid_desc:"\u0110\u1EA3o c\u00E1c th\u00E0nh ph\u1EA7n h\u01B0\u1EDBng d\u1EABn ho\u1EB7c \u1EA9n",
anchor_desc:"Ch\u00E8n/s\u1EEDa m\u1ECF neo",
cut_desc:"C\u1EAFt",
copy_desc:"Sao ch\u00E9p",
paste_desc:"D\u00E1n",
image_props_desc:"Thu\u1ED9c t\u00EDnh \u1EA3nh",
newdocument_desc:"V\u0103n b\u1EA3n m\u1EDBi",
help_desc:"Tr\u1EE3 gi\u00FAp",
blockquote_desc:"Blockquote",
clipboard_msg:"Sao ch\u00E9p/C\u1EAFt/D\u00E1n kh\u00F4ng c\u00F3 s\u1EB5n trong Mozilla v\u00E0 Firefox.\r\n\t\t\tB\u1EA1n c\u00F3 mu\u1ED1n bi\u1EBFt th\u00EAm th\u00F4ng tin v\u1EC1 v\u1EA5n \u0111\u1EC1 n\u00E0y?",
path:"\u0110\u01B0\u1EDDng d\u1EABn",
newdocument:"B\u1EA1n c\u00F3 ch\u1EAFc ch\u1EAFn mu\u1ED1n x\u00F3a t\u1EA5t c\u1EA3 n\u1ED9i dung?",
toolbar_focus:"Nh\u1EA3y t\u1EDBi c\u00E1c n\u00FAt c\u00F4ng c\u1EE5 - Alt+Q, T\u1EDBi tr\u00ECnh so\u1EA1n th\u1EA3o - Alt-Z, T\u1EDBi \u0111\u01B0\u1EDDng d\u1EABn c\u00E1c ph\u1EA7n t\u1EED - Alt-X",
more_colors:"Th\u00EAm m\u00E0u"
});