tinyMCE.addI18n('lb.table_dlg',{
general_tab:"Allgemeng",
advanced_tab:"Erweidert",
general_props:"Allgemeng Astellungen",
advanced_props:"Erweidert Astellungen",
rowtype:"Grupp\u00E9ierung",
title:"Tabelle af\u00FCgen/beaarbechten",
width:"Breet",
height:"H\u00E9icht",
cols:"Spalten",
rows:"Zeilen",
cellspacing:"Zellenofstand",
cellpadding:"Ofstand innerhalb vun den Zellen",
border:"Rumm",
align:"Ausriichtung",
align_default:"Standard",
align_left:"L\u00E9nks",
align_right:"Riets",
align_middle:"M\u00EBtteg",
row_title:"Eegeschafte vun der Zeil",
cell_title:"Eegeschafte vun der Zell",
cell_type:"Zellentyp",
valign:"Vertikal Ausriichtung",
align_top:"Uewen",
align_bottom:"\u00CBnnen",
bordercolor:"Fuerf vun der Rumm",
bgcolor:"Hannergrondfuerf",
merge_cells_title:"Zelle vereenen",
id:"ID",
style:"Format",
langdir:"Schr\u00EBftrichtung",
langcode:"Sproochecode",
mime:"MIME-Typ vum Inhalt",
ltr:"L\u00E9nks no riets",
rtl:"Riets no l\u00E9nks",
bgimage:"Hannergrondbild",
summary:"Zesummefaassung",
td:"Textzell",
th:"Iwwerschr\u00EBft",
cell_cell:"D\u00EBs Zell ver\u00E4nneren",
cell_row:"All Zellen an d\u00EBser Zeil ver\u00E4nneren",
cell_all:"All Zellen der Tabelle ver\u00E4nneren",
row_row:"D\u00EBs Zeil ver\u00E4nneren",
row_odd:"Ongrued Zeilen ver\u00E4nneren",
row_even:"Grued Zeilen ver\u00E4nneren",
row_all:"All d'Zeilen ver\u00E4nneren",
thead:"Tabellekapp",
tbody:"Tabelleninhalt",
tfoot:"Tabellefouss",
scope:"Bezuch",
rowgroup:"Vertikal grupp\u00E9ieren",
colgroup:"Horizontal grupp\u00E9ieren",
col_limit:"Dir hutt d\u00E9i maximal Spaltenzuel vun {$cols} iwwerschratt.",
row_limit:"Dir hutt d\u00E9i maximal Zeilenzuel vun {$rows} iwwerschratt.",
cell_limit:"Dir hutt d\u00E9i maximal Zellenzuel vun {$cells} iwwerschratt.",
missing_scope:"W\u00EBllt Dir wierklech keng Bez\u00E9iung fir d\u00EBs Iwwerschr\u00EBft uginn? Benotzer mat kierperlechen Aschr\u00E4nkungen k\u00EBnne Schwieregkeeten hunn, den Inhalt vun der Tabelle ze verstoen.",
caption:"Beschr\u00EBftung vun der Tabelle",
frame:"Rumm",
frame_none:"keng",
frame_groups:"zw\u00EBschen Gruppen",
frame_rows:"zw\u00EBschen Zeilen",
frame_cols:"zw\u00EBschen Spalten",
frame_all:"zw\u00EBschen allen Zellen",
rules:"Gitter",
rules_void:"keen",
rules_above:"n\u00EBmmen uewen",
rules_below:"n\u00EBmmen \u00EBnnen",
rules_hsides:"uewen an \u00EBnnen",
rules_lhs:"n\u00EBmmen l\u00E9nks",
rules_rhs:"n\u00EBmmen riets",
rules_vsides:"l\u00E9nks a riets",
rules_box:"all 4 S\u00E4iten (Box)",
rules_border:"all 4 S\u00E4iten (Bord)"
});