tinyMCE.addI18n('cy.advimage_dlg',{
tab_general:"Cyffredinol",
tab_appearance:"Ymddangosiad",
tab_advanced:"Uwch",
general:"Cyffredinol",
title:"Teitl",
preview:"Rhagolwg",
constrain_proportions:"Cynfyngu cyfraneddau",
langdir:"Cyfeiriad iaith",
langcode:"Cod iaith",
long_desc:"Cyswllt disgrifiad hir",
style:"Arddull",
classes:"Dosbarthiadau",
ltr:"Chwith i'r dde",
rtl:"De i'r chwith",
id:"Id",
map:"Map delweddau",
swap_image:"Cyfnewid delwedd",
alt_image:"Delwedd arall",
mouseover:"ar gyfer llygoden drosti",
mouseout:"ar gyfer llygoden allan",
misc:"Amrywiol",
example_img:"Delwedd rhagolygiad ymddangosiad",
missing_alt:"A ydych chi'n si\u0175r eich bod eisiau parhau heb cynnwys Disgrifiad Delwedd? Hebddo fo ni fydd y delwedd yn hygyrchol i ddefnyddwyr gyda anableddau, neu sy'n defnyddio porwr testun, neu sy'n pori'r we gyda delweddau wedi'u diffodd.",
dialog_title:"Mewnosod/golygu delwedd",
src:"URL delwedd",
alt:"Disgrifiad delwedd",
list:"Rhestr delweddau",
border:"Border",
dimensions:"Dimensiynau",
vspace:"Gofod fertigol",
hspace:"Gofod llorweddol",
align:"Aliniad",
align_baseline:"Gwaelodlin",
align_top:"Pen",
align_middle:"Canol",
align_bottom:"Gwaelod",
align_texttop:"Pen testun",
align_textbottom:"Gwaelod testun",
align_left:"Chwith",
align_right:"De",
image_list:"Rhestr delweddau"
});