tinyMCE.addI18n('sk.table_dlg',{
general_tab:"Obecn\u00E9",
advanced_tab:"Roz\u0161\u00EDren\u00E9",
general_props:"Obecn\u00E9 parametre",
advanced_props:"Roz\u0161\u00EDren\u00E9 parametre",
rowtype:"Typ riadku",
title:"Vlo\u017Ei\u0165/Upravi\u0165 tabu\u013Eku",
width:"\u0160\u00EDrka",
height:"V\u00FD\u0161ka",
cols:"St\u013Apce",
rows:"Riadky",
cellspacing:"Rozstup buniek",
cellpadding:"Odsadenie obsahu",
border:"Or\u00E1movanie",
align:"Zarovnanie",
align_default:"Predvolen\u00E9",
align_left:"V\u013Eavo",
align_right:"Vpravo",
align_middle:"Na stred",
row_title:"Vlastnosti riadkov",
cell_title:"Vlastnosti bunky",
cell_type:"Typ bunky",
valign:"Vertik\u00E1lne zarovnanie",
align_top:"Hore",
align_bottom:"Dolu",
bordercolor:"Farba or\u00E1movania",
bgcolor:"Farba pozadia",
merge_cells_title:"Zl\u00FA\u010Di\u0165 bunky",
id:"ID",
style:"\u0160t\u00FDl",
langdir:"Smer textu",
langcode:"K\u00F3d jazyka",
mime:"MIME typ cie\u013Ea",
ltr:"Z\u013Eava doprava",
rtl:"Sprava do\u013Eava",
bgimage:"Obr\u00E1zok pozadia",
summary:"Obsah tabu\u013Eky",
td:"D\u00E1ta",
th:"Hlavi\u010Dka",
cell_cell:"Aktualizova\u0165 aktu\u00E1lnu bunku",
cell_row:"Aktualizova\u0165 v\u0161etky bunky v riadku",
cell_all:"Aktualizova\u0165 v\u0161etky bunky v tabu\u013Eke",
row_row:"Aktualizova\u0165 aktu\u00E1lny riadok",
row_odd:"Aktualizova\u0165 nep\u00E1rne riadky tabu\u013Eky",
row_even:"Aktualizova\u0165 p\u00E1rne riadky tabu\u013Eky",
row_all:"Aktualizova\u0165 v\u0161etky riadky tabu\u013Eky",
thead:"Hlavi\u010Dka tabu\u013Eky",
tbody:"Telo tabu\u013Eky",
tfoot:"P\u00E4ta tabu\u013Eky",
scope:"Hlavi\u010Dka pre",
rowgroup:"Skupina riadkov",
colgroup:"Skupina st\u013Apcov",
col_limit:"Prekro\u010Dili ste maxim\u00E1lny po\u010Det st\u013Apcov {$cols}.",
row_limit:"Prekro\u010Dili ste maxim\u00E1lny po\u010Det riadkov {$rows}.",
cell_limit:"Prekro\u010Dili ste maxim\u00E1lny po\u010Det buniek {$cells}.",
missing_scope:"Skuto\u010Dne chcete pokra\u010Dova\u0165 bez ur\u010Denia oblasti hlavi\u010Dky tejto tabu\u013Eky? Bez nej m\u00F4\u017Ee u niektor\u00FDch u\u017E\u00EDvate\u013Eov doch\u00E1dza\u0165 k ur\u010Dit\u00FDm probl\u00E9mom pri intepret\u00E1cii a zobrazovan\u00ED d\u00E1t v tabu\u013Eke.",
caption:"Nadpis tabu\u013Eky",
frame:"Or\u00E1movanie tabu\u013Eky",
frame_none:"\u017Eiadna",
frame_groups:"oblasti a skupiny st\u013Apcov",
frame_rows:"riadky",
frame_cols:"st\u013Apce",
frame_all:"v\u0161etko",
rules:"Vykreslenie mrie\u017Eky",
rules_void:"\u017Eiadne",
rules_above:"hore",
rules_below:"dole",
rules_hsides:"hore a dole",
rules_lhs:"v\u013Eavo",
rules_rhs:"vpravo",
rules_vsides:"v\u013Eavo a vpravo",
rules_box:"box okolo",
rules_border:"or\u00E1movanie okolo"
});