tinyMCE.addI18n({da:{
common:{
edit_confirm:"Vil du bruge den avancerede tekstredigering?",
apply:"Anvend",
insert:"Inds\u00E6t",
update:"Opdater",
cancel:"Annuller",
close:"Luk",
browse:"Gennemse",
class_name:"Klasse",
not_set:"-- Ikke sat --",
clipboard_msg:"Kopier/Klip/inds\u00E6t er ikke muligt i Mozilla eller Firefox.\nVil du have mere information om dette emne?",
clipboard_no_support:"P\u00E5 nuv\u00E6rende tidspunkt ikke supporteret af din browser. Anvend i stedet genvejene p\u00E5 tastaturet.",
popup_blocked:"Undskyld, men vi har noteret os, at din popup-blocker har forhindret et vindue, der giver programmet funktionalitet, at \u00E5bne op. Hvis du vil have  den fulde funktionalitet, m\u00E5 du sl\u00E5 popup-blockeren fra for dette websted.",
invalid_data:"Fejl: Forkerte v\u00E6rdier indtastet i felter markeret med r\u00F8d.",
more_colors:"Flere farver"
},
contextmenu:{
align:"Justering",
left:"Venstre",
center:"Centreret",
right:"H\u00F8jre",
full:"Lige marginer"
},
insertdatetime:{
date_fmt:"%Y-%m-%d",
time_fmt:"%H:%M:%S",
insertdate_desc:"Inds\u00E6t dato",
inserttime_desc:"Inds\u00E6t klokkeslet",
months_long:"Januar,Februar,Marts,April,Maj,Juni,Juli,August,September,Oktober,November,December",
months_short:"Jan,Feb,Mar,Apr,Maj,Jun,Jul,Aug,Sep,Okt,Nov,Dec",
day_long:"S\u00F8ndag,Mandag,Tirsdag,Onsdag,Torsdag,Fredag,L\u00F8rdag,S\u00F8ndag",
day_short:"S\u00F8n,Man,Tir,Ons,Tors,Fre,L\u00F8r,S\u00F8n"
},
print:{
print_desc:"Udskriv"
},
preview:{
preview_desc:"Vis udskrift"
},
directionality:{
ltr_desc:"Retning venstre mod h\u00F8jre",
rtl_desc:"Retning h\u00F8jre mod venstre"
},
layer:{
insertlayer_desc:"Inds\u00E6t nyt lag",
forward_desc:"Flyt fremad",
backward_desc:"Flyt bagud",
absolute_desc:"Sl\u00E5 absolut positionering til/fra",
content:"Nyt lag..."
},
save:{
save_desc:"Gem",
cancel_desc:"Annuller alle \u00E6ndringer"
},
nonbreaking:{
nonbreaking_desc:"Inds\u00E6t et blanktegn"
},
iespell:{
iespell_desc:"Udf\u00F8r stavekontrol",
download:"ieSpell blev ikke fundet. Vil du installere det nu?"
},
advhr:{
advhr_desc:"Horisontal linie"
},
emotions:{
emotions_desc:"Hum\u00F8rikoner"
},
searchreplace:{
search_desc:"S\u00F8g",
replace_desc:"S\u00F8g/erstat"
},
advimage:{
image_desc:"Inds\u00E6t/rediger billede"
},
advlink:{
link_desc:"Inds\u00E6t/rediger link",
delta_width:"40"
},
xhtmlxtras:{
cite_desc:"Citat",
abbr_desc:"Forkortelse",
acronym_desc:"Akronym",
del_desc:"Sletning",
ins_desc:"Inds\u00E6ttelse",
attribs_desc:"Inds\u00E6t/rediger attributter"
},
style:{
desc:"Rediger CSS stil"
},
paste:{
paste_text_desc:"Inds\u00E6t ikke-formatteret tekst",
paste_word_desc:"Inds\u00E6t fra  Word",
selectall_desc:"V\u00E6lg alle",
plaintext_mode_sticky:"Paste is now in plain text mode. Click again to toggle back to regular paste mode. After you paste something you will be returned to regular paste mode.",
plaintext_mode:"Paste is now in plain text mode. Click again to toggle back to regular paste mode."
},
paste_dlg:{
text_title:"Anvend CTRL+V p\u00E5 tastaturet for at inds\u00E6tte teksten.",
text_linebreaks:"Bevar linieskift",
word_title:"Anvend CTRL+V p\u00E5 tastaturet for at inds\u00E6tte teksten."
},
table:{
desc:"Inds\u00E6t tabel",
row_before_desc:"Inds\u00E6t r\u00E6kke f\u00F8r",
row_after_desc:"Inds\u00E6t r\u00E6kke efter",
delete_row_desc:"Slet r\u00E6kke",
col_before_desc:"Inds\u00E6t kolonne f\u00F8r",
col_after_desc:"Inds\u00E6t kolonne efter",
delete_col_desc:"Slet kolonne",
split_cells_desc:"Opdel flettede celler",
merge_cells_desc:"Flet celler",
row_desc:"R\u00E6kkeegenskaber",
cell_desc:"Celleegenskaber",
props_desc:"Tabelegenskaber",
paste_row_before_desc:"Inds\u00E6t r\u00E6kke f\u00F8r",
paste_row_after_desc:"Inds\u00E6t r\u00E6kke efter",
cut_row_desc:"Klip r\u00E6kke",
copy_row_desc:"Kopier r\u00E6kke",
del:"Slet tabel",
row:"R\u00E6kke",
col:"Kolonne",
cell:"Celle"
},
autosave:{
unload_msg:"Har du foretaget nogle \u00E6ndringer, vil de g\u00E5 tabt, hvis du navigerer v\u00E6k fra denne side.",
restore_content:"Restore auto-saved content.",
warning_message:"If you restore the saved content, you will lose all the content that is currently in the editor.\n\nAre you sure you want to restore the saved content?."
},
fullscreen:{
desc:"Vis/skjul fuldsk\u00E6rmstilstand"
},
media:{
desc:"Inds\u00E6t/rediger indlejret mediefil",
edit:"Rediger indlejret mediefil"
},
fullpage:{
desc:"Dokumentegenskaber"
},
template:{
desc:"Inds\u00E6t pr\u00E6defineret skabelonindhold"
},
visualchars:{
desc:"Vis/Skjul visuelle kontroltegn."
},
spellchecker:{
desc:"Vis/skjul stavekontrol",
menu:"Indstillinger for stavekontrol",
ignore_word:"Ignorer ord",
ignore_words:"Ignorer alle",
langs:"Sprog",
wait:"Vent venligst...",
sug:"Forslag",
no_sug:"Ingen forslag",
no_mpell:"Ingen stavefejl fundet."
},
pagebreak:{
desc:"Inds\u00E6t sideskift."
},
advlist:{
types:"Types",
def:"Default",
lower_alpha:"Lower alpha",
lower_greek:"Lower greek",
lower_roman:"Lower roman",
upper_alpha:"Upper alpha",
upper_roman:"Upper roman",
circle:"Circle",
disc:"Disc",
square:"Square"
}}});