tinyMCE.addI18n('pl.media_dlg',{
title:"Wstaw/Edytuj wbudowane media",
general:"G\u0142\u00F3wny",
advanced:"Zaawansowany",
file:"Plik/URL",
list:"Lista",
size:"Wymiary",
preview:"Podgl\u0105d",
constrain_proportions:"Zachowaj proporcje",
type:"Typ",
id:"Id",
name:"Nazwa",
class_name:"Klasa",
vspace:"V-Space",
hspace:"H-Space",
play:"Autoodtwarzanie",
loop:"Zap\u0119tlenie",
menu:"Poka\u017C menu",
quality:"Jako\u015B\u0107",
scale:"Skala",
align:"Wyr\u00F3wnaj",
salign:"SAlign",
wmode:"WMode",
bgcolor:"T\u0142o",
base:"Baza",
flashvars:"Flashvars",
liveconnect:"SWLiveConnect",
autohref:"AutoHREF",
cache:"Cache",
hidden:"Ukryty",
controller:"Controller",
kioskmode:"Kiosk mode",
playeveryframe:"Play every frame",
targetcache:"Target cache",
correction:"Bez korekcji",
enablejavascript:"W\u0142\u0105cz JavaScript",
starttime:"Start time",
endtime:"End time",
href:"Href",
qtsrcchokespeed:"Choke speed",
target:"Kom\u00F3rka",
volume:"G\u0142o\u015Bno\u015B\u0107",
autostart:"Auto start",
enabled:"Enabled",
fullscreen:"Pe\u0142ny ekran",
invokeurls:"Odwo\u0142aj si\u0119 do URLs",
mute:"Wycisz",
stretchtofit:"Rozci\u0105gnij aby dopasowa\u0107",
windowlessvideo:"Windowless video",
balance:"Balance",
baseurl:"Base URL",
captioningid:"Captioning id",
currentmarker:"Current marker",
currentposition:"Aktualna pozycja",
defaultframe:"Default frame",
playcount:"Play count",
rate:"Rate",
uimode:"UI Mode",
flash_options:"Flash opcje",
qt_options:"Quicktime opcje",
wmp_options:"Windows media player opcje",
rmp_options:"Real media player options",
shockwave_options:"Shockwave options",
autogotourl:"Auto goto URL",
center:"Center",
imagestatus:"Image status",
maintainaspect:"Maintain aspect",
nojava:"No java",
prefetch:"Prefetch",
shuffle:"Shuffle",
console:"Konsola",
numloop:"Liczba powt\u00F3rze\u0144",
controls:"Controls",
scriptcallbacks:"Script callbacks",
swstretchstyle:"Stretch style",
swstretchhalign:"Stretch H-Align",
swstretchvalign:"Stretch V-Align",
sound:"D\u017Awi\u0119k",
progress:"Progress",
qtsrc:"QT Src",
qt_stream_warn:"Streamed rtsp resources should be added to the QT Src field under the advanced tab.\nYou should also add a non streamed version to the Src field..",
align_top:"G\u00F3ra",
align_right:"Prawo",
align_bottom:"D\u00F3\u0142",
align_left:"Lewo",
align_center:"\u015Arodek",
align_top_left:"G\u00F3rny lewy",
align_top_right:"G\u00F3rny prawy",
align_bottom_left:"Dolny lewy",
align_bottom_right:"Dolny prawy",
flv_options:"Flash video opcje",
flv_scalemode:"Scale mode",
flv_buffer:"Buffer",
flv_startimage:"Start image",
flv_starttime:"Start time",
flv_defaultvolume:"Default volumne",
flv_hiddengui:"Ukryte GUI",
flv_autostart:"Auto start",
flv_loop:"Loop",
flv_showscalemodes:"Show scale modes",
flv_smoothvideo:"Smooth video",
flv_jscallback:"JS Callback"
});