tinyMCE.addI18n({nl:{
common:{
edit_confirm:"Weet u zeker dat u tekst in WYSIWYG mode wilt bewerken in dit tekstveld?",
apply:"Toepassen",
insert:"Invoegen",
update:"Bijwerken",
cancel:"Annuleren",
close:"Sluiten",
browse:"Bladeren",
class_name:"Klasse",
not_set:"- Standaard -",
clipboard_msg:"Kopi\u00EBren/knippen/plakken is niet beschikbaar in Mozilla en Firefox.\nWilt u meer informatie over deze beperking?",
clipboard_no_support:"Kopi\u00EBren/knippen/plakken wordt niet ondersteund door uw browser, gebruik hiervoor de sneltoetsen.",
popup_blocked:"U zult uw popup-blocker tijdelijk moeten uitschakelen voor deze website om gebruik te kunnen maken van alle functies van deze teksteditor.",
invalid_data:"Fout: Er zijn ongeldige waardes ingevoerd, deze zijn rood gemarkeerd.",
more_colors:"Meer kleuren"
},
contextmenu:{
align:"Uitlijning",
left:"Links",
center:"Centreren",
right:"Rechts",
full:"Uitvullen"
},
insertdatetime:{
date_fmt:"%d-%m-%Y",
time_fmt:"%H:%M:%S",
insertdate_desc:"Datum invoegen",
inserttime_desc:"Tijd invoegen",
months_long:"Januari,Februari,Maart,April,Mei,Juni,Juli,Augustus,September,Oktober,November,December",
months_short:"Jan,Feb,Mar,Apr,Mei,Jun,Jul,Aug,Sep,Okt,Nov,Dec",
day_long:"Zondag,Maandag,Dinsdag,Woensdag,Donderdag,Vrijdag,Zaterdag,Zondag",
day_short:"zo,ma,di,wo,do,vr,za,zo"
},
print:{
print_desc:"Afdrukken"
},
preview:{
preview_desc:"Voorbeeld"
},
directionality:{
ltr_desc:"Van links naar rechts",
rtl_desc:"Van rechts naar links"
},
layer:{
insertlayer_desc:"Nieuwe laag invoegen",
forward_desc:"Volgende laag",
backward_desc:"Vorige laag",
absolute_desc:"Absoluut positioneren inschakelen",
content:"Nieuwe laag..."
},
save:{
save_desc:"Opslaan",
cancel_desc:"Alle wijzigingen annuleren"
},
nonbreaking:{
nonbreaking_desc:"Open ruimte invoegen"
},
iespell:{
iespell_desc:"Spellingcontrole",
download:"ieSpell niet gevonden. Wilt u deze nu installeren?"
},
advhr:{
advhr_desc:"Scheidingslijn"
},
emotions:{
emotions_desc:"Emoties"
},
searchreplace:{
search_desc:"Zoeken",
replace_desc:"Zoeken/Vervangen"
},
advimage:{
image_desc:"Afbeelding invoegen/bewerken"
},
advlink:{
link_desc:"Link invoegen/bewerken"
},
xhtmlxtras:{
cite_desc:"Citaat",
abbr_desc:"Afkorting",
acronym_desc:"Synoniem",
del_desc:"Verwijderd",
ins_desc:"Ingevoegd",
attribs_desc:"Attributen invoegen/bewerken"
},
style:{
desc:"CSS Stijl bewerken"
},
paste:{
paste_text_desc:"Als platte tekst plakken",
paste_word_desc:"Vanuit Word plakken",
selectall_desc:"Alles selecteren",
plaintext_mode_sticky:"Plakken is nu in plattetekstmodus. Klik nog een keer om terug te gaan naar normaal plakken. Nadat u iets plakt, keert u terug naar normaal plakken.",
plaintext_mode:"Plakken is nu in plattetekstmoduse. Klik nog een keer om terug te gaan naar normaal plakken."
},
paste_dlg:{
text_title:"Gebruik Ctrl+V om tekst in het venster te plakken.",
text_linebreaks:"Regelafbreking bewaren",
word_title:"Gebruik Ctrl+V om tekst in het venster te plakken."
},
table:{
desc:"Nieuwe tabel invoegen",
row_before_desc:"Rij boven invoegen",
row_after_desc:"Rij onder invoegen",
delete_row_desc:"Rij verwijderen",
col_before_desc:"Kolom links invoegen",
col_after_desc:"Kolom rechts invoegen",
delete_col_desc:"Kolom verwijderen",
split_cells_desc:"Cellen splitsen",
merge_cells_desc:"Cellen samenvoegen",
row_desc:"Rij-eigenschappen",
cell_desc:"Cel-eigenschappen",
props_desc:"Tabeleigenschappen",
paste_row_before_desc:"Rij boven plakken",
paste_row_after_desc:"Rij onder plakken",
cut_row_desc:"Rij knippen",
copy_row_desc:"Rij kopi\u00EBren",
del:"Tabel verwijderen",
row:"Rij",
col:"Kolom",
cell:"Cel"
},
autosave:{
unload_msg:"De wijzigingen zullen verloren gaan als u nu deze pagina verlaat.",
restore_content:"Automatisch opgeslagen inhoud laden.",
warning_message:"Als u de opgeslagen inhoud laadt, verliest u de inhoud die zich momenteel in de editor bevindt.\n\nWeet u zeker dat u de opgeslagen inhoud wilt laden?"
},
fullscreen:{
desc:"Volledig scherm"
},
media:{
desc:"Media invoegen/bewerken",
edit:"Media bewerken"
},
fullpage:{
desc:"Documenteigenschappen"
},
template:{
desc:"Voorgedefinieerd sjabloon invoegen"
},
visualchars:{
desc:"Zichtbare symbolen"
},
spellchecker:{
desc:"Spellingcontrole",
menu:"Instellingen spellingcontrole",
ignore_word:"Woord negeren",
ignore_words:"Alles negeren",
langs:"Talen",
wait:"Een ogenblik geduld\u2026",
sug:"Suggesties",
no_sug:"Geen suggesties",
no_mpell:"Geen spelfouten gevonden."
},
pagebreak:{
desc:"Pagina-einde invoegen"
},
advlist:{
types:"Types",
def:"Standaard",
lower_alpha:"Alfa (klein)",
lower_greek:"Griekse letters (klein)",
lower_roman:"Romeinse letters (klein)",
upper_alpha:"Alfa (groot)",
upper_roman:"Romeinse letters (groot)",
circle:"Cirkel",
disc:"Schijf",
square:"Vierkant"
}}});