tinyMCE.addI18n('eu.advanced_dlg',{
about_title:"TinyMCEri buruz",
about_general:"Honi buruz",
about_help:"Laguntza",
about_license:"Lizentzia",
about_plugins:"Gehigarriak",
about_plugin:"Gehiagarria",
about_author:"Egilea",
about_version:"Bertsioa",
about_loaded:"Kargatutako gehigarriak",
anchor_title:"Aingura txertatu/editatu",
anchor_name:"Ainguraren izena",
code_title:"HTML kodearen editorea",
code_wordwrap:"Itzulbiratu",
colorpicker_title:"Kolorea aukeratu",
colorpicker_picker_tab:"Aukeratu",
colorpicker_picker_title:"Kolore aukeratzailea",
colorpicker_palette_tab:"Paleta",
colorpicker_palette_title:"Kolore paleta",
colorpicker_named_tab:"Izendunak",
colorpicker_named_title:"Izendun koloreak",
colorpicker_color:"Kolorea:",
colorpicker_name:"Izena:",
charmap_title:"Karaktere berezia aukeratu",
image_title:"Irudia txertatu/editatu",
image_src:"Irudiaren URL helbidea",
image_alt:"Irudiaren deskribapena",
image_list:"Irudi zerrenda",
image_border:"Inguruko marra",
image_dimensions:"Tamaina",
image_vspace:"Tarte bertikala",
image_hspace:"Tarte horizontala",
image_align:"Alineazioa",
image_align_baseline:"Oinarriko marra",
image_align_top:"Goian",
image_align_middle:"Tartean",
image_align_bottom:"Behean",
image_align_texttop:"Testua goian",
image_align_textbottom:"Testua behean",
image_align_left:"Ezkerrean",
image_align_right:"Eskuinean",
link_title:"Lotura txertatu/editatu",
link_url:"Loturaren URLa",
link_target:"Helburua",
link_target_same:"Lotura leiho berean ireki",
link_target_blank:"Lotura leiho berrian ireki",
link_titlefield:"Izenburua",
link_is_email:"Sartutako helbideak e-posta bat dirudi, aurretik mailto: gehitzea nahi duzu?",
link_is_external:"Sartutako helbideak kanpoko webgune batena dirudi, aurretik http:// gehitzea nahi duzu?",
link_list:"Lotura zerrenda"
});