tinyMCE.addI18n('vi.media_dlg',{
title:"Ch\u00E8n / s\u1EEDa ph\u01B0\u01A1ng ti\u1EC7n truy\u1EC1n th\u00F4ng nh\u00FAng",
general:"Chung",
advanced:"N\u00E2ng cao",
file:"T\u1EADp tin/URL",
list:"Danh s\u00E1ch",
size:"K\u00EDch th\u01B0\u1EDBc",
preview:"Xem tr\u01B0\u1EDBc",
constrain_proportions:"R\u00E0ng bu\u1ED9c t\u1EC9 l\u1EC7",
type:"Ki\u1EC3u",
id:"Id",
name:"T\u00EAn",
class_name:"L\u1EDBp",
vspace:"V-Space",
hspace:"H-Space",
play:"T\u1EF1 \u0111\u1ED9ng ph\u00E1t",
loop:"L\u1EB7p",
menu:"Hi\u1EC3n th\u1ECB menu",
quality:"Ch\u1EA5t l\u01B0\u1EE3ng",
scale:"T\u1EC9 l\u1EC7",
align:"Canh l\u1EC1",
salign:"SAlign",
wmode:"WMode",
bgcolor:"N\u1EC1n",
base:"C\u01A1 s\u1EDF",
flashvars:"Flashvars",
liveconnect:"SWLiveConnect",
autohref:"AutoHREF",
cache:"B\u1ED9 nh\u1EDB \u0111\u1EC7m",
hidden:"\u1EA8n",
controller:"Tr\u00ECnh \u0111i\u1EC1u khi\u1EC3n",
kioskmode:"Ch\u1EBF \u0111\u1ED9 Kiosk",
playeveryframe:"Ph\u00E1t t\u1EA5t c\u1EA3 khung",
targetcache:"B\u1ED9 nh\u1EDB \u0111\u1EC7m \u0111\u00EDch",
correction:"Kh\u00F4ng ch\u1EC9nh",
enablejavascript:"Cho ph\u00E9p JavaScript",
starttime:"Th\u1EDDi gian b\u1EAFt \u0111\u1EA7u",
endtime:"Th\u1EDDi gian k\u1EBFt th\u00FAc",
href:"Href",
qtsrcchokespeed:"T\u1ED1c \u0111\u1ED9 Choke",
target:"\u0110\u00EDch",
volume:"\u00C2m l\u01B0\u1EE3ng",
autostart:"T\u1EF1 \u0111\u1ED9ng b\u1EAFt \u0111\u1EA7u",
enabled:"Cho ph\u00E9p",
fullscreen:"To\u00E0n m\u00E0n h\u00ECnh",
invokeurls:"URL tri\u1EC7u g\u1ECDi",
mute:"T\u1EAFt \u00E2m thanh",
stretchtofit:"D\u00E3n \u0111\u1EC3 ph\u00F9 h\u1EE3p",
windowlessvideo:"Video kh\u00F4ng c\u1EEDa s\u1ED5",
balance:"C\u00E2n b\u1EB1ng",
baseurl:"Base URL",
captioningid:"id \u0111\u1EA7u \u0111\u1EC1",
currentmarker:"B\u1ED9 t\u1EA1o hi\u1EC7n th\u1EDDi",
currentposition:"V\u1ECB tr\u00ED hi\u1EC7n th\u1EDDi",
defaultframe:"Khung m\u1EB7c \u0111\u1ECBnh",
playcount:"\u0110\u1EBFm l\u1EA7n ph\u00E1t",
rate:"T\u1ED1c \u0111\u1ED9",
uimode:"Ch\u1EBF \u0111\u1ED9 UI",
flash_options:"T\u00F9y ch\u1ECDn Flash",
qt_options:"T\u00F9y ch\u1ECDn Quicktime",
wmp_options:"T\u00F9y ch\u1ECDn tr\u00ECnh ch\u01A1i media Windows",
rmp_options:"T\u00F9y ch\u1ECDn tr\u00ECnh ch\u01A1i media Real",
shockwave_options:"T\u00F9y ch\u1ECDn Shockwave",
autogotourl:"T\u1EF1 \u0111\u1ED9ng nh\u1EA3y t\u1EDBi URL",
center:"Gi\u1EEFa",
imagestatus:"Tr\u1EA1ng th\u00E1i \u1EA3nh",
maintainaspect:"Duy tr\u00EC c\u1EA1nh",
nojava:"Kh\u00F4ng c\u00F3 java",
prefetch:"T\u00ECm n\u1EA1p tr\u01B0\u1EDBc",
shuffle:"Kh\u00F4ng theo tr\u1EADt t\u1EF1",
console:"B\u00E0n \u0111i\u1EC1u khi\u1EC3n",
numloop:"S\u1ED1 l\u1EB7p",
controls:"\u0110i\u1EC1u khi\u1EC3n",
scriptcallbacks:"H\u00E0m g\u1ECDi ng\u01B0\u1EE3c Script",
swstretchstyle:"Ki\u1EC3u d\u00E3n",
swstretchhalign:"D\u00E3n theo H-Align",
swstretchvalign:"D\u00E3n theo V-Align",
sound:"\u00C2m thanh",
progress:"\u0110ang ti\u1EBFn tri\u1EC3n",
qtsrc:"QT Src",
qt_stream_warn:"Ngu\u1ED3n rtsp theo lu\u1ED3ng n\u00EAn \u0111\u01B0\u1EE3c th\u00EAm v\u00E0o tr\u01B0\u1EDDng QT Src d\u01B0\u1EDBi th\u1EBB n\u00E2ng cao.\nB\u1EA1n c\u0169ng n\u00EAn th\u00EAm m\u1ED9t phi\u00EAn b\u1EA3n kh\u00F4ng theo lu\u1ED3ng v\u00E0o tr\u01B0\u1EDDng Src..",
align_top:"Tr\u00EAn c\u00F9ng",
align_right:"Ph\u1EA3i",
align_bottom:"D\u01B0\u1EDBi c\u00F9ng",
align_left:"Tr\u00E1i",
align_center:"Gi\u1EEFa",
align_top_left:"Tr\u00EAn c\u00F9ng tr\u00E1i",
align_top_right:"Tr\u00EAn c\u00F9ng ph\u1EA3i",
align_bottom_left:"D\u01B0\u1EDBi c\u00F9ng tr\u00E1i",
align_bottom_right:"D\u01B0\u1EDBi c\u00F9ng ph\u1EA3i",
flv_options:"T\u00F9y ch\u1ECDn video Flash",
flv_scalemode:"Ch\u1EBF \u0111\u1ED9 thang",
flv_buffer:"B\u1ED9 \u0111\u1EC7m",
flv_startimage:"\u1EA2nh b\u1EAFt \u0111\u1EA7u",
flv_starttime:"Th\u1EDDi gian b\u1EAFt \u0111\u1EA7u",
flv_defaultvolume:"\u00C2m l\u01B0\u1EE3ng m\u1EB7c \u0111\u1ECBnh",
flv_hiddengui:"\u1EA8n GUI",
flv_autostart:"T\u1EF1 b\u1EAFt \u0111\u1EA7u",
flv_loop:"L\u1EB7p",
flv_showscalemodes:"Hi\u1EC3n th\u1ECB ch\u1EBF \u0111\u1ED9 thang",
flv_smoothvideo:"Video m\u01B0\u1EE3t",
flv_jscallback:"H\u00E0m g\u1ECDi ng\u01B0\u1EE3c JS"
});