tinyMCE.addI18n('lb.media_dlg',{
title:"Multimedia-Inhalt abannen/beaarbechten",
general:"Allgemeng",
advanced:"Erweidert",
file:"Datei/URL",
list:"L\u00EBscht",
size:"Ofmiessungen",
preview:"Virschau",
constrain_proportions:"Proportiounen erhalen",
type:"Typ",
id:"Id",
name:"Numm",
class_name:"CSS-Klass",
vspace:"Vertikalen Ofstand",
hspace:"Horizontalen Ofstand",
play:"Automatesch Ofspillen",
loop:"Widderhuelung",
menu:"Men\u00FC uweisen",
quality:"Qualit\u00E9it",
scale:"Skal\u00E9ierung",
align:"Ausriichtung",
salign:"S-Ausriichtung",
wmode:"WMode",
bgcolor:"Hannergrond",
base:"Basis",
flashvars:"Flash-Variablen",
liveconnect:"SWLiveConnect",
autohref:"AutoHREF",
cache:"Zw\u00EBschesp\u00E4icher",
hidden:"Verstoppt",
controller:"Kontroller",
kioskmode:"Kioskmodus",
playeveryframe:"All Frame ofspillen",
targetcache:"Zil zw\u00EBschesp\u00E4icheren",
correction:"Ouni Korrektur",
enablejavascript:"JavaScript aktiv\u00E9ieren",
starttime:"Startz\u00E4itpunkt",
endtime:"Endz\u00E4itpunkt",
href:"Href",
qtsrcchokespeed:"Vitesse drosselen",
target:"Zil",
volume:"Lautst\u00E4rkt",
autostart:"Autostart",
enabled:"Aktiv\u00E9iert",
fullscreen:"Vollbild",
invokeurls:"URLen opruffen",
mute:"Stomm",
stretchtofit:"Breet un d\u00E9i verf\u00FCgbar Plaz upassen",
windowlessvideo:"F\u00EBnsterlose Video",
balance:"Balance",
baseurl:"Basis-URL",
captioningid:"Beschr\u00EBftungs Id",
currentmarker:"Aktuelle Marker",
currentposition:"Aktuell Positioun",
defaultframe:"Frame-Virastellung",
playcount:"Zieler",
rate:"Quote",
uimode:"UI Modus",
flash_options:"Flash-Optiounen",
qt_options:"Quicktime-Optiounen",
wmp_options:"Optiounen fir Windows Media Player",
rmp_options:"Optiounen fir Real Media Player",
shockwave_options:"Shockwave-Optiounen",
autogotourl:"Auto goto URL",
center:"Zentr\u00E9iert",
imagestatus:"Bildstatus",
maintainaspect:"Bildverh\u00E4ltnis b\u00E4ibehalen",
nojava:"Kee Java",
prefetch:"Prefetch",
shuffle:"Zouf\u00E4lleg Widdergab",
console:"Konsol",
numloop:"Unzuel Widderhuelungen",
controls:"Steierung",
scriptcallbacks:"Script callbacks",
swstretchstyle:"Stretch style",
swstretchhalign:"Stretch H-Ausriichtung",
swstretchvalign:"Stretch V-Ausriichtung",
sound:"Toun",
progress:"Fortschr\u00EBtt",
qtsrc:"QT Src",
qt_stream_warn:"An den erweiderten Astellunge sollten am Feld 'QT Src' gestreamte RTSP Ressourcen b\u00E4igesat ginn.\nZous\u00E4tzlech sollt Dir do och eng net-gestreamte Ressource uginn.",
align_top:"Uewen",
align_right:"Riets",
align_bottom:"\u00CBnnen",
align_left:"L\u00E9nks",
align_center:"Zentr\u00E9iert",
align_top_left:"Uewe L\u00E9nks",
align_top_right:"Uewe Riets",
align_bottom_left:"\u00CBnne L\u00E9nks",
align_bottom_right:"\u00CBnne Riets",
flv_options:"Optiounen fir Flash Video",
flv_scalemode:"Skal\u00E9ierungsmodus",
flv_buffer:"Puffer",
flv_startimage:"Startbild",
flv_starttime:"Startz\u00E4itpunkt",
flv_defaultvolume:"Standardlautst\u00E4rk",
flv_hiddengui:"Verstoppte GUI",
flv_autostart:"Autostart",
flv_loop:"Widderhuelung",
flv_showscalemodes:"Skal\u00E9ierungsmodi uweisen",
flv_smoothvideo:"Smooth Video",
flv_jscallback:"JS Callback"
});