tinyMCE.addI18n('lb.advimage_dlg',{
tab_general:"Allgemeng",
tab_appearance:"Ausgesinn",
tab_advanced:"Erweidert",
general:"Allgemeng",
title:"Titel",
preview:"Virschau",
constrain_proportions:"S\u00E4iteverh\u00E4ltnis b\u00E4ibehalen",
langdir:"Schr\u00EBftrichtung",
langcode:"Sproochcode",
long_desc:"Ausf\u00E9ierlech Beschreiwung",
style:"Format",
classes:"Klassen",
ltr:"L\u00E9nks no riets",
rtl:"Riets no l\u00E9nks",
id:"ID",
map:"Image-Map",
swap_image:"Bild austauschen",
alt_image:"Alternativt Bild",
mouseover:"bei Mauskontakt",
mouseout:"bei kengem Mauskontakt",
misc:"Verschiddenes",
example_img:"Ausgesinn vun der Virschau",
missing_alt:"W\u00EBll Dir wierklech keng Beschreiwung aginn? Best\u00EBmmt Benotzer mat kierperlechen Aschr\u00E4nkungen k\u00EBnnen sou net dorop zougr\u00E4ifen, genau sou d\u00E9i, d\u00E9i een Textbrowser benotzen oder d'Uweise vu Biller desaktiv\u00E9iert hunn.",
dialog_title:"Bild af\u00FCgen/beaarbechten",
src:"Adress",
alt:"Beschreiwung",
list:"Billerl\u00EBschten",
border:"Rumm",
dimensions:"Ausmoossen",
vspace:"Vertikalen Ofstand",
hspace:"Horizontalen Ofstand",
align:"Ausriichtung",
align_baseline:"Zeil",
align_top:"Uewen",
align_middle:"M\u00EBtteg",
align_bottom:"\u00CBnnen",
align_texttop:"Uewen am Text",
align_textbottom:"\u00CBnnen am Text",
align_left:"L\u00E9nks",
align_right:"Riets",
image_list:"Billerl\u00EBscht"
});