tinyMCE.addI18n('sq.advanced',{
style_select:"Stilet",
font_size:"Madh\u00EBsia e tekstit",
fontdefault:"Familja e tekstit",
block:"Formati",
paragraph:"Paragraf",
div:"Div",
address:"Adres\u00EB",
pre:"Para formatuar",
h1:"Kok\u00EB 1",
h2:"Kok\u00EB 2",
h3:"Kok\u00EB 3",
h4:"Kok\u00EB 4",
h5:"Kok\u00EB 5",
h6:"Kok\u00EB 6",
blockquote:"Bllok",
code:"Kod",
samp:"Shembull kodi",
dt:"Terma e p\u00EBrcaktimit ",
dd:"P\u00EBrshkrimi i p\u00EBrcaktimit",
bold_desc:"I Trash\u00EB (Ctrl+B)",
italic_desc:"I Pjerr\u00EBt (Ctrl+I)",
underline_desc:"I N\u00EBnvizuar (Ctrl+U)",
striketrough_desc:"Vij\u00EB n\u00EB mes",
justifyleft_desc:"Drejtimi majtas",
justifycenter_desc:"Drejtimi qend\u00EBr",
justifyright_desc:"Drejtimi djathtas",
justifyfull_desc:"Drejtim i plot\u00EB",
bullist_desc:"List\u00EB e parregullt",
numlist_desc:"List\u00EB e rregullt",
outdent_desc:"Hiq kryerradh\u00EB",
indent_desc:"Vendos kryerradh\u00EB",
undo_desc:"\u00C7b\u00EBj (Ctrl+Z)",
redo_desc:"Rib\u00EBj (Ctrl+Y)",
link_desc:"Fut/edito lidhje",
unlink_desc:"Hiq lidhje",
image_desc:"Fut/edito foto",
cleanup_desc:"Pastro kodin",
code_desc:"Edito kodin HTML",
sub_desc:"N\u00EBn shkrim",
sup_desc:"Mbi shkrim",
hr_desc:"Fut linj\u00EB horizontale",
removeformat_desc:"Fshi formatimin",
custom1_desc:"P\u00EBshkrimi i personalizuar k\u00EBtu",
forecolor_desc:"Zgjidh ngjyr\u00EBn e tekstit",
backcolor_desc:"Zgjidh ngjyr\u00EBn e fush\u00EBs",
charmap_desc:"Fut karakter t\u00EB personalizuar",
visualaid_desc:"Shfaq/Fshih vijat ndihm\u00EBse dhe element\u00EBt e paduksh\u00EBm",
anchor_desc:"Fut/edito lidhje",
cut_desc:"Prit",
copy_desc:"Kopjo",
paste_desc:"Ngjit",
image_props_desc:"Opsionet e fotos",
newdocument_desc:"Dokument i Ri",
help_desc:"Ndihm\u00EB",
blockquote_desc:"Bllok",
clipboard_msg:"Kopja/Prerja/Ngjitja nuk suportohen n\u00EB Mozilla dhe Firefox.\nD\u00EBshironi m\u00EB shum\u00EB informacione p\u00EBr k\u00EBt\u00EB \u00E7\u00EBshtje?",
path:"Rruga",
newdocument:"Jeni t\u00EB sigurt q\u00EB doni t'a fshini p\u00EBrmbajtjen?",
toolbar_focus:"Shko tek butonat - Alt+Q, Shko tek editori - Alt+Z, Shko tek rruga e elementit - Alt+X",
more_colors:"M\u00EB shum\u00EB ngjyra"
});