tinyMCE.addI18n('nl.advanced',{
style_select:"Stijlen",
font_size:"Tekengrootte",
fontdefault:"Lettertype",
block:"Opmaak",
paragraph:"Alinea",
div:"Div",
address:"Adres",
pre:"Vaste opmaak",
h1:"Kop 1",
h2:"Kop 2",
h3:"Kop 3",
h4:"Kop 4",
h5:"Kop 5",
h6:"Kop 6",
blockquote:"Citaat",
code:"Code",
samp:"Codevoorbeeld",
dt:"Definitieterm",
dd:"Definitiebeschrijving",
bold_desc:"Vet (Ctrl+B)",
italic_desc:"Cursief (Ctrl+I)",
underline_desc:"Onderstrepen (Ctrl+U)",
striketrough_desc:"Doorhalen",
justifyleft_desc:"Links uitlijnen",
justifycenter_desc:"Centreren",
justifyright_desc:"Rechts uitlijnen",
justifyfull_desc:"Uitvullen",
bullist_desc:"Opsommingstekens",
numlist_desc:"Nummering",
outdent_desc:"Inspringing verkleinen",
indent_desc:"Inspringing vergroten",
undo_desc:"Ongedaan maken (Ctrl+Z)",
redo_desc:"Herhalen (Ctrl+Y)",
link_desc:"Link invoegen/bewerken",
unlink_desc:"Link verwijderen",
image_desc:"Afbeelding invoegen/bewerken",
cleanup_desc:"Code opruimen",
code_desc:"HTML bron bewerken",
sub_desc:"Subscript",
sup_desc:"Superscript",
hr_desc:"Scheidingslijn invoegen",
removeformat_desc:"Opmaak verwijderen",
custom1_desc:"Uw eigen beschrijving hier",
forecolor_desc:"Tekstkleur",
backcolor_desc:"Tekstmarkeringskleur",
charmap_desc:"Symbool invoegen",
visualaid_desc:"Hulplijnen weergeven",
anchor_desc:"Anker invoegen/bewerken",
cut_desc:"Knippen",
copy_desc:"Kopi\u00EBren",
paste_desc:"Plakken",
image_props_desc:"Afbeeldingseigenschappen",
newdocument_desc:"Nieuw document",
help_desc:"Help",
blockquote_desc:"Citaat",
clipboard_msg:"Kopi\u00EBren/knippen/plakken is niet beschikbaar in Mozilla en Firefox.\nWilt u meer informatie over deze beperking?",
path:"Pad",
newdocument:"Weet u zeker dat u alle inhoud wilt wissen?",
toolbar_focus:"Spring naar werkbalk - Alt+Q, Spring naar tekst - Alt-Z, Spring naar elementpad - Alt-X",
more_colors:"Meer kleuren"
});