tinyMCE.addI18n('eu.table_dlg',{
general_tab:"Orokorra",
advanced_tab:"Aurreratua",
general_props:"Ezaugarri orokorrak",
advanced_props:"Ezaugarri aurreratuak",
rowtype:"Row in table part",
title:"Txertatu/Aldatu taula",
width:"Zabalera",
height:"Altuera",
cols:"Zutabeak",
rows:"Lerroak",
cellspacing:"Cellspacing",
cellpadding:"Cellpadding",
border:"Border",
align:"Lerrokatzea",
align_default:"Default",
align_left:"Ezkerrera",
align_right:"Eskuinera",
align_middle:"Erdian",
row_title:"Lerro ezaugarriak",
cell_title:"Gelaxka ezaugarriak",
cell_type:"Gelaxka mota",
valign:"Lerrokatze bertikala",
align_top:"Goian",
align_bottom:"Behean",
bordercolor:"Border color",
bgcolor:"Atzeko kolorea",
merge_cells_title:"Bateratu gelaxkak",
id:"Id",
style:"Estiloa",
langdir:"Hizkuntza norabidea",
langcode:"Hizkuntza kodea",
mime:"Helburuareb MIME mota",
ltr:"Ezkerretik eskuinera",
rtl:"Eskuinetik ezkerrera",
bgimage:"Atzeko irudia",
summary:"Laburpena",
td:"Datuak",
th:"Goiburua",
cell_cell:"Eguneratu uneko gelaxka",
cell_row:"Eguneratu lerroko gelaxka guztiak",
cell_all:"Eguneratu gelaxka guztiak",
row_row:"Eguneratu uneko lerroa",
row_odd:"Eguneratu lerro bikoitiak",
row_even:"Eguneratu lerro bakoitiak",
row_all:"Eguneratu lerro guztiak",
thead:"Taularen Goiburukoa",
tbody:"Taularen Gorputza",
tfoot:"Taularen Oina",
scope:"Eremua",
rowgroup:"Lerro Taldea",
colgroup:"Zut Taldea",
col_limit:"Zutabe kopuru maximoa ({$cols}) gainditu duzu.",
row_limit:"Lerro kopuru maximoa ({$rows}) gainditu duzu.",
cell_limit:"Gelaxka kopuru maximoa ({$cells}) gainditu duzu..",
missing_scope:"Taularen goiburukoari eremu bat zehaztu gabe jarritu nahi duzula ziur zaude? Eremu hori gabe, ezintasunak dituzten erabiltzaileentzat zaila izango da taularen datuak ulertzea.",
caption:"Table caption",
frame:"Markoa",
frame_none:"none",
frame_groups:"taldeak",
frame_rows:"lerroak",
frame_cols:"zurabeak",
frame_all:"guztiak",
rules:"Rules",
rules_void:"void",
rules_above:"above",
rules_below:"below",
rules_hsides:"hsides",
rules_lhs:"lhs",
rules_rhs:"rhs",
rules_vsides:"vsides",
rules_box:"box",
rules_border:"border"
});