tinyMCE.addI18n('az.table_dlg',{
general_tab:"\u00DCmumi",
advanced_tab:"\u018Flav\u0259l\u0259r",
general_props:"\u00DCmumi x\u00FCsusiyy\u0259tl\u0259r",
advanced_props:"\u018Flav\u0259 x\u00FCsusiyy\u0259tl\u0259r",
rowtype:"C\u0259dv\u0259l hiss\u0259sind\u0259ki s\u0259tr",
title:"C\u0259dv\u0259li \u0259lav\u0259 et/d\u0259yi\u015Fdir",
width:"Eni",
height:"H\u00FCnd\u00FCrl\u00FCy\u00FC",
cols:"S\u00FCtunlar",
rows:"S\u0259trl\u0259r",
cellspacing:"\u00D6z\u0259kl\u0259r aras\u0131ndak\u0131 m\u0259saf\u0259",
cellpadding:"\u00D6z\u0259kl\u0259rd\u0259 doldurma",
border:"S\u0259rh\u0259d",
align:"Tarazla\u015Fd\u0131rma",
align_default:"Default",
align_left:"Sola",
align_right:"Sa\u011Fa",
align_middle:"M\u0259rk\u0259z il\u0259",
row_title:"S\u0259tr x\u00FCsusiyy\u0259ti",
cell_title:"\u00D6z\u0259k x\u00FCsusiyy\u0259ti",
cell_type:"\u00D6z\u0259k n\u00F6v\u00FC",
valign:"\u015Eaquli tarazla\u015Fma",
align_top:"Yuxar\u0131 il\u0259",
align_bottom:"A\u015Fa\u011F\u0131 il\u0259",
bordercolor:"S\u0259rh\u0259d r\u0259ngi",
bgcolor:"Fon r\u0259ngi",
merge_cells_title:"\u00D6z\u0259k stili",
id:"\u0130dentifikator",
style:"Stil",
langdir:"Dil istiqam\u0259ti",
langcode:"Dil kodu",
mime:"H\u0259d\u0259fli MIME-n\u00F6v",
ltr:"Solda-sa\u011Fa",
rtl:"Sa\u011Fda-sola",
bgimage:"Fon \u015F\u0259kli",
summary:"X\u00FClas\u0259",
td:"Veril\u0259nl\u0259r",
th:"Ba\u015Fl\u0131q",
cell_cell:"Haz\u0131rki \u00F6z\u0259yi yenil\u0259",
cell_row:"S\u0259trd\u0259ki b\u00FCt\u00FCn \u00F6z\u0259kl\u0259ri yenil\u0259",
cell_all:"C\u0259dv\u0259ld\u0259ki b\u00FCt\u00FCn \u00F6z\u0259kl\u0259ri yenil\u0259",
row_row:"Haz\u0131rki s\u0259tri yenil\u0259",
row_odd:"C\u0259d\u0259ld\u0259ki t\u0259k (\u0259d\u0259d) s\u0259trl\u0259ri yenil\u0259",
row_even:"C\u0259dv\u0259ld\u0259ki c\u00FCt (\u0259d\u0259d) s\u0259trl\u0259ri yenil\u0259",
row_all:"C\u0259dv\u0259ld\u0259ki b\u00FCt\u00FCn s\u0259trl\u0259ri yenil\u0259",
thead:"C\u0259dv\u0259lin yuxar\u0131 hiss\u0259si",
tbody:"C\u0259dv\u0259lin \u0259sas hiss\u0259si",
tfoot:"C\u0259dv\u0259lin a\u015Fa\u011F\u0131 hiss\u0259si",
scope:"H\u0259dd",
rowgroup:"S\u0259tr qrupu",
colgroup:"S\u00FCtun qrupu",
col_limit:"Siz s\u00FCtunlarda {$cols} maksimum say\u0131 a\u015Fd\u0131n\u0131z.",
row_limit:"Siz s\u0259trl\u0259rd\u0259 {$rows} maksimum say\u0131 a\u015Fd\u0131n\u0131z.",
cell_limit:"Siz \u00F6z\u0259kl\u0259rd\u0259 {$cells} maksimum say\u0131 a\u015Fd\u0131n\u0131z.",
missing_scope:"\u018Fminsiniz ki, ba\u015Fl\u0131q \u00F6z\u0259yinin h\u0259ddini g\u00F6st\u0259rm\u0259d\u0259n davam etm\u0259k ist\u0259yirsiniz? Bunsuz b\u0259zi i\u015F qabiliyy\u0259ti a\u015Fa\u011F\u0131 olan istifad\u0259\u00E7il\u0259r\u0259 c\u0259dv\u0259lin m\u0259lumatlar\u0131 v\u0259 t\u0259rkibini anlamaq \u00E7\u0259tin olacaq.",
caption:"C\u0259dv\u0259l ba\u015Fl\u0131\u011F\u0131",
frame:"\u00C7\u0259r\u00E7iv\u0259",
frame_none:"he\u00E7n\u0259",
frame_groups:"qruplar",
frame_rows:"s\u0259trl\u0259r",
frame_cols:"s\u00FCtunlar",
frame_all:"ham\u0131s\u0131",
rules:"X\u0259ttl\u0259r",
rules_void:"he\u00E7 n\u0259",
rules_above:"yuxar\u0131dan",
rules_below:"a\u015Fa\u011F\u0131dan",
rules_hsides:"\u00FCf\u00FCqi t\u0259r\u0259fl\u0259r",
rules_lhs:"sol \u00FCf\u00FCqi t\u0259r\u0259fl\u0259r",
rules_rhs:"sa\u011F \u00FCf\u00FCqi t\u0259r\u0259fl\u0259r",
rules_vsides:"\u015Faquli t\u0259r\u0259fl\u0259r",
rules_box:"konteyner",
rules_border:"s\u0259rh\u0259d"
});