tinyMCE.addI18n('it.emotions_dlg',{
title:"Inserisci faccina",
desc:"Faccina",
cool:"Fico",
cry:"Piango",
embarassed:"Imbarazzato",
foot_in_mouth:"Piede in bocca",
frown:"Triste",
innocent:"Santarellino",
kiss:"Bacio",
laughing:"Risatona",
money_mouth:"Bocca danarosa",
sealed:"Bocca sigillata",
smile:"Sorridente",
surprised:"Sorpreso",
tongue_out:"Linguaccia",
undecided:"Indeciso",
wink:"Occhiolino",
yell:"Arrabbiato"
});