tinyMCE.addI18n('id.advlink_dlg',{
title:"Sisipkan/Ubah link",
url:"Link URL",
target:"Target",
titlefield:"Judul",
is_email:"URL yang Anda sisipkan tampaknya e-mail, Anda ingin menambahkan awalan 'mailto:'?",
is_external:"URL yang Anda sisipkan tampaknya link eksternal, Anda ingin menambahkan awalan 'http://'?",
list:"Daftar Link",
general_tab:"Umum",
popup_tab:"Popup",
events_tab:"Events",
advanced_tab:"Advanced",
general_props:"Properti Umum",
popup_props:"Properti Pop-Up",
event_props:"Events",
advanced_props:"Advanced properties",
popup_opts:"Options",
anchor_names:"Anchors",
target_same:"Buka pada window/frame ini",
target_parent:"Buka pada parent window/frame",
target_top:"Buka pada frame atas (Gantikan semua frame)",
target_blank:"Buka pada Window baru",
popup:"Javascript popup",
popup_url:"Popup URL",
popup_name:"Nama Window",
popup_return:"sisipkan 'return false'",
popup_scrollbars:"Tampilkan scrollbars",
popup_statusbar:"Tampilkan status bar",
popup_toolbar:"Tampilkan toolbars",
popup_menubar:"Tampilkan menu bar",
popup_location:"Tampilkan location bar",
popup_resizable:"Jadikan window resizable",
popup_dependent:"Tergantung (khusus Mozilla/Firefox)",
popup_size:"Ukuran",
popup_position:"Posisi (X/Y)",
id:"Id",
style:"Style",
classes:"Classes",
target_name:"Nama Target",
langdir:"Bahasa",
target_langcode:"Bahasa Target",
langcode:"Kode Bahasa",
encoding:"Target character encoding",
mime:"Target MIME type",
rel:"Hubungan page dengan target",
rev:"Hubungan target dengan page",
tabindex:"Tabindex",
accesskey:"Accesskey",
ltr:"Kiri ke kanan",
rtl:"Kanan ke kiri",
link_list:"Daftar Link"
});