tinyMCE.addI18n('lb.advanced',{
style_select:"Format",
font_size:"Schr\u00EBftgr\u00E9isst",
fontdefault:"Schr\u00EBftaart",
block:"Virlag",
paragraph:"Ofsatz",
div:"Zesummenh\u00E4nkende Ber\u00E4ich",
address:"Adress",
pre:"R\u00E9idaten",
h1:"Iwwerschr\u00EBft 1",
h2:"Iwwerschr\u00EBft 2",
h3:"Iwwerschr\u00EBft 3",
h4:"Iwwerschr\u00EBft 4",
h5:"Iwwerschr\u00EBft 5",
h6:"Iwwerschr\u00EBft 6",
blockquote:"Zitatblock",
code:"Code",
samp:"Beispill",
dt:"Definitiounsbegr\u00EBff",
dd:"Definitiounsbeschreiwung",
bold_desc:"Fett (Strg+B)",
italic_desc:"Kursiv (Strg+I)",
underline_desc:"\u00CBnnerstrach (Strg+U)",
striketrough_desc:"Duerchgestrach",
justifyleft_desc:"L\u00E9nks align\u00E9iert",
justifycenter_desc:"Zentr\u00E9iert",
justifyright_desc:"Riets align\u00E9iert",
justifyfull_desc:"B\u00E9ids\u00E4iteg align\u00E9iert",
bullist_desc:"Onsort\u00E9iert L\u00EBscht",
numlist_desc:"Sort\u00E9iert L\u00EBscht",
outdent_desc:"Ausr\u00E9cken",
indent_desc:"Ar\u00E9cken",
undo_desc:"R\u00E9ckg\u00E4ngeg (Strg+Z)",
redo_desc:"Widderhuelen (Strg+Y)",
link_desc:"Link af\u00FCgen/ver\u00E4nneren",
unlink_desc:"Link ewechhuelen",
image_desc:"Bild af\u00FCgen/ver\u00E4nneren",
cleanup_desc:"Quellcode botzen",
code_desc:"HTML-Quellcode beaarbechten",
sub_desc:"D\u00E9ifgestallt",
sup_desc:"H\u00E9ichgestallt",
hr_desc:"Trennlinn af\u00FCgen",
removeformat_desc:"Format\u00E9ierungen zer\u00E9cksetzen",
custom1_desc:"Benotzerdefin\u00E9iert Beschreiwung",
forecolor_desc:"Textfuerf",
backcolor_desc:"Hannergrondfuerf",
charmap_desc:"Sonnerzeechen af\u00FCgen",
visualaid_desc:"H\u00EBllefslinnen an onsiichtbar Elementer an-/ausblennen",
anchor_desc:"Anker af\u00FCgen/ver\u00E4nneren",
cut_desc:"Ausschneiden",
copy_desc:"Kop\u00E9ieren",
paste_desc:"Af\u00FCgen",
image_props_desc:"Bildeegeschaften",
newdocument_desc:"Neit Dokument",
help_desc:"H\u00EBllef",
blockquote_desc:"Zitatblock",
clipboard_msg:"Kop\u00E9ieren, Ausschneiden an Af\u00FCgen sinn am Mozilla Firefox net m\u00E9iglech.\r\nW\u00EBllt Dir m\u00E9i iwwert d\u00EBse Problem gewuer ginn?",
path:"Pad",
newdocument:"W\u00EBllt Dir wierklech de ganzen Inhalt l\u00E4schen?",
toolbar_focus:"Bei d'Geschirleescht sprangen: Alt+Q; Bei den Editor sprangen: Alt+Z; Bei den Elementpad sprangen: Alt+X",
more_colors:"Weider Fuerwen",
anchor_delta_width:"13"
});