tinyMCE.addI18n('nb.emotions_dlg',{
title:"Sett inn hum\u00F8rfjes",
desc:"Hum\u00F8rfjes",
cool:"Cool",
cry:"Gr\u00E5ter",
embarassed:"Flau",
foot_in_mouth:"Fot i munnen",
frown:"Skuffet",
innocent:"Uskyldig",
kiss:"Kyss",
laughing:"Ler",
money_mouth:"Penger i munnen",
sealed:"Hemmelig",
smile:"Glad",
surprised:"Overrasket",
tongue_out:"Rekke tunge",
undecided:"Skeptisk",
wink:"Blunke",
yell:"Skri"
});