tinyMCE.addI18n('lb.xhtmlxtras_dlg',{
attribute_label_title:"Titel",
attribute_label_id:"ID",
attribute_label_class:"Klasse",
attribute_label_style:"Format",
attribute_label_cite:"Quellenangab",
attribute_label_datetime:"Z\u00E4it/Datum",
attribute_label_langdir:"Schr\u00EBftrichtung",
attribute_option_ltr:"L\u00E9nks no riets",
attribute_option_rtl:"Riets no l\u00E9nks",
attribute_label_langcode:"Sproochen",
attribute_label_tabindex:"Tabindex",
attribute_label_accesskey:"Tastekierzel",
attribute_events_tab:"Ereegnes",
attribute_attrib_tab:"Attributer",
general_tab:"Allgemeng",
attrib_tab:"Attributer",
events_tab:"Ereegnes",
fieldset_general_tab:"Allgemeng Astellungen",
fieldset_attrib_tab:"Attributer",
fieldset_events_tab:"Ereegnes",
title_ins_element:"Agef\u00FCgtenen Text",
title_del_element:"Ewechgehollenen Text",
title_acronym_element:"Akronym",
title_abbr_element:"Ofkierzung",
title_cite_element:"Quellenangab",
remove:"Ewechhuelen",
insert_date:"Aktuell Z\u00E4it/Datum af\u00FCgen",
option_ltr:"L\u00E9nks no riets",
option_rtl:"Riets no l\u00E9nks",
attribs_title:"Attributer af\u00FCgen/beaarbechten"
});