tinyMCE.addI18n('is.advimage_dlg',{
tab_general:"Almennt",
tab_appearance:"\u00DAtlit",
tab_advanced:"N\u00E1nar",
general:"Almennt",
title:"Titill",
preview:"Forsko\u00F0un",
constrain_proportions:"Halda hlutf\u00F6llum",
langdir:"\u00C1tt tungum\u00E1ls",
langcode:"K\u00F3\u00F0i tungum\u00E1ls",
long_desc:"L\u00F6ng l\u00FDsing \u00E1 hlekki",
style:"St\u00EDll",
classes:"Klasar",
ltr:"Vinstri til h\u00E6gri",
rtl:"H\u00E6gri til vinstri",
id:"Id",
map:"Image map",
swap_image:"Skipta mynd \u00FAt",
alt_image:"\u00D6nnur mynd",
mouseover:"\u00FEegar m\u00FAs er yfir",
mouseout:"\u00FEegar m\u00FAs fer af",
misc:"\u00DDmislegt",
example_img:"Appearance preview image",
missing_alt:"Are you sure you want to continue without including an Image Description? Without it the image may not be accessible to some users with disabilities, or to those using a text browser, or browsing the Web with images turned off.",
dialog_title:"Insert/edit image",
src:"Sl\u00F3\u00F0 \u00E1 mynd",
alt:"L\u00FDsing",
list:"Myndalisti",
border:"Rammi",
dimensions:"St\u00E6r\u00F0ir",
vspace:"L\u00F3\u00F0r\u00E9tt loftun",
hspace:"L\u00E1r\u00E9tt loftun",
align:"J\u00F6fnun",
align_baseline:"Baseline",
align_top:"Top",
align_middle:"Middle",
align_bottom:"Bottom",
align_texttop:"Text top",
align_textbottom:"Text bottom",
align_left:"Left",
align_right:"Right",
image_list:"Image list"
});