tinyMCE.addI18n('tw.xhtmlxtras_dlg',{
attribute_label_title:"\u6A19\u984C",
attribute_label_id:"ID \u8B58\u5225",
attribute_label_class:"\u985E\u578B",
attribute_label_style:"\u6A23\u5F0F",
attribute_label_cite:"\u5F15\u7528",
attribute_label_datetime:"\u65E5\u671F/\u6642\u9593",
attribute_label_langdir:"\u6587\u5B57\u6392\u5217\u65B9\u5F0F",
attribute_option_ltr:"\u7531\u5DE6\u5230\u53F3",
attribute_option_rtl:"\u7531\u53F3\u5230\u5DE6",
attribute_label_langcode:"\u8A9E\u8A00",
attribute_label_tabindex:"Tab\u7D22\u5F15",
attribute_label_accesskey:"\u5FEB\u6377\u9375",
attribute_events_tab:"\u4E8B\u4EF6",
attribute_attrib_tab:"\u5C6C\u6027",
general_tab:"\u4E00\u822C",
attrib_tab:"\u5C6C\u6027",
events_tab:"\u4E8B\u4EF6",
fieldset_general_tab:"\u4E00\u822C",
fieldset_attrib_tab:"\u5143\u7D20\u5C6C\u6027",
fieldset_events_tab:"\u5143\u7D20\u4E8B\u4EF6",
title_ins_element:"\u63D2\u5165\u5143\u7D20",
title_del_element:"\u522A\u9664\u5143\u7D20",
title_acronym_element:"\u9996\u5B57\u6BCD\u7C21\u7565\u8A5E\u5143\u7D20",
title_abbr_element:"\u7E2E\u5BEB\u8A5E\u5143\u7D20",
title_cite_element:"\u5F15\u7528\u5143\u7D20",
remove:"\u522A\u9664",
insert_date:"\u63D2\u5165\u73FE\u5728\u65E5\u671F/\u6642\u9593",
option_ltr:"\u7531\u5DE6\u5230\u53F3",
option_rtl:"\u7531\u53F3\u5230\u5DE6",
attribs_title:"\u63D2\u5165/\u7DE8\u8F2F\u5C6C\u6027"
});