tinyMCE.addI18n('gl.advimage_dlg',{
tab_general:"Xeral",
tab_appearance:"Apariencia",
tab_advanced:"Avanzado",
general:"Xeral",
title:"T\u00EDtulo",
preview:"Vista previa",
constrain_proportions:"Bloquear proporci\u00F3ns",
langdir:"Direcci\u00F3n do idioma",
langcode:"C\u00F3digo do idioma",
long_desc:"V\u00EDnculo pra descripci\u00F3n larga",
style:"Estilos",
classes:"Clases",
ltr:"Esquerda a dereita",
rtl:"Dereita a esquerda",
id:"Id",
map:"Mapa de imaxe",
swap_image:"Intercambiar imaxe",
alt_image:"Imaxe alternativa",
mouseover:"pra mouseover",
mouseout:"pra mouseout",
misc:"Miscel\u00E1neo",
example_img:"Vista previa da imaxe",
missing_alt:"\u00BFEsta seguro de continuar sen introducir unha descripci\u00F3n \u00E1 imaxe? Sen ela pode non ser accesible pra usuarios con discapacidades, ou pra aqueles que usen navegadores de modo texto, ou te\u00F1an deshabilitadas as imaxes da p\u00E1xina.",
dialog_title:"Insertar/editar imaxe",
src:"URL da imaxe",
alt:"Descripci\u00F3n da imaxe",
list:"Lista de imaxes",
border:"Bordes",
dimensions:"Dimensi\u00F3ns",
vspace:"Espacio vertical",
hspace:"Espacio horizontal",
align:"Ali\u00F1amento",
align_baseline:"Li\u00F1a base",
align_top:"Arriba",
align_middle:"Medio",
align_bottom:"Abaixo",
align_texttop:"Texto arriba",
align_textbottom:"Texto abaixo",
align_left:"Esquerda",
align_right:"Dereita",
image_list:"Lista de imaxes"
});