tinyMCE.addI18n({fi:{
common:{
edit_confirm:"Haluatko k\u00E4ytt\u00E4\u00E4 WYSIWYG-tilaa t\u00E4ss\u00E4 tekstikent\u00E4ss\u00E4?",
apply:"K\u00E4yt\u00E4",
insert:"Lis\u00E4\u00E4",
update:"P\u00E4ivit\u00E4",
cancel:"Peruuta",
close:"Sulje",
browse:"Selaa",
class_name:"Luokka",
not_set:"-- Ei m\u00E4\u00E4ritetty --",
clipboard_msg:"Kopioi/Leikkaa/Liit\u00E4 ei ole k\u00E4ytett\u00E4viss\u00E4 Mozilla ja Firefox -selaimilla.\nHaluatko lis\u00E4tietoa t\u00E4st\u00E4 ongelmasta?",
clipboard_no_support:"Selaimesi ei ole tuettu, k\u00E4yt\u00E4 sen sijaan n\u00E4pp\u00E4inoikoteit\u00E4.",
popup_blocked:"Sinulla on k\u00E4yt\u00F6ss\u00E4si ohjelma, joka est\u00E4\u00E4 ponnahdusikkunoiden n\u00E4yt\u00F6n. Sinun t\u00E4ytyy kytke\u00E4 ponnahdusikkunoiden esto pois p\u00E4\u00E4lt\u00E4 voidaksesi hy\u00F6dynt\u00E4\u00E4 t\u00E4ysin t\u00E4t\u00E4 ty\u00F6kalua.",
invalid_data:"Virhe: Sy\u00F6tit virheellisi\u00E4 arvoja, ne n\u00E4kyv\u00E4t punaisina.",
more_colors:"Enemm\u00E4n v\u00E4rej\u00E4"
},
contextmenu:{
align:"Tasaus",
left:"Vasemmalle",
center:"Keskelle",
right:"Oikealle",
full:"Molemmille puolille"
},
insertdatetime:{
date_fmt:"%d.%m.%Y",
time_fmt:"%H:%M:%S",
insertdate_desc:"Lis\u00E4\u00E4 p\u00E4iv\u00E4m\u00E4\u00E4r\u00E4",
inserttime_desc:"Lis\u00E4\u00E4 kellonaika",
months_long:"tammikuu,helmikuu,maaliskuu,huhtikuu,toukokuu,kes\u00E4kuu,hein\u00E4kuu,elokuu,syyskuu,lokakuu,marraskuu,joulukuu",
months_short:"tammi,helmi,maalis,huhti,touko,kes\u00E4,hein\u00E4,elo,syys,loka,marras,joulu",
day_long:"sunnuntai,maanantai,tiistai,keskiviikko,torstai,perjantai,lauantai,sunnuntai",
day_short:"su,ma,ti,ke,to,pe,la,su"
},
print:{
print_desc:"Tulosta"
},
preview:{
preview_desc:"Esikatselu"
},
directionality:{
ltr_desc:"Suunta vasemmalta oikealle",
rtl_desc:"Suunta oikealta vasemmalle"
},
layer:{
insertlayer_desc:"Lis\u00E4\u00E4 uusi taso",
forward_desc:"Siirr\u00E4 eteenp\u00E4in",
backward_desc:"Siirr\u00E4 taaksep\u00E4in",
absolute_desc:"Absoluuttinen sijainti",
content:"Uusi taso..."
},
save:{
save_desc:"Tallenna",
cancel_desc:"Peruuta kaikki muutokset"
},
nonbreaking:{
nonbreaking_desc:"Lis\u00E4\u00E4 tyhj\u00E4 merkki (nbsp)"
},
iespell:{
iespell_desc:"Oikeinkirjoituksen tarkistus",
download:"ieSpell-ohjelmaa ei havaittu. Haluatko asentaa sen nyt?"
},
advhr:{
advhr_desc:"Vaakatasoviivain"
},
emotions:{
emotions_desc:"Hymi\u00F6t"
},
searchreplace:{
search_desc:"Etsi",
replace_desc:"Etsi ja korvaa"
},
advimage:{
image_desc:"Lis\u00E4\u00E4/muokkaa kuvaa"
},
advlink:{
link_desc:"Lis\u00E4\u00E4/muokkaa linkki\u00E4"
},
xhtmlxtras:{
cite_desc:"Sitaatti",
abbr_desc:"Lyhenne",
acronym_desc:"Kirjainlyhenne",
del_desc:"Poisto",
ins_desc:"Lis\u00E4ys",
attribs_desc:"Lis\u00E4\u00E4/muokkaa attribuutteja"
},
style:{
desc:"Muokkaa CSS-tyylej\u00E4"
},
paste:{
paste_text_desc:"Liit\u00E4 pelkk\u00E4n\u00E4 tekstin\u00E4",
paste_word_desc:"Liit\u00E4 Wordist\u00E4",
selectall_desc:"Valitse kaikki",
plaintext_mode_sticky:"Liitt\u00E4minen on nyt pelkk\u00E4n\u00E4 tekstin\u00E4. Klikkaa uudelleen vaihtaaksesi takaisin tavalliseen tilaan. Palaat takaisin tavalliseen tilaan liitetty\u00E4si jotakin.",
plaintext_mode:"Liitt\u00E4minen on nyt pelkk\u00E4n\u00E4 tekstin\u00E4. Klikkaa uudelleen vaihtaaksesi takaisin tavalliseen tilaan."
},
paste_dlg:{
text_title:"Paina CTRL+V liitt\u00E4\u00E4ksesi sis\u00E4ll\u00F6n ikkunaan.",
text_linebreaks:"S\u00E4ilyt\u00E4 rivinvaihdot",
word_title:"Paina CTRL+V liitt\u00E4\u00E4ksesi sis\u00E4ll\u00F6n ikkunaan."
},
table:{
desc:"Lis\u00E4\u00E4 uusi taulukko",
row_before_desc:"Lis\u00E4\u00E4 rivi ennen",
row_after_desc:"Lis\u00E4\u00E4 rivi j\u00E4lkeen",
delete_row_desc:"Poista rivi",
col_before_desc:"Lis\u00E4\u00E4 sarake ennen",
col_after_desc:"Lis\u00E4\u00E4 sarake j\u00E4lkeen",
delete_col_desc:"Poista sarake",
split_cells_desc:"Jaa yhdistetyt taulukon solut",
merge_cells_desc:"Yhdist\u00E4 taulukon solut",
row_desc:"Taulukon rivin asetukset",
cell_desc:"Taulukon solun asetukset",
props_desc:"Taulukon asetukset",
paste_row_before_desc:"Liit\u00E4 taulukon rivi ennen",
paste_row_after_desc:"Liit\u00E4 taulukon rivi j\u00E4lkeen",
cut_row_desc:"Leikkaa taulukon rivi",
copy_row_desc:"Kopioi taulukon rivi",
del:"Poista taulukko",
row:"Rivi",
col:"Sarake",
cell:"Solu",
cellprops_delta_width:"80"
},
autosave:{
unload_msg:"Tekem\u00E4si muutokset menetet\u00E4\u00E4n jos poistut t\u00E4lt\u00E4 sivulta.",
restore_content:"Palauta automaattisesti tallennettu sis\u00E4lt\u00F6.",
warning_message:"Jos palautat automaattisesti tallennetun sis\u00E4ll\u00F6n, menet\u00E4t t\u00E4ll\u00E4 hetkell\u00E4 editorissa olevan sis\u00E4ll\u00F6n.\n\nHaluatko varmasti palauttaa tallennetun sis\u00E4ll\u00F6n?"
},
fullscreen:{
desc:"Kokoruututila"
},
media:{
desc:"Lis\u00E4\u00E4/muokkaa upotettua mediaa",
edit:"Muokkaa upotettua mediaa"
},
fullpage:{
desc:"Tiedoston asetukset"
},
template:{
desc:"Lis\u00E4\u00E4 esim\u00E4\u00E4ritetty\u00E4 sivupohjasis\u00E4lt\u00F6\u00E4"
},
visualchars:{
desc:"N\u00E4yt\u00E4/piilota muotoilumerkit."
},
spellchecker:{
desc:"Oikeinkirjoituksen tarkistus",
menu:"Oikeinkirjoituksen asetukset",
ignore_word:"Ohita sana",
ignore_words:"Ohita kaikki",
langs:"Kielet",
wait:"Odota ole hyv\u00E4...",
sug:"Ehdotukset",
no_sug:"Ei ehdotuksia",
no_mpell:"Virheit\u00E4 ei l\u00F6ytynyt."
},
pagebreak:{
desc:"Lis\u00E4\u00E4 sivunvaihto."
},
advlist:{
types:"Tyypit",
def:"Oletus",
lower_alpha:"pienet kirjaimet: a, b, c",
lower_greek:"pienet kirjaimet: \u03B1, \u03B2, \u03B3",
lower_roman:"pienet kirjaimet: i, ii, iii",
upper_alpha:"isot kirjaimet: A, B, C",
upper_roman:"isot kirjaimet: I, II, III",
circle:"Pallo",
disc:"Ympyr\u00E4",
square:"Neli\u00F6"
}}});