tinyMCE.addI18n('gl.media_dlg',{
title:"Insertar/editar medio embebido",
general:"Xeral",
advanced:"Avanzado",
file:"Arquivo/URL",
list:"Lista",
size:"Tama\u00F1o",
preview:"Vista Previa",
constrain_proportions:"Bloquear proporci\u00F3ns",
type:"Tipo",
id:"Id",
name:"Nome",
class_name:"Clase",
vspace:"Espacio V.",
hspace:"Espacio H.",
play:"Comezo Autom\u00E1tico",
loop:"Repetitivo",
menu:"Mostrar Men\u00FA",
quality:"Calidade",
scale:"Escala",
align:"Ali\u00F1aci\u00F3n",
salign:"SAlign",
wmode:"WMode",
bgcolor:"Fondo",
base:"Base",
flashvars:"Flashvars",
liveconnect:"SWLiveConnect",
autohref:"AutoHREF",
cache:"Cach\u00E9",
hidden:"Oculto",
controller:"Controller",
kioskmode:"Modo kiosco",
playeveryframe:"Reproducir t\u00F3dolos frames",
targetcache:"Obxetivo cache",
correction:"Sen correci\u00F3n",
enablejavascript:"Habilitar JavaScript",
starttime:"Inicio",
endtime:"Fin",
href:"Href",
qtsrcchokespeed:"Vel. de choque",
target:"Obxetivo",
volume:"Volume",
autostart:"Comezo Autom\u00E1tico",
enabled:"Habilitado",
fullscreen:"Pantalla Completa",
invokeurls:"Invocar URLs",
mute:"Silencio",
stretchtofit:"Estirar pra axustar",
windowlessvideo:"Video sen vent\u00E1",
balance:"Balance",
baseurl:"URL Base",
captioningid:"Id de lenda",
currentmarker:"Marcador actual",
currentposition:"Posici\u00F3n actual",
defaultframe:"Frame predet.",
playcount:"Cantas reproducci\u00F3ns",
rate:"Relaci\u00F3n",
uimode:"Modo UI",
flash_options:"Opci\u00F3ns Flash",
qt_options:"Opci\u00F3ns Quicktime",
wmp_options:"Opci\u00F3ns Windows media player",
rmp_options:"Opci\u00F3ns Real media player",
shockwave_options:"Opci\u00F3ns Shockwave",
autogotourl:"Ir a URL autom\u00E1t.",
center:"Centrado",
imagestatus:"Estado de imaxe",
maintainaspect:"Manter aspecto",
nojava:"No java",
prefetch:"PreBusca",
shuffle:"Aleatorio",
console:"Consola",
numloop:"N\u00FAm. repetici\u00F3ns",
controls:"Controis",
scriptcallbacks:"Script callbacks",
swstretchstyle:"Estilo estiramento",
swstretchhalign:"Estirar ali\u00F1. H.",
swstretchvalign:"Esturar ali\u00F1. V.",
sound:"Son",
progress:"Progreso",
qtsrc:"QT Src",
qt_stream_warn:"Os recursos rtsp de Streaming deber\u00EDan engadirse no campo QT Src da pesta\u00F1a avanzada.\nAdem\u00E1is deber\u00EDa engadir unha versi\u00F3n no Streaming no campo Src.",
align_top:"Arriba",
align_right:"Dereita",
align_bottom:"Abaixo",
align_left:"Esquerda",
align_center:"Centrado",
align_top_left:"Arriba Izda.",
align_top_right:"Arriba Dta.",
align_bottom_left:"Abaixo Izda.",
align_bottom_right:"Abaixo Dta.",
flv_options:"Opci\u00F3ns Video Flash",
flv_scalemode:"Modo escalado",
flv_buffer:"Buffer",
flv_startimage:"Imaxe inicio",
flv_starttime:"Tempo inicio",
flv_defaultvolume:"Volume predet.",
flv_hiddengui:"Ocultar GUI",
flv_autostart:"Inicio auto.",
flv_loop:"Repetitivo",
flv_showscalemodes:"Mostrar modos escala",
flv_smoothvideo:"Video suave",
flv_jscallback:"JS Callback"
});