tinyMCE.addI18n('eu.advimage_dlg',{
tab_general:"Orokorra",
tab_appearance:"Itxura",
tab_advanced:"Aurreratua",
general:"Orokorra",
title:"Izenburua",
preview:"Aurrebista",
constrain_proportions:"Proportzioak mantendu",
langdir:"Hizkuntzaren norabidea",
langcode:"Hizkuntza-kodea",
long_desc:"Deskribaepn luzearen lotura",
style:"Estiloa",
classes:"Klaseak",
ltr:"Ezkerretik eskumara",
rtl:"Eskuinatik ezkerrera",
id:"Id",
map:"Irudi-mapa",
swap_image:"Irudia ordezkatu",
alt_image:"Ordezko irudia",
mouseover:"xagua gainean dagoenean",
mouseout:"xagua kentzen denean",
misc:"Bestelakoak",
example_img:"Nola ikusiko den",
missing_alt:"Irudiaren deskribapena gehitu gabe jarraitu nahi duzu? Hau horrela, ezgaitasunak dituztenentzat edo testu nabigatzaile bat darabiltenentzat ez da irisgarria izango.",
dialog_title:"Irudia txertatu/editatu",
src:"Irudiaren URL helbidea",
alt:"Irudiaren deskribapena",
list:"Irudi-zerrenda",
border:"Inguruko marra",
dimensions:"Tamaina",
vspace:"Tarte bertikala",
hspace:"Tarte horizontala",
align:"Alineazioa",
align_baseline:"Oinarri-marra",
align_top:"Goian",
align_middle:"Tartean",
align_bottom:"Behean",
align_texttop:"Testua goian",
align_textbottom:"Testua behean",
align_left:"Ezkerrean",
align_right:"Eskuinean",
image_list:"Irudi-zerrenda"
});