tinyMCE.addI18n('sk.advanced',{
style_select:"\u0160t\u00FDly",
font_size:"Ve\u013Ekos\u0165 p\u00EDsma",
fontdefault:"P\u00EDsmo",
block:"Form\u00E1t",
paragraph:"Odstavec",
div:"Oddiel",
address:"Adresa",
pre:"Predform\u00E1tovan\u00E9",
h1:"Nadpis 1",
h2:"Nadpis 2",
h3:"Nadpis 3",
h4:"Nadpis 4",
h5:"Nadpis 5",
h6:"Nadpis 6",
blockquote:"Blokov\u00E1 cit\u00E1cia",
code:"K\u00F3d",
samp:"Uk\u00E1\u017Eka k\u00F3du",
dt:"Term\u00EDn defin\u00EDcie",
dd:"Popis defin\u00EDcie",
bold_desc:"Tu\u010Dn\u00E9 (Ctrl+B)",
italic_desc:"Kurz\u00EDva (Ctrl+I)",
underline_desc:"Pod\u010Diarknut\u00E9 (Ctrl+U)",
striketrough_desc:"Pre\u010Diarknut\u00E9",
justifyleft_desc:"Zarovna\u0165 do\u013Eava",
justifycenter_desc:"Zarovna\u0165 na stred",
justifyright_desc:"Zarovna\u0165 doprava",
justifyfull_desc:"Zarovna\u0165 do bloku",
bullist_desc:"Zoznam s odr\u00E1\u017Ekami",
numlist_desc:"\u010C\u00EDslovan\u00FD zoznam",
outdent_desc:"Zmen\u0161i\u0165 odsadenie",
indent_desc:"Zv\u00E4\u010D\u0161i\u0165 odsadenie",
undo_desc:"Sp\u00E4\u0165 (Ctrl+Z)",
redo_desc:"Znovu (Ctrl+Y)",
link_desc:"Vlo\u017Ei\u0165/upravi\u0165 odkaz",
unlink_desc:"Odobra\u0165 odkaz",
image_desc:"Vlo\u017Ei\u0165/upravi\u0165 obr\u00E1zok",
cleanup_desc:"Vy\u010Disti\u0165 k\u00F3d",
code_desc:"Upravi\u0165 HTML zdroj",
sub_desc:"Doln\u00FD index",
sup_desc:"Horn\u00FD index",
hr_desc:"Vlo\u017Ei\u0165 vodorovn\u00FD odde\u013Eova\u010D",
removeformat_desc:"Odstr\u00E1ni\u0165 form\u00E1tovanie",
custom1_desc:"\u013Dubovoln\u00FD popisok",
forecolor_desc:"Farba p\u00EDsma",
backcolor_desc:"Farba zv\u00FDraznenia textu",
charmap_desc:"Vlo\u017Ei\u0165 \u0161peci\u00E1lny znak",
visualaid_desc:"Zobrazi\u0165 pomocn\u00E9 linky/skryt\u00E9 prvky",
anchor_desc:"Vlo\u017Ei\u0165/upravi\u0165 z\u00E1lo\u017Eku (kotvu)",
cut_desc:"Vystrihn\u00FA\u0165",
copy_desc:"Kop\u00EDrova\u0165",
paste_desc:"Vlo\u017Ei\u0165",
image_props_desc:"Vlastnosti obr\u00E1zka",
newdocument_desc:"Nov\u00FD dokument",
help_desc:"Pomocn\u00EDk",
blockquote_desc:"Blokov\u00E1 cit\u00E1cia",
clipboard_msg:"Funkcie kop\u00EDrova\u0165/vystrihn\u00FA\u0165/vlo\u017Ei\u0165 nie s\u00FA podporovan\u00E9 v prehliada\u010Doch Mozilla a Firefox.\nChcete viac inform\u00E1ci\u00ED o tomto probl\u00E9me?",
path:"Cesta",
newdocument:"Ste si naozaj ist\u00ED, \u017Ee chcete odstr\u00E1ni\u0165 v\u0161etok obsah?",
toolbar_focus:"Prechod na li\u0161tu n\u00E1strojov - Alt+Q, prechod do editora - Alt-Z, prechod na cestu k objektom - Alt-X",
more_colors:"\u010Eal\u0161ie farby"
});