tinyMCE.addI18n('nb.advanced_dlg',{
about_title:"Om TinyMCE",
about_general:"Om",
about_help:"Hjelp",
about_license:"Lisens",
about_plugins:"Programtillegg",
about_plugin:"Programtillegg",
about_author:"Utvikler",
about_version:"Versjon",
about_loaded:"Lastede programtillegg",
anchor_title:"Sett inn / endre anker",
anchor_name:"Ankernavn",
code_title:"HTML-editor",
code_wordwrap:"Tekstbryting",
colorpicker_title:"Velg en farge",
colorpicker_picker_tab:"Velg farge",
colorpicker_picker_title:"Fargevalg",
colorpicker_palette_tab:"Palett",
colorpicker_palette_title:"Palettfarger",
colorpicker_named_tab:"Navnevalg",
colorpicker_named_title:"Fargenavn",
colorpicker_color:"Farge:",
colorpicker_name:"Navn:",
charmap_title:"Velg spesialtegn",
image_title:"Sett inn / endre bilde",
image_src:"Bildets URL",
image_alt:"Bildebeskrivelse",
image_list:"Bildeliste",
image_border:"Ramme",
image_dimensions:"Dimensjoner",
image_vspace:"Vertikal avstand",
image_hspace:"Horisontal avstand",
image_align:"Justering",
image_align_baseline:"Bunnlinje",
image_align_top:"Topp",
image_align_middle:"Midtstilt",
image_align_bottom:"Bunn",
image_align_texttop:"Teksttopp",
image_align_textbottom:"Tekstbunn",
image_align_left:"Venstre",
image_align_right:"H\u00F8yre",
link_title:"Sett inn /endre lenke",
link_url:"Lenkens URL",
link_target:"M\u00E5lside",
link_target_same:"\u00C5pne i dette vinduet",
link_target_blank:"\u00C5pne i nytt vindu",
link_titlefield:"Tittel",
link_is_email:"Nettadressen du skrev inn ser ut til \u00E5 v\u00E6re en e-postadresse. \u00D8nsker du \u00E5 legge til det p\u00E5krevde mailto:-prefikset?",
link_is_external:"Nettadressen du skrev inn ser ut til \u00E5 v\u00E6re en ekstern nettadresse. \u00D8nsker du \u00E5 legge til det p\u00E5krevde http://-prefikset?",
link_list:"Lenkeliste"
});