tinyMCE.addI18n('sl.advanced',{
style_select:"Izberite slog",
font_size:"Velikost pisave",
fontdefault:"Dru\u017Eina pisave",
block:"oblika",
paragraph:"odstavek",
div:"blok",
address:"naslov",
pre:"predoblikovano",
h1:"naslov 1",
h2:"naslov 2",
h3:"naslov 3",
h4:"naslov 4",
h5:"naslov 5",
h6:"naslov 6",
blockquote:"citat",
code:"koda",
samp:"kodni zgled",
dt:"definicija - izraz",
dd:"definicija - opis",
bold_desc:"Krepko (Ctrl+B)",
italic_desc:"Po\u0161evno (Ctrl+I)",
underline_desc:"Pod\u010Drtano (Ctrl+U)",
striketrough_desc:"Pre\u010Drtano",
justifyleft_desc:"Poravnava levo",
justifycenter_desc:"Poravnava na sredino",
justifyright_desc:"Poravnava desno",
justifyfull_desc:"Polna poravnava",
bullist_desc:"Alineje",
numlist_desc:"Na\u0161tevanje",
outdent_desc:"Zamakni",
indent_desc:"Odmakni ven",
undo_desc:"Razveljavi (Ctrl+Z)",
redo_desc:"Uveljavi (Ctrl+Y)",
link_desc:"Vstavi/uredi povezavo",
unlink_desc:"Odstrani povezavo",
image_desc:"Vstavi/uredi sliko",
cleanup_desc:"Pre\u010Disti kodo",
code_desc:"Uredi kodo HTML",
sub_desc:"Podpisano",
sup_desc:"Nadpisano",
hr_desc:"Vstavi \u010Drto",
removeformat_desc:"Odstrani oblikovanje",
custom1_desc:"Opis tule",
forecolor_desc:"Izberite barvo pisave",
backcolor_desc:"Izberite barvo ozadja",
charmap_desc:"Vstavi posebni znak",
visualaid_desc:"Preklop prikaza vodil",
anchor_desc:"Vstavi/uredi sidro",
cut_desc:"Izre\u017Ei",
copy_desc:"Kopiraj",
paste_desc:"Prilepi",
image_props_desc:"Lastnosti slike",
newdocument_desc:"Nov dokument",
help_desc:"Pomo\u010D",
blockquote_desc:"Citat",
clipboard_msg:"Delo z odlo\u017Ei\u0161\u010Dem ni mogo\u010De v tem brskalniku. Lahko uporabljate kombinacije tipk Ctrl+X, Ctrl+C, Ctrl+V.\n\u017Delite ve\u010D informacij o tem?",
path:"Pot",
newdocument:"Ste prepri\u010Dani, da \u017Eelite odstraniti vsebino?",
toolbar_focus:"Preskok na orodjarno - Alt+Q, Preskok v urejevalnik - Alt-Z, Preskok na pot elementa - Alt-X",
more_colors:"Ve\u010D barv"
});