tinyMCE.addI18n('az.advanced',{
style_select:"Still\u0259r",
font_size:"\u015Erift \u00F6l\u00E7\u00FC\u015F\u00FC",
fontdefault:"\u015Erift",
block:"Format",
paragraph:"Abzas",
div:"B\u00F6lm\u0259",
address:"\u00DCnvan",
pre:"Formatlanm\u0131\u015F m\u0259tn",
h1:"Ba\u015Fl\u0131q 1",
h2:"Ba\u015Fl\u0131q 2",
h3:"Ba\u015Fl\u0131q 3",
h4:"Ba\u015Fl\u0131q 4",
h5:"Ba\u015Fl\u0131q 5",
h6:"Ba\u015Fl\u0131q 6",
blockquote:"Sitat bloku",
code:"Kod",
samp:"Kod n\u00FCmun\u0259si",
dt:"M\u00FC\u0259yy\u0259n edil\u0259n termin",
dd:"Terminin m\u00FC\u0259yy\u0259n edilm\u0259si",
bold_desc:"Yar\u0131qal\u0131n (Ctrl+B)",
italic_desc:"Kursiv (Ctrl+I)",
underline_desc:"Altdan x\u0259tt (Ctrl+U)",
striketrough_desc:"Qaralanm\u0131\u015F",
justifyleft_desc:"Soldan d\u00FCzl\u0259ndir",
justifycenter_desc:"M\u0259rk\u0259z\u0259 d\u00FCzl\u0259ndir",
justifyright_desc:"Sa\u011Fdan d\u00FCzl\u0259ndir",
justifyfull_desc:"Enin\u0259 d\u00FCzl\u0259ndir",
bullist_desc:"Qeyd edilmi\u015F siyah\u0131",
numlist_desc:"N\u00F6mr\u0259l\u0259nmi\u015F siyah\u0131",
outdent_desc:"Bo\u015F yeri ki\u00E7ilt",
indent_desc:"Bo\u015F yeri b\u00F6y\u00FCt",
undo_desc:"L\u0259\u011Fv et (Ctrl+Z)",
redo_desc:"T\u0259krarla (Ctrl+Y)",
link_desc:"\u018Flav\u0259 et/ke\u00E7idi redakt\u0259 et",
unlink_desc:"Ke\u00E7idi sil",
image_desc:"\u018Flav\u0259 et/\u015F\u0259kili redakt\u0259 et",
cleanup_desc:"\u018Fyri kodu t\u0259mizl\u0259",
code_desc:"HTML-m\u0259nb\u0259ni redakt\u0259 et",
sub_desc:"A\u015Fa\u011F\u0131 indeks",
sup_desc:"Yuxar\u0131 indeks",
hr_desc:"\u00DCf\u00FCqi x\u0259tt \u0259lav\u0259 et",
removeformat_desc:"Formatlaman\u0131 l\u0259\u011Fv et",
custom1_desc:"\u00D6z t\u0259svirinizi daxil edin",
forecolor_desc:"M\u0259tnin r\u0259ngini se\u00E7",
backcolor_desc:"Fonun r\u0259ngini se\u00E7",
charmap_desc:"X\u00FCsusi simvol \u0259lav\u0259 et",
visualaid_desc:"G\u00F6nd\u0259ril\u0259n/g\u00F6r\u00FCnm\u0259z elementl\u0259ri yand\u0131r/s\u00F6nd\u00FCr",
anchor_desc:"L\u00F6vb\u0259r \u0259lav\u0259/redakt\u0259 et",
cut_desc:"K\u0259s",
copy_desc:"Kopyala",
paste_desc:"\u018Flav\u0259 et",
image_props_desc:"\u015E\u0259kil x\u00FCsusiyy\u0259ti",
newdocument_desc:"Yeni s\u0259n\u0259d",
help_desc:"K\u00F6m\u0259k",
blockquote_desc:"Sitat bloku",
clipboard_msg:"Kopyalama/\u018Flav\u0259 et Mozilla v\u0259 Firefox-da i\u015Fl\u0259mir.\r\nN\u0259 ba\u015F verdiyi haqda daha \u0259trafl\u0131 \u00F6yr\u0259nm\u0259k ist\u0259yirsiniz?",
path:"Yol",
newdocument:"\u0130\u00E7ind\u0259kil\u0259ri tam t\u0259mizl\u0259m\u0259kd\u0259 \u0259minsiniz?",
toolbar_focus:"Alt+Q - al\u0259t d\u00FCym\u0259l\u0259rin\u0259 ke\u00E7, Alt-Z - redaktoruna ke\u00E7, Alt-X - elementl\u0259r yoluna ke\u00E7",
more_colors:"Daha \u00E7ox r\u0259ng",
image_delta_width:"65"
});