tinyMCE.addI18n('ca.table_dlg',{
general_tab:"General",
advanced_tab:"Avan\u00E7at",
general_props:"Propietats generals",
advanced_props:"Propietats avan\u00E7ades",
rowtype:"Fila",
title:"Insereix/Modifica taula",
width:"Amplada",
height:"Al\u00E7ada",
cols:"Columnes",
rows:"Files",
cellspacing:"Espaiat de cel\u00B7la",
cellpadding:"Separaci\u00F3 de cel\u00B7la",
border:"Vora",
align:"Alineaci\u00F3",
align_default:"Per defecte",
align_left:"Esquerra",
align_right:"Dreta",
align_middle:"Centre",
row_title:"Propietats de fila",
cell_title:"Propietats de cel\u00B7la",
cell_type:"Tipus de cel\u00B7la",
valign:"Alineaci\u00F3 vertical",
align_top:"A dalt",
align_bottom:"A baix",
bordercolor:"Color de vora",
bgcolor:"Color de fons",
merge_cells_title:"Fusiona cel\u00B7les",
id:"Id",
style:"Estil",
langdir:"Direcci\u00F3 de l\'idioma",
langcode:"Codi de l\'idioma",
mime:"Tipus MIME",
ltr:"D\'esquerra a dreta",
rtl:"De dreta a esquerra",
bgimage:"Imatge de fons",
summary:"Resum",
td:"Dades",
th:"Cap\u00E7alera",
cell_cell:"Actualitza la cel\u00B7la",
cell_row:"Actualitza totes les cel\u00B7les de la fila",
cell_all:"Actualitza totes les cel\u00B7les de la taula",
row_row:"Actualitza la fila",
row_odd:"Actualitza les files senars",
row_even:"Actualitza les files parells",
row_all:"Actualitza totes les files",
thead:"Cap\u00E7alera de la taula",
tbody:"Cos de la taula",
tfoot:"Peu de la taula",
scope:"Abast",
rowgroup:"Grup de files",
colgroup:"Grup de columnes",
col_limit:"Heu superat el nombre m\u00E0xim de columnes de {$cols}.",
row_limit:"Heu superat el nombre m\u00E0xim de files de {$rows}.",
cell_limit:"Heu superat el nombre m\u00E0xim de cel\u00B7les de {$cells}..",
missing_scope:"Esteu segur que voleu continuar sense indicar un abast per a aquesta cel\u00B7la de cap\u00E7alera. Pot ser dif\u00EDcil per a alguns usuaris amb discapacitats entendre el contingut o les dades mostrades a la taula.",
caption:"T\u00EDtol de la taula",
frame:"Marc",
frame_none:"cap",
frame_groups:"grups",
frame_rows:"files",
frame_cols:"columnes",
frame_all:"tot",
rules:"Regles",
rules_void:"buit",
rules_above:"per damunt de",
rules_below:"per sota de",
rules_hsides:"hsides",
rules_lhs:"lhs",
rules_rhs:"rhs",
rules_vsides:"vsides",
rules_box:"quadre",
rules_border:"vora"
});