tinyMCE.addI18n('fi.emotions_dlg',{
title:"Lis\u00E4\u00E4 hymi\u00F6",
desc:"Hymi\u00F6t",
cool:"Cool",
cry:"Itku",
embarassed:"Nolostunut",
foot_in_mouth:"Jalka suussa",
frown:"Otsan rypistys",
innocent:"Viaton",
kiss:"Pusu",
laughing:"Nauru",
money_mouth:"Klink Klink (raha)",
sealed:"Tukittu",
smile:"Hymy",
surprised:"Yll\u00E4ttynyt",
tongue_out:"Kieli ulkona",
undecided:"P\u00E4\u00E4tt\u00E4m\u00E4t\u00F6n",
wink:"Silm\u00E4nisku",
yell:"Huuto"
});