tinyMCE.addI18n('vi.xhtmlxtras_dlg',{
attribute_label_title:"Ti\u00EAu \u0111\u1EC1",
attribute_label_id:"ID",
attribute_label_class:"L\u1EDBp",
attribute_label_style:"Ki\u1EC3u d\u00E1ng",
attribute_label_cite:"Ch\u00FA th\u00EDch",
attribute_label_datetime:"Ng\u00E0y/gi\u1EDD",
attribute_label_langdir:"H\u01B0\u1EDBng v\u0103n b\u1EA3n",
attribute_option_ltr:"Tr\u00E1i qua ph\u1EA3i",
attribute_option_rtl:"Ph\u1EA3i qua tr\u00E1i",
attribute_label_langcode:"Ng\u00F4n ng\u1EEF",
attribute_label_tabindex:"Ch\u1EC9 m\u1EE5c th\u1EBB",
attribute_label_accesskey:"Ph\u00EDm truy c\u1EADp",
attribute_events_tab:"S\u1EF1 ki\u1EC7n",
attribute_attrib_tab:"Thu\u1ED9c t\u00EDnh",
general_tab:"Chung",
attrib_tab:"Thu\u1ED9c t\u00EDnh",
events_tab:"S\u1EF1 ki\u1EC7n",
fieldset_general_tab:"Thi\u1EBFt l\u1EADp chung",
fieldset_attrib_tab:"Thu\u1ED9c t\u00EDnh ph\u1EA7n t\u1EED",
fieldset_events_tab:"S\u1EF1 ki\u1EC7n ph\u1EA7n t\u1EED",
title_ins_element:"Ch\u00E8n ph\u1EA7n t\u1EED",
title_del_element:"X\u00F3a ph\u1EA7n t\u1EED",
title_acronym_element:"Vi\u1EBFt t\u1EAFt ph\u1EA7n t\u1EED",
title_abbr_element:"T\u00EAn vi\u1EBFt t\u1EAFt ph\u1EA7n t\u1EED",
title_cite_element:"Bi\u00EA\u0309u ch\u01B0\u01A1ng ph\u1EA7n t\u1EED",
remove:"Lo\u1EA1i b\u1ECF",
insert_date:"Ch\u00E8n ng\u00E0y/gi\u1EDD hi\u1EC7n th\u1EDDi",
option_ltr:"Tr\u00E1i qua ph\u1EA3i",
option_rtl:"Ph\u1EA3i qua tr\u00E1i",
attribs_title:"Ch\u00E8n/S\u1EEDa thu\u1ED9c t\u00EDnh"
});