tinyMCE.addI18n('mk.xhtmlxtras_dlg',{
attribute_label_title:"\u041D\u0430\u0441\u043B\u043E\u0432",
attribute_label_id:"ID",
attribute_label_class:"Klasa",
attribute_label_style:"Stil",
attribute_label_cite:"Citat",
attribute_label_datetime:"Datum/vreme",
attribute_label_langdir:"Smjer teksta",
attribute_option_ltr:"S leva na desno",
attribute_option_rtl:"S desna na levo",
attribute_label_langcode:"Jezik",
attribute_label_tabindex:"TabIndex",
attribute_label_accesskey:"AccessKey",
attribute_events_tab:"Doga\u0111aji",
attribute_attrib_tab:"Atributi",
general_tab:"Osnovno",
attrib_tab:"Atributi",
events_tab:"Doga\u0111aji",
fieldset_general_tab:"Osnovne postavke",
fieldset_attrib_tab:"Atributi elemenata",
fieldset_events_tab:"Doga\u0111aji elemenata",
title_ins_element:"Element za unos",
title_del_element:"Element za brisanje",
title_acronym_element:"Element akronima",
title_abbr_element:"Element kratice",
title_cite_element:"Element citata",
remove:"Ukloni",
insert_date:"\u0412\u043C\u0435\u0442\u043D\u0438 trenuta\u010Dni datum/vreme",
option_ltr:"S leva na desno",
option_rtl:"S desna na levo",
attribs_title:"\u0412\u043C\u0435\u0442\u043D\u0438/uredi atribute"
});