tinyMCE.addI18n('sk.advanced_dlg',{
about_title:"O TinyMCE",
about_general:"O programe",
about_help:"Pomocn\u00EDk",
about_license:"Licencia",
about_plugins:"Z\u00E1suvn\u00E9 moduly",
about_plugin:"Z\u00E1suvn\u00FD modul",
about_author:"Autor",
about_version:"Verzia",
about_loaded:"Na\u010D\u00EDtan\u00E9 z\u00E1suvn\u00E9 moduly",
anchor_title:"Vlo\u017Ei\u0165/upravi\u0165 z\u00E1lo\u017Eku (kotvu)",
anchor_name:"N\u00E1zov z\u00E1lo\u017Eky",
code_title:"Editor HTML",
code_wordwrap:"Zalamovanie riadkov",
colorpicker_title:"V\u00FDber farby",
colorpicker_picker_tab:"Kvapkadlo",
colorpicker_picker_title:"Kvapkadlo",
colorpicker_palette_tab:"Vzorkovn\u00EDk",
colorpicker_palette_title:"Vzorkovn\u00EDk farieb",
colorpicker_named_tab:"N\u00E1zvy",
colorpicker_named_title:"Pomenovan\u00E9 farby",
colorpicker_color:"Vybrat\u00E1 farba:",
colorpicker_name:"N\u00E1zov:",
charmap_title:"Vlo\u017Ei\u0165 \u0161peci\u00E1lny znak",
image_title:"Vlo\u017Ei\u0165/upravi\u0165 obr\u00E1zok",
image_src:"URL obr\u00E1zka",
image_alt:"Popis obr\u00E1zka",
image_list:"Zoznam obr\u00E1zkov",
image_border:"Or\u00E1movanie",
image_dimensions:"Rozmery",
image_vspace:"Vertik\u00E1lne odsadenie",
image_hspace:"Horizont\u00E1lne odsadenie",
image_align:"Zarovnanie",
image_align_baseline:"Na z\u00E1klad\u0148u",
image_align_top:"Hore",
image_align_middle:"Na stred riadku",
image_align_bottom:"Dole",
image_align_texttop:"S vrcholom riadku",
image_align_textbottom:"So spodkom riadku",
image_align_left:"V\u013Eavo",
image_align_right:"Vpravo",
link_title:"Vlo\u017Ei\u0165/upravi\u0165 odkaz",
link_url:"URL odkazu",
link_target:"Cie\u013E",
link_target_same:"Otvori\u0165 odkaz v rovnakom okne",
link_target_blank:"Otvori\u0165 odkaz v novom okne",
link_titlefield:"Titulok",
link_is_email:"Zadan\u00E9 URL vyzer\u00E1 ako e-mailov\u00E1 adresa, chcete doplni\u0165 povinn\u00FD prefix mailto:?",
link_is_external:"Zadan\u00E9 URL vyzer\u00E1 ako extern\u00FD odkaz, chcete doplni\u0165 povinn\u00FD prefix http://?",
link_list:"Zoznam odkazov"
});