tinyMCE.addI18n('ko.advanced_dlg',{
about_title:"TinyMCE\uC5D0 \uB300\uD558\uC5EC",
about_general:"About",
about_help:"\uB3C4\uC6C0\uB9D0",
about_license:"\uB77C\uC774\uC13C\uC2A4",
about_plugins:"\uD50C\uB7EC\uADF8\uC778",
about_plugin:"\uD50C\uB7EC\uADF8\uC778",
about_author:"\uC81C\uC791\uC790",
about_version:"\uBC84\uC83C",
about_loaded:"\uC2E4\uD589\uB41C \uD50C\uB7EC\uADF8\uC778",
anchor_title:"\uC5E5\uCEE4 \uC0BD\uC785/\uD3B8\uC9D1",
anchor_name:"\uC5E5\uCEE4\uBA85",
code_title:"\uC18C\uC2A4 \uD3B8\uC9D1",
code_wordwrap:"\uC6CC\uB4DC\uB7A9",
colorpicker_title:"\uC0C9\uC744 \uC120\uD0DD",
colorpicker_picker_tab:"\uD53D\uCEE4",
colorpicker_picker_title:"\uCEEC\uB7EC \uD53D\uCEE4",
colorpicker_palette_tab:"\uD314\uB808\uD2B8",
colorpicker_palette_title:"\uD314\uB808\uD2B8 \uC0C9",
colorpicker_named_tab:"\uC0C9 \uC774\uB984",
colorpicker_named_title:"\uC0C9",
colorpicker_color:"Color:",
colorpicker_name:"\uC0C9 \uC774\uB984:",
charmap_title:"\uD2B9\uC218 \uBB38\uC790",
image_title:"\uC774\uBBF8\uC9C0\uC758 \uC0BD\uC785/\uD3B8\uC9D1",
image_src:"\uC774\uBBF8\uC9C0 URL",
image_alt:"\uC774\uBBF8\uC9C0 \uC124\uBA85",
image_list:"\uC774\uBBF8\uC9C0 \uBAA9\uB85D",
image_border:"\uD14C\uB450\uB9AC\uC120",
image_dimensions:"\uD06C\uAE30",
image_vspace:"\uC0C1\uD558 \uC5EC\uBC31",
image_hspace:"\uC88C\uC6B0 \uC5EC\uBC31",
image_align:"\uC815\uB82C",
image_align_baseline:"\uAE30\uC900\uC120",
image_align_top:"Top",
image_align_middle:"Middle",
image_align_bottom:"Bottom",
image_align_texttop:"Text top",
image_align_textbottom:"Text bottom",
image_align_left:"Left",
image_align_right:"Right",
link_title:"\uB9C1\uD06C\uC758 \uC0BD\uC785/\uD3B8\uC9D1",
link_url:"\uB9C1\uD06C URL",
link_target:"Target",
link_target_same:"\uAC19\uC740\uCC3D",
link_target_blank:"\uC0C8\uCC3D",
link_titlefield:"\uC81C\uBAA9",
link_is_email:"\uBA54\uC77C\uC8FC\uC18C\uAC00 \uC785\uB825\uB418\uC5C8\uC2B5\uB2C8\uB2E4.\n\uBA54\uC77C\uC8FC\uC18C\uC758 \uC55E\uC5D0 mailto:\uB97C \uBD99\uC785\uB2C8\uAE4C?",
link_is_external:"\uC678\uBD80URL\uC774 \uC785\uB825\uB418\uC5C8\uC2B5\uB2C8\uB2E4.\nURL\uC758 \uC55E\uC5D0 http://\uB97C \uBD99\uC785\uB2C8\uAE4C?",
link_list:"\uB9C1\uD06C \uBAA9\uB85D"
});