tinyMCE.addI18n('et.advimage_dlg',{
tab_general:"\u00DCldine",
tab_appearance:"V\u00E4limus",
tab_advanced:"P\u00F5hjalikum",
general:"\u00DCldine",
title:"Pealkiri",
preview:"Eelvaade",
constrain_proportions:"Piira proportioone",
langdir:"Keele suund",
langcode:"Keele kood",
long_desc:"Pikk kirjelduse link",
style:"Stiil",
classes:"Klassid",
ltr:"Vasakult paremale",
rtl:"Paremalt vasakule",
id:"ID",
map:"Pildi kaart",
swap_image:"Vaheta pilti",
alt_image:"Alternatiivne pilt",
mouseover:"\u201EKursor peal\u201C",
mouseout:"\u201EKursor maas\u201C",
misc:"Mitmesugune",
example_img:"Eelvaate pildi v\u00E4limus",
missing_alt:"Oled kindel, et soovid j\u00E4tkata pildile kirjeldust lisamata?",
dialog_title:"Sisesta/muuda pilti",
src:"Pildi URL",
alt:"Pildi kirjeldus",
list:"Piltide nimekiri",
border:"Raam",
dimensions:"M\u00F5\u00F5tmed",
vspace:"Vertikaalne vahe",
hspace:"Horisontaalne vahe",
align:"Joondus",
align_baseline:"Baas",
align_top:"\u00DCleval",
align_middle:"Keskel",
align_bottom:"All",
align_texttop:"Tekst \u00FCleval",
align_textbottom:"Tekst all",
align_left:"Vasakul",
align_right:"Paremal",
image_list:"Piltide nimekiri"
});