tinyMCE.addI18n('eu.advlink_dlg',{
title:"Lotura txertatu/editatu",
url:"Loturaren URL helbidea",
target:"Helburua",
titlefield:"Izenburua",
is_email:"Sartutako helbideak e-posta bat dirudi, aurretik mailto: gehitzea nahi duzu?",
is_external:"Sartutako helbideak kanpoko webgune batena dirudi, aurretik http:// gehitzea nahi duzu?",
list:"Lotura-zerrenda",
general_tab:"Orokorra",
popup_tab:"Popupa",
events_tab:"Ebentuak",
advanced_tab:"Gehigarriak",
general_props:"Aukera orokorrak",
popup_props:"Popuparen aukerak",
event_props:"Ebentuak",
advanced_props:"Aukera aurreratuak",
popup_opts:"Aukerak",
anchor_names:"Aingurak",
target_same:"Leiho/marko honetan ireki",
target_parent:"Leiho/marko gurasoan ireki",
target_top:"Gorengo markoan ireki (marko guztiak ordezkatzen ditu)",
target_blank:"Leiho berrian ireki",
popup:"Javascript popupa",
popup_url:"Popuparen URL helbidea",
popup_name:"Leihoaren izena",
popup_return:"'return false' txertatu",
popup_scrollbars:"Gora-behera barra erakutsi",
popup_statusbar:"Egoera-barra erakutsi",
popup_toolbar:"Tresna-barrak erakutsi",
popup_menubar:"Menu-barra erakutsi",
popup_location:"Helbide-barra erakutsi",
popup_resizable:"Leihoaren tamaina aldatzea aktibatu",
popup_dependent:"Menpekoa (Mozilla/Firefoxen bakarrik)",
popup_size:"Tamaina",
popup_position:"Kokapena (X/Y)",
id:"Id",
style:"Estiloa",
classes:"Klaseak",
target_name:"Helburuaren izena",
langdir:"Hizkuntzaren norabidea",
target_langcode:"Helburu-hizkuntza",
langcode:"Hizkuntza-kodea",
encoding:"Helburuaren karaktere-kodeketa",
mime:"Helburuaren MIME mota",
rel:"Orrialdearen eta helburuaren arteko erlazioa",
rev:"Helburuaren eta orrialdearen arteko erlazioa",
tabindex:"Tabulazio ordena",
accesskey:"Laster-tekla",
ltr:"Ezkerretik eskuinera",
rtl:"Eskuinetik ezkerrera",
link_list:"Lotura-zerrenda"
});