tinyMCE.addI18n('eu.media_dlg',{
title:"Insert / edit embedded media",
general:"Orokorra",
advanced:"Aurreratua",
file:"Fitxategia/URL",
list:"Zerrenda",
size:"Tamaina",
preview:"Aurrebista",
constrain_proportions:"Constrain proportions",
type:"Mota",
id:"Id",
name:"Izena",
class_name:"Class",
vspace:"V-Space",
hspace:"H-Space",
play:"Auto play",
loop:"Loop",
menu:"Erakutsi menua",
quality:"Kalitatea",
scale:"Scale",
align:"Lerrokatu",
salign:"SAlign",
wmode:"WMode",
bgcolor:"Atzea",
base:"Oinarria",
flashvars:"Flashvars",
liveconnect:"SWLiveConnect",
autohref:"AutoHREF",
cache:"Katxea",
hidden:"Ezkutuan",
controller:"Controller",
kioskmode:"Kiosk modua",
playeveryframe:"Play every frame",
targetcache:"Helburu katxea",
correction:"Zuzenketarik ez",
enablejavascript:"Gaitu JavaScript",
starttime:"Noiz hasi",
endtime:"Noiz bukatu",
href:"Href",
qtsrcchokespeed:"Choke speed",
target:"Helburua",
volume:"Volume",
autostart:"Automatikoki hasi",
enabled:"Gaituta",
fullscreen:"Pantaila osoa",
invokeurls:"Invoke URLs",
mute:"Ixilik",
stretchtofit:"Stretch to fit",
windowlessvideo:"Lehiogabeko bideoa",
balance:"Balance",
baseurl:"Base URL",
captioningid:"Captioning id",
currentmarker:"Current marker",
currentposition:"Uneko posizioa",
defaultframe:"Default frame",
playcount:"Play count",
rate:"Rate",
uimode:"UI Modua",
flash_options:"Flash aukerak",
qt_options:"Quicktime aukerak",
wmp_options:"Windows media player aukerak",
rmp_options:"Real media player aukerak",
shockwave_options:"Shockwave aukerak",
autogotourl:"Automatikoi joan URLra",
center:"Erdian",
imagestatus:"Irudi edoera",
maintainaspect:"Maintain aspect",
nojava:"Java ez",
prefetch:"Prefetch",
shuffle:"Shuffle",
console:"Console",
numloop:"Begizta kopurua",
controls:"Controls",
scriptcallbacks:"Script callbacks",
swstretchstyle:"Stretch style",
swstretchhalign:"Stretch H-Align",
swstretchvalign:"Stretch V-Align",
sound:"Soinua",
progress:"Progress",
qtsrc:"QT Src",
qt_stream_warn:"Streaming bidez ematen diren rtsp baliabideak aurreratuak fitxa n dagoen QT Src eremuan gehitu behar dira.\n Streaming gabeko bertsio bat ere gehitu beharko zenuke.",
align_top:"Goian",
align_right:"Eskuinean",
align_bottom:"Behean",
align_left:"Ezkerrean",
align_center:"Erdian",
align_top_left:"Goian ezkerran",
align_top_right:"Goian eskuinean",
align_bottom_left:"Behean ezkerrean",
align_bottom_right:"Behean eskuinean",
flv_options:"Flash video aukerak",
flv_scalemode:"Scale modua",
flv_buffer:"Buffer",
flv_startimage:"Hasiera irudiae",
flv_starttime:"Noiz hasi",
flv_defaultvolume:"Default volumne",
flv_hiddengui:"Ezkutuko GUI",
flv_autostart:"Auto start",
flv_loop:"Loop",
flv_showscalemodes:"Erakutsi scale moduak",
flv_smoothvideo:"Smooth video",
flv_jscallback:"JS Callback"
});