#frmbody {
	padding: 10px;
	background-color: #FFF;
	border: 1px solid #CCC;
}

.frmRow {
	margin-bottom: 10px;
}

#templatesrc {
	border: none;
	width: 320px;
	height: 240px;
}

.title {
	padding-bottom: 5px;
}

.mceActionPanel {
	padding-top: 5px;
}

.mceActionPanel .left {
    float: left;
}
.mceActionPanel .right {
    float: right;
}
.mceActionPanel .clearboth {
	clear: both;
}
