tinyMCE.addI18n('az.media_dlg',{
title:"Mediya-obyekti \u0259lav\u0259/redakt\u0259 et",
general:"\u00DCmumi",
advanced:"\u018Flav\u0259l\u0259r",
file:"Fayl/\u00FCnvan",
list:"Siyah\u0131",
size:"\u00D6\u00E7\u00FCl\u0259ri",
preview:"\u0130lkin bax\u0131\u015F",
constrain_proportions:"Proporsiyalar\u0131 saxla",
type:"N\u00F6v",
id:"\u0130dentifikator",
name:"Ad\u0131",
class_name:"Sinif",
vspace:"\u015Eaquli f\u0259za",
hspace:"\u00DCf\u00FCqi f\u0259za",
play:"Avtomatik oynat",
loop:"\u0130lm\u0259k",
menu:"Menyunu g\u00F6st\u0259r",
quality:"Keyfiyy\u0259t",
scale:"Miqyas",
align:"Tarazla\u015Fmaq",
salign:"SAlign",
wmode:"WMode",
bgcolor:"Fon",
base:"T\u0259m\u0259l",
flashvars:"Flashvars",
liveconnect:"SWLiveConnect",
autohref:"AutoHREF",
cache:"Ke\u015F",
hidden:"Gizli",
controller:"\u0130dar\u0259\u00E7i",
kioskmode:"Kiosk \u00FCsulu",
playeveryframe:"H\u0259r \u00E7\u0259r\u00E7iv\u0259ni oynat",
targetcache:"H\u0259d\u0259f ke\u015F",
correction:"D\u0259yi\u015Fiklik yoxdur",
enablejavascript:"JavaScript-i yand\u0131r",
starttime:"Ba\u015Flan\u011F\u0131c zaman",
endtime:"Bit\u0259c\u0259k zaman",
href:"Href",
qtsrcchokespeed:"Drossel s\u00FCr\u0259ti",
target:"H\u0259d\u0259f",
volume:"S\u0259s",
autostart:"Avtomatik ba\u015Flat",
enabled:"Yan\u0131l\u0131b",
fullscreen:"Tam ekran",
invokeurls:"\u00C7a\u011F\u0131r\u0131lacaq URL \u00FCnvanlar",
mute:"S\u0259ssiz",
stretchtofit:"S\u0131\u011Facaq q\u0259d\u0259r \u00F6l\u00E7\u00FCl\u0259ndir",
windowlessvideo:"P\u0259nc\u0259r\u0259siz vide",
balance:"Balans",
baseurl:"Baza URL",
captioningid:"Ba\u015Fl\u0131qland\u0131rma id",
currentmarker:"Haz\u0131rki marker",
currentposition:"Haz\u0131rki m\u00F6vqe",
defaultframe:"Susmaya g\u00F6r\u0259 \u00E7\u0259r\u00E7iv\u0259",
playcount:"Oynatma say\u0131",
rate:"Norma",
uimode:"UI \u00DCsulu",
flash_options:"Flash nizamlamalar\u0131",
qt_options:"Quicktime nizamlamalar\u0131",
wmp_options:"Windows media player nizamlamalar\u0131",
rmp_options:"Real media player nizamlamalar\u0131",
shockwave_options:"Shockwave nizamlamalar\u0131",
autogotourl:"Avtomatik gedil\u0259c\u0259k URL",
center:"M\u0259rk\u0259z",
imagestatus:"\u015E\u0259kil statusu",
maintainaspect:"Aspekti qoru",
nojava:"Java yox",
prefetch:"\u00D6n-g\u0259tirm\u0259",
shuffle:"Qar\u0131\u015Fd\u0131r",
console:"Konsol",
numloop:"R\u0259q\u0259mli ilm\u0259l\u0259r",
controls:"Kontroller",
scriptcallbacks:"Skript \u00E7a\u011F\u0131r\u0131mlar\u0131",
swstretchstyle:"Uzatma stili",
swstretchhalign:"Uzat Y-D\u00FCzl\u0259ndir",
swstretchvalign:"Uzat D-D\u00FCzl\u0259ndir",
sound:"S\u0259s",
progress:"\u0130l\u0259rl\u0259yi\u015F",
qtsrc:"QT Src",
qt_stream_warn:"Haz\u0131rki ax\u0131lan rtsp m\u0259nb\u0259l\u0259ri QT Src sah\u0259sin\u0259 \u0259lav\u0259 edilm\u0259lidir.\nSiz h\u0259m\u00E7inin Src sah\u0259sin\u0259 qeyri-ax\u0131lan versiyan\u0131 da \u0259lav\u0259 etm\u0259lisiniz..",
align_top:"\u00DCst",
align_right:"Sa\u011F",
align_bottom:"Alt",
align_left:"Sol",
align_center:"M\u0259tk\u0259z",
align_top_left:"\u00DCst sol",
align_top_right:"\u00DCst sa\u011F",
align_bottom_left:"A\u015Fa\u011F\u0131 sol",
align_bottom_right:"A\u015Fa\u011F\u0131 sa\u011F",
flv_options:"Fla\u015F video nizamlamalar\u0131",
flv_scalemode:"Miqyas \u00FCsulu",
flv_buffer:"Bufer",
flv_startimage:"Ba\u015Flan\u011F\u0131c \u015F\u0259kil",
flv_starttime:"Ba\u015Flan\u011F\u0131c zaman",
flv_defaultvolume:"Susmaya g\u00F6r\u0259 s\u0259s",
flv_hiddengui:"Gizli GUI",
flv_autostart:"Avtomatik ba\u015Flat",
flv_loop:"\u0130lm\u0259",
flv_showscalemodes:"\u00D6l\u00E7\u0259k rejiml\u0259ri g\u00F6st\u0259r",
flv_smoothvideo:"Videonu yum\u015Falt",
flv_jscallback:"JS \u00C7a\u011F\u0131r\u0131mlar\u0131"
});