tinyMCE.addI18n('hu.xhtmlxtras_dlg',{
attribute_label_title:"C\u00EDm",
attribute_label_id:"ID",
attribute_label_class:"Class",
attribute_label_style:"Style",
attribute_label_cite:"Id\u00E9zet",
attribute_label_datetime:"D\u00E1tum/Id\u0151",
attribute_label_langdir:"Sz\u00F6veg ir\u00E1nya",
attribute_option_ltr:"Balr\u00F3l jobbra",
attribute_option_rtl:"Jobbr\u00F3l balra",
attribute_label_langcode:"Nyelv",
attribute_label_tabindex:"TabIndex",
attribute_label_accesskey:"Gyorsbilenty\u0171",
attribute_events_tab:"Esem\u00E9nyek",
attribute_attrib_tab:"Tulajdons\u00E1gok",
general_tab:"\u00C1ltal\u00E1nos",
attrib_tab:"Tulajdons\u00E1gok",
events_tab:"Esem\u00E9nyek",
fieldset_general_tab:"\u00C1ltal\u00E1nos be\u00E1ll\u00EDt\u00E1sok",
fieldset_attrib_tab:"Elem tulajdons\u00E1gok",
fieldset_events_tab:"Elem esem\u00E9nyek",
title_ins_element:"Besz\u00FArt elem",
title_del_element:"T\u00F6r\u00F6lt elem",
title_acronym_element:"Bet\u0171sz\u00F3 elem",
title_abbr_element:"R\u00F6vid\u00EDt\u00E9s elem",
title_cite_element:"Id\u00E9zet elem",
remove:"Elt\u00E1vol\u00EDt\u00E1s",
insert_date:"Aktu\u00E1lis d\u00E1tum/id\u0151 besz\u00FAr\u00E1sa",
option_ltr:"Balr\u00F3l jobra",
option_rtl:"Jobbr\u00F3l balra",
attribs_title:"Tulajdons\u00E1gok besz\u00FAr\u00E1sa/szerkeszt\u00E9se"
});