tinyMCE.addI18n('tr.table_dlg',{
general_tab:"Genel",
advanced_tab:"Geli\u015Fmi\u015F",
general_props:"Genel \u00F6zellikler",
advanced_props:"Geli\u015Fmi\u015F \u00F6zellikler",
rowtype:"Tablo b\u00F6l\u00FCm\u00FCndeki sat\u0131r",
title:"Tablo Ekle/D\u00FCzenle",
width:"Geni\u015Flik",
height:"Y\u00FCkseklik",
cols:"S\u00FCtunlar",
rows:"Sat\u0131rlar",
cellspacing:"H\u00FCcre i\u00E7i bo\u015Flu\u011Fu",
cellpadding:"H\u00FCcre d\u0131\u015F\u0131 bo\u015Flu\u011Fu",
border:"Kenarl\u0131k",
align:"Hizalama",
align_default:"Varsay\u0131lan",
align_left:"Sol",
align_right:"Sa\u011F",
align_middle:"Orta",
row_title:"Tablo sat\u0131r \u00F6zellikleri",
cell_title:"Tablo h\u00FCcre \u00F6zellikleri",
cell_type:"H\u00FCcre tipi",
valign:"Dikey hizalama",
align_top:"\u00DCst",
align_bottom:"Alt",
bordercolor:"Kenarl\u0131k rengi",
bgcolor:"Arkaplan rengi",
merge_cells_title:"Tablo h\u00FCcrelerini birle\u015Ftir",
id:"Id",
style:"Stil",
langdir:"Dil y\u00F6n\u00FC",
langcode:"Dil kodu",
mime:"Hedef MIME tipi",
ltr:"Sa\u011Fdan sola",
rtl:"Soldan sa\u011Fa",
bgimage:"Arkaplan resmi",
summary:"\u00D6zet",
td:"Veri",
th:"Ba\u015Fl\u0131k",
cell_cell:"Se\u00E7ili h\u00FCcreleri g\u00FCncelle",
cell_row:"Sat\u0131rdaki t\u00FCm h\u00FCcreleri g\u00FCncelle",
cell_all:"Tablodaki t\u00FCm h\u00FCcreleri g\u00FCncelle",
row_row:"Se\u00E7ili sat\u0131r\u0131 g\u00FCncelle",
row_odd:"Tablodaki tek nolu sat\u0131rlar\u0131 g\u00FCncelle",
row_even:"Tablodaki \u00E7ift nolu sat\u0131rlar\u0131 g\u00FCncelle",
row_all:"Tablodaki t\u00FCm sat\u0131rlar\u0131 g\u00FCncelle",
thead:"Tablo Ba\u015Fl\u0131\u011F\u0131",
tbody:"Tablo G\u00F6vdesi",
tfoot:"Tablo Alt\u0131",
scope:"Kapsam",
rowgroup:"Sat\u0131r Grubu",
colgroup:"S\u00FCtun Grubu",
col_limit:"Maksimum s\u00FCtun say\u0131s\u0131 ($cols) a\u015F\u0131ld\u0131.",
row_limit:"Maksimum sat\u0131r say\u0131s\u0131 ($rows) a\u015F\u0131ld\u0131.",
cell_limit:"Maksimum h\u00FCcre say\u0131s\u0131 ($cells) a\u015F\u0131ld\u0131.",
missing_scope:"Tablo ba\u015Fl\u0131k h\u00FCcresi i\u00E7in bir kapsam belirlemeden devam etmek istedi\u011Finize emin misiniz? Bu de\u011Fer olmadan, engelli kullan\u0131c\u0131lar  tabloda g\u00F6sterilen verileri ve i\u00E7eri\u011Fi anlamas\u0131 zordur.",
caption:"Tablo ba\u015Fl\u0131\u011F\u0131",
frame:"\u00C7er\u00E7eve",
frame_none:"hi\u00E7biri",
frame_groups:"gruplar",
frame_rows:"sat\u0131rlar",
frame_cols:"s\u00FCtunlar",
frame_all:"t\u00FCm\u00FC",
rules:"\u00C7izgiler",
rules_void:"yok",
rules_above:"\u00FCst\u00FCnde",
rules_below:"alt\u0131nda",
rules_hsides:"yatay kenarlar",
rules_lhs:"sol yatay kenarlar",
rules_rhs:"sa\u011F yatay kenarlar",
rules_vsides:"dikey kenarlar",
rules_box:"kutu",
rules_border:"kenarl\u0131k"
});