tinyMCE.addI18n('sk.media_dlg',{
title:"Vlo\u017Ei\u0165/upravi\u0165 vkladan\u00E9 m\u00E9di\u00E1",
general:"Obecn\u00E9",
advanced:"Roz\u0161\u00EDren\u00E9",
file:"S\u00FAbor/URL",
list:"Zoznam",
size:"Rozmery",
preview:"N\u00E1h\u013Ead",
constrain_proportions:"Zachova\u0165 proporcie",
type:"Typ",
id:"ID",
name:"N\u00E1zov",
class_name:"Trieda",
vspace:"Vertik\u00E1lne odsadenie",
hspace:"Horizont\u00E1lne odsadenie",
play:"Automatick\u00E9 prehr\u00E1vanie",
loop:"Opakovanie",
menu:"Zobrazi\u0165 ponuku",
quality:"Kvalita",
scale:"Pomer",
align:"Zarovnanie",
salign:"Zarovnanie okna",
wmode:"Re\u017Eim okna",
bgcolor:"Pozadie",
base:"Z\u00E1kladn\u00FD prie\u010Dinok",
flashvars:"Parametre (Flashvars)",
liveconnect:"Spusti\u0165 Javu (SWLiveConnect)",
autohref:"Automatick\u00E9 na\u010D\u00EDtanie",
cache:"Medzipam\u00E4\u0165",
hidden:"Skry\u0165",
controller:"Ovl\u00E1dac\u00ED panel",
kioskmode:"Zak\u00E1za\u0165 ukladanie",
playeveryframe:"Prehra\u0165 ka\u017Ed\u00FD sn\u00EDmok",
targetcache:"Cie\u013Eov\u00E1 medzipam\u00E4\u0165",
correction:"Bez korekci\u00ED",
enablejavascript:"Povoli\u0165 JavaScript",
starttime:"Po\u010Diato\u010Dn\u00FD \u010Das",
endtime:"Koncov\u00FD \u010Das",
href:"Odkaz",
qtsrcchokespeed:"Zn\u00ED\u017Eenie r\u00FDchlosti",
target:"Cie\u013E",
volume:"Hlasitos\u0165",
autostart:"Automatick\u00E9 spustenie",
enabled:"Povoli\u0165 ovl\u00E1dac\u00ED panel",
fullscreen:"Cel\u00E1 obrazovka",
invokeurls:"Po\u017Eadova\u0165 URL",
mute:"Uml\u010Da\u0165",
stretchtofit:"Roztiahn\u00FA\u0165 do okna",
windowlessvideo:"Video bez okna",
balance:"Rovnov\u00E1ha",
baseurl:"Z\u00E1kladn\u00E1 URL",
captioningid:"ID popisku m\u00E9dia",
currentmarker:"Aktu\u00E1lna z\u00E1lo\u017Eka",
currentposition:"Aktu\u00E1lna poz\u00EDcia",
defaultframe:"Predvolen\u00FD sn\u00EDmok",
playcount:"Po\u010D\u00EDtadlo prehrat\u00ED",
rate:"Relat\u00EDvna r\u00FDchlos\u0165",
uimode:"Re\u017Eim ovl\u00E1dacieho panelu",
flash_options:"Mo\u017Enosti Flashu",
qt_options:"Mo\u017Enosti Quicktime",
wmp_options:"Mo\u017Enosti prehr\u00E1va\u010Da Windows media",
rmp_options:"Mo\u017Enosti prehr\u00E1va\u010Da Real media",
shockwave_options:"Mo\u017Enosti Shockwave",
autogotourl:"Automatick\u00FD prechod na URL",
center:"Na stred",
imagestatus:"Stav obrazu",
maintainaspect:"Zachova\u0165 pomer str\u00E1n",
nojava:"Nesp\u00FA\u0161\u0165a\u0165 Javu",
prefetch:"Predna\u010D\u00EDtanie",
shuffle:"N\u00E1hodne",
console:"Konzola",
numloop:"Po\u010Det opakovan\u00ED",
controls:"Ovl\u00E1dac\u00ED panel",
scriptcallbacks:"Skripty sp\u00E4tn\u00FDch volan\u00ED",
swstretchstyle:"\u0160t\u00FDl roztiahnutia",
swstretchhalign:"Zarovnanie horiz. roztiahnutia",
swstretchvalign:"Zarovnanie vert. roztiahnutia",
sound:"Zvuk",
progress:"Priebeh",
qtsrc:"S\u00FAbor/URL streamu pre QT",
qt_stream_warn:"Streamovan\u00E9 rtsp zdroje m\u00F4\u017Eu by\u0165 pridan\u00E9 do polia 'S\u00FAbor/URL streamu pre QT' na z\u00E1lo\u017Eke 'Roz\u0161\u00EDren\u00E9'.\nYM\u00F4\u017Ete tie\u017E prida\u0165 nie streamovan\u00FA verziu do polia 'S\u00FAbor/URL'.",
align_top:"Hore",
align_right:"Vpravo",
align_bottom:"Dolu",
align_left:"V\u013Eavo",
align_center:"Na stred",
align_top_left:"Hore v\u013Eavo",
align_top_right:"Hore vpravo",
align_bottom_left:"Dolu v\u013Eavo",
align_bottom_right:"Dolu vpravo",
flv_options:"Mo\u017Enosti Flash video",
flv_scalemode:"Zmena ve\u013Ekosti",
flv_buffer:"Z\u00E1sobn\u00EDk",
flv_startimage:"Po\u010Diato\u010Dn\u00FD obr\u00E1zok",
flv_starttime:"Po\u010Diato\u010Dn\u00FD \u010Das",
flv_defaultvolume:"Predvolen\u00E1 hlasitos\u0165",
flv_hiddengui:"Skryt\u00FD ovl\u00E1dac\u00ED panel",
flv_autostart:"Automatick\u00E9 spustenie",
flv_loop:"Opakovanie",
flv_showscalemodes:"Zobrazi\u0165 vo\u013Eby zmeny ve\u013Ekosti",
flv_smoothvideo:"Vyhladzovan\u00FD obraz",
flv_jscallback:"Sp\u00E4tn\u00E9 volanie JavaScriptu"
});