tinyMCE.addI18n('ca.advlink_dlg',{
title:"Insereix/edita enlla\u00E7",
url:"URL de l\'enlla\u00E7",
target:"Objectiu",
titlefield:"T\u00EDtol",
is_email:"L\'URL que heu introdu\u00EFt sembla ser una adre\u00E7a de correu electr\u00F2nic, voleu afegir-hi el prefix requerit mailto: ?",
is_external:"L\'URL que heu introdu\u00EFt sembla ser un enlla\u00E7 extern, voleu afegir-hi el prefix requerit http:// ?",
list:"Llista d\'enlla\u00E7os",
general_tab:"General",
popup_tab:"Finestra emergent",
events_tab:"Esdeveniments",
advanced_tab:"Avan\u00E7at",
general_props:"Propietats generals",
popup_props:"Propietats de la finestra emergent",
event_props:"Esdeveniments",
advanced_props:"Propietats avan\u00E7ades",
popup_opts:"Opcions",
anchor_names:"\u00C0ncores",
target_same:"Obre en aquesta finestra / marc",
target_parent:"Obre en la finestra / marc pare",
target_top:"Obre en el marc superior (reempla\u00E7a tots els marcs)",
target_blank:"Obre en una nova finestra",
popup:"Finestra emergent javascript",
popup_url:"URL de la finestra emergent",
popup_name:"Nom de la finestra",
popup_return:"Insereix \'return false\'",
popup_scrollbars:"Mostra les barres de despla\u00E7ament",
popup_statusbar:"Mostra la barra d\'estat",
popup_toolbar:"Mostra la barra d\'eines",
popup_menubar:"Mostra la barra de men\u00FA",
popup_location:"Mostra la barra d\'ubicaci\u00F3",
popup_resizable:"Fes la finestra redimensionable",
popup_dependent:"Dependent (nom\u00E9s Mozilla/Firefox)",
popup_size:"Mida",
popup_position:"Posici\u00F3 (X/Y)",
id:"Id",
style:"Estil",
classes:"Classes",
target_name:"Nom del dest\u00ED",
langdir:"Direcci\u00F3 de l\'idioma",
target_langcode:"Idioma del dest\u00ED",
langcode:"Codi de l\'idioma",
encoding:"Codificaci\u00F3 de car\u00E0cters del dest\u00ED",
mime:"Tipus MIME del dest\u00ED",
rel:"Relaci\u00F3 de p\u00E0gina a dest\u00ED",
rev:"Relaci\u00F3 de dest\u00ED a p\u00E0gina",
tabindex:"Tabindex",
accesskey:"Accesskey",
ltr:"D\'esquerra a dreta",
rtl:"De dreta a esquerra",
link_list:"Llista d\'enlla\u00E7os"
});