tinyMCE.addI18n('tr.advanced',{
style_select:"Stiller",
font_size:"Yaz\u0131 boyutu",
fontdefault:"Yaz\u0131 tipi",
block:"Bi\u00E7im",
paragraph:"Paragraf",
div:"Blok",
address:"Adres",
pre:"\u00D6nceden bi\u00E7imlendirilmi\u015F",
h1:"Ba\u015Fl\u0131k 1",
h2:"Ba\u015Fl\u0131k 2",
h3:"Ba\u015Fl\u0131k 3",
h4:"Ba\u015Fl\u0131k 4",
h5:"Ba\u015Fl\u0131k 5",
h6:"Ba\u015Fl\u0131k 6",
blockquote:"Blok al\u0131nt\u0131",
code:"Kod",
samp:"\u00D6rnek kod",
dt:"\u0130fade tan\u0131mlama ",
dd:"A\u00E7\u0131klama tan\u0131mlama",
bold_desc:"Kal\u0131n (Ctrl+B)",
italic_desc:"\u0130talik (Ctrl+I)",
underline_desc:"Alt\u0131 \u00E7izili (Ctrl+U)",
striketrough_desc:"\u00DCst\u00FC \u00E7izili",
justifyleft_desc:"Sola hizala",
justifycenter_desc:"Ortala",
justifyright_desc:"Sa\u011Fa hizala",
justifyfull_desc:"\u0130ki yana yasla",
bullist_desc:"S\u0131ras\u0131z liste",
numlist_desc:"S\u0131ral\u0131 liste",
outdent_desc:"Girintiyi azalt",
indent_desc:"Girintiyi art\u0131r",
undo_desc:"Geri al (Ctrl+Z)",
redo_desc:"Yinele (Ctrl+Y)",
link_desc:"Ba\u011Flant\u0131 ekle/d\u00FCzenle",
unlink_desc:"Ba\u011Flant\u0131y\u0131 kald\u0131r",
image_desc:"Resim ekle/d\u00FCzenle",
cleanup_desc:"Da\u011F\u0131n\u0131k kodu temizle",
code_desc:"HTML Kayna\u011F\u0131n\u0131 D\u00FCzenle",
sub_desc:"Altsimge",
sup_desc:"\u00DCstsimge",
hr_desc:"Yatay cetvel ekle",
removeformat_desc:"Bi\u00E7imi temizle",
custom1_desc:"\u00D6zel a\u00E7\u0131klamalar burada",
forecolor_desc:"Metin rengini se\u00E7",
backcolor_desc:"Arkaplan rengini se\u00E7",
charmap_desc:"\u00D6zel karakter ekle",
visualaid_desc:"K\u0131lavuz/g\u00F6r\u00FCnmez nesneleri a\u00E7/kapat.",
anchor_desc:"K\u00F6pr\u00FC ekle/d\u00FCzenle",
cut_desc:"Kes",
copy_desc:"Kopyala",
paste_desc:"Yap\u0131\u015Ft\u0131r",
image_props_desc:"Resim \u00F6zellikleri",
newdocument_desc:"Bo\u015F belge",
help_desc:"Yard\u0131m",
blockquote_desc:"Blok al\u0131nt\u0131",
clipboard_msg:"Mozilla Firefox da Kes/Kopyala/Yap\u0131\u015Ft\u0131r kullan\u0131lamaz. Bu konu hakk\u0131nda daha fazla bilgi almak ister misiniz?",
path:"Yol",
newdocument:"T\u00FCm i\u00E7eriklerleri temizlemek istedi\u011Finizden emin misiniz?",
toolbar_focus:"Alt+Q ara\u00E7 d\u00FC\u011Fmelerine ge\u00E7. Alt+Z: Edit\u00F6re ge\u00E7. Alt+X:Elementin yoluna ge\u00E7.",
more_colors:"Daha fazla renk"
});