tinyMCE.addI18n({sk:{
common:{
edit_confirm:"Chcete pou\u017Ei\u0165 WYSIWYG re\u017Eim pre tento text?",
apply:"Pou\u017Ei\u0165",
insert:"Vlo\u017Ei\u0165",
update:"Aktualizova\u0165",
cancel:"Storno",
close:"Zavrie\u0165",
browse:"Prech\u00E1dza\u0165",
class_name:"Trieda",
not_set:"-- Nezadan\u00E9 --",
clipboard_msg:"Funkcie kop\u00EDrova\u0165/vystrihn\u00FA\u0165/vlo\u017Ei\u0165 nie s\u00FA podporovan\u00E9 v prehliada\u010Doch Mozilla a Firefox.\nChcete viac inform\u00E1ci\u00ED o tomto probl\u00E9me?",
clipboard_no_support:"T\u00E1to funkcia nie je va\u0161\u00EDm prehliada\u010Dom podporovan\u00E1. Pou\u017Eite namiesto toho kl\u00E1vesov\u00FA skratku.",
popup_blocked:"Blokovanie vyskakovac\u00EDch okien neumo\u017Enilo otvori\u0165 okno, ktor\u00E9 poskytuje funk\u010Dnos\u0165 aplik\u00E1cie. Pre pln\u00E9 vyu\u017Eitie mo\u017Enost\u00ED aplik\u00E1cie mus\u00EDte vypn\u00FA\u0165 blokovanie vyskakovac\u00EDch okien pre tento web.",
invalid_data:"Chyba: Boli zadan\u00E9 neplatn\u00E9 hodnoty a tieto boli ozna\u010Den\u00E9 \u010Dervenou farbou.",
more_colors:"\u010Eal\u0161ie farby"
},
contextmenu:{
align:"Zarovnanie",
left:"Do\u013Eava",
center:"Na stred",
right:"Doprava",
full:"Do bloku"
},
insertdatetime:{
date_fmt:"%d.%m.%Y",
time_fmt:"%H:%M:%S",
insertdate_desc:"Vlo\u017Ei\u0165 d\u00E1tum",
inserttime_desc:"Vlo\u017Ei\u0165 \u010Das",
months_long:"Janu\u00E1r,Febru\u00E1r,Marec,Apr\u00EDl,M\u00E1j,J\u00FAn,J\u00FAl,August,September,Okt\u00F3ber,November,December",
months_short:"Jan,Feb,Mar,Apr,M\u00E1j,J\u00FAn,J\u00FAl,Aug,Sep,Okt,Nov,Dec",
day_long:"Nede\u013Ea,Pondelok,Utorok,Streda,\u0160tvrtok,Piatok,Sobota,Nede\u013Ea",
day_short:"Ne,Po,Ut,St,\u0160t,Pi,So,Ne"
},
print:{
print_desc:"Tla\u010D"
},
preview:{
preview_desc:"N\u00E1h\u013Ead"
},
directionality:{
ltr_desc:"Smer z\u013Eava doprava",
rtl_desc:"Smer sprava do\u013Eava"
},
layer:{
insertlayer_desc:"Vlo\u017Ei\u0165 nov\u00FA vrstvu",
forward_desc:"Presun\u00FA\u0165 dopredu",
backward_desc:"Presun\u00FA\u0165 dozadu",
absolute_desc:"Prepn\u00FA\u0165 na absol\u00FAtne poziciovanie",
content:"Nov\u00E1 vrstva..."
},
save:{
save_desc:"Ulo\u017Ei\u0165",
cancel_desc:"Zru\u0161i\u0165 v\u0161etky zmeny"
},
nonbreaking:{
nonbreaking_desc:"Vlo\u017Ei\u0165 nerozdelite\u013En\u00FA medzeru"
},
iespell:{
iespell_desc:"Spusti\u0165 kontrolu pravopisu",
download:"Slovn\u00EDk ieSpell nebol detekovan\u00FD. Chcete ho nain\u0161talova\u0165?"
},
advhr:{
advhr_desc:"Vodorovn\u00FD odde\u013Eova\u010D"
},
emotions:{
emotions_desc:"Emotikony"
},
searchreplace:{
search_desc:"H\u013Eada\u0165",
replace_desc:"H\u013Eada\u0165 a nahradi\u0165"
},
advimage:{
image_desc:"Vlo\u017Ei\u0165/upravi\u0165 obr\u00E1zok",
delta_width:"40"
},
advlink:{
link_desc:"Vlo\u017Ei\u0165/upravi\u0165 odkaz"
},
xhtmlxtras:{
cite_desc:"Cit\u00E1cia",
abbr_desc:"Skratka",
acronym_desc:"Akronym",
del_desc:"Odstr\u00E1nen\u00FD text",
ins_desc:"Pridan\u00FD text",
attribs_desc:"Vlo\u017Ei\u0165/upravi\u0165 atrib\u00FAty"
},
style:{
desc:"Upravi\u0165 CSS \u0161t\u00FDl",
delta_width:"35"
},
paste:{
paste_text_desc:"Vlo\u017Ei\u0165 ako prost\u00FD text",
paste_word_desc:"Vlo\u017Ei\u0165 z Wordu",
selectall_desc:"Ozna\u010Di\u0165 v\u0161etko",
plaintext_mode_sticky:"Funkcia vlo\u017Ei\u0165 je teraz v re\u017Eime prost\u00FD text. Op\u00E4tovn\u00E9 kliknutie prepne t\u00FAto funkciu nasp\u00E4\u0165 do norm\u00E1lneho re\u017Eimu. Po vlo\u017Een\u00ED \u010Dohoko\u013Evek bude t\u00E1to funkcia navr\u00E1ten\u00E1 sp\u00E4\u0165 do norm\u00E1lneho re\u017Eimu.",
plaintext_mode:"Funkcia vlo\u017Ei\u0165 je teraz v re\u017Eime prost\u00FD text. Op\u00E4tovn\u00E9 kliknutie prepne t\u00FAto funkciu nasp\u00E4\u0165 do norm\u00E1lneho re\u017Eimu."
},
paste_dlg:{
text_title:"Pou\u017Eite CTRL+V pre vlo\u017Eenie textu do okna.",
text_linebreaks:"Zachova\u0165 zalamovanie riadkov",
word_title:"Pou\u017Eite CTRL+V pre vlo\u017Eenie textu do okna."
},
table:{
desc:"Vlo\u017Ei\u0165 nov\u00FA tabu\u013Eku",
row_before_desc:"Vlo\u017Ei\u0165 riadok pred",
row_after_desc:"Vlo\u017Ei\u0165 riadok za",
delete_row_desc:"Odstr\u00E1ni\u0165 riadok tabu\u013Eky",
col_before_desc:"Vlo\u017Ei\u0165 st\u013Apec pred",
col_after_desc:"Vlo\u017Ei\u0165 st\u013Apec za",
delete_col_desc:"Odstr\u00E1ni\u0165 st\u013Apec tabu\u013Eky",
split_cells_desc:"Rozdeli\u0165 bunky",
merge_cells_desc:"Zl\u00FA\u010Di\u0165 bunky",
row_desc:"Vlastnosti riadky tabu\u013Eky",
cell_desc:"Vlastnosti bunky",
props_desc:"Vlastnosti tabu\u013Eky",
paste_row_before_desc:"Vlo\u017Ei\u0165 riadok pred",
paste_row_after_desc:"Vlo\u017Ei\u0165 riadok za",
cut_row_desc:"Vystrihn\u00FA\u0165 riadok tabu\u013Eky",
copy_row_desc:"Kop\u00EDrova\u0165 riadok tabu\u013Eky",
del:"Odstr\u00E1ni\u0165 tabu\u013Eku",
row:"Riadok",
col:"St\u013Apec",
cell:"Bunka",
cellprops_delta_width:"105",
table_delta_width:"50"
},
autosave:{
unload_msg:"Preveden\u00E9 zmeny m\u00F4\u017Eu by\u0165 straten\u00E9, ak opust\u00EDte t\u00FAto str\u00E1nku.",
restore_content:"Obnovi\u0165 automaticky ulo\u017Een\u00FD obsah.",
warning_message:"Pokia\u013E obnov\u00EDte ulo\u017Een\u00FD obsah, strat\u00EDte t\u00FDm v\u0161etok obsah, ktor\u00FD je pr\u00E1ve v okne editora.\n\nSkuto\u010Dne chcete obnovi\u0165 ulo\u017Een\u00FD obsah?."
},
fullscreen:{
desc:"Prepn\u00FA\u0165 na celostr\u00E1nkov\u00E9 zobrazenie"
},
media:{
desc:"Vlo\u017Ei\u0165/upravi\u0165 m\u00E9di\u00E1",
edit:"Upravi\u0165 m\u00E9di\u00E1",
delta_width:"180"
},
fullpage:{
desc:"Vlastnosti dokumentu",
delta_width:"115"
},
template:{
desc:"Vlo\u017Ei\u0165 preddefinovan\u00FD obsah zo \u0161abl\u00F3ny"
},
visualchars:{
desc:"Zobrazenie skryt\u00FDch znakov zap/vyp"
},
spellchecker:{
desc:"Prepn\u00FA\u0165 kontrolu pravopisu",
menu:"Nastavenie kontroly pravopisu",
ignore_word:"Vynecha\u0165 slovo",
ignore_words:"Vynecha\u0165 v\u0161etky",
langs:"Jazyky",
wait:"\u010Cakajte pros\u00EDm...",
sug:"Ponuky",
no_sug:"\u017Diadne ponuky",
no_mpell:"Bez pravopisn\u00FDch ch\u00FDb."
},
pagebreak:{
desc:"Vlo\u017Ei\u0165 zalomenie str\u00E1nky."
},
advlist:{
types:"Typ",
def:"Predvolen\u00FD",
lower_alpha:"Mal\u00E9 p\u00EDsmen\u00E1",
lower_greek:"Mal\u00E9 gr\u00E9cke p\u00EDsmen\u00E1",
lower_roman:"Mal\u00E9 r\u00EDmske \u010D\u00EDslice",
upper_alpha:"Ve\u013Ek\u00E9 p\u00EDsmen\u00E1",
upper_roman:"Ve\u013Ek\u00E9 r\u00EDmske \u010D\u00EDslice",
circle:"Kr\u00FA\u017Eok",
disc:"Pln\u00E9 koliesko",
square:"\u0160tvor\u010Dek"
}}});