tinyMCE.addI18n('sl.table_dlg',{
general_tab:"Splo\u0161no",
advanced_tab:"Napredno",
general_props:"Splo\u0161ne lastnosti",
advanced_props:"Napredne lastnosti",
rowtype:"Vrstica v tabeli",
title:"Vstavi/posodobi tabelo",
width:"\u0160irina",
height:"Vi\u0161ina",
cols:"Stolpcev",
rows:"Vrstic",
cellspacing:"Razmik celic",
cellpadding:"Podlaganje celic",
border:"Obroba",
align:"Poravnava",
align_default:"Privzeto",
align_left:"Levo",
align_right:"Desno",
align_middle:"Sredina",
row_title:"Lastnosti vrstice",
cell_title:"Lastnosti celice",
cell_type:"Tip celice",
valign:"Navpi\u010Dna poravnava",
align_top:"Vrh",
align_bottom:"Dno",
bordercolor:"Barva obrobe",
bgcolor:"Barva ozadja",
merge_cells_title:"Spoji celice",
id:"Oznaka",
style:"Slog",
langdir:"Smer pisave",
langcode:"Koda jezika",
mime:"Ciljni tip MIME",
ltr:"Od leve proti desni",
rtl:"Od desne proti levi",
bgimage:"Slika ozadja",
summary:"Povzetek",
td:"Podatek",
th:"Glava",
cell_cell:"Posodobi trenutno celico",
cell_row:"Posodobi vse celice vrstice",
cell_all:"Posodobi vse celice tabele",
row_row:"Posodobi trenutno vrstico",
row_odd:"Posodobi lihe vrstice",
row_even:"Posodobi sode vrstice",
row_all:"Posodobi vse vrstice",
thead:"Glava tabele",
tbody:"Telo tabele",
tfoot:"Noga tabele",
scope:"Doseg",
rowgroup:"Skup. vrst.",
colgroup:"Skup. stolp.",
col_limit:"Presegli ste dovoljeno \u0161tevilo stolpcev: {$cols}.",
row_limit:"Presegli ste dovoljeno \u0161tevilo vrstic: {$rows}.",
cell_limit:"Presegli ste dovoljeno \u0161tevilo celic: {$cells}.",
missing_scope:"Ste prepri\u010Dani, da \u017Eelite nadaljevati brez dolo\u010Denega dosega? Brez dosega je razumevanje tabele lahko ote\u017Eeno ljudem s slab\u0161o zaznavo!",
caption:"Opis tabele",
frame:"Okvir",
frame_none:"brez",
frame_groups:"skupine",
frame_rows:"vrstice",
frame_cols:"stolpci",
frame_all:"vse",
rules:"Pravila",
rules_void:"prazno",
rules_above:"nad",
rules_below:"pod",
rules_hsides:"v-strani",
rules_lhs:"l-strani",
rules_rhs:"d-strani",
rules_vsides:"n-strani",
rules_box:"\u0161katla",
rules_border:"obroba"
});