tinyMCE.addI18n('mk.emotions_dlg',{
title:"\u0412\u043C\u0435\u0442\u043D\u0438 emociju",
desc:"Emocije",
cool:"Cool",
cry:"Pla\u010D",
embarassed:"Sramim se",
foot_in_mouth:"Izlanuo se",
frown:"Mr\u0161ti se",
innocent:"Nevina\u0161ce",
kiss:"Poljubac",
laughing:"Smeh",
money_mouth:"Bogata\u0161",
sealed:"\u0160utim",
smile:"Osmeh",
surprised:"Iznena\u0111en",
tongue_out:"Belji se",
undecided:"Neodlu\u010Dan",
wink:"Namigiva",
yell:"Vi\u010De"
});