tinyMCE.addI18n('sk.xhtmlxtras_dlg',{
attribute_label_title:"Titulok",
attribute_label_id:"ID",
attribute_label_class:"Trieda",
attribute_label_style:"\u0160t\u00FDl",
attribute_label_cite:"Cit\u00E1cia",
attribute_label_datetime:"D\u00E1tum/\u010Das",
attribute_label_langdir:"Smer textu",
attribute_option_ltr:"Z\u013Eava doprava",
attribute_option_rtl:"Sprava do\u013Eava",
attribute_label_langcode:"Jazyk",
attribute_label_tabindex:"Poradie pre tabul\u00E1tor",
attribute_label_accesskey:"Kl\u00E1vesov\u00E1 skratka",
attribute_events_tab:"Udalosti",
attribute_attrib_tab:"Atrib\u00FAty",
general_tab:"Obecn\u00E9",
attrib_tab:"Atrib\u00FAty",
events_tab:"Udalosti",
fieldset_general_tab:"Obecn\u00E9 parametre",
fieldset_attrib_tab:"Atrib\u00FAty prvku",
fieldset_events_tab:"Atrib\u00FAty udalost\u00ED",
title_ins_element:"Pridan\u00FD text",
title_del_element:"Odstr\u00E1nen\u00FD text",
title_acronym_element:"Akronym",
title_abbr_element:"Skratka",
title_cite_element:"Cit\u00E1cia",
remove:"Odstr\u00E1ni\u0165",
insert_date:"Vlo\u017Ei\u0165 aktu\u00E1lny d\u00E1tum/\u010Das",
option_ltr:"Z\u013Eava doprava",
option_rtl:"Sprava do\u013Eava",
attribs_title:"Vlo\u017Ei\u0165/upravi\u0165 atrib\u00FAty"
});