tinyMCE.addI18n('ms.emotions_dlg',{
title:"Masukkan emosi",
desc:"Simbol Emosi",
cool:"Tampan",
cry:"Menangis",
embarassed:"Malu",
foot_in_mouth:"Kaki dalam mulut",
frown:"Mengerut",
innocent:"Tidak bersalah",
kiss:"Cium",
laughing:"Gelak",
money_mouth:"Duit mulut",
sealed:"Kacip",
smile:"Senyum",
surprised:"Terkejut",
tongue_out:"Jelir lidah",
undecided:"Tak pasti",
wink:"Kenyit",
yell:"Menguap"
});