tinyMCE.addI18n('pl.template_dlg',{
title:"Szablony",
label:"Szablon",
desc_label:"Opis",
desc:"Wstaw szablon dokumentu",
select:"Wybierz szablon",
preview:"Podgl\u0105d",
warning:"Uwaga: Aktualizacja szablon\u00F3w mo\u017Ce spowodowa\u0107 utrat\u0119 danych.",
mdate_format:"%Y-%m-%d %H:%M:%S",
cdate_format:"%Y-%m-%d %H:%M:%S",
months_long:"Stycze\u0144,Luty,Marzec.Kwiecie\u0144,Maj,Czerwiec,Lipiec,Sierpie\u0144,Wrzesie\u0144,Pa\u017Adziernik,Listopad,Grudzie\u0144",
months_short:"Sty,Lut,Mar,Kwi,Maj,Cze,Lip,Sie,Wrz,Pa\u017A,Lis,Gru",
day_long:"Niedziela,Poniedzia\u0142ek,Wtorek,\u015Aroda,Czwartek,Pi\u0105tek,Sobota,Niedziela",
day_short:"N,Pn,Wt,\u015Ar,Cz,Pt,So,N"
});