tinyMCE.addI18n('sk.advimage_dlg',{
tab_general:"Obecn\u00E9",
tab_appearance:"Vzh\u013Ead",
tab_advanced:"Roz\u0161\u00EDren\u00E9",
general:"Obecn\u00E9 parametre",
title:"Titulok",
preview:"N\u00E1h\u013Ead",
constrain_proportions:"Zachova\u0165 pomer str\u00E1n",
langdir:"Smer textu",
langcode:"K\u00F3d jazyka",
long_desc:"Dlh\u00FD popis",
style:"\u0160t\u00FDl",
classes:"Triedy",
ltr:"Z\u013Eava doprava",
rtl:"Sprava do\u013Eava",
id:"ID",
map:"Obr\u00E1zkov\u00E1 mapa",
swap_image:"Prepnutie obr\u00E1zka",
alt_image:"Alternat\u00EDvny obr\u00E1zok",
mouseover:"Pri nabehnut\u00ED my\u0161i",
mouseout:"Po odjazden\u00ED my\u0161i",
misc:"R\u00F4zne",
example_img:"Pr\u00EDklad obr\u00E1zka",
missing_alt:"Naozaj chcete pokra\u010Dova\u0165 bez vlo\u017Een\u00E9ho popisu obr\u00E1zka? Bez popisu m\u00F4\u017Ee by\u0165 obr\u00E1zok nepr\u00EDstupn\u00FD u\u017E\u00EDvate\u013Eom so zrakov\u00FDm postihnut\u00EDm, u\u017E\u00EDvate\u013Eom textov\u00FDch prehliada\u010Dov alebo u\u017E\u00EDvate\u013Eom, ktor\u00ED maj\u00FA vypnut\u00E9 zobrazovanie obr\u00E1zkov.",
dialog_title:"Vlo\u017Ei\u0165/upravi\u0165 obr\u00E1zok",
src:"URL obr\u00E1zka",
alt:"Popis obr\u00E1zku",
list:"Zoznam obr\u00E1zkov",
border:"Or\u00E1movanie",
dimensions:"Rozmery",
vspace:"Vertik\u00E1lne odsadenie",
hspace:"Horizont\u00E1lne odsadenie",
align:"Zarovnanie",
align_baseline:"Na z\u00E1klad\u0148u",
align_top:"Hore",
align_middle:"Na stred riadku",
align_bottom:"Dole",
align_texttop:"S vrcholom riadku",
align_textbottom:"So spodkom riadku",
align_left:"V\u013Eavo",
align_right:"Vpravo",
image_list:"Zoznam obr\u00E1zkov"
});