tinyMCE.addI18n({eu:{
common:{
edit_confirm:"Testu-kutxa honek WYSIWYG editorea izatea nahi duzu?",
apply:"Aplikatu",
insert:"Txertatu",
update:"Eguneratu",
cancel:"Utzi",
close:"Itxi",
browse:"Arakatu",
class_name:"Kalsea",
not_set:"-- Ezarri gabe --",
clipboard_msg:"Kopiatu/Ebaki/Itsatsi ez dago Mozilla eta Firefoxen.\nHonen inguruko informazioa nahi duzu??",
clipboard_no_support:"Zure nabigatzailean ez dabil, erabili teklatuko laster-teklak honetarako..",
popup_blocked:"Ups, zure popup blokeatzaileak funtzionalitate bat eskaintzen duen leihoa blokeatu du. Blokeatzailea desgaitu beharko duzu tresna hau erabiltzeko.",
invalid_data:"Errorea: baliogabeak diren aukerak sartu dituzu, gorriz agertzen dira.",
more_colors:"Kolore gehiago"
},
contextmenu:{
align:"Alineazioa",
left:"Ezkerrean",
center:"Zentratuta",
right:"Eskuinean",
full:"Justifikatuta"
},
insertdatetime:{
date_fmt:"%Y-%m-%d",
time_fmt:"%H:%M:%S",
insertdate_desc:"Data txertatu",
inserttime_desc:"Ordua txertatu",
months_long:"Urtarrila,Otsaila,Martxoa,Apirila,Maiatza,Ekaina,Uztaila,Abuztua,Iraila,Urria,Azaroa,Abendua",
months_short:"Urt,Ots,Mar,Api,Mai,Eka,Uzt,Abu,Ira,Urr,Aza,Abe",
day_long:"Igandea,Astelehena,Asteartea,Asteazkena,Osteguna,Ostirala,Larunbata,Igandea",
day_short:"Ig,Al,As,Az,Og,Or,Lr,Ig"
},
print:{
print_desc:"Inprimatu"
},
preview:{
preview_desc:"Aurreikusi"
},
directionality:{
ltr_desc:"Ezkerretik eskumara",
rtl_desc:"Eskuinatik ezkerrera"
},
layer:{
insertlayer_desc:"Kapa berria txertatu",
forward_desc:"Aurrera joan",
backward_desc:"Atzera joan",
absolute_desc:"Posizionatze-absolutua aktibatu/desaktibatu",
content:"Kapa berria..."
},
save:{
save_desc:"Gorde",
cancel_desc:"Aldaketak bertan behera utzi"
},
nonbreaking:{
nonbreaking_desc:"Espazioa txertatu"
},
iespell:{
iespell_desc:"Hizkuntza zuzendu",
download:"ieSpell ez da aurkitu. Instalatu egin nahi duzu?"
},
advhr:{
advhr_desc:"Marra horizontala",
delta_width:"Zabalera",
delta_height:"Altuera"
},
emotions:{
emotions_desc:"Ikonotxoak",
delta_width:"Zabalera",
delta_height:"Altuera"
},
searchreplace:{
search_desc:"Bilatu",
replace_desc:"Bilatu/Ordeztu",
delta_width:"Zabalera",
delta_height:"Altuera"
},
advimage:{
image_desc:"Irudia txertatu/editatu",
delta_width:"Zabalera",
delta_height:"Altuera"
},
advlink:{
link_desc:"Lotura txertatu/editatu",
delta_width:"Zabalera",
delta_height:"Altuera"
},
xhtmlxtras:{
cite_desc:"Zita",
abbr_desc:"Laburdura",
acronym_desc:"Akronimoa",
del_desc:"Ezabaketa",
ins_desc:"Txertaketa",
attribs_desc:"Atributuak txertatu/editatu",
cite_delta_width:"Ziten zabalera",
cite_delta_height:"Ziten altuera",
abbr_delta_width:"Laburduren zabalera",
abbr_delta_height:"Laburduren altuera",
acronym_delta_width:"Akronimoen zabalera",
acronym_delta_height:"Akronimoen altuera",
del_delta_width:"Ezabaketaren zabalera",
del_delta_height:"Ezabaketaren altuera",
ins_delta_width:"Txertaketaren zabalera",
ins_delta_height:"Txertaketaren altuera",
attribs_delta_width:"Atributuen zabalera",
attribs_delta_height:"Atributuen altuera"
},
style:{
desc:"Aldatu CSS estiloa",
delta_width:"Zabalera",
delta_height:"Altuera"
},
paste:{
paste_text_desc:"Testu gisa itsatsi",
paste_word_desc:"Word-etik itsatsi",
selectall_desc:"Aukeratu guztia",
plaintext_mode_sticky:"Itsasketa testu moduan dago orain. Egin klik itsasketa arruntera itzultzeko. Zerbait itsatsi ostean, modu arruntera pasatuko zara automatikoki.",
plaintext_mode:"Itsasketa testu moduan dago orain. Egin klik itsasketa arruntera itzultzeko."
},
paste_dlg:{
text_title:"Erabili CTRL+V testua lehioan itsasteko.",
text_linebreaks:"Mantendu lerro-jauziak",
word_title:"Erabili CTRL+V testua lehioan itsasteko.."
},
table:{
desc:"Taula berri bat txertatu",
row_before_desc:"Txertatu lerroa aurretik",
row_after_desc:"Txertatu lerroa ondoren",
delete_row_desc:"Ezabatu lerroa",
col_before_desc:"Txertatu zutabea aurretik",
col_after_desc:"Txertatu zutabea ondoren",
delete_col_desc:"Ezabatu zutabea",
split_cells_desc:"Banatu bateratutako gelaxkak",
merge_cells_desc:"Bateratu gelaxkak",
row_desc:"Lerro ezaugarriak",
cell_desc:"Gelaxka ezaugarriak",
props_desc:"Taula ezaugarriak",
paste_row_before_desc:"Itsatsi lerroa aurretik",
paste_row_after_desc:"Itsatsi lerroa ondoren",
cut_row_desc:"Moztu lerroa",
copy_row_desc:"Kopiatu lerroa",
del:"Ezabatu taula",
row:"Lerroa",
col:"Zutabea",
cell:"Gelaxka",
rowprops_delta_width:"Lerroen propietateen zabalera",
rowprops_delta_height:"Lerroen propietateen altuera",
cellprops_delta_width:"Gelaxken propietateen zabalera",
cellprops_delta_height:"Gelaxken propietateen altuera",
table_delta_width:"Taularen zabalera",
table_delta_height:"Taularen altuera",
merge_cells_delta_width:"Gelaxkak batzearen zabalera",
merge_cells_delta_height:"Gelaxkak batzearen altuera"
},
autosave:{
unload_msg:"Egindako aldaketak galdu egingo dira orri honetatik kanpona nabigatzen baldin baduzu.",
restore_content:"Automatikoki gordetako edukia errekuperatu.",
warning_message:"Gordetako edukia errekuperatzen baduzu, orain editorean dagoena galdu egingo duzu.\n\nZiur zaude gordetakoa errekuperatzea nahi duzula?"
},
fullscreen:{
desc:"Aldatu pantaila osoko modura"
},
media:{
desc:"Insert / edit embedded media",
edit:"Edit embedded media",
delta_width:"Zabalera",
delta_height:"Altuera"
},
fullpage:{
desc:"Dokumentuaren ezaugarriak",
delta_width:"Zabalera",
delta_height:"Altuera"
},
template:{
desc:"Txertatu aurredefinitutako txantiloiaren edukia"
},
visualchars:{
desc:"Begi kontrol karaktereak gaitu/ezgaitu."
},
spellchecker:{
desc:"Toggle spellchecker",
menu:"Spellchecker settings",
ignore_word:"Ezikusi hitza",
ignore_words:"Ezikusi guztiak",
langs:"Hizkuntzak",
wait:"Itxaron mesedez...",
sug:"Gomendioa",
no_sug:"Gomendiorik ez",
no_mpell:"Ez da akatsik aurkitu."
},
pagebreak:{
desc:"Txertatu orri jauzia."
},
advlist:{
types:"Motak",
def:"Defektuzkoa",
lower_alpha:"Hizki xeheak",
lower_greek:"Hizki greko xeheak",
lower_roman:"Zenbaki erromatar xeheak",
upper_alpha:"Hizki larriak",
upper_roman:"Zenbaki erromatar larriak",
circle:"Borobila",
disc:"Diskoa",
square:"Karratua"
}}});