tinyMCE.addI18n('vi.advlink_dlg',{
title:"Th\u00EAm/S\u1EEDa Li\u00EAn k\u1EBFt",
url:"URL Li\u00EAn k\u1EBFt",
target:"\u0110\u00EDch",
titlefield:"Ti\u00EAu \u0111\u1EC1",
is_email:"URL b\u1EA1n \u0111\u00E3 nh\u1EADp c\u00F3 v\u1EBB l\u00E0 m\u1ED9t \u0111\u1ECBa ch\u1EC9 \u0111i\u1EC7n th\u01B0, B\u1EA1n c\u00F3 mu\u1ED1n th\u00EAm ti\u1EC1n t\u1ED1 mailto?",
is_external:"URL b\u1EA1n \u0111\u00E3 nh\u1EADp c\u00F3 v\u1EBB l\u00E0 m\u1ED9t li\u00EAn k\u1EBFt ngo\u00E0i, b\u1EA1n c\u00F3 mu\u1ED1n th\u00EAm ti\u1EC1n t\u1ED1 http://?",
list:"Danh s\u00E1ch li\u00EAn k\u1EBFt",
general_tab:"Chung",
popup_tab:"B\u1EADt l\u00EAn",
events_tab:"S\u1EF1 ki\u1EC7n",
advanced_tab:"N\u00E2ng cao",
general_props:"Thu\u1ED9c t\u00EDnh chung",
popup_props:"Thu\u1ED9c t\u00EDnh b\u1EADt l\u00EAn",
event_props:"S\u1EF1 ki\u1EC7n",
advanced_props:"Thu\u1ED9c t\u00EDnh n\u00E2ng cao",
popup_opts:"T\u00F9y ch\u1ECDn",
anchor_names:"M\u1ECF neo",
target_same:"M\u1EDF trong c\u1EEDa s\u1ED5/khung n\u00E0y",
target_parent:"M\u1EDF trong c\u1EEDa s\u1ED5/khung cha",
target_top:"M\u1EDF trong khung tr\u00EAn c\u00F9ng (thay th\u1EBF t\u1EA5t c\u00E1c khung)",
target_blank:"M\u1EDF trong c\u1EEDa s\u1ED5 m\u1EDBi",
popup:"Javascript b\u1EADt l\u00EAn",
popup_url:"URL b\u1EADt l\u00EAn",
popup_name:"T\u00EAn c\u1EEDa s\u1ED5",
popup_return:"Ch\u00E8n 'return false'",
popup_scrollbars:"Hi\u1EC3n th\u1ECB thanh cu\u1ED9n",
popup_statusbar:"Hi\u1EC7n th\u1ECB thanh tr\u1EA1ng th\u00E1i",
popup_toolbar:"Hi\u1EC7n th\u1ECB thanh c\u00F4ng c\u1EE5",
popup_menubar:"Hi\u1EC3n th\u1ECB thanh th\u1EF1c \u0111\u01A1n",
popup_location:"Hi\u1EC7n th\u1ECB thanh v\u1ECB tr\u00ED",
popup_resizable:"L\u00E0m cho c\u1EEDa s\u1ED5 c\u00F3 th\u1EC3 thay \u0111\u1ED5i k\u00EDch c\u1EE1",
popup_dependent:"Ph\u1EE5 thu\u1ED9c (ch\u1EC9 Mozilla/Firefox)",
popup_size:"K\u00EDch th\u01B0\u1EDBc",
popup_position:"V\u1ECB tr\u00ED (X/Y)",
id:"Id",
style:"Ki\u1EC3u d\u00E1ng",
classes:"L\u1EDBp",
target_name:"T\u00EAn \u0111\u00EDch",
langdir:"H\u01B0\u1EDBng ng\u00F4n ng\u1EEF",
target_langcode:"Ng\u00F4n ng\u1EEF \u0111\u00EDch",
langcode:"M\u00E3 ng\u00F4n ng\u1EEF",
encoding:"M\u00E3 h\u00F3a k\u00FD t\u1EF1 \u0111\u00EDch",
mime:"Ki\u1EC3u MIME \u0111\u00EDch",
rel:"Trang li\u00EAn quan t\u1EDBi \u0111\u00EDch",
rev:"\u0110\u00EDch li\u00EAn quan t\u1EDBi trang",
tabindex:"Ch\u1EC9 m\u1EE5c th\u1EBB",
accesskey:"Ph\u00EDm truy c\u1EADp",
ltr:"Tr\u00E1i qua ph\u1EA3i",
rtl:"Ph\u1EA3i qua tr\u00E1i",
link_list:"Danh s\u00E1ch li\u00EAn k\u1EBFt"
});