tinyMCE.addI18n('no.advanced',{
style_select:"Stiler",
font_size:"Skriftst\u00F8rrelse",
fontdefault:"Skriftfamilie",
block:"Format",
paragraph:"Avsnitt",
div:"Div",
address:"Adresse",
pre:"Pre-formatert",
h1:"Overskrift 1",
h2:"Overskrift 2",
h3:"Overskrift 3",
h4:"Overskrift 4",
h5:"Overskrift 5",
h6:"Overskrift 6",
blockquote:"Innrykk",
code:"Kode",
samp:"Kodeeksempel",
dt:"Definisjonsuttrykk",
dd:"Definisjonsbeskrivelse",
bold_desc:"Fet",
italic_desc:"Kursiv",
underline_desc:"Understrek",
striketrough_desc:"Gjennomstrek",
justifyleft_desc:"Venstrejustert",
justifycenter_desc:"Midtstilt",
justifyright_desc:"H\u00F8yrejustert",
justifyfull_desc:"Blokkjustert",
bullist_desc:"Punktliste",
numlist_desc:"Nummerliste",
outdent_desc:"Reduser innrykk",
indent_desc:"\u00D8k innrykk",
undo_desc:"Angre",
redo_desc:"Gj\u00F8r om",
link_desc:"Sett inn / endre lenke",
unlink_desc:"Fjern lenke",
image_desc:"Sett inn / endre bilde",
cleanup_desc:"Rens grisete kode",
code_desc:"Redigere HTML-kode",
sub_desc:"Senk skrift",
sup_desc:"Hev skrift",
hr_desc:"Sett inn horisontal linje",
removeformat_desc:"Fjern formatering",
custom1_desc:"Din spesialfunksjondefinisjon her",
forecolor_desc:"Vel skriftfarge",
backcolor_desc:"Vel bakgrunnsfarge",
charmap_desc:"Sett inn spesialtegn",
visualaid_desc:"Sl\u00E5 av/p\u00E5 usynlige element",
anchor_desc:"Sett inn / endre anker",
cut_desc:"Klipp ut",
copy_desc:"Kopier",
paste_desc:"Lim inn",
image_props_desc:"Egenskaper for bilde",
newdocument_desc:"Nytt dokument",
help_desc:"Hjelp",
blockquote_desc:"Innrykk",
clipboard_msg:"Klipp ut / Kopier /Lim inn fungerer ikke i Mozilla og Firefox. \r\n  Vil du vite mer om dette?",
path:"Sti",
newdocument:"Er du sikker p\u00E5 at du vil slette alt innhold?",
toolbar_focus:"Skift til verkt\u00F8yknapper - Alt+Q, Skift til editor - Alt-Z, Skift til elementsti - Alt-",
more_colors:"Flere farger"
});