tinyMCE.addI18n('th.xhtmlxtras_dlg',{
attribute_label_title:"\u0E0A\u0E37\u0E48\u0E2D",
attribute_label_id:"ID",
attribute_label_class:"\u0E04\u0E25\u0E32\u0E2A",
attribute_label_style:"\u0E23\u0E39\u0E1B\u0E41\u0E1A\u0E1A",
attribute_label_cite:"Cite",
attribute_label_datetime:"\u0E27\u0E31\u0E19/\u0E40\u0E27\u0E25\u0E32",
attribute_label_langdir:"\u0E17\u0E34\u0E28\u0E17\u0E32\u0E07\u0E15\u0E31\u0E27\u0E2D\u0E31\u0E01\u0E29\u0E23",
attribute_option_ltr:"\u0E0B\u0E49\u0E32\u0E22\u0E44\u0E1B\u0E02\u0E27\u0E32",
attribute_option_rtl:"\u0E02\u0E27\u0E32\u0E44\u0E1B\u0E0B\u0E49\u0E32\u0E22",
attribute_label_langcode:"\u0E20\u0E32\u0E29\u0E32",
attribute_label_tabindex:"\u0E25\u0E33\u0E14\u0E31\u0E1A\u0E41\u0E17\u0E47\u0E1A",
attribute_label_accesskey:"\u0E1B\u0E38\u0E48\u0E21\u0E25\u0E31\u0E14",
attribute_events_tab:"Event",
attribute_attrib_tab:"Attributes",
general_tab:"\u0E17\u0E31\u0E48\u0E27\u0E44\u0E1B",
attrib_tab:"Attributes",
events_tab:"\u0E01\u0E34\u0E08\u0E01\u0E23\u0E23\u0E21",
fieldset_general_tab:"\u0E15\u0E31\u0E49\u0E07\u0E04\u0E48\u0E32\u0E17\u0E31\u0E48\u0E27\u0E44\u0E1B",
fieldset_attrib_tab:"Element Attributes",
fieldset_events_tab:"Element Event",
title_ins_element:"Insertion Element",
title_del_element:"Deletion Element",
title_acronym_element:"Acronym Element",
title_abbr_element:"Abbreviation Element",
title_cite_element:"Citation Element",
remove:"\u0E25\u0E1A",
insert_date:"\u0E40\u0E1E\u0E34\u0E48\u0E21 \u0E27\u0E31\u0E19/\u0E40\u0E27\u0E25\u0E32",
option_ltr:"\u0E0B\u0E49\u0E32\u0E22\u0E44\u0E1B\u0E02\u0E27\u0E32",
option_rtl:"\u0E02\u0E27\u0E32\u0E44\u0E1B\u0E0B\u0E49\u0E32\u0E22",
attribs_title:"\u0E40\u0E1E\u0E34\u0E48\u0E21/\u0E41\u0E01\u0E49\u0E44\u0E02 Attributes"
});