tinyMCE.addI18n('tr.emotions_dlg',{
title:"\u0130fade ekle",
desc:"\u0130fadeler",
cool:"Sakin",
cry:"A\u011Flayan",
embarassed:"Utanga\u00E7",
foot_in_mouth:"Pot k\u0131rm\u0131\u015F",
frown:"As\u0131k",
innocent:"Masum",
kiss:"\u00D6p\u00FCc\u00FCk",
laughing:"Kahkaha",
money_mouth:"Para g\u00F6z",
sealed:"Gizli",
smile:"G\u00FCl\u00FCmseme",
surprised:"\u015Ea\u015F\u0131rma",
tongue_out:"Dil \u00E7\u0131karma",
undecided:"Karars\u0131z",
wink:"G\u00F6z k\u0131rpma",
yell:"Ba\u011F\u0131rma"
});