tinyMCE.addI18n({id:{
common:{
edit_confirm:"Gunakan mode WYSIWYG untuk textarea ini?",
apply:"Apply",
insert:"Insert",
update:"Update",
cancel:"Cancel",
close:"Close",
browse:"Browse",
class_name:"Class",
not_set:"-- Not set --",
clipboard_msg:"Copy/Cut/Paste tidak tersedia pada Mozilla dan Firefox.\nButuh info selengkapnya?",
clipboard_no_support:"Tidak didukung Browser, gunakan shortcut dari keyboard.",
popup_blocked:"Maaf, popup-blocker anda telah menonaktifkan jendela aplikasi yang menyediakan fungsionalitas. Nonaktifkan popup-blocker untuk sepenuhnya memanfaatkan alat ini.",
invalid_data:"Error: nilai invalid, ditandai dengan dengan warna merah",
more_colors:"More colors"
},
contextmenu:{
align:"Alignment",
left:"Kiri",
center:"Tengah",
right:"Kanan",
full:"Penuh"
},
insertdatetime:{
date_fmt:"%Y-%m-%d",
time_fmt:"%H:%M:%S",
insertdate_desc:"sisipkan tanggal",
inserttime_desc:"sisipkan waktu",
months_long:"Januari,Februari,Maren,April,Mei,Juni,Juli,Agustus,September,Oktober,November,Desember",
months_short:"Jan,Feb,Mar,Apr,Mei,Jun,Jul,Ags,Sep,Okt,Nov,Des",
day_long:"Minggu,Senin,Selasa,Rabu,Kamis,Jumat,Sabtu,Minggu",
day_short:"Min,Sen,Sel,Rab,Kam,Jum,Sab,Min"
},
print:{
print_desc:"Cetak"
},
preview:{
preview_desc:"Preview"
},
directionality:{
ltr_desc:"Arah kiri ke kanan",
rtl_desc:"Arah kanan ke kiri"
},
layer:{
insertlayer_desc:"sisipkan layer Baru",
forward_desc:"Pindah ke depan",
backward_desc:"Pindah ke belakang",
absolute_desc:"Beralih posisi absolut",
content:"Layer baru..."
},
save:{
save_desc:"Simpan",
cancel_desc:"Batalkan semua perubahan"
},
nonbreaking:{
nonbreaking_desc:"sisipkan karakter non-breaking space"
},
iespell:{
iespell_desc:"Jalankan spell checking",
download:"ieSpell tidak terdeteksi. Instal sekarang?"
},
advhr:{
advhr_desc:"Horizontal rule"
},
emotions:{
emotions_desc:"Emotions"
},
searchreplace:{
search_desc:"Cari",
replace_desc:"Cari/Ganti"
},
advimage:{
image_desc:"sisipkan/Ubah Gambar"
},
advlink:{
link_desc:"Sisipkan/Ubah link"
},
xhtmlxtras:{
cite_desc:"Kutipan",
abbr_desc:"Singkatan/Kependekan Kata",
acronym_desc:"Akronim",
del_desc:"Penghapusan",
ins_desc:"Penyisipan",
attribs_desc:"Sisip/Ubah Atribut"
},
style:{
desc:"Ubah CSS Style"
},
paste:{
paste_text_desc:"Paste as Plain Text",
paste_word_desc:"Paste from Word",
selectall_desc:"Select All",
plaintext_mode_sticky:"Paste is now in plain text mode. Click again to toggle back to regular paste mode. After you paste something you will be returned to regular paste mode.",
plaintext_mode:"Paste is now in plain text mode. Click again to toggle back to regular paste mode."
},
paste_dlg:{
text_title:"Gunakan CTRL+V pada keyboard untuk paste.",
text_linebreaks:"Keep linebreaks",
word_title:"Gunakan CTRL+V pada keyboard untuk paste."
},
table:{
desc:"Sisipkan tabel baru",
row_before_desc:"Sisipkan row sebelum",
row_after_desc:"Sisipkan row sesudah",
delete_row_desc:"Hapus row",
col_before_desc:"Sisipkan column sebelum",
col_after_desc:"Sisipkan column setelah",
delete_col_desc:"Hapus column",
split_cells_desc:"Pisahkan cell tabel yang di-merge",
merge_cells_desc:"Merge cell tabel",
row_desc:"Properti row tabel",
cell_desc:"Properti cell tabel",
props_desc:"Properti tabel",
paste_row_before_desc:"Paste row tabel sebelum",
paste_row_after_desc:"Paste row tabel sesudah",
cut_row_desc:"Cut row tabel",
copy_row_desc:"Copy row tabel",
del:"Hapus Tabel",
row:"Row",
col:"Column",
cell:"Cell"
},
autosave:{
unload_msg:"Perubahan yang dilakukan akan hilang jika Anda pindah dari halaman ini.",
restore_content:"Restore auto-saved content.",
warning_message:"If you restore the saved content, you will lose all the content that is currently in the editor.\n\nAre you sure you want to restore the saved content?."
},
fullscreen:{
desc:"Toggle fullscreen mode"
},
media:{
desc:"Insert / edit embedded media",
edit:"Edit embedded media"
},
fullpage:{
desc:"Properti Dokumen"
},
template:{
desc:"Menyisipkan template standar isi"
},
visualchars:{
desc:"Pengendalian visual karakter on/off"
},
spellchecker:{
desc:"Toggle spellchecker",
menu:"Pengaturan Spellchecker ",
ignore_word:"Abaikan kata",
ignore_words:"Abaikan semua",
langs:"Bahasa",
wait:"Harap tunggu...",
sug:"Saran",
no_sug:"Tidak ada saran",
no_mpell:"Tidak ada misspellings ditemukan."
},
pagebreak:{
desc:"Sisipkan page break."
},
advlist:{
types:"Types",
def:"Default",
lower_alpha:"Lower alpha",
lower_greek:"Lower greek",
lower_roman:"Lower roman",
upper_alpha:"Upper alpha",
upper_roman:"Upper roman",
circle:"Circle",
disc:"Disc",
square:"Square"
}}});