tinyMCE.addI18n('es.advimage_dlg',{
tab_general:"General",
tab_appearance:"Apariencia",
tab_advanced:"Avanzado",
general:"General",
title:"T\u00EDtulo",
preview:"Vista previa",
constrain_proportions:"Bloquear relaci\u00F3n de aspecto",
langdir:"Direcci\u00F3n del lenguaje",
langcode:"C\u00F3digo del lenguaje",
long_desc:"V\u00EDnculo para descripci\u00F3n larga",
style:"Estilos",
classes:"Clases",
ltr:"Izquierda a derecha",
rtl:"Derecha a izquierda",
id:"Id",
map:"Mapa de imagen",
swap_image:"Intercambiar imagen",
alt_image:"Imagen alternativa",
mouseover:"para mouseover",
mouseout:"para mouseout",
misc:"Miscel\u00E1neo",
example_img:"Vista previa de la imagen",
missing_alt:" \u00BFEsta seguro de continuar sin introducir una descripci\u00F3n a la imagen? Sin ella puede no ser accesible para usuarios con discapacidades, o para aquellos que usen navegadores de modo texto, o tengan deshabilitadas las im\u00E1genes de la p\u00E1gina.",
dialog_title:"Insertar/editar imagen",
src:"URL de la imagen",
alt:"Descripci\u00F3n de la imagen",
list:"Lista de imagen",
border:"Bordes",
dimensions:"Dimensiones",
vspace:"Espacio vertical",
hspace:"Espacio horizontal",
align:"Alineaci\u00F3n",
align_baseline:"L\u00EDnea base",
align_top:"Arriba",
align_middle:"Medio",
align_bottom:"Debajo",
align_texttop:"Texto arriba",
align_textbottom:"Texto abajo",
align_left:"Izquierda",
align_right:"Derecha",
image_list:"Lista de imagen"
});