.panel_wrapper {height:85px;}
.panel_wrapper div.current {height:85px;}

/* IE */
* html .panel_wrapper {height:100px;}
* html .panel_wrapper div.current {height:100px;}

#replace_panel { display: none; }
