tinyMCE.addI18n('ca.emotions_dlg',{
title:"Insereix una emoticona",
desc:"Emoticones",
cool:"Guai",
cry:"Plorant",
embarassed:"Avergonyit",
foot_in_mouth:"Amb un peu a la boca",
frown:"Arrufant les celles",
innocent:"Innocent",
kiss:"Pet\u00F3",
laughing:"Rient",
money_mouth:"Amb fam de diners",
sealed:"Censurat",
smile:"Somriure",
surprised:"Sorpr\u00E8s",
tongue_out:"Llengua a fora",
undecided:"Indec\u00EDs",
wink:"Fent l\'ullet",
yell:"Cridant"
});