tinyMCE.addI18n('sr.advanced',{
style_select:"Stilovi",
font_size:"Veli\u010Dina pisma",
fontdefault:"Vrsta pisma",
block:"Format",
paragraph:"Paragraf",
div:"Div",
address:"Adresa",
pre:"Oblikovano",
h1:"Naslov 1",
h2:"Naslov 2",
h3:"Naslov 3",
h4:"Naslov 4",
h5:"Naslov 5",
h6:"Naslov 6",
blockquote:"Citat",
code:"Kod",
samp:"Primjer koda",
dt:"Definicija pojma",
dd:"Opis definicije",
bold_desc:"Podebljaj (Ctrl+B)",
italic_desc:"Iskosi (Ctrl+I)",
underline_desc:"Podcrtaj (Ctrl+U)",
striketrough_desc:"Precrtaj",
justifyleft_desc:"Poravnaj levo",
justifycenter_desc:"Centriraj",
justifyright_desc:"Poravnaj desno",
justifyfull_desc:"Poravnaj potpuno",
bullist_desc:"Neure\u0111ena lista",
numlist_desc:"Ure\u0111ena lista",
outdent_desc:"Uvuci",
indent_desc:"Izvuci",
undo_desc:"Poni\u0161ti (Ctrl+Z)",
redo_desc:"Ponovi (Ctrl+Y)",
link_desc:"Ubaci/promijeni link",
unlink_desc:"Poni\u0161ti link",
image_desc:"Umetni/uredi sliku",
cleanup_desc:"Po\u010Disti kod",
code_desc:"Uredi HTML izvor",
sub_desc:"Indeks",
sup_desc:"Eksponent",
hr_desc:"Umetni vodoravnu crtu",
removeformat_desc:"Poni\u0161ti oblikovanje",
custom1_desc:"Vlastiti opis ovdje",
forecolor_desc:"Odaberite boju teksta",
backcolor_desc:"Odaberite boju pozadine",
charmap_desc:"Umetni vlastiti znak",
visualaid_desc:"Vodilice/nevidljivi elementi",
anchor_desc:"Umetni/uredi sidro",
cut_desc:"Izre\u017Ei",
copy_desc:"Kopiraj",
paste_desc:"Zalepi",
image_props_desc:"Svojstva slike",
newdocument_desc:"Novi dokument",
help_desc:"Pomo\u0107",
blockquote_desc:"Citiraj",
clipboard_msg:"Kopiraj/Izre\u017Ei/Zalepi nije dostupno u Mozilla i Firefox preglednicima. Vi\u0161e informacija?",
path:"Staza",
newdocument:"Jeste li sigurni da \u017Eelite izbrisati celi sadr\u017Eaj?",
toolbar_focus:"Pre\u0111i na alatnu traku - Alt+Q, pre\u0111i na ure\u0111iva\u010D - Alt-Z, pre\u0111i na element path - Alt-X",
more_colors:"Vi\u0161e boja"
});