tinyMCE.addI18n('sq.table_dlg',{
general_tab:"T\u00EB p\u00EBrgjithshme",
advanced_tab:"T\u00EB avancuara",
general_props:"Tipare t\u00EB p\u00EBrgjithshme",
advanced_props:"Tipare t\u00EB avancuara",
rowtype:"Rresht n\u00EB",
title:"Fut/Edito tabel\u00EB",
width:"Gjer\u00EBsia",
height:"Gjat\u00EBsia",
cols:"Kolona",
rows:"Rreshta",
cellspacing:"Hap\u00EBsira midis qelizave",
cellpadding:"Hap\u00EBsira e br\u00EBndshme",
border:"Korniza",
align:"Drejtimi",
align_default:"Paracaktuar",
align_left:"Majtas",
align_right:"Djathtas",
align_middle:"Qend\u00EBr",
row_title:"Tiparet e rreshtit",
cell_title:"Tiparet e qeliz\u00EBs",
cell_type:"Tipi i qeliz\u00EBs",
valign:"Drejtimi vertikal",
align_top:"Krye",
align_bottom:"Fund",
bordercolor:"Ngjyra e korniz\u00EBs",
bgcolor:"Ngjyra e fush\u00EBs",
merge_cells_title:"Bashko qelizat",
id:"Id",
style:"Stili",
langdir:"Drejtimi i gjuh\u00EBs",
langcode:"Kodi i gjuh\u00EBs",
mime:"Tipi MIME i sh\u00EBnjestr\u00EBs",
ltr:"Majtas-Djathtas",
rtl:"Djathtas-Majtas",
bgimage:"Foto e fush\u00EBs",
summary:"P\u00EBrmbledhja",
td:"T\u00EB dh\u00EBna",
th:"Kok\u00EB",
cell_cell:"Rifresko qeliz\u00EBn aktuale",
cell_row:"Rifresko t\u00EB gjitha qelizat n\u00EB rresht",
cell_all:"Rifresko t\u00EB gjitha qelizat",
row_row:"Rifresko rreshtin aktual",
row_odd:"Rifresko rreshtat tek",
row_even:"Rifresko rreshtat \u00E7ift",
row_all:"Rifresko t\u00EB gjitha rreshtat n\u00EB tabel\u00EB",
thead:"Kok\u00EBn e Tabel\u00EBs",
tbody:"Trupin e Tabel\u00EBs",
tfoot:"K\u00EBmb\u00EBt e Tabel\u00EBs",
scope:"Objektivi",
rowgroup:"Grup Rreshtash",
colgroup:"Grup Kolonash",
col_limit:"Keni kaluar numrin maksimal t\u00EB kolonave: {$cols}.",
row_limit:"Keni kaluar numrin maksimal t\u00EB rreshtave: {$rows}.",
cell_limit:"Keni kaluar numrin maksimal t\u00EB qelizave {$cells}.",
missing_scope:"Jeni t\u00EB sigurt q\u00EB nuk doni t\u00EB vendosni objektiv p\u00EBr k\u00EBt\u00EB qeliz\u00EB t\u00EB kok\u00EBs. Pa t\u00EB mund t\u00EB jet\u00EB e v\u00EBshtir\u00EB p\u00EBr disa p\u00EBrdorues me aft\u00EBsi t\u00EB kufizuara t\u00EB lexojn\u00EB p\u00EBrmbajtjen e tabel\u00EBs.",
caption:"Krijo hap\u00EBsir\u00EB p\u00EBr titull",
frame:"Korniza",
frame_none:"asnj\u00EB",
frame_groups:"grupe",
frame_rows:"rreshta",
frame_cols:"kolona",
frame_all:"t\u00EB gjitha",
rules:"Rregullat",
rules_void:"zbrazur",
rules_above:"sip\u00EBr",
rules_below:"posht\u00EB",
rules_hsides:"hsides",
rules_lhs:"lhs",
rules_rhs:"rhs",
rules_vsides:"vsides",
rules_box:"kuti",
rules_border:"korniz\u00EB"
});