tinyMCE.addI18n({fr:{
common:{
edit_confirm:"Souhaitez-vous utiliser le mode WYSIWYG pour cette zone de texte ?",
apply:"Appliquer",
insert:"Ins\u00E9rer",
update:"Mettre \u00E0 jour",
cancel:"Annuler",
close:"Fermer",
browse:"parcourir",
class_name:"Classe",
not_set:"-- non d\u00E9fini --",
clipboard_msg:"Les fonctions Copier/Couper/Coller ne sont pas valables sur Mozilla et Firefox.\nSouhaitez-vous avoir plus d'informations sur ce sujet ?",
clipboard_no_support:"Actuellement non support\u00E9 par votre navigateur.\n Veuillez utiliser les raccourcis clavier \u00E0 la place.",
popup_blocked:"D\u00E9sol\u00E9, nous avons d\u00E9tect\u00E9 que votre bloqueur de popup a bloqu\u00E9 une fen\u00EAtre dont l'application a besoin. Vous devez d\u00E9sactiver votre bloqueur de popup pour pouvoir utiliser cet outil.",
invalid_data:"Erreur : saisie de valeurs incorrectes. Elles sont mises en \u00E9vidence en rouge.",
more_colors:"Plus de couleurs"
},
contextmenu:{
align:"Alignement",
left:"Gauche",
center:"Centr\u00E9",
right:"Droite",
full:"Justifi\u00E9"
},
insertdatetime:{
date_fmt:"%d-%m-%Y",
time_fmt:"%H:%M:%S",
insertdate_desc:"Ins\u00E9rer la date",
inserttime_desc:"Ins\u00E9rer l'heure",
months_long:"Janvier,F\u00E9vrier,Mars,Avril,Mai,Juin,Juillet,Ao\u00FBt,Septembre,Octobre,Novembre,D\u00E9cembre",
months_short:"Jan,F\u00E9v,Mar,Avr,Mai,Juin,Juil,Ao\u00FBt,Sep,Oct,Nov,D\u00E9c",
day_long:"Dimanche,Lundi,Mardi,Mercredi,Jeudi,Vendredi,Samedi,Dimanche",
day_short:"Dim,Lun,Mar,Mer,Jeu,Ven,Sam,Dim"
},
print:{
print_desc:"Imprimer"
},
preview:{
preview_desc:"Pr\u00E9visualiser"
},
directionality:{
ltr_desc:"\u00C9criture de gauche \u00E0 droite",
rtl_desc:"\u00C9criture de droite \u00E0 gauche"
},
layer:{
insertlayer_desc:"Ins\u00E9rer une nouvelle couche",
forward_desc:"D\u00E9placer vers l'avant",
backward_desc:"D\u00E9placer vers l'arri\u00E8re",
absolute_desc:"Activer le positionnement absolu",
content:"Nouvelle couche\u2026"
},
save:{
save_desc:"Enregistrer",
cancel_desc:"Annuler toutes les modifications"
},
nonbreaking:{
nonbreaking_desc:"Ins\u00E9rer une espace ins\u00E9cable"
},
iespell:{
iespell_desc:"Lancer le v\u00E9rificateur d'orthographe",
download:"ieSpell n'est pas install\u00E9. Souhaitez-vous l'installer maintenant ?"
},
advhr:{
advhr_desc:"Ins\u00E9rer un trait horizontal"
},
emotions:{
emotions_desc:"\u00C9motic\u00F4nes"
},
searchreplace:{
search_desc:"Rechercher",
replace_desc:"Rechercher / remplacer"
},
advimage:{
image_desc:"Ins\u00E9rer / \u00E9diter une image"
},
advlink:{
link_desc:"Ins\u00E9rer / \u00E9diter un lien"
},
xhtmlxtras:{
cite_desc:"Citation",
abbr_desc:"Abr\u00E9viation",
acronym_desc:"Acronyme",
del_desc:"Barr\u00E9",
ins_desc:"Ins\u00E9r\u00E9",
attribs_desc:"Ins\u00E9rer / \u00E9diter les attributs"
},
style:{
desc:"\u00C9diter la feuille de style (CSS)"
},
paste:{
paste_text_desc:"Coller comme texte brut",
paste_word_desc:"Coller un texte cr\u00E9\u00E9 sous Word",
selectall_desc:"Tout s\u00E9lectionner",
plaintext_mode_sticky:"Le collage est actuellement en mode texte non format\u00E9. Cliquez \u00E0 nouveau pour revenir en mode de collage ordinaire. Apr\u00E8s avoir coll\u00E9 quelque chose, vous retournerez en mode de collage ordinaire.",
plaintext_mode:"Le collage est actuellement en mode texte non format\u00E9. Cliquez \u00E0 nouveau pour revenir en mode de collage ordinaire."
},
paste_dlg:{
text_title:"Utilisez CTRL+V sur votre clavier pour coller le texte dans la fen\u00EAtre.",
text_linebreaks:"Conserver les retours \u00E0 la ligne",
word_title:"Utilisez CTRL+V sur votre clavier pour coller le texte dans la fen\u00EAtre."
},
table:{
desc:"Ins\u00E9rer un nouveau tableau",
row_before_desc:"Ins\u00E9rer une ligne avant",
row_after_desc:"Ins\u00E9rer une ligne apr\u00E8s",
delete_row_desc:"Effacer la ligne",
col_before_desc:"Ins\u00E9rer une colonne avant",
col_after_desc:"Ins\u00E9rer une colonne apr\u00E8s",
delete_col_desc:"Effacer la colonne",
split_cells_desc:"Scinder les cellules fusionn\u00E9es",
merge_cells_desc:"Fusionner les cellules",
row_desc:"Propri\u00E9t\u00E9s de la ligne",
cell_desc:"Propri\u00E9t\u00E9s de la cellule",
props_desc:"Propri\u00E9t\u00E9s du tableau",
paste_row_before_desc:"Coller la ligne avant",
paste_row_after_desc:"Coller la ligne apr\u00E8s",
cut_row_desc:"Couper la ligne",
copy_row_desc:"Copier la ligne",
del:"Effacer le tableau",
row:"Ligne",
col:"Colonne",
cell:"Cellule"
},
autosave:{
unload_msg:"Les modifications apport\u00E9es seront perdus si vous quittez cette page.",
restore_content:"Restaurer le contenu auto-sauvegard\u00E9.",
warning_message:"Si vous restaurez le contenu sauv\u00E9, vous perdrez le contenu qui est actuellement dans l'\u00E9diteur.\n\n\u00CAtes-vous s\u00FBr de vouloir restaurer le contenu sauv\u00E9 ?"
},
fullscreen:{
desc:"Passer en mode plein \u00E9cran"
},
media:{
desc:"Ins\u00E9rer / \u00E9diter un m\u00E9dia incorpor\u00E9",
edit:"\u00C9diter un m\u00E9dia incorpor\u00E9"
},
fullpage:{
desc:"Propri\u00E9t\u00E9s du document"
},
template:{
desc:"Ins\u00E9rer un mod\u00E8le pr\u00E9d\u00E9fini."
},
visualchars:{
desc:"Activer les caract\u00E8res de mise en page."
},
spellchecker:{
desc:"Activer le v\u00E9rificateur d'orthographe",
menu:"Param\u00E8tres du v\u00E9rificateur d'orthographe",
ignore_word:"Ignorer le mot",
ignore_words:"Tout ignorer",
langs:"Langues",
wait:"Veuillez patienter\u2026",
sug:"Suggestions",
no_sug:"Aucune suggestion",
no_mpell:"Aucune erreur trouv\u00E9e."
},
pagebreak:{
desc:"Ins\u00E9rer un saut de page."
},
advlist:{
types:"Types",
def:"Defaut",
lower_alpha:"Alpha minuscule",
lower_greek:"Grec minuscule",
lower_roman:"Romain minuscule",
upper_alpha:"Alpha majuscule",
upper_roman:"Romain majuscule",
circle:"Cercle",
disc:"Disque",
square:"Carr\u00E9"
}}});