tinyMCE.addI18n('vi.advimage_dlg',{
tab_general:"Chung",
tab_appearance:"Xu\u1EA5t hi\u1EC7n",
tab_advanced:"N\u00E2ng cao",
general:"Chung",
title:"Ti\u00EAu \u0111\u1EC1",
preview:"Xem tr\u01B0\u1EDBc",
constrain_proportions:"R\u00E0ng bu\u1ED9c t\u1EC9 l\u1EC7",
langdir:"H\u01B0\u1EDBng ng\u00F4n ng\u1EEF",
langcode:"M\u00E3 ng\u00F4n ng\u1EEF",
long_desc:"Li\u00EAn k\u1EBFt m\u00F4 t\u1EA3 d\u00E0i",
style:"Ki\u1EC3u d\u00E1ng",
classes:"L\u1EDBp",
ltr:"Tr\u00E1i qua ph\u1EA3i",
rtl:"Ph\u1EA3i qua tr\u00E1i",
id:"Id",
map:"S\u01A1 \u0111\u1ED3 \u1EA3nh",
swap_image:"Trao \u0111\u1ED5i \u1EA3nh",
alt_image:"\u1EA2nh thay th\u1EBF",
mouseover:"cho chu\u1ED9t l\u00EAn",
mouseout:"cho chu\u1ED9t ra",
misc:"Linh tinh",
example_img:"Hi\u1EC3n th\u1ECB h\u00ECnh \u1EA3nh xem tr\u01B0\u1EDBc",
missing_alt:"B\u1EA1n c\u00F3 ch\u1EAFc ch\u1EAFn mu\u1ED1n ti\u1EBFp t\u1EE5c m\u00E0 kh\u00F4ng bao g\u1ED3m m\u1ED9t m\u00F4 t\u1EA3 h\u00ECnh \u1EA3nh? Kh\u00F4ng c\u00F3 n\u00F3 h\u00ECnh \u1EA3nh kh\u00F4ng th\u1EC3 truy c\u1EADp t\u1EDBi m\u1ED9t s\u1ED1 ng\u01B0\u1EDDi d\u00F9ng t\u00E0n t\u1EADt, ho\u1EB7c t\u1EDBi nh\u1EEFng ng\u01B0\u1EDDi s\u1EED d\u1EE5ng tr\u00ECnh duy\u1EC7t v\u0103n b\u1EA3n, h\u1EB7c duy\u1EC7t Web m\u00E0 kh\u00F4ng cho hi\u1EC3n th\u1ECB h\u00ECnh \u1EA3nh.",
dialog_title:"Ch\u00E8n/s\u1EEDa \u1EA3nh",
src:"URL \u1EA3nh",
alt:"M\u00F4 t\u1EA3 \u1EA3nh",
list:"Danh s\u00E1ch \u1EA3nh",
border:"Vi\u1EC1n",
dimensions:"K\u00EDch th\u01B0\u1EDBc",
vspace:"Kho\u1EA3ng c\u00E1ch d\u1ECDc",
hspace:"Kho\u1EA3ng c\u00E1ch ngang",
align:"Canh l\u1EC1",
align_baseline:"D\u00F2ng c\u01A1 s\u1EDF",
align_top:"Tr\u00EAn c\u00F9ng",
align_middle:"Gi\u1EEFa",
align_bottom:"D\u01B0\u1EDBi c\u00F9ng",
align_texttop:"V\u0103n b\u1EA3n tr\u00EAn c\u00F9ng",
align_textbottom:"V\u0103n b\u1EA3n d\u01B0\u1EDBi c\u00F9ng",
align_left:"Tr\u00E1i",
align_right:"Ph\u1EA3i",
image_list:"Danh s\u00E1ch \u1EA3nh"
});