tinyMCE.addI18n('fr.table_dlg',{
general_tab:"G\u00E9n\u00E9ral",
advanced_tab:"Avanc\u00E9",
general_props:"Propri\u00E9t\u00E9s g\u00E9n\u00E9rales",
advanced_props:"Propri\u00E9t\u00E9s avanc\u00E9es",
rowtype:"Type de ligne",
title:"Ins\u00E9rer / modifier un tableau",
width:"Largeur",
height:"Hauteur",
cols:"Colonnes",
rows:"Lignes",
cellspacing:"Espacement entre les cellules",
cellpadding:"Espacement dans les cellules",
border:"Bordure",
align:"Alignement",
align_default:"Par d\u00E9faut",
align_left:"Gauche",
align_right:"Droite",
align_middle:"Centr\u00E9",
row_title:"Propri\u00E9t\u00E9s de la ligne",
cell_title:"Propri\u00E9t\u00E9s de la cellule",
cell_type:"Type de cellule",
valign:"Alignement vertical",
align_top:"Haut",
align_bottom:"Bas",
bordercolor:"Couleur de la bordure",
bgcolor:"Couleur du fond",
merge_cells_title:"Fusionner les cellules",
id:"Id",
style:"Style",
langdir:"Sens de lecture",
langcode:"Code de la langue",
mime:"Type MIME de la cible",
ltr:"De gauche \u00E0 droite",
rtl:"de droite \u00E0 gauche",
bgimage:"Image de fond",
summary:"R\u00E9sum\u00E9",
td:"Donn\u00E9es",
th:"Titre",
cell_cell:"Mettre \u00E0 jour la cellule courante",
cell_row:"Mettre \u00E0 jour toutes les cellules de la ligne",
cell_all:"Mettre \u00E0 jour toutes les cellules du tableau",
row_row:"Mettre \u00E0 jour la ligne courante",
row_odd:"Mettre \u00E0 jour les lignes impaires",
row_even:"Mettre \u00E0 jour les lignes paires",
row_all:"Mettre \u00E0 jour toutes les lignes du tableau",
thead:"En-t\u00EAtes de tableau",
tbody:"Corps de tableau",
tfoot:"Pied de tableau",
scope:"Port\u00E9e",
rowgroup:"Groupe de lignes",
colgroup:"Groupe de colonnes",
col_limit:"Vous avez d\u00E9pass\u00E9 le nombre maximum de colonnes ({$cols}).",
row_limit:"Vous avez d\u00E9pass\u00E9 le nombre maximum de lignes ({$rows}).",
cell_limit:"Vous avez d\u00E9pass\u00E9 le nombre maximum de cellules ({$cells}).",
missing_scope:"\u00CAtes-vous s\u00FBr de vouloir continuer sans sp\u00E9cifier de port\u00E9e pour cette cellule de titre ? Sans port\u00E9e, cela peut \u00EAtre difficile pour certains utilisateurs de comprendre le contenu ou les donn\u00E9es affich\u00E9es dans le tableau.",
caption:"Afficher la l\u00E9gende du tableau",
frame:"Cadre",
frame_none:"aucun",
frame_groups:"groupe",
frame_rows:"lignes",
frame_cols:"colonnes",
frame_all:"tous",
rules:"R\u00E8gles",
rules_void:"aucune",
rules_above:"au-dessus",
rules_below:"au-dessous",
rules_hsides:"horizontales",
rules_lhs:"\u00E0 gauche",
rules_rhs:"\u00E0 droite",
rules_vsides:"verticales",
rules_box:"bo\u00EEte",
rules_border:"bordure"
});