tinyMCE.addI18n('ca.xhtmlxtras_dlg',{
attribute_label_title:"T\u00EDtol",
attribute_label_id:"ID",
attribute_label_class:"Classe",
attribute_label_style:"Estil",
attribute_label_cite:"Cita",
attribute_label_datetime:"Data/Hora",
attribute_label_langdir:"Direcci\u00F3 del text",
attribute_option_ltr:"D\'esquerra a dreta",
attribute_option_rtl:"De dreta a esquerra",
attribute_label_langcode:"Idioma",
attribute_label_tabindex:"TabIndex",
attribute_label_accesskey:"AccessKey",
attribute_events_tab:"Esdeveniments",
attribute_attrib_tab:"Atributs",
general_tab:"General",
attrib_tab:"Atributs",
events_tab:"Esdeveniments",
fieldset_general_tab:"Configuraci\u00F3 general",
fieldset_attrib_tab:"Atributs d\'element",
fieldset_events_tab:"Esdeveniments d\'element",
title_ins_element:"Element d\'inserci\u00F3",
title_del_element:"Element d\'eliminaci\u00F3",
title_acronym_element:"Element d\'acr\u00F2nim",
title_abbr_element:"Element d\'abreviatura",
title_cite_element:"Element de menci\u00F3",
remove:"Elimina",
insert_date:"Insereix la data/hora actuals",
option_ltr:"D\'esquerra a dreta",
option_rtl:"De dreta a esquerra",
attribs_title:"Insereix/Edita atributs"
});