tinyMCE.addI18n('sl.emotions_dlg',{
title:"Vstavi sme\u0161ka",
desc:"Sme\u0161ki",
cool:"kul",
cry:"jok",
embarassed:"v zadregi",
foot_in_mouth:"zare\u010Deni kruh",
frown:"nagubano \u010Delo",
innocent:"nedol\u017Een",
kiss:"poljub",
laughing:"smeh",
money_mouth:"zlati kljun",
sealed:"zape\u010Dateno",
smile:"nasmeh",
surprised:"presene\u010Den",
tongue_out:"ka\u017Ee jezik",
undecided:"neodlo\u010Den",
wink:"me\u017Eik",
yell:"krik"
});