tinyMCE.addI18n('id.xhtmlxtras_dlg',{
attribute_label_title:"Judul",
attribute_label_id:"ID",
attribute_label_class:"Class",
attribute_label_style:"Style",
attribute_label_cite:"Kutip",
attribute_label_datetime:"Tanggal/waktu",
attribute_label_langdir:"Arah Text",
attribute_option_ltr:"Kiri ke kanan",
attribute_option_rtl:"Kanan ke kiri",
attribute_label_langcode:"Bahasa",
attribute_label_tabindex:"TabIndex",
attribute_label_accesskey:"AccessKey",
attribute_events_tab:"Events",
attribute_attrib_tab:"Atribut",
general_tab:"Umum",
attrib_tab:"Atribut",
events_tab:"Events",
fieldset_general_tab:"Pengaturan Umum",
fieldset_attrib_tab:"Atribut Element",
fieldset_events_tab:"Element Events",
title_ins_element:"Elemen Penyisipak",
title_del_element:"Elemen penghapusan",
title_acronym_element:"Elemen Akronim",
title_abbr_element:"Elemen Singkatan",
title_cite_element:"Elemen Kutipan",
remove:"Hapus",
insert_date:"Sisipkan tanggal/waktu sekarang",
option_ltr:"Kiri ke kanan",
option_rtl:"Kanan ke kiri",
attribs_title:"Sisipkan/Ubah atribut"
});