tinyMCE.addI18n('sl.advimage_dlg',{
tab_general:"Splo\u0161no",
tab_appearance:"Izgled",
tab_advanced:"Napredno",
general:"Splo\u0161no",
title:"Naslov",
preview:"Predogled",
constrain_proportions:"Zakleni razmerje",
langdir:"Smer jezika",
langcode:"Koda jezika",
long_desc:"Povezava do opisa",
style:"Slog",
classes:"Razredi",
ltr:"Od leve proti desni",
rtl:"Od desne proti levi",
id:"Id",
map:"Karta slike",
swap_image:"Zamenjava slike",
alt_image:"Nadomestna slika",
mouseover:"pri mi\u0161ki nad",
mouseout:"pri mi\u0161ki izven",
misc:"Razno",
example_img:"Predogled izgleda",
missing_alt:"Zares \u017Eelite nadaljevati, brez da bi dolo\u010Dili opis slike? Brez njega slika nekaterim uporabnikom ne bo na voljo (izklopljen prikaz slik, tekstni brskalnik ali ljudje s slab\u0161im vidom).",
dialog_title:"Vstavi/uredi sliko",
src:"Naslov URL slike",
alt:"Opis slike",
list:"Seznam slik",
border:"Obroba",
dimensions:"Dimenzije",
vspace:"Prostor zg/sp",
hspace:"Prostor le/de",
align:"Poravnava",
align_baseline:"osnovna \u010Drta",
align_top:"vrh",
align_middle:"sredina",
align_bottom:"dno",
align_texttop:"vrh besedila",
align_textbottom:"dno besedila",
align_left:"levo, plavajo\u010De",
align_right:"desno, plavajo\u010De",
image_list:"Seznam slik"
});