tinyMCE.addI18n('hu.advimage_dlg',{
tab_general:"\u00C1ltal\u00E1nos",
tab_appearance:"Megjelen\u00E9s",
tab_advanced:"Halad\u00F3",
general:"\u00C1ltal\u00E1nos",
title:"C\u00EDm",
preview:"El\u0151n\u00E9zet",
constrain_proportions:"Ar\u00E1nytart\u00E1s",
langdir:"Nyelv \u00EDr\u00E1s ir\u00E1ny",
langcode:"Nyelv k\u00F3d",
long_desc:"B\u0151vebb le\u00EDr\u00E1s link",
style:"Style",
classes:"Class-ok",
ltr:"Balr\u00F3l jobbra",
rtl:"Jobbr\u00F3l balra",
id:"Id",
map:"K\u00E9p t\u00E9rk\u00E9p",
swap_image:"K\u00E9pcsere",
alt_image:"Alternat\u00EDv k\u00E9p",
mouseover:"K\u00E9p az eg\u00E9rkurzor f\u00F6l\u00E9vitelekor",
mouseout:"K\u00E9p az eg\u00E9rkurzor lev\u00E9telekor",
misc:"Vegyes",
example_img:"El\u0151n\u00E9zeti k\u00E9p",
missing_alt:"Biztosan folytatja helyettes\u00EDt\u0151 sz\u00F6veg n\u00E9lk\u00FCl? En\u00E9lk\u00FCl a korl\u00E1toz\u00E1ssal \u00E9l\u0151k, sz\u00F6veges b\u00F6ng\u00E9sz\u0151t haszn\u00E1l\u00F3k \u00E9s a k\u00E9pek megjelen\u00EDt\u00E9s\u00E9t letilt\u00F3 felhaszn\u00E1l\u00F3k h\u00E1tr\u00E1nyban lesznek.",
dialog_title:"K\u00E9p besz\u00FAr\u00E1s/szerkeszt\u00E9s",
src:"K\u00E9p URL",
alt:"K\u00E9p helyettes\u00EDt\u0151 sz\u00F6vege",
list:"K\u00E9plista",
border:"Keret",
dimensions:"Dimenzi\u00F3k",
vspace:"F\u00FCgg\u0151leges t\u00E1vols\u00E1g",
hspace:"V\u00EDzszintes t\u00E1vols\u00E1g",
align:"Igaz\u00EDt\u00E1s",
align_baseline:"Alapvonalhoz",
align_top:"Fentre",
align_middle:"K\u00F6z\u00E9pre",
align_bottom:"Lentre",
align_texttop:"Sz\u00F6veg tetej\u00E9hez",
align_textbottom:"Sz\u00F6veg alj\u00E1hoz",
align_left:"Balra",
align_right:"Jobbra",
image_list:"K\u00E9plista"
});