tinyMCE.addI18n('cy.media_dlg',{
title:"Mewnosod / golygu cyfrwng planedig",
general:"Cyffredinol",
advanced:"Uwch",
file:"Ffeil/URL",
list:"Rhestr",
size:"Dimensiynau",
preview:"Rhagolygu",
constrain_proportions:"Cynfyngu cyfraneddau",
type:"Math",
id:"Id",
name:"Enw",
class_name:"Dosbarth",
vspace:"Gofod fertigol",
hspace:"Gofod llorweddol",
play:"Awto-chwarae",
loop:"Dolen",
menu:"Dangos dewislen",
quality:"Ansawdd",
scale:"Gradd",
align:"Alinio",
salign:"Alinio-S",
wmode:"Modd-W",
bgcolor:"Cefndir",
base:"Sail",
flashvars:"Flashvars",
liveconnect:"SWLiveConnect",
autohref:"AutoHREF",
cache:"Storfa",
hidden:"Wedi'i cuddio",
controller:"Rheolydd",
kioskmode:"Modd ciosk",
playeveryframe:"Chwarae pob ffr\u00E2m",
targetcache:"Storfa targed",
correction:"Dim cywiriad",
enablejavascript:"Galluogi JavaScript",
starttime:"Amser dechrae",
endtime:"Amser gorffen",
href:"Href",
qtsrcchokespeed:"Tagu cyflymder",
target:"Targed",
volume:"Cyfrol",
autostart:"Awto-cychwyn",
enabled:"Wedi'i galluogi",
fullscreen:"Sgrin llawn",
invokeurls:"Defnyddio URLs",
mute:"Mudo",
stretchtofit:"Ymestun i ffitio",
windowlessvideo:"Fideo heb-ffenest",
balance:"Cydbwysedd",
baseurl:"URL seiledig",
captioningid:"Id egluro",
currentmarker:"Marciwr cyfredol",
currentposition:"Lleoliad cyfredol",
defaultframe:"Ffr\u00E2m rhagosodedig",
playcount:"Cyfrif chwarae",
rate:"Cyfradd",
uimode:"Modd UI",
flash_options:"Dewisiadau Flash",
qt_options:"Dewisiadau Quicktime",
wmp_options:"Dewisiadau Windows Media Player",
rmp_options:"Dewisiadau Real Media Player",
shockwave_options:"Dewisiadau Shockwave",
autogotourl:"URL awto-mynd-i",
center:"Canol",
imagestatus:"Statws delwedd",
maintainaspect:"Cynnal agwedd",
nojava:"Dim java",
prefetch:"Cyn-n\u00F4l",
shuffle:"Cymysgu",
console:"Consol",
numloop:"Nifer o dolenau",
controls:"Rheolyddion",
scriptcallbacks:"N\u00F4l-galwadau sgript",
swstretchstyle:"Arddull ymestyn",
swstretchhalign:"Aliniad llorweddol ymestyn",
swstretchvalign:"Aliniad fertigol ymestyn",
sound:"Sain",
progress:"Cynnydd",
qtsrc:"Fynhonell QT",
qt_stream_warn:"Dylai adnoddau RTSP ffrydio cael eu ychwanegu i'r maes Fynhonell QT o dan y tab Uwch.\n Dylai chi hefyd ychwanegu fersiwn heb-ffrydio i'r maes Fynhonell.",
align_top:"Pen",
align_right:"De",
align_bottom:"Gwaelod",
align_left:"Chwith",
align_center:"Canol",
align_top_left:"Pen canol",
align_top_right:"Pen dde",
align_bottom_left:"Gwaelod chwith",
align_bottom_right:"Gwaelod dde",
flv_options:"Dewisiadau fideo Flash",
flv_scalemode:"Modd graddfa",
flv_buffer:"Buffer",
flv_startimage:"Delwedd cychwyn",
flv_starttime:"Amser cychwyn",
flv_defaultvolume:"Cyfrol rhagosodedig",
flv_hiddengui:"GUI wedi'i cuddio",
flv_autostart:"Awto-cychwyn",
flv_loop:"Doleni",
flv_showscalemodes:"Dangos moddau graddfa",
flv_smoothvideo:"Fideo llyfn",
flv_jscallback:"N\u00F4l-galwad JS"
});