tinyMCE.addI18n({no:{
common:{
edit_confirm:"Vil du bruke WYSIWYG-editoren for dette tekstfeltet?",
apply:"Legg til",
insert:"Sett inn",
update:"Oppdater",
cancel:"Avbryt",
close:"Stopp",
browse:"Bla gjennom",
class_name:"Klasse",
not_set:"--ikke sett--",
clipboard_msg:"Klipp ut / Kopier /Lim inn fungerer ikke i Mozilla og Firefox. Vil du vite mer om dette?",
clipboard_no_support:"For tiden ikke st\u00F8ttet av nettleseren din, bruk tastatursnarveier i stedet.",
popup_blocked:"Beklager, det er registrert at du har popup-sperre aktivert i nettleseren. Du m\u00E5 oppheve popup-sperren for nettstedet for \u00E5 f\u00E5 tilgang til dette verkt\u00F8yet",
invalid_data:"Feil: Ugyldige verdier er skrevet inn, disse er merket med r\u00F8dt",
more_colors:"Flere farger"
},
contextmenu:{
align:"Justering",
left:"Venstre",
center:"Midtstill",
right:"H\u00F8yre",
full:"Full"
},
insertdatetime:{
date_fmt:"%d-%m-%Y",
time_fmt:"%H:%M:%S",
insertdate_desc:"Lim inn dato",
inserttime_desc:"Lim inn tid",
months_long:"januar,februar,mars,april,mai,juni,juli,august,september,oktober,november,desember",
months_short:"jan,feb,mar,apr,mai,jun,jul,aug,sep,oct,nov,des",
day_long:"s\u00F8ndag,mandag,tirsdag,onsdag,torsdag,fredag,l\u00F8rdag,s\u00F8ndag",
day_short:"s\u00F8n,man,tir,ons,tor,fre,l\u00F8r,s\u00F8n"
},
print:{
print_desc:"Skriv ut"
},
preview:{
preview_desc:"Forh\u00E5ndsvisning"
},
directionality:{
ltr_desc:"Retning venstre mot h\u00F8yre",
rtl_desc:"Retning h\u00F8yre mot venstre"
},
layer:{
insertlayer_desc:"Sett inn nytt lag",
forward_desc:"Flytt framover",
backward_desc:"Flytt bakover",
absolute_desc:"Sl\u00E5 p\u00E5/av absolutt plassering",
content:"Nytt lag..."
},
save:{
save_desc:"Lagre",
cancel_desc:"Kanseller alle endringer"
},
nonbreaking:{
nonbreaking_desc:"Sett inn hardt mellomrom"
},
iespell:{
iespell_desc:"Kontroller rettskriving",
download:"ieSpell ikke funnet. \u00D8nsker du \u00E5 installere ieSpell?"
},
advhr:{
advhr_desc:"Horisontal linje"
},
emotions:{
emotions_desc:"Hum\u00F8rfjes"
},
searchreplace:{
search_desc:"S\u00F8k",
replace_desc:"S\u00F8k/Erstatt"
},
advimage:{
image_desc:"Sett inn / endre bilde"
},
advlink:{
link_desc:"Sett inn / endre lenke"
},
xhtmlxtras:{
cite_desc:"Sitat",
abbr_desc:"Forkortning",
acronym_desc:"Akronym",
del_desc:"Sletting",
ins_desc:"Innsetting",
attribs_desc:"Sett inn / Endre egenskaper"
},
style:{
desc:"Rediger CSS-stil"
},
paste:{
paste_text_desc:"Lim inn som vanlig tekst",
paste_word_desc:"Lim inn fra Word",
selectall_desc:"Marker alt",
plaintext_mode_sticky:"Paste is now in plain text mode. Click again to toggle back to regular paste mode. After you paste something you will be returned to regular paste mode.",
plaintext_mode:"Paste is now in plain text mode. Click again to toggle back to regular paste mode."
},
paste_dlg:{
text_title:"Bruk CTRL+V p\u00E5 tastaturet for \u00E5 lime inn i dette vinduet.",
text_linebreaks:"Behold tekstbryting",
word_title:"Bruk CTRL+V p\u00E5 tastaturet for \u00E5 lime inn i dette vinduet."
},
table:{
desc:"Sett inn en ny tabell",
row_before_desc:"Sett inn rad framfor",
row_after_desc:"Sett inn rad etter",
delete_row_desc:"Fjern rad",
col_before_desc:"Sett inn kolonne framfor",
col_after_desc:"Sett inn kolonne etter",
delete_col_desc:"Fjern kolonne",
split_cells_desc:"Del celler",
merge_cells_desc:"Sl\u00E5 sammen celler",
row_desc:"Radegenskaper",
cell_desc:"Celleegenskaper",
props_desc:"Tabellegenskaper",
paste_row_before_desc:"Lim inn rad framfor",
paste_row_after_desc:"Lim inn rad etter",
cut_row_desc:"Fjern rad",
copy_row_desc:"Kopier rad",
del:"Slett tabell",
row:"Rad",
col:"Kolonne",
cell:"Celle"
},
autosave:{
unload_msg:"Endringene du gjorde g\u00E5r tapt om du forlater denne siden!",
restore_content:"Restore auto-saved content.",
warning_message:"If you restore the saved content, you will lose all the content that is currently in the editor.\n\nAre you sure you want to restore the saved content?."
},
fullscreen:{
desc:"Skift til/fra fullskjermmodus"
},
media:{
desc:"Sett inn / rediger inkludert objekt",
edit:"Endre innsatt objekt"
},
fullpage:{
desc:"Dokumentegenskaper"
},
template:{
desc:"Sett inn forh\u00E5ndsdefinert malinnhold"
},
visualchars:{
desc:"Visuelle konktrolltegn p\u00E5/av"
},
spellchecker:{
desc:"Stavekontroll p\u00E5/av",
menu:"Vis meny",
ignore_word:"Ignorer ord",
ignore_words:"Ignorer alt",
langs:"Spr\u00E5k",
wait:"Vennligst vent...",
sug:"Framlegg",
no_sug:"Ingen framlegg",
no_mpell:"Ingen stavefeil funnet."
},
pagebreak:{
desc:"Sett inn sideskift"
},
advlist:{
types:"Types",
def:"Default",
lower_alpha:"Lower alpha",
lower_greek:"Lower greek",
lower_roman:"Lower roman",
upper_alpha:"Upper alpha",
upper_roman:"Upper roman",
circle:"Circle",
disc:"Disc",
square:"Square"
}}});