tinyMCE.addI18n('tr.advanced_dlg',{
about_title:"TinyMCE hakk\u0131nda",
about_general:"Hakk\u0131nda",
about_help:"Yard\u0131m",
about_license:"Lisans",
about_plugins:"Eklentiler",
about_plugin:"Eklenti",
about_author:"Yazar",
about_version:"Versiyon",
about_loaded:"Y\u00FCkl\u00FC eklentiler",
anchor_title:"K\u00F6pr\u00FC ekle/d\u00FCzenle",
anchor_name:"K\u00F6pr\u00FC ad\u0131",
code_title:"HTML Kaynak Edit\u00F6r\u00FC",
code_wordwrap:"Kelimeleri birlikte tut",
colorpicker_title:"Renk se\u00E7",
colorpicker_picker_tab:"Se\u00E7ici",
colorpicker_picker_title:"Renk se\u00E7ici",
colorpicker_palette_tab:"Palet",
colorpicker_palette_title:"Renk paleti",
colorpicker_named_tab:"Ad\u0131",
colorpicker_named_title:"Renk ad\u0131",
colorpicker_color:"Renk:",
colorpicker_name:"\u0130sim:",
charmap_title:"\u00D6zel karakter se\u00E7",
image_title:"Resim ekle/d\u00FCzenle",
image_src:"Resmin URL'si",
image_alt:"Resim a\u00E7\u0131klamas\u0131",
image_list:"Resim listesi",
image_border:"Kenarl\u0131k",
image_dimensions:"Boyutlar",
image_vspace:"Dikey bo\u015Fluk",
image_hspace:"Yatay bo\u015Fluk",
image_align:"Hizalama",
image_align_baseline:"Taban hizas\u0131",
image_align_top:"\u00DCst",
image_align_middle:"Orta",
image_align_bottom:"Alt",
image_align_texttop:"Metin \u00FCstte",
image_align_textbottom:"Metin altta",
image_align_left:"Sol",
image_align_right:"Sa\u011F",
link_title:"Ba\u011Flant\u0131 ekle/d\u00FCzenle",
link_url:"Ba\u011Flant\u0131 URL'si",
link_target:"Hedef",
link_target_same:"Ba\u011Flant\u0131y\u0131 ayn\u0131 pencerede a\u00E7",
link_target_blank:"Ba\u011Flant\u0131y\u0131 yeni pencerede a\u00E7",
link_titlefield:"Ba\u015Fl\u0131k",
link_is_email:"Girdi\u011Finiz URL e-posta adresi gibi g\u00F6r\u00FCn\u00FCyor; gerekli olan mailto: \u00F6nekinin eklenmesini ister misiniz? prefix?",
link_is_external:"Girdi\u011Fiz URL d\u0131\u015F ba\u011Flant\u0131 gibi g\u00F6r\u00FCn\u00FCyor; gerekli olan http:// \u00F6nekinin eklenmesini ister misiniz?",
link_list:"Ba\u011Flant\u0131 listesi"
});