tinyMCE.addI18n('br.media_dlg',{
title:"Inserir/Editar m\u00EDdia incorporada",
general:"Geral",
advanced:"Avan\u00E7ado",
file:"Arquivo/URL",
list:"Lista",
size:"Dimens\u00F5es",
preview:"Previs\u00E3o",
constrain_proportions:"Manter propor\u00E7\u00F5es",
type:"Tipo",
id:"Id",
name:"Nome",
class_name:"Classe",
vspace:"Espa\u00E7o vertical",
hspace:"Espa\u00E7o horizontal",
play:"Execu\u00E7\u00E3o autom\u00E1tica",
loop:"Repeti\u00E7\u00E3o autom\u00E1tica",
menu:"Mostrar menu",
quality:"Qualidade",
scale:"Escala",
align:"Alinhamento",
salign:"SAlign",
wmode:"WMode",
bgcolor:"Fundo",
base:"Base",
flashvars:"Flashvars",
liveconnect:"SWLiveConnect",
autohref:"AutoHREF",
cache:"Cache",
hidden:"Oculto",
controller:"Controlador",
kioskmode:"Modo Quiosque",
playeveryframe:"Executar todas as frames",
targetcache:"Cache alvo",
correction:"Sem correc\u00E7\u00F5es",
enablejavascript:"Disponibilizar javaScript",
starttime:"Hora de in\u00EDcio",
endtime:"Hora do fim",
href:"Href",
qtsrcchokespeed:"Choke speed",
target:"Alvo",
volume:"Volume",
autostart:"Execu\u00E7\u00E3o autom\u00E1tica",
enabled:"Activado",
fullscreen:"Ecr\u00E3 inteiro",
invokeurls:"Invocar URLs",
mute:"Mudo",
stretchtofit:"Estender",
windowlessvideo:"V\u00EDdeo sem janela",
balance:"Stereo",
baseurl:"Base URL",
captioningid:"Id de legenda",
currentmarker:"Marcador actual",
currentposition:"Posi\u00E7\u00E3o actual",
defaultframe:"Frame padr\u00E3o",
playcount:"Play count",
rate:"Rate",
uimode:"UI Mode",
flash_options:"Op\u00E7\u00F5es Flash",
qt_options:"Op\u00E7\u00F5es Quicktime",
wmp_options:"Op\u00E7\u00F5es Windows Media Player",
rmp_options:"Op\u00E7\u00F5es Real Media Player",
shockwave_options:"Op\u00E7\u00F5es Shockwave",
autogotourl:"Auto goto URL",
center:"Centro",
imagestatus:"Image status",
maintainaspect:"Maintain aspect",
nojava:"No java",
prefetch:"Prefetch",
shuffle:"Shuffle",
console:"Console",
numloop:"Num loops",
controls:"Controles",
scriptcallbacks:"callbacks de script",
swstretchstyle:"Stretch style",
swstretchhalign:"Stretch H-Align",
swstretchvalign:"Stretch V-Align",
sound:"Som",
progress:"Progresso",
qtsrc:"QT Src",
qt_stream_warn:"Fluxos de recursos rtsp devem ser acrescentados ao campo QT Src no Modo Avan\u00E7ado.\NUma vers\u00E3o sem fluxo tamb\u00E9m deve ser acrescentada ao campo Src.",
align_top:"Topo",
align_right:"Direita",
align_bottom:"Abaixo",
align_left:"Esquerda",
align_center:"Centro",
align_top_left:"Topo \u00E0\u00A0 esquerda",
align_top_right:"Topo \u00E0\u00A0 direita",
align_bottom_left:"Abaixo \u00E0\u00A0 esquerda",
align_bottom_right:"Abaixo \u00E0\u00A0 direita",
flv_options:"Op\u00E7\u00F5es de Flash video",
flv_scalemode:"Modo escala",
flv_buffer:"Buffer",
flv_startimage:"Imagem inicial",
flv_starttime:"Hora inicial",
flv_defaultvolume:"Volume padr\u00E3o",
flv_hiddengui:"GUI oculta",
flv_autostart:"Execu\u00E7\u00E3o Autom\u00E1tica",
flv_loop:"Loop",
flv_showscalemodes:"Mostrar modos escala",
flv_smoothvideo:"Smooth video",
flv_jscallback:"JS callback"
});