tinyMCE.addI18n('lt.table_dlg',{
general_tab:"Bendra",
advanced_tab:"I\u0161pl\u0117sta",
general_props:"Bendri nustatymai",
advanced_props:"I\u0161pl\u0117stiniai nustatymai",
rowtype:"Eilut\u0117 lentel\u0117s dalyje",
title:"\u012Eterpti/modifikuoti lentel\u0119",
width:"Ilgis",
height:"Auk\u0161tis",
cols:"Stulpeliai",
rows:"Eilut\u0117s",
cellspacing:"Tarpas tarp langeli\u0173",
cellpadding:"Tarpas langelio viduje",
border:"R\u0117melis",
align:"Lygiavimas",
align_default:"Standartinis",
align_left:"Lygiuoti kair\u0117je",
align_right:"Lygiuoti de\u0161in\u0117je",
align_middle:"Centruoti",
row_title:"Lentel\u0117s eilut\u0117s nustatymai",
cell_title:"Lentel\u0117s langeli\u0173 nustatymai",
cell_type:"Langelio tipas",
valign:"Vertikalus lygiavimas",
align_top:"Vir\u0161uje",
align_bottom:"Apa\u010Dioje",
bordercolor:"R\u0117melio spalva",
bgcolor:"Fono spalva",
merge_cells_title:"Sujungti lentel\u0117s langelius",
id:"Id",
style:"Stilius",
langdir:"Kalbos kryptis",
langcode:"Kalbos kodas",
mime:"Paskirties MIME tipas",
ltr:"I\u0161 kair\u0117s \u012F de\u0161in\u0119",
rtl:"I\u0161 de\u0161in\u0117s \u012F kair\u0119",
bgimage:"Fono paveiksl\u0117lis",
summary:"Apibendrinimas",
td:"Duomenys",
th:"Antra\u0161t\u0117",
cell_cell:"Atnaujinti dabartin\u012F langel\u012F",
cell_row:"Atnaujinti visus eilut\u0117s langelius",
cell_all:"Atnaujinti visus lentel\u0117s langelius",
row_row:"Atnaujinti dabartin\u0119 eilut\u0119",
row_odd:"Atnaujinti nelygines lentel\u0117s eilutes",
row_even:"Atnaujinti lygines lentel\u0117s eilutes",
row_all:"Atnaujinti visas lentel\u0117s eilutes",
thead:"Lentel\u0117s vir\u0161us",
tbody:"Lentel\u0117s vidus",
tfoot:"Lentel\u0117s apa\u010Dia",
scope:"Galiojimo sritis",
rowgroup:"Eilu\u010Di\u0173 grup\u0117",
colgroup:"Stulpeli\u0173 grup\u0117",
col_limit:"Vir\u0161ijote did\u017Eiausi\u0105 ({$cols}) stulpeli\u0173 kiek\u012F.",
row_limit:"Vir\u0161ijote did\u017Eiausi\u0105 ({$rows}) eilu\u010Di\u0173 kiek\u012F.",
cell_limit:"Vir\u0161ijote did\u017Eiausi\u0105 ({$cells}) langeli\u0173 kiek\u012F.",
missing_scope:"Ar norite t\u0119sti nenurod\u0119 galiojimo srities \u0161iam lentel\u0117s vir\u0161utiniam langeliui. Be nurodymo, kai kuriems naudotojams su negalia gali b\u016Bti sunku suprasti lentel\u0117je atvaizduojam\u0173 duomen\u0173 turin\u012F.",
caption:"Lentel\u0117s antra\u0161t\u0117",
frame:"R\u0117melis",
frame_none:"joks",
frame_groups:"grup\u0117s",
frame_rows:"eilut\u0117s",
frame_cols:"stulpeliai",
frame_all:"visi",
rules:"Taisykl\u0117s",
rules_void:"negaliojantis",
rules_above:"vir\u0161utinis",
rules_below:"apatinis",
rules_hsides:"hor. pus\u0117s",
rules_lhs:"lhs",
rules_rhs:"rhs",
rules_vsides:"vert. pus\u0117s",
rules_box:"d\u0117\u017Eut\u0117",
rules_border:"r\u0117melis"
});