tinyMCE.addI18n('es.table_dlg',{
general_tab:"General",
advanced_tab:"Avanzado",
general_props:"Propiedades generales",
advanced_props:"Propiedades avanzadas",
rowtype:"Tipo de fila",
title:"Insertar/Modificar tabla",
width:"Ancho",
height:"Alto",
cols:"Cols",
rows:"Filas",
cellspacing:"Espaciado de celda",
cellpadding:"Relleno de celda",
border:"Borde",
align:"Alineaci\u00F3n",
align_default:"Predet.",
align_left:"Izquierda",
align_right:"Derecha",
align_middle:"Centrado",
row_title:"Propiedades de la fila",
cell_title:"Propiedades de la celda",
cell_type:"Tipo de celda",
valign:"Alineaci\u00F3n vertical",
align_top:"Arriba",
align_bottom:"Debajo",
bordercolor:"Color del borde",
bgcolor:"Color de fondo",
merge_cells_title:"Vincular celdas",
id:"Id",
style:"Estilo",
langdir:"Direcci\u00F3n del lenguaje",
langcode:"C\u00F3digo del lenguaje",
mime:"Tipo MIME",
ltr:"Izquierda a derecha",
rtl:"Derecha a izquierda",
bgimage:"Imagen de fondo",
summary:"Resumen",
td:"Datos",
th:"Encabezado",
cell_cell:"Actualizar celda actual",
cell_row:"Actualizar todas las celdas en la fila",
cell_all:"Actualizar todas las celdas en la tabla",
row_row:"Actualizar fila actual",
row_odd:"Actualizar filas impares",
row_even:"Actualizar filas pares",
row_all:"Actualizar todas las filas",
thead:"Encabezado de la tabla",
tbody:"Cuerpo de la tabla",
tfoot:"Pie de la tabla",
scope:"Alcance",
rowgroup:"Grupo de filas",
colgroup:"Grupo de columnas",
col_limit:"Ha superado el n\u00FAmero m\u00E1ximo de columnas: {$cols}.",
row_limit:"Ha superado el n\u00FAmero m\u00E1ximo de filas: {$rows}.",
cell_limit:"Ha superado el n\u00FAmero m\u00E1ximo de celdas: {$cells}.",
missing_scope:" \u00BFEst\u00E1 seguro que desea continuar sin especificar el alcance del encabezado de celda? Sin \u00E9l podr\u00EDa ser dificultoso para algunos usuarios entender el contenido o los datos mostrados en la tabla.",
caption:"Subt\u00EDtulo de la tabla",
frame:"Recuadro",
frame_none:"ninguno",
frame_groups:"grupos",
frame_rows:"filas",
frame_cols:"cols",
frame_all:"todos",
rules:"Reglas",
rules_void:"vac\u00EDo",
rules_above:"encima",
rules_below:"debajo",
rules_hsides:"hsides",
rules_lhs:"lhs",
rules_rhs:"rhs",
rules_vsides:"vsides",
rules_box:"box",
rules_border:"border"
});