tinyMCE.addI18n('cy.advanced',{
style_select:"Ardulliau",
font_size:"Maint Ffont",
fontdefault:"Teulu ffont",
block:"Fformat",
paragraph:"Paragraff",
div:"Div",
address:"Cyfeririad",
pre:"Rhagffomatiwyd",
h1:"Pennawd 1",
h2:"Pennawd 2",
h3:"Pennawd 3",
h4:"Pennawd 4",
h5:"Pennawd 5",
h6:"Pennawd 6",
blockquote:"Dyfyniad bloc",
code:"C\u00F4d",
samp:"Sampl c\u00F4d",
dt:"Term diffiniad ",
dd:"Disgrifiad diffiniad",
bold_desc:"Trwm (Ctrl+B)",
italic_desc:"Italig (Ctrl+I)",
underline_desc:"Tanlinellu (Ctrl+U)",
striketrough_desc:"Taro drwodd",
justifyleft_desc:"Alinio i'r chwith",
justifycenter_desc:"Alinio i'r canol",
justifyright_desc:"Alinio i'r dde",
justifyfull_desc:"Alinio llawn",
bullist_desc:"Rhestr didrenus",
numlist_desc:"Rhestr trenus",
outdent_desc:"Alloli",
indent_desc:"Mewnoli",
undo_desc:"Dadwneud (Ctrl+Z)",
redo_desc:"Ailwneud (Ctrl+Y)",
link_desc:"Mewnosod/golygu cyswllt",
unlink_desc:"Datgysylltu",
image_desc:"Mewnosod/golygu delwedd",
cleanup_desc:"Glanhau c\u00F4d anhrefnus",
code_desc:"Golygu Ffynhonell HTML",
sub_desc:"Isysgrif",
sup_desc:"Uwchysgrif",
hr_desc:"Mewnosod mesurydd llorweddol",
removeformat_desc:"Tynnu fformatio",
custom1_desc:"Eich disgrifiad addasiedig yma",
forecolor_desc:"Dewis lliw testun",
backcolor_desc:"Dewis lliw cefndir",
charmap_desc:"Mewnosod n\u00F4d addasiedig",
visualaid_desc:"Toglu llinellau cyfeirydd/elfennau anweledig",
anchor_desc:"Mewnosod/golygu angor",
cut_desc:"Torri",
copy_desc:"Cop\u00EFo",
paste_desc:"Gludo",
image_props_desc:"Priodweddau delwedd",
newdocument_desc:"Dogfen newydd",
help_desc:"Cymorth",
blockquote_desc:"Dyfyniad bloc",
clipboard_msg:"Nid yw Cop\u00EFo/Torri/Gludo ar gael mewn Mozilla a Firefox.\r\nYdych chi eisiau mwy o wybodaeth am y mater yma?",
path:"Llwybr",
newdocument:"A ydych chi'n si\u0175r eich bod eisiau clirio'r holl cynnwys?",
toolbar_focus:"Neidio i botymau offeryn - Alt+Q, Neidio i olygydd - Alt-Z, Neidio i lwybr elfen - Alt-X",
more_colors:"Mwy o liwiau"
});