tinyMCE.addI18n('nn.paste_dlg',{
text_title:"Bruk CTRL+V p\u00E5 tastaturet for \u00E5 lime inn i dette vindauget.",
text_linebreaks:"Behald tekstbryting",
word_title:"Bruk CTRL+V p\u00E5 tastaturet for \u00E5 lime inn i dette vindauget."
});