tinyMCE.addI18n('eu.emotions_dlg',{
title:"Ikonotxoa sartu",
desc:"Ikonotsoak",
cool:"Ondo",
cry:"Negarrez",
embarassed:"Lotsatuta",
foot_in_mouth:"Hanka ahoan",
frown:"Desadostasuna",
innocent:"Ni ez naiz izan",
kiss:"Muxua",
laughing:"Barrez",
money_mouth:"Ahoa diruz beteta",
sealed:"Ixilik",
smile:"Irriparra",
surprised:"Harrituta",
tongue_out:"Mihia atera",
undecided:"Zalantzan",
wink:"Keinua",
yell:"Ohiua"
});