tinyMCE.addI18n('eu.xhtmlxtras_dlg',{
attribute_label_title:"Izenburua",
attribute_label_id:"ID",
attribute_label_class:"Klasea",
attribute_label_style:"Estiloa",
attribute_label_cite:"Zita",
attribute_label_datetime:"Data/Ordua",
attribute_label_langdir:"Testuaren norabidea",
attribute_option_ltr:"Ezkerretik eskuinera",
attribute_option_rtl:"Eskuinetik ezkerrera",
attribute_label_langcode:"Hizkuntza",
attribute_label_tabindex:"Tabulazio ordena",
attribute_label_accesskey:"Laster-tekla",
attribute_events_tab:"Ebentuak",
attribute_attrib_tab:"Atributuak",
general_tab:"Orokorra",
attrib_tab:"Atributuak",
events_tab:"Ebentuak",
fieldset_general_tab:"Aukera orokorrak",
fieldset_attrib_tab:"Elementuen atributuak",
fieldset_events_tab:"Elementuen ebentuak",
title_ins_element:"Elementuaren txertaketa",
title_del_element:"Elementuaren ezabaketa",
title_acronym_element:"Elementuaren akronimoa",
title_abbr_element:"Elementuaren laburdura",
title_cite_element:"Elementuaren zita",
remove:"Ezabatu",
insert_date:"Data/ordua txertatu",
option_ltr:"Ezkerretik eskuinera",
option_rtl:"Eskuinetik ezkerrera",
attribs_title:"Atributuak txertatu/editatu"
});