tinyMCE.addI18n('hu.media_dlg',{
title:"Be\u00E1gyazott m\u00E9dia besz\u00FAr\u00E1sa/szerkeszt\u00E9se",
general:"\u00C1ltal\u00E1nos",
advanced:"Halad\u00F3",
file:"F\u00E1jl/URL",
list:"Lista",
size:"Dimenzi\u00F3k",
preview:"El\u0151n\u00E9zet",
constrain_proportions:"Ar\u00E1nytart\u00E1s",
type:"T\u00EDpus",
id:"Id",
name:"N\u00E9v",
class_name:"Oszt\u00E1ly",
vspace:"F-t\u00E1v",
hspace:"V-t\u00E1v",
play:"Automatikus lej\u00E1tsz\u00E1s",
loop:"Ism\u00E9tl\u00E9s",
menu:"Men\u00FC mutat\u00E1sa",
quality:"Min\u0151s\u00E9g",
scale:"Nagy\u00EDt\u00E1s",
align:"Elrendez\u00E9s",
salign:"SElrendez\u00E9s",
wmode:"WM\u00F3d",
bgcolor:"H\u00E1tt\u00E9r",
base:"Base",
flashvars:"Flashvars",
liveconnect:"SWLiveConnect",
autohref:"AutoHREF",
cache:"Cache",
hidden:"Rejtett",
controller:"Vez\u00E9rl\u0151",
kioskmode:"Kiosk m\u00F3d",
playeveryframe:"Minden kocka lej\u00E1tsz\u00E1sa",
targetcache:"C\u00E9l cache",
correction:"Nincs jav\u00EDt\u00E1s",
enablejavascript:"JavaScript enged\u00E9se",
starttime:"Kezd\u00E9si id\u0151",
endtime:"Z\u00E1r\u00F3 id\u0151",
href:"Href",
qtsrcchokespeed:"Folyt\u00E1s sebess\u00E9ge",
target:"C\u00E9l",
volume:"Hanger\u0151",
autostart:"Automatikus kezd\u00E9s",
enabled:"Enged\u00E9lyezve",
fullscreen:"Teljes k\u00E9perny\u0151",
invokeurls:"URL-ek bevon\u00E1sa",
mute:"N\u00E9ma",
stretchtofit:"Ny\u00FAjtva igaz\u00EDt\u00E1s",
windowlessvideo:"Ablak n\u00E9lk\u00FCli vide\u00F3",
balance:"Balance",
baseurl:"Base URL",
captioningid:"Captioning id",
currentmarker:"Aktu\u00E1lis marker",
currentposition:"Aktu\u00E1lis poz\u00EDci\u00F3",
defaultframe:"Alap\u00E9rtelmezett frame",
playcount:"Lej\u00E1tsz\u00E1ssz\u00E1m",
rate:"Rate",
uimode:"UI M\u00F3d",
flash_options:"Flash be\u00E1ll\u00EDt\u00E1sai",
qt_options:"Quicktime be\u00E1ll\u00EDt\u00E1sai",
wmp_options:"Windows media player be\u00E1ll\u00EDt\u00E1sai",
rmp_options:"Real media player be\u00E1ll\u00EDt\u00E1sai",
shockwave_options:"Shockwave be\u00E1ll\u00EDt\u00E1sai",
autogotourl:"Automatikus URL-re ugr\u00E1s",
center:"K\u00F6z\u00E9pre",
imagestatus:"K\u00E9p \u00E1llapot",
maintainaspect:"Ar\u00E1nytart\u00E1s",
nojava:"Nincs java",
prefetch:"El\u0151t\u00F6lt\u00E9s",
shuffle:"V\u00E9letlenszer\u0171",
console:"Console",
numloop:"Ism\u00E9tl\u00E9ssz\u00E1m",
controls:"Kezel\u0151k",
scriptcallbacks:"Script callbacks",
swstretchstyle:"Ny\u00FAjt\u00E1s st\u00EDlus",
swstretchhalign:"Ny\u00FAjt\u00E1s V-igaz\u00EDt\u00E1s",
swstretchvalign:"Ny\u00FAjt\u00E1s F-igaz\u00EDt\u00E1s",
sound:"Hang",
progress:"Folymat",
qtsrc:"QT Src",
qt_stream_warn:"Streamelt rtsp forr\u00E1sok a QT Src mez\u0151be val\u00F3k a halad\u00F3 lapon.\nHozz\u00E1 kellene adnia egy nem streamelt verzi\u00F3t a Src mez\u0151ben.",
align_top:"Fent",
align_right:"Jobbra",
align_bottom:"Lent",
align_left:"Balra",
align_center:"K\u00F6z\u00E9pen",
align_top_left:"Bal-fent",
align_top_right:"Jobb-fent",
align_bottom_left:"Bal-lent",
align_bottom_right:"Bal-jobbra",
flv_options:"Flash vide\u00F3 be\u00E1ll\u00EDt\u00E1sai",
flv_scalemode:"Nagy\u00EDt\u00E1s m\u00F3d",
flv_buffer:"Buffer",
flv_startimage:"Start k\u00E9p",
flv_starttime:"Start id\u0151",
flv_defaultvolume:"Alap\u00E9rtelmezett hanger\u0151",
flv_hiddengui:"Rejtett GUI",
flv_autostart:"Aut\u00F3 start",
flv_loop:"Ism\u00E9tl\u00E9s",
flv_showscalemodes:"Nagy\u00EDt\u00E1si m\u00F3dok mutat\u00E1sa",
flv_smoothvideo:"Vide\u00F3 sim\u00EDt\u00E1sa",
flv_jscallback:"JS Callback"
});