tinyMCE.addI18n('ko.advanced',{
style_select:"\uC2A4\uD0C0\uC77C",
font_size:"\uAE00\uAF34 \uD06C\uAE30",
fontdefault:"\uAE00\uAF34",
block:"\uD3EC\uB9F7",
paragraph:"\uB2E8\uB77D",
div:"Div",
address:"\uC8FC\uC18C",
pre:"pre",
h1:"\uD45C\uC81C1",
h2:"\uD45C\uC81C2",
h3:"\uD45C\uC81C3",
h4:"\uD45C\uC81C4",
h5:"\uD45C\uC81C5",
h6:"\uD45C\uC81C6",
blockquote:"\uC778\uC6A9\uBB38",
code:"\uCF54\uB4DC",
samp:"\uC0D8\uD50C\uCF54\uB4DC",
dt:"\uC5B4\uAD6C \uC815\uC758",
dd:"\uC815\uC758 \uC124\uBA85",
bold_desc:"\uAD75\uC740 \uAE00\uC528(Ctrl+B)",
italic_desc:"\uC774\uD0E4\uB9AD(Ctrl+I)",
underline_desc:"\uBC11\uC904(Ctrl+U)",
striketrough_desc:"\uCDE8\uC18C\uC120",
justifyleft_desc:"\uC67C\uCABD \uC815\uB82C",
justifycenter_desc:"\uAC00\uC6B4\uB370 \uC815\uB82C",
justifyright_desc:"\uC624\uB978\uCABD \uC815\uB82C",
justifyfull_desc:"\uBC30\uBD84 \uC815\uB82C",
bullist_desc:"\uBE44\uC21C\uCC28\uBAA9\uB85D",
numlist_desc:"\uC21C\uCC28\uBAA9\uB85D",
outdent_desc:"\uB0B4\uC5B4\uC4F0\uAE30",
indent_desc:"\uB4E4\uC5EC\uC4F0\uAE30",
undo_desc:"\uC2E4\uD589\uCDE8\uC18C(Ctrl+Z)",
redo_desc:"\uB2E4\uC2DC\uC2E4\uD589(Ctrl+Y)",
link_desc:"\uB9C1\uD06C\uC758 \uC0BD\uC785/\uD3B8\uC9D1",
unlink_desc:"\uB9C1\uD06C \uC0AD\uC81C",
image_desc:"\uC774\uBBF8\uC9C0 \uC0BD\uC785/\uD3B8\uC9D1",
cleanup_desc:"\uC9C0\uC800\uBD84\uD55C \uCF54\uB4DC \uC0AD\uC81C",
code_desc:"HTML \uD3B8\uC9D1",
sub_desc:"\uC544\uB798\uCCA8\uC790",
sup_desc:"\uC704\uCCA8\uC790",
hr_desc:"\uAD6C\uBD84\uC120",
removeformat_desc:"\uC11C\uC2DD \uD574\uC81C",
custom1_desc:"\uCEE4\uC2A4\uD140 \uC124\uBA85",
forecolor_desc:"\uAE00\uC790\uC0C9",
backcolor_desc:"\uBC30\uACBD\uC0C9",
charmap_desc:"\uD2B9\uC218 \uBB38\uC790",
visualaid_desc:"\uAC00\uC774\uB4DC\uB77C\uC778 \uD45C\uC2DC/\uBE44\uD45C\uC2DC",
anchor_desc:"\uC5E5\uCEE4 \uC0BD\uC785/\uD3B8\uC9D1",
cut_desc:"\uC798\uB77C\uB0B4\uAE30",
copy_desc:"\uBCF5\uC0AC",
paste_desc:"\uBD99\uC774\uAE30",
image_props_desc:"\uC774\uBBF8\uC9C0\uC18D\uC131",
newdocument_desc:"\uC2E0\uADDC\uAE00 \uC791\uC131",
help_desc:"\uB3C4\uC6C0\uB9D0",
blockquote_desc:"\uC778\uC6A9\uBB38",
clipboard_msg:"\uBCF5\uC0AC/\uC798\uB77C\uB0B4\uAE30/\uBD99\uC774\uAE30\uB294 Mozilla \uBC0FFirefox \uC5D0\uC11C \uC0AC\uC6A9\uB418\uC9C0 \uC54A\uC2B5\uB2C8\uB2E4.\n\uC0C1\uC138\uC815\uBCF4\uB97C \uD45C\uC2DC\uD569\uB2C8\uAE4C?",
path:"Path",
newdocument:"\uD3B8\uC9D1\uC911\uC758 \uB370\uC774\uD130\uB97C \uBAA8\uB450 \uC783\uC5B4\uB3C4 \uAD1C\uCC2E\uC2B5\uB2C8\uAE4C?",
toolbar_focus:"\uBC84\uD2BC\uC73C\uB85C \uC810\uD504 - Alt+Q, \uC5D0\uB514\uD130\uB85C \uC810\uD504 - Alt-Z, Jump to element path - Alt-X",
more_colors:"\uADF8 \uC678\uC758 \uC0C9"
});