tinyMCE.addI18n('et.emotions_dlg',{
title:"Sisesta emotsioon",
desc:"Emotsioonid",
cool:"Lahe",
cry:"Nutt",
embarassed:"H\u00E4bitunne",
foot_in_mouth:"Jalg suus",
frown:"Kulmu kortsutamine",
innocent:"S\u00FC\u00FCtu",
kiss:"Suudlus",
laughing:"Naermine",
money_mouth:"Rahasuu",
sealed:"Suletud",
smile:"Naeratus",
surprised:"\u00DCllatunud",
tongue_out:"Keel v\u00E4ljas",
undecided:"K\u00F5hklev",
wink:"Silmapilgutus",
yell:"Karje"
});