tinyMCE.addI18n('lb.advlink_dlg',{
title:"Link af\u00FCgen/beaarbechten",
url:"Adress",
target:"F\u00EBnster",
titlefield:"Titel",
is_email:"D\u00EBs Adress sch\u00E9ngt eng Email-Adress ze sinn. W\u00EBllt Dir den dofir ben\u00E9idegte Pr\u00E4fix \"mailto:\" virdru setzen?",
is_external:"D\u00EBs Adress sch\u00E9ngt een externe Link ze sinn. W\u00EBllt Dir den dofir ben\u00E9idegte Pr\u00E4fix \"http://\" virdru setzen?",
list:"Linkl\u00EBscht",
general_tab:"Allgemeng",
popup_tab:"Popup",
events_tab:"Evenement",
advanced_tab:"Erweidert",
general_props:"Allgemeng Eegeschaften",
popup_props:"Popup-Eegeschaften",
event_props:"Evenement",
advanced_props:"Erweidert Eegeschaften",
popup_opts:"Optiounen",
anchor_names:"Anker",
target_same:"An der selwechter F\u00EBnster/Frame opmaachen",
target_parent:"An der iwwergeuerdneter F\u00EBnster/Frame opmaachen",
target_top:"Am ieweschte Frame opmaacheen (sprengt d'Frameset)",
target_blank:"An enger neier F\u00EBnster opmaachen",
popup:"JavaScript-Popup",
popup_url:"Popup-Adress",
popup_name:"Numm vun der F\u00EBnster",
popup_return:"Link trotz Popup suiv\u00E9ieren",
popup_scrollbars:"Scrollbalken uweisen",
popup_statusbar:"Statusleeschten uweisen",
popup_toolbar:"Geschirleeschten uweisen",
popup_menubar:"Browsermen\u00FC uweisen",
popup_location:"Adressleescht uweisen",
popup_resizable:"Vergr\u00E9isseren vun der F\u00EBnster zouloossen",
popup_dependent:"Vun der Elteref\u00EBnster onofh\u00E4ngeg <br /> (n\u00EBmmen Mozilla/Firefox) ",
popup_size:"Gr\u00E9isst",
popup_position:"Positioun (X/Y)",
id:"ID",
style:"Format",
classes:"Klassen",
target_name:"Numm vun der Zils\u00E4it",
langdir:"Schr\u00EBftrichtung",
target_langcode:"Sprooch vun der Zils\u00E4it",
langcode:"Sproochcode",
encoding:"Zeechekod\u00E9ierung vun der Zils\u00E4it",
mime:"MIME-Typ vun der Zils\u00E4it",
rel:"Bez\u00E9iung vun der S\u00E4it zum Linkzil",
rev:"Bez\u00E9iung vum Linkzil zur S\u00E4it",
tabindex:"Tabindex",
accesskey:"Tastekierzel",
ltr:"L\u00E9nks no riets",
rtl:"Riets no l\u00E9nks",
link_list:"Linkl\u00EBscht"
});