tinyMCE.addI18n('ca.advanced_dlg',{
about_title:"Quant al TinyMCE",
about_general:"Quant a",
about_help:"Ajuda",
about_license:"Llic\u00E8ncia",
about_plugins:"Connectors",
about_plugin:"Connector",
about_author:"Autor",
about_version:"Versi\u00F3",
about_loaded:"Connectors carregats",
anchor_title:"Insereix/edita \u00E0ncora",
anchor_name:"Nom de l\'\u00E0ncora",
code_title:"Editor de codi font HTML",
code_wordwrap:"Embolcall de paraula",
colorpicker_title:"Selecci\u00F3 de color",
colorpicker_picker_tab:"Capturador",
colorpicker_picker_title:"Capturador de color",
colorpicker_palette_tab:"Paleta",
colorpicker_palette_title:"Paleta de colors",
colorpicker_named_tab:"Per nom",
colorpicker_named_title:"Colors pel seu nom",
colorpicker_color:"Color:",
colorpicker_name:"Nom:",
charmap_title:"Selecci\u00F3 de car\u00E0cter",
image_title:"Insereix/edita imatge",
image_src:"URL de la imatge",
image_alt:"Descripci\u00F3 de la imatge",
image_list:"Llista de la imatge",
image_border:"Vora",
image_dimensions:"Dimensions",
image_vspace:"Espai vertical",
image_hspace:"Espai horitzontal",
image_align:"Alineaci\u00F3",
image_align_baseline:"L\u00EDnia de base",
image_align_top:"A dalt",
image_align_middle:"Al Mig",
image_align_bottom:"A baix",
image_align_texttop:"Part superior del text",
image_align_textbottom:"Part inferior del text",
image_align_left:"Esquerra",
image_align_right:"Dreta",
link_title:"Insereix/edita enlla\u00E7",
link_url:"URL de l\'enlla\u00E7",
link_target:"Dest\u00ED",
link_target_same:"Obre l\'enlla\u00E7 a la mateixa finestra",
link_target_blank:"Obre l\'enlla\u00E7 a una nova finestra",
link_titlefield:"T\u00EDtol",
link_is_email:"L\'URL que heu introdu\u00EFt sembla ser una adre\u00E7a de correu, voleu afegir-hi el prefix requerit mailto: ?",
link_is_external:"L\'URL que heu introdu\u00EFt sembla ser un enlla\u00E7 extern, voleu afegir-hi el prefix requerit http:// ?",
link_list:"Llista d\'enlla\u00E7os"
});