tinyMCE.addI18n('nn.emotions_dlg',{
title:"Set inn hum\u00F8rfjes",
desc:"Hum\u00F8rfjes",
cool:"Cool",
cry:"Gret",
embarassed:"Flau",
foot_in_mouth:"Fot i munnen",
frown:"Skuffa",
innocent:"Uskyldig",
kiss:"Kyss",
laughing:"Ler",
money_mouth:"Pengar i munnen",
sealed:"Hemmeleg",
smile:"Glad",
surprised:"Overraska",
tongue_out:"Rekkje tunge",
undecided:"Skeptisk",
wink:"Blunke",
yell:"Skri"
});