tinyMCE.addI18n('ca.advanced',{
style_select:"Estils",
font_size:"Mida de font",
fontdefault:"Fam\u00EDlia de font",
block:"Format",
paragraph:"Par\u00E0graf",
div:"Capa",
address:"Adre\u00E7a",
pre:"Preformatat",
h1:"Encap\u00E7alament 1",
h2:"Encap\u00E7alament 2",
h3:"Encap\u00E7alament 3",
h4:"Encap\u00E7alament 4",
h5:"Encap\u00E7alament 5",
h6:"Encap\u00E7alament 6",
blockquote:"Citabloc",
code:"Codi",
samp:"Mostra el Codi",
dt:"Terme de definici\u00F3 ",
dd:"Descripci\u00F3 de definici\u00F3",
bold_desc:"Negreta (Ctrl+B)",
italic_desc:"Cursiva (Ctrl+I)",
underline_desc:"Subratllat (Ctrl+U)",
striketrough_desc:"Barrat",
justifyleft_desc:"Alineaci\u00F3 esquerra",
justifycenter_desc:"Alineaci\u00F3 al centre",
justifyright_desc:"Alineaci\u00F3 dreta",
justifyfull_desc:"Justificat",
bullist_desc:"Llista no numerada",
numlist_desc:"Llista numerada",
outdent_desc:"Redueix el sagnat",
indent_desc:"Augmenta el sagnat",
undo_desc:"Desf\u00E9s (Ctrl+Z)",
redo_desc:"Ref\u00E9s (Ctrl+Y)",
link_desc:"Insereix/edita enlla\u00E7",
unlink_desc:"Desenlla\u00E7a",
image_desc:"Insereix/edita imatge",
cleanup_desc:"Poleix el codi",
code_desc:"Edita el codi font HTML",
sub_desc:"Sub\u00EDndex",
sup_desc:"Super\u00EDndex",
hr_desc:"Insereix un filet horitzontal",
removeformat_desc:"Elimina el format",
custom1_desc:"Aqu\u00ED la vostra pr\u00F2pia descripci\u00F3",
forecolor_desc:"Selecci\u00F3 del color de text",
backcolor_desc:"Selecci\u00F3 del color de fons",
charmap_desc:"Insereix un car\u00E0cter",
visualaid_desc:"Commuta elements guies/invisibles",
anchor_desc:"Insereix/edita \u00E0ncora",
cut_desc:"Retalla",
copy_desc:"Copia",
paste_desc:"Enganxa",
image_props_desc:"Propietats de la imatge",
newdocument_desc:"Nou document",
help_desc:"Ajuda",
blockquote_desc:"Citabloc",
clipboard_msg:"Copia/Retalla/Enganxa no es troba disponible ni al Mozilla ni al Firefox.\r\nVoleu m\u00E9s informaci\u00F3 sobre aix\u00F2?",
path:"Cam\u00ED",
newdocument:"Esteu segur que voleu buidar tots els continguts?",
toolbar_focus:"Salta als botons d\'eina - Alt+Q, Salta a l\'editor - Alt-Z, Salta al cam\u00ED de l\'element - Alt-X",
more_colors:"M\u00E9s colors"
});