tinyMCE.addI18n('ro.emotions_dlg',{
title:"Insereaz\u0103 o figurin\u0103",
desc:"Figurine emotive",
cool:"Cool",
cry:"Trist",
embarassed:"Ru\u015Finat",
foot_in_mouth:"Picior \u00EEn gur\u0103",
frown:"\u00CEncruntat",
innocent:"Nevinovat",
kiss:"Pupic",
laughing:"R\u00E2de",
money_mouth:"Bani \u00EEn gur\u0103",
sealed:"Sigilat",
smile:"Z\u00E2mbet",
surprised:"Surprins",
tongue_out:"Cu limba afar\u0103",
undecided:"Indecis",
wink:"Face cu ochiul",
yell:"\u0162ip\u0103"
});