tinyMCE.addI18n('az.xhtmlxtras_dlg',{
attribute_label_title:"Ad\u0131",
attribute_label_id:"\u0130dentifikator",
attribute_label_class:"Sinif",
attribute_label_style:"Stil",
attribute_label_cite:"Sitat",
attribute_label_datetime:"Tarix/vaxt",
attribute_label_langdir:"M\u0259tnin istiqam\u0259ti",
attribute_option_ltr:"Solda-sa\u011Fa",
attribute_option_rtl:"Sa\u011Fda-sola",
attribute_label_langcode:"Dil",
attribute_label_tabindex:"Hesab indeksi",
attribute_label_accesskey:"Giri\u015F klavi\u015Fi",
attribute_events_tab:"Hadis\u0259l\u0259r",
attribute_attrib_tab:"Atributlar",
general_tab:"\u00DCmumi",
attrib_tab:"Atributlar",
events_tab:"Hadis\u0259l\u0259r",
fieldset_general_tab:"\u00DCmumi nizamlamalar",
fieldset_attrib_tab:"Element atributlar\u0131",
fieldset_events_tab:"Element hadis\u0259l\u0259ri",
title_ins_element:"\u018Flav\u0259 edilmi\u015F m\u0259tnin elementi",
title_del_element:"Silinmi\u015F m\u0259tnin elementi",
title_acronym_element:"Akronim elementi",
title_abbr_element:"Abbreviatura elementi",
title_cite_element:"Sitat elementi",
remove:"L\u0259\u011Fv et",
insert_date:"Haz\u0131rki tarixi/vaxt\u0131 \u0259lav\u0259 et",
option_ltr:"Solda-sa\u011Fa",
option_rtl:"Sa\u011Fda-sola",
attribs_title:"Atribut \u0259lav\u0259/redakt\u0259 et"
});