tinyMCE.addI18n('sk.emotions_dlg',{
title:"Vlo\u017Ei\u0165 emotikonu",
desc:"Emotikony",
cool:"\u00DA\u017Easn\u00FD",
cry:"Pla\u010D\u00FAci",
embarassed:"Zahanben\u00FD",
foot_in_mouth:"\u0160liapol ved\u013Ea",
frown:"Zamra\u010Den\u00FD",
innocent:"Nevinn\u00FD",
kiss:"Bozkaj\u00FAci",
laughing:"Smej\u00FAci sa",
money_mouth:"Je na prachy",
sealed:"Ml\u010Diaci",
smile:"Usmiaty",
surprised:"Prekvapen\u00FD",
tongue_out:"S vyplazen\u00FDm jazykom",
undecided:"Nerozhodn\u00FD",
wink:"\u017Dmurkaj\u00FAci",
yell:"Kri\u010Diaci"
});