tinyMCE.addI18n('ca.media_dlg',{
title:"Insereix / edita multim\u00E8dia incrustada",
general:"General",
advanced:"Avan\u00E7at",
file:"Fitxer/URL",
list:"Llista",
size:"Dimensions",
preview:"Previsualitzaci\u00F3",
constrain_proportions:"Mant\u00E9 les proporcions",
type:"Tipus",
id:"Id",
name:"Nom",
class_name:"Classe",
vspace:"Espai vertical",
hspace:"Espai horitzontal",
play:"Reproducci\u00F3 autom\u00E0tica",
loop:"Bucle",
menu:"Mostra el men\u00FA",
quality:"Qualitat",
scale:"Escala",
align:"Alinea",
salign:"Alinea S",
wmode:"Mode W",
bgcolor:"Fons",
base:"Base",
flashvars:"Flashvars",
liveconnect:"SWLiveConnect",
autohref:"AutoHREF",
cache:"Mem\u00F2ria cau",
hidden:"Ocult",
controller:"Controlador",
kioskmode:"Mode quiosc",
playeveryframe:"Reprodueix cada marc",
targetcache:"Target cache",
correction:"Sense correcci\u00F3",
enablejavascript:"Habilita el javascript",
starttime:"Inici",
endtime:"Fi",
href:"Href",
qtsrcchokespeed:"Velocitat",
target:"Dest\u00ED",
volume:"Volumen",
autostart:"Inici autom\u00E0tic",
enabled:"Habilitat",
fullscreen:"Pantalla completa",
invokeurls:"Invoca els URL",
mute:"Silenci",
stretchtofit:"Estirar fins a encaixar",
windowlessvideo:"V\u00EDdeo sense finestra",
balance:"Equilibri",
baseurl:"URL base",
captioningid:"Id nominal",
currentmarker:"Retolador actual",
currentposition:"Posici\u00F3 actual",
defaultframe:"Marc per defecte",
playcount:"Compte de reproducci\u00F3",
rate:"Velocitat",
uimode:"Mode UI",
flash_options:"Opcions del Flash",
qt_options:"Opcions del Quicktime",
wmp_options:"Opcions del Windows media player",
rmp_options:"Opcions del Real media player",
shockwave_options:"Opcions del Shockwave",
autogotourl:"URL goto autom\u00E0tic",
center:"Alinea al centre",
imagestatus:"Estat de la imatge",
maintainaspect:"Mant\u00E9 l\'aspecte",
nojava:"Sense java",
prefetch:"Prec\u00E0rrega",
shuffle:"Shuffle",
console:"Consola",
numloop:"Nre. bucles",
controls:"Controls",
scriptcallbacks:"Crides de retorn a script",
swstretchstyle:"Estil de l\'extensor",
swstretchhalign:"Alineaci\u00F3 horitzontal de l\'extensor",
swstretchvalign:"Alineaci\u00F3 vertical de l\'extensor",
sound:"S\u00F2",
progress:"Progr\u00E9s",
qtsrc:"QT Src",
qt_stream_warn:"Els recursos rtsp fets flux s\'haurien d\'afegir al camp QT Src sota la pestanya avan\u00E7ada.\nTamb\u00E9 haur\u00EDeu d\'afegir una versi\u00F3 no feta flux al camp Src..",
align_top:"Superior",
align_right:"Dreta",
align_bottom:"Inferior",
align_left:"Esquerra",
align_center:"Centre",
align_top_left:"Superior esquerra",
align_top_right:"Superior dreta",
align_bottom_left:"Inferior esquerra",
align_bottom_right:"Inferior dreta",
flv_options:"Opcions de v\u00EDdeo Flash",
flv_scalemode:"Mode d'escalat",
flv_buffer:"Mem\u00F2ria interm\u00E8dia",
flv_startimage:"Imatge d\'inici",
flv_starttime:"Hora d\'inici",
flv_defaultvolume:"Volumen per defecte",
flv_hiddengui:"GUI ocult",
flv_autostart:"Inici autom\u00E0tic",
flv_loop:"Bucle",
flv_showscalemodes:"Mostra els modes d'escalat",
flv_smoothvideo:"V\u00EDdeo suau",
flv_jscallback:"Crida de retorn JS"
});