tinyMCE.addI18n('gl.table_dlg',{
general_tab:"Xeral",
advanced_tab:"Avanzado",
general_props:"Propiedades xerales",
advanced_props:"Propiedades avanzadas",
rowtype:"Tipo de fila",
title:"Insertar/Modificar t\u00E1boa",
width:"Ancho",
height:"Alto",
cols:"Cols",
rows:"Filas",
cellspacing:"Espaciado de celda",
cellpadding:"Relleno de celda",
border:"Borde",
align:"Ali\u00F1aci\u00F3n",
align_default:"Predet.",
align_left:"Esquerda",
align_right:"Dereita",
align_middle:"Centrado",
row_title:"Propiedades da fila",
cell_title:"Propiedades da celda",
cell_type:"Tipo de celda",
valign:"Ali\u00F1aci\u00F3n vertical",
align_top:"Arriba",
align_bottom:"Abaixo",
bordercolor:"Cor do borde",
bgcolor:"Cor de fondo",
merge_cells_title:"Unir celdas",
id:"Id",
style:"Estilo",
langdir:"Direcci\u00F3n da lenguaxe",
langcode:"C\u00F3digo da lenguaxe",
mime:"Tipo MIME",
ltr:"Esquerda a dereita",
rtl:"Dereita a esquerda",
bgimage:"Imaxe de fondo",
summary:"Resumen",
td:"Datos",
th:"Encabezamento",
cell_cell:"Actualizar celda actual",
cell_row:"Actualizar todalas celdas na fila",
cell_all:"Actualizar todalas celdas na t\u00E1boa",
row_row:"Actualizar fila actual",
row_odd:"Actualizar filas impares",
row_even:"Actualizar filas pares",
row_all:"Actualizar todalas filas",
thead:"Encabezamento da t\u00E1boa",
tbody:"Corpo da t\u00E1boa",
tfoot:"Pe da t\u00E1boa",
scope:"\u00C1mbito",
rowgroup:"Grupo de filas",
colgroup:"Grupo de columnas",
col_limit:"Super\u00F3u o n\u00FAmero m\u00E1ximo de columnas: {$cols}.",
row_limit:"Super\u00F3u o n\u00FAmero m\u00E1ximo de filas: {$rows}.",
cell_limit:"Super\u00F3u o n\u00FAmero m\u00E1ximo de celdas: {$cells}.",
missing_scope:"\u00BFEst\u00E1 seguro que desexa continuar sen especifica-lo \u00E1mbito do encabezado de celda? Sen \u00E9l podr\u00EDa ser dificultoso pra algunos usuarios entende-lo contido ou os datos mostrados na t\u00E1boa.",
caption:"Subt\u00EDtulo da t\u00E1boa",
frame:"Recadro",
frame_none:"ning\u00FAn",
frame_groups:"grupos",
frame_rows:"filas",
frame_cols:"columnas",
frame_all:"todos",
rules:"Regras",
rules_void:"vac\u00EDo",
rules_above:"encima",
rules_below:"debaixo",
rules_hsides:"hsides",
rules_lhs:"lhs",
rules_rhs:"rhs",
rules_vsides:"vsides",
rules_box:"box",
rules_border:"borde"
});