tinyMCE.addI18n('pt.advanced_dlg',{
about_title:"Sobre o TinyMCE",
about_general:"Sobre",
about_help:"Ajuda",
about_license:"Licen\u00E7a",
about_plugins:"Plugins",
about_plugin:"Plugin",
about_author:"Autor",
about_version:"Vers\u00E3o",
about_loaded:"Plugins Instalados",
anchor_title:"Inserir/editar \u00E2ncora",
anchor_name:"Nome da \u00E2ncora",
code_title:"Editor HTML",
code_wordwrap:"Quebra autom\u00E1tica de linha",
colorpicker_title:"Selecione uma cor",
colorpicker_picker_tab:"Editor",
colorpicker_picker_title:"Editor de Cores",
colorpicker_palette_tab:"Paleta",
colorpicker_palette_title:"Paleta de Cores",
colorpicker_named_tab:"Personalizadas",
colorpicker_named_title:"Cores Personalizadas",
colorpicker_color:"Cor:",
colorpicker_name:"Nome:",
charmap_title:"Selecionar caracteres personalizados",
image_title:"Inserir/editar imagem",
image_src:"Endere\u00E7o da imagem",
image_alt:"Descri\u00E7\u00E3o da imagem",
image_list:"Lista de imagens",
image_border:"Limites",
image_dimensions:"Dimens\u00F5es",
image_vspace:"Espa\u00E7o Vertical",
image_hspace:"Espa\u00E7o Horizontal",
image_align:"Alinhamento",
image_align_baseline:"Sobre a linha de texto",
image_align_top:"Topo",
image_align_middle:"Meio",
image_align_bottom:"Abaixo",
image_align_texttop:"Topo do texto",
image_align_textbottom:"Base do texto",
image_align_left:"Esquerda",
image_align_right:"Direita",
link_title:"Inserir/editar hyperlink",
link_url:"URL do hyperink",
link_target:"Alvo",
link_target_same:"Abrir hyperlink na mesma janela",
link_target_blank:"Abrir hyperlink em nova janela",
link_titlefield:"T\u00EDtulo",
link_is_email:"A URL digitada parece ser um endere\u00E7o de e-mail. Deseja acrescentar o prefixo necess\u00E1rio mailto:?",
link_is_external:"A URL digitada parece conduzir a um link externo. Deseja acrescentar o prefixo necess\u00E1rio http://?",
link_list:"Lista de Links"
});