tinyMCE.addI18n({sl:{
common:{
edit_confirm:"\u017Delite uporabiti na\u010Din \'videz ne vara\' (WYSIWYG) za to vnosno polje?",
apply:"Uporabi",
insert:"Vstavi",
update:"Posodobi",
cancel:"Prekli\u010Di",
close:"Zapri",
browse:"Prebrskaj",
class_name:"Razred",
not_set:"-- ni nastavljeno --",
clipboard_msg:"Delo z odlo\u017Ei\u0161\u010Dem ni mogo\u010De v tem brskalniku. Lahko uporabljate kombinacije tipk Ctrl+X, Ctrl+C, Ctrl+V.\n\u017Delite ve\u010D informacij o tem?",
clipboard_no_support:"Trenutno ni podporto v va\u0161em brskalniku. Uporabite bli\u017Enjice tipkovnice.",
popup_blocked:"\u017Dal va\u0161e orodje za prepre\u010Devanje odpiranja neza\u017Eelenih oken (popup-blocker) ne omogo\u010Da prikaza pomo\u017Enega okna izbranega orodja. Prepre\u010Devanje odpiranja oken morate onemogo\u010Diti.",
invalid_data:"Napaka: vne\u0161ene so bile nepravilne vrednosti, ozna\u010Dene so z rde\u010Do.",
more_colors:"Ve\u010D barv"
},
contextmenu:{
align:"Poravnava",
left:"Levo",
center:"Sredina",
right:"Desno",
full:"Polno"
},
insertdatetime:{
date_fmt:"%d.%m.%Y",
time_fmt:"%H:%M:%S",
insertdate_desc:"Vstavi datum",
inserttime_desc:"Vstavi \u010Das",
months_long:"januar,februar,marec,april,maj,junij,julij,avgust,september,oktober,november,december",
months_short:"jan,feb,mar,apr,maj,jun,jul,avg,sep,okt,nov,dec",
day_long:"nedelja,ponedeljek,torek,sreda,\u010Detrtek,petek,sobota,nedelja",
day_short:"ned,pon,tor,sre,\u010Det,pet,sob,ned"
},
print:{
print_desc:"Natisni"
},
preview:{
preview_desc:"Predogled"
},
directionality:{
ltr_desc:"Smer od leve proti desni",
rtl_desc:"Smer od desne proti levi"
},
layer:{
insertlayer_desc:"Vstavi nov sloj",
forward_desc:"Premakni v ospredje",
backward_desc:"Premakni v ozadje",
absolute_desc:"Preklop absolutnega polo\u017Eaja",
content:"Nov sloj..."
},
save:{
save_desc:"Shrani",
cancel_desc:"Prekli\u010Di vse spremembe"
},
nonbreaking:{
nonbreaking_desc:"Vstavi nedeljivi presledek"
},
iespell:{
iespell_desc:"Za\u017Eeni preverjanje \u010Drkovanja",
download:"ieSpell ni zaznan. \u017Delite, da ga namestim?"
},
advhr:{
advhr_desc:"Vodoravna \u010Drta"
},
emotions:{
emotions_desc:"Sme\u0161ki"
},
searchreplace:{
search_desc:"Najdi",
replace_desc:"Najdi/zamenjaj"
},
advimage:{
image_desc:"Vstavi/uredi sliko"
},
advlink:{
link_desc:"Vstavi/uredi povezavo"
},
xhtmlxtras:{
cite_desc:"Citat",
abbr_desc:"Okraj\u0161ava",
acronym_desc:"Kratica",
del_desc:"Izbrisano",
ins_desc:"Vstavljeno",
attribs_desc:"Vstavi/uredi atribute"
},
style:{
desc:"Uredi sloge CSS"
},
paste:{
paste_text_desc:"Prilepi kot golo besedilo",
paste_word_desc:"Prilepi iz Word-a",
selectall_desc:"Izberi vse",
plaintext_mode_sticky:"Paste is now in plain text mode. Click again to toggle back to regular paste mode. After you paste something you will be returned to regular paste mode.",
plaintext_mode:"Paste is now in plain text mode. Click again to toggle back to regular paste mode."
},
paste_dlg:{
text_title:"Uporabite kombinacijo tipk CTRL+V, da prilepite vsebino v okno.",
text_linebreaks:"Obdr\u017Ei prelome vrstic",
word_title:"Uporabite kombinacijo tipk CTRL+V, da prilepite vsebino v okno."
},
table:{
desc:"Vstavi/posodobi tabelo",
row_before_desc:"Vstavi vrstico nad",
row_after_desc:"Vstavi vrstico pod",
delete_row_desc:"Odstrani vrstico",
col_before_desc:"Vstavi stolpec pred",
col_after_desc:"Vstavi stolpec po",
delete_col_desc:"Odstrani stolpec",
split_cells_desc:"Razcepi celico",
merge_cells_desc:"Spoji celice",
row_desc:"Lastnosti vrstice",
cell_desc:"Lastnosti celice",
props_desc:"Lastnosti tabele",
paste_row_before_desc:"Prilepi vrstico pred",
paste_row_after_desc:"Prilepi vrstico po",
cut_row_desc:"Izre\u017Ei vrstico",
copy_row_desc:"Kopiraj vrstico",
del:"Odstrani tabelo",
row:"Vrstica",
col:"Stolpec",
cell:"Celica",
cellprops_delta_width:"100"
},
autosave:{
unload_msg:"Ce se premaknete na drugo stran, bodo narejene spremembe izgubljene!",
restore_content:"Restore auto-saved content.",
warning_message:"If you restore the saved content, you will lose all the content that is currently in the editor.\n\nAre you sure you want to restore the saved content?."
},
fullscreen:{
desc:"Preklopi celozaslonski na\u010Din"
},
media:{
desc:"Vstavi / uredi multimedijsko vsebino",
edit:"Uredi multimedijsko vsebino"
},
fullpage:{
desc:"Lastnosti dokumenta"
},
template:{
desc:"Vstavi pripravljeno vsebino predloge"
},
visualchars:{
desc:"Preklopi prikaz nadzornih znakov."
},
spellchecker:{
desc:"Preklopi \u010Drkovalnik",
menu:"Nastavitve \u010Drkovalnika",
ignore_word:"Prezri besedo",
ignore_words:"Prezri vse",
langs:"Jeziki",
wait:"Prosim po\u010Dakaj...",
sug:"Predlogi",
no_sug:"Ni predlogov",
no_mpell:"Napa\u010Dnega \u010Drkovanja nisem na\u0161el."
},
pagebreak:{
desc:"Vstavi lom strani."
},
advlist:{
types:"Types",
def:"Default",
lower_alpha:"Lower alpha",
lower_greek:"Lower greek",
lower_roman:"Lower roman",
upper_alpha:"Upper alpha",
upper_roman:"Upper roman",
circle:"Circle",
disc:"Disc",
square:"Square"
}}});