tinyMCE.addI18n('vi.emotions_dlg',{
title:"Bi\u1EC3u T\u01B0\u1EE3ng C\u1EA3m X\u00FAc",
desc:"Bi\u1EC3u T\u01B0\u1EE3ng C\u1EA3m X\u00FAc",
cool:"Kh\u00F4ng bi\u1EBFt ng\u01B0\u1EE3ng",
cry:"Kh\u00F3c",
embarassed:"X\u1EA5u h\u1ED5",
foot_in_mouth:"L\u1EE1 l\u1EDDi",
frown:"Cau m\u00E0y",
innocent:"Ng\u00E2y th\u01A1",
kiss:"N\u1EE5 h\u00F4n",
laughing:"C\u01B0\u1EDDi nh\u0103n r\u0103ng",
money_mouth:"S\u00E1ng m\u1EAFt v\u00EC $",
sealed:"K\u00EDn mi\u1EC7ng",
smile:"M\u1EC9m c\u01B0\u1EDDi",
surprised:"Ng\u1EA1c nhi\u00EAn",
tongue_out:"L\u00E8 l\u01B0\u1EE1i",
undecided:"L\u01B0\u1EE1ng l\u1EF1",
wink:"Nh\u00E1y m\u1EAFt",
yell:"La h\u00E9t"
});