tinyMCE.addI18n('da.emotions_dlg',{
title:"Inds\u00E6t hum\u00F8rikon",
desc:"Hum\u00F8rikoner",
cool:"Cool",
cry:"Gr\u00E6de",
embarassed:"Flov",
foot_in_mouth:"Fod i munden",
frown:"Forskr\u00E6kket",
innocent:"Uskyldig",
kiss:"Kys",
laughing:"Grine",
money_mouth:"Pengemund",
sealed:"Lukket",
smile:"Smil",
surprised:"Overrasket",
tongue_out:"Tunge ud",
undecided:"Ubeslutsom",
wink:"Vink",
yell:"R\u00E5be"
});