tinyMCE.addI18n('se.advlink_dlg',{
title:"Infoga/redigera l\u00E4nk",
url:"L\u00E4nkens URL",
target:"M\u00E5l",
titlefield:"Titel",
is_email:"L\u00E4nken du angav verkar vara en e-post adress. Vill du infoga mailto: prefixet p\u00E5 l\u00E4nken?",
is_external:"L\u00E4nken du angav verkar vara en extern adress. Vill du infoga http:// prefixet p\u00E5 l\u00E4nken?",
list:"L\u00E4nklista",
general_tab:"Generellt",
popup_tab:"Popup",
events_tab:"H\u00E4ndelser",
advanced_tab:"Avancerat",
general_props:"Generella inst\u00E4llningar",
popup_props:"Popup-inst\u00E4llningar",
event_props:"H\u00E4ndelser",
advanced_props:"Avancerade inst\u00E4llningar",
popup_opts:"Inst\u00E4llningar",
anchor_names:"Bokm\u00E4rken",
target_same:"\u00D6ppna i detta f\u00F6nster/ram",
target_parent:"\u00D6ppna i \u00F6verliggande f\u00F6nster/ram",
target_top:"\u00D6ppna i toppramen (ers\u00E4tter alla ramar)",
target_blank:"\u00D6ppna i nytt f\u00F6nster",
popup:"Javascript popup",
popup_url:"Popup URL",
popup_name:"F\u00F6nsternamn",
popup_return:"Infoga 'return false'",
popup_scrollbars:"Rullningslister",
popup_statusbar:"Statusf\u00E4lt",
popup_toolbar:"Verktygsf\u00E4lt",
popup_menubar:"Menyrad",
popup_location:"Adressraden",
popup_resizable:"Skalbart f\u00F6nster",
popup_dependent:"Beroende av (Mozilla/Firefox enbart)",
popup_size:"Storlek",
popup_position:"Position (x/y)",
id:"Id",
style:"Stil",
classes:"Klasser",
target_name:"M\u00E5lnamn",
langdir:"Skriftriktning",
target_langcode:"M\u00E5lspr\u00E5k",
langcode:"Spr\u00E5kkod",
encoding:"Teckenformattering",
mime:"MIME type",
rel:"Relation (rel attribut)",
rev:"Omv\u00E4nd relation (rev)",
tabindex:"Tabbindex",
accesskey:"Snabbtangent",
ltr:"V\u00E4nster till h\u00F6ger",
rtl:"H\u00F6ger till v\u00E4nster",
link_list:"L\u00E4nklista"
});