tinyMCE.addI18n('sk.advlink_dlg',{
title:"Vlo\u017Ei\u0165/upravi\u0165 odkaz",
url:"URL odkazu",
target:"Cie\u013E",
titlefield:"Titulok",
is_email:"Zadan\u00E1 URL vyzer\u00E1 ako e-mailov\u00E1 adresa, chcete doplni\u0165 povinn\u00FD prefix mailto:?",
is_external:"Zadan\u00E1 URL vyzer\u00E1 ako extern\u00FD odkaz, chcete doplni\u0165 povinn\u00FD prefix http://?",
list:"Zoznam odkazov",
general_tab:"Obecn\u00E9",
popup_tab:"Vyskakovacie okno",
events_tab:"Udalosti",
advanced_tab:"Roz\u0161\u00EDren\u00E9",
general_props:"Obecn\u00E9 parametre",
popup_props:"Vlastnosti vyskakovacieho okna",
event_props:"Udalosti",
advanced_props:"Roz\u0161\u00EDren\u00E9 parametre",
popup_opts:"Mo\u017Enosti",
anchor_names:"Z\u00E1lo\u017Eka",
target_same:"Otvori\u0165 v rovnakom okne/r\u00E1me",
target_parent:"Otvori\u0165 v nadradenom okne/r\u00E1me",
target_top:"Otvori\u0165 v hlavnom okne/r\u00E1me (nahradi\u0165 v\u0161etky r\u00E1my)",
target_blank:"Otvori\u0165 v novom okne",
popup:"JavaScriptov\u00E9 okno",
popup_url:"URL vyskakovacieho okna",
popup_name:"N\u00E1zov okna",
popup_return:"Vlo\u017Ei\u0165 'return false'",
popup_scrollbars:"Zobrazi\u0165 posuvn\u00EDky",
popup_statusbar:"Zobrazi\u0165 stavov\u00FD riadok",
popup_toolbar:"Zobrazi\u0165 n\u00E1strojov\u00FA li\u0161tu",
popup_menubar:"Zobrazi\u0165 ponuku",
popup_location:"Zobrazi\u0165 li\u0161tu umiestnen\u00ED",
popup_resizable:"Umo\u017Eni\u0165 zmenu ve\u013Ekosti",
popup_dependent:"Z\u00E1vislos\u0165 (iba Mozilla/Firefox)",
popup_size:"Ve\u013Ekos\u0165",
popup_position:"Umiestnenie (X/Y)",
id:"ID",
style:"\u0160t\u00FDl",
classes:"Triedy",
target_name:"N\u00E1zov cie\u013Ea",
langdir:"Smer textu",
target_langcode:"Jazyk cie\u013Ea",
langcode:"K\u00F3d jazyka",
encoding:"K\u00F3dovanie",
mime:"MIME typ",
rel:"Vz\u0165ah str\u00E1nky k cie\u013Eu",
rev:"Vz\u0165ah cie\u013Ea k str\u00E1nke",
tabindex:"Poradie pre tabul\u00E1tor",
accesskey:"Kl\u00E1vesov\u00E1 skratka",
ltr:"Z\u013Eava doprava",
rtl:"Sprava do\u013Eava",
link_list:"Zoznam odkazov"
});