tinyMCE.addI18n('cs.media_dlg',{
title:"Vlo\u017Eit/upravit vkl\u00E1dan\u00E1 m\u00E9dia",
general:"Obecn\u00E9",
advanced:"Roz\u0161\u00ED\u0159en\u00E9",
file:"Soubor/URL",
list:"Seznam",
size:"Rozm\u011Bry",
preview:"N\u00E1hled",
constrain_proportions:"Zachovat proporce",
type:"Typ",
id:"ID",
name:"N\u00E1zev",
class_name:"T\u0159\u00EDda",
vspace:"Vertik\u00E1ln\u00ED odsazen\u00ED",
hspace:"Horizont\u00E1ln\u00ED odsazen\u00ED",
play:"Automatick\u00E9 p\u0159ehr\u00E1v\u00E1n\u00ED",
loop:"Opakov\u00E1n\u00ED",
menu:"Zobrazit nab\u00EDdku",
quality:"Kvalita",
scale:"Pom\u011Br",
align:"Zarovn\u00E1n\u00ED",
salign:"Zarovn\u00E1n\u00ED okna",
wmode:"Re\u017Eim okna",
bgcolor:"Pozad\u00ED",
base:"Z\u00E1kladn\u00ED slo\u017Eka",
flashvars:"Parametry (Flashvars)",
liveconnect:"Spustit Javu (SWLiveConnect)",
autohref:"Automatick\u00E9 na\u010Dten\u00ED",
cache:"Mezipam\u011B\u0165",
hidden:"Skr\u00FDt",
controller:"Ovl\u00E1dac\u00ED panel",
kioskmode:"Zak\u00E1zat ukl\u00E1d\u00E1n\u00ED",
playeveryframe:"P\u0159ehr\u00E1t ka\u017Ed\u00FD sn\u00EDmek",
targetcache:"C\u00EDlov\u00E1 mezipam\u011B\u0165",
correction:"Bez korekc\u00ED",
enablejavascript:"Povolit Javascript",
starttime:"Po\u010D\u00E1te\u010Dn\u00ED \u010Das",
endtime:"\u010Cas ukon\u010Den\u00ED",
href:"Odkaz",
qtsrcchokespeed:"Sn\u00ED\u017Een\u00ED rychlosti",
target:"C\u00EDl",
volume:"Hlasitost",
autostart:"Automatick\u00E9 spu\u0161t\u011Bn\u00ED",
enabled:"Povolit ovl\u00E1dac\u00ED panel",
fullscreen:"Cel\u00E1 obrazovka",
invokeurls:"Po\u017Eadovat URL",
mute:"Ztlumit",
stretchtofit:"Rozt\u00E1hnout do okna",
windowlessvideo:"Video bez okna",
balance:"Vyv\u00E1\u017Een\u00ED",
baseurl:"Z\u00E1kladn\u00ED URL",
captioningid:"ID popisku m\u00E9dia",
currentmarker:"Aktu\u00E1ln\u00ED z\u00E1lo\u017Eka",
currentposition:"Aktu\u00E1ln\u00ED pozice",
defaultframe:"V\u00FDchoz\u00ED sn\u00EDmek",
playcount:"Po\u010Det p\u0159ehr\u00E1n\u00ED",
rate:"Relativn\u00ED rychlost",
uimode:"Re\u017Eim ovl\u00E1dac\u00EDho panelu",
flash_options:"Mo\u017Enosti Flashe",
qt_options:"Mo\u017Enosti Quicktime",
wmp_options:"Mo\u017Enosti p\u0159ehr\u00E1va\u010De Windows media",
rmp_options:"Mo\u017Enosti p\u0159ehr\u00E1va\u010De Real media",
shockwave_options:"Mo\u017Enosti Shockwave",
autogotourl:"Automatick\u00FD p\u0159echod na URL",
center:"Na st\u0159ed",
imagestatus:"Stav obrazu",
maintainaspect:"Zachovat pom\u011Br stran",
nojava:"Nespout\u011Bt Javu",
prefetch:"P\u0159edna\u010Dten\u00ED",
shuffle:"N\u00E1hodn\u011B",
console:"Konzola",
numloop:"Po\u010Det opakov\u00E1n\u00ED",
controls:"Ovl\u00E1dac\u00ED panel",
scriptcallbacks:"Skripty zp\u011Btn\u00FDch vol\u00E1n\u00ED",
swstretchstyle:"Styl rozta\u017Een\u00ED",
swstretchhalign:"Zarovn\u00E1n\u00ED horiz. rozta\u017Een\u00ED",
swstretchvalign:"Zarovn\u00E1n\u00ED vert. rozta\u017Een\u00ED",
sound:"Zvuk",
progress:"Pr\u016Fb\u011Bh",
qtsrc:"Soubor/URL streamu pro QT",
qt_stream_warn:"Streamovan\u00E9 rtsp zdroje mohou b\u00FDt p\u0159id\u00E1ny do pole 'Soubor/URL streamu pro QT' na z\u00E1lo\u017Ece 'Roz\u0161\u00ED\u0159en\u00E9'.\nYM\u016F\u017Eete tak\u00E9 p\u0159idat nestreamovanou verzi do pole 'Soubor/URL'.",
align_top:"Nahoru",
align_right:"Vpravo",
align_bottom:"Dol\u016F",
align_left:"Vlevo",
align_center:"Na st\u0159ed",
align_top_left:"Nahoru vlevo",
align_top_right:"Nahoru vpravo",
align_bottom_left:"Dol\u016F vlevo",
align_bottom_right:"Dol\u016F vpravo",
flv_options:"Mo\u017Enosti Flash video",
flv_scalemode:"Zm\u011Bna velikosti",
flv_buffer:"Z\u00E1sobn\u00EDk",
flv_startimage:"Po\u010D\u00E1te\u010Dn\u00ED obr\u00E1zek",
flv_starttime:"Po\u010D\u00E1te\u010Dn\u00ED \u010Das",
flv_defaultvolume:"V\u00FDchoz\u00ED hlasitost",
flv_hiddengui:"Skryt\u00FD ovl\u00E1dac\u00ED panel",
flv_autostart:"Automatick\u00E9 spu\u0161t\u011Bn\u00ED",
flv_loop:"Opakov\u00E1n\u00ED",
flv_showscalemodes:"Zobrazit volby zm\u011Bny velikosti",
flv_smoothvideo:"Vyhlazen\u00E9 video",
flv_jscallback:"Zp\u011Btn\u00E9 vol\u00E1n\u00ED Javascriptu"
});