tinyMCE.addI18n('it.media_dlg',{
title:"Inserisci/modifica file multimediale",
general:"Generale",
advanced:"Avanzate",
file:"File/URL",
list:"Lista",
size:"Dimensioni",
preview:"Anteprima",
constrain_proportions:"Mantieni proporzioni",
type:"Tipo",
id:"Id",
name:"Nome",
class_name:"Classe",
vspace:"V-Space",
hspace:"H-Space",
play:"Esecuzione automatica",
loop:"Riproduzione ciclica",
menu:"Mostra menu",
quality:"Qualit\u00E0",
scale:"Scala",
align:"Allineamento",
salign:"SAlign",
wmode:"WMode",
bgcolor:"Sfondo",
base:"Base",
flashvars:"Flashvars",
liveconnect:"SWLiveConnect",
autohref:"AutoHREF",
cache:"Cache",
hidden:"Nascosto",
controller:"Controller",
kioskmode:"Modalit\u00E0 Kiosk",
playeveryframe:"Esegui ogni frame",
targetcache:"Cache del target",
correction:"Nessuna correzione",
enablejavascript:"Abilita JavaScript",
starttime:"Ora inizio",
endtime:"Ora fine",
href:"Href",
qtsrcchokespeed:"Velocit\u00E0 cursore",
target:"Target",
volume:"Volume",
autostart:"Avvio automatico",
enabled:"Abilitato",
fullscreen:"Tutto schermo",
invokeurls:"Invoca URLs",
mute:"Muto",
stretchtofit:"Adatta dimensioni",
windowlessvideo:"Video senza finestra",
balance:"Bilanciamento",
baseurl:"URL base",
captioningid:"Didascalia dell'Id",
currentmarker:"Indicatore corrente",
currentposition:"Posizione corrente",
defaultframe:"frame predefinito",
playcount:"Conteggio esecuzione",
rate:"Qualit\u00E0",
uimode:"Modalit\u00E0 Interfaccia Utente",
flash_options:"Opzioni Flash",
qt_options:"Opzioni Quicktime",
wmp_options:"Opzioni Windows media player",
rmp_options:"Opzioni Real media player",
shockwave_options:"Opzioni Shockwave",
autogotourl:"Vai a URL automatico",
center:"Centra",
imagestatus:"Stato immagine",
maintainaspect:"Mantieni aspetto",
nojava:"No java",
prefetch:"Precaricamento",
shuffle:"Shuffle",
console:"Console",
numloop:"Numero cicli",
controls:"Controlli",
scriptcallbacks:"Script callbacks",
swstretchstyle:"Stretch style",
swstretchhalign:"Stretch H-Align",
swstretchvalign:"Stretch V-Align",
sound:"Suono",
progress:"Avanzamento",
qtsrc:"Sorgente QT",
qt_stream_warn:"Le risorse rstp 'streamed' devono essere aggiunte al campo Sorgente QT nella tabella Avanzate.\nSi dovrebbe inserire anche una versione non 'streamed' al campo Sorgente..",
align_top:"Alto",
align_right:"Destra",
align_bottom:"Basso",
align_left:"Sinistra",
align_center:"Centro",
align_top_left:"Alto a sinistra",
align_top_right:"Alto a destra",
align_bottom_left:"Basso a sinistra",
align_bottom_right:"Basso a destra",
flv_options:"Opzioni video Flash",
flv_scalemode:"Scale mode",
flv_buffer:"Buffer",
flv_startimage:"Immagine avvio",
flv_starttime:"Tempo avvio",
flv_defaultvolume:"Volume predefinito",
flv_hiddengui:"GUI nascosta",
flv_autostart:"Avvio automatico",
flv_loop:"Riproduzione ciclica",
flv_showscalemodes:"Mostra scale modes",
flv_smoothvideo:"Smooth video",
flv_jscallback:"JS Callback"
});