tinyMCE.addI18n('id.table_dlg',{
general_tab:"Umum",
advanced_tab:"Advanced",
general_props:"Properti Umum",
advanced_props:"Properti Advanced",
rowtype:"Row in table part",
title:"Sisipkan/Ubah Tabel",
width:"Lebar",
height:"Tinggi",
cols:"Cols",
rows:"Rows",
cellspacing:"Cellspacing",
cellpadding:"Cellpadding",
border:"Border",
align:"Alignment",
align_default:"Default",
align_left:"Kiri",
align_right:"Kanan",
align_middle:"Tengah",
row_title:"Properti row tabel",
cell_title:"Properti cell tabel",
cell_type:"Cell type",
valign:"Vertical alignment",
align_top:"Atas",
align_bottom:"Bawah",
bordercolor:"Warna Border",
bgcolor:"Warna Background",
merge_cells_title:"Merge cell tabel",
id:"Id",
style:"Style",
langdir:"Bahasa",
langcode:"Kode Bahasa",
mime:"Target MIME type",
ltr:"Kiri ke kanan",
rtl:"Kanan ke kiri",
bgimage:"Gambar Background",
summary:"Summary",
td:"Data",
th:"Header",
cell_cell:"Update current cell",
cell_row:"Update all cells in row",
cell_all:"Update all cells in table",
row_row:"Update current row",
row_odd:"Update odd rows in table",
row_even:"Update even rows in table",
row_all:"Update all rows in table",
thead:"Table Head",
tbody:"Table Body",
tfoot:"Table Foot",
scope:"Scope",
rowgroup:"Row Group",
colgroup:"Col Group",
col_limit:"Anda telah melebihi jumlah maksimum kolom {$cols}.",
row_limit:"Anda telah melebihi jumlah maksimum row {$rows}.",
cell_limit:"Anda telah melebihi jumlah maksimum cell {$cells}.",
missing_scope:"Yakin ingin melanjutkan tanpa menetapkan cakupan sel header tabel ini. Tanpa itu, mungkin sulit bagi beberapa pengguna yang memiliki keterbatasan untuk memahami isi atau data yang ditampilkan dari tabel.",
caption:"Table caption",
frame:"Frame",
frame_none:"none",
frame_groups:"groups",
frame_rows:"rows",
frame_cols:"cols",
frame_all:"all",
rules:"Rules",
rules_void:"void",
rules_above:"above",
rules_below:"below",
rules_hsides:"hsides",
rules_lhs:"lhs",
rules_rhs:"rhs",
rules_vsides:"vsides",
rules_box:"box",
rules_border:"border"
});