tinyMCE.addI18n('nb.table_dlg',{
general_tab:"Generelt",
advanced_tab:"Avansert",
general_props:"Generelt",
advanced_props:"Generelle egenskaper",
rowtype:"Rad i tabell",
title:"Sett inn / rediger tabell",
width:"Bredde",
height:"H\u00F8yde",
cols:"Kolonner",
rows:"Rader",
cellspacing:"Celleavstand",
cellpadding:"Cellefylling",
border:"Ramme",
align:"Justering",
align_default:"Standard",
align_left:"Venstre",
align_right:"H\u00F8yre",
align_middle:"Midtstilt",
row_title:"Radegenskaper",
cell_title:"Celleegenskaper",
cell_type:"Celletype",
valign:"Vertikal justering",
align_top:"Topp",
align_bottom:"Bunn",
bordercolor:"Rammefarge",
bgcolor:"Bakgrunn",
merge_cells_title:"Sl\u00E5 sammen celler",
id:"Id",
style:"Stil",
langdir:"Skriftretning",
langcode:"Spr\u00E5kkode",
mime:"M\u00E5lets MIME-type",
ltr:"Venstre mot h\u00F8yre",
rtl:"H\u00F8yre  mot venstre",
bgimage:"Bakgrunnsbilde",
summary:"Sammendrag",
td:"Data",
th:"Overskrift",
cell_cell:"Oppdater aktuell celle",
cell_row:"Oppdater alle celler i raden",
cell_all:"Oppdater alle celler i tabellen",
row_row:"Oppdater aktuell rad",
row_odd:"Oppdater oddetallsrader",
row_even:"Oppdater partallsrader",
row_all:"Oppdater alle rader",
thead:"Tabellhode",
tbody:"Tabellkropp",
tfoot:"Tabellfot",
scope:"Omr\u00E5de",
rowgroup:"Radgruppe",
colgroup:"Kolonnegruppe",
col_limit:"Du har overskredet maksimalt antall kolonner p\u00E5 {$cols}.",
row_limit:"Du har overskredet maksimalt antall rader p\u00E5 {$rows}.",
cell_limit:"Du har overskredet maksimalt antall celler p\u00E5 {$cells}.",
missing_scope:"Er du sikker p\u00E5 at du vil fortsette uten \u00E5 angi et omr\u00E5de for denne overskrifscellen? Uten dette kan det bli vanskelig for enkelte funksjonshemmede brukere \u00E5 forst\u00E5 innholdet eller dataene som blir presentert i tabellen.",
caption:"Tabelloverskrift",
frame:"Ramme",
frame_none:"ingen",
frame_groups:"grupper",
frame_rows:"rader",
frame_cols:"kolonner",
frame_all:"alle",
rules:"Streker",
rules_void:"ingen",
rules_above:"over",
rules_below:"under",
rules_hsides:"hsider",
rules_lhs:"lhs",
rules_rhs:"rhs",
rules_vsides:"vsides",
rules_box:"boks",
rules_border:"ramme"
});