tinyMCE.addI18n('es.media_dlg',{
title:"Insertar/editar medio embebido",
general:"General",
advanced:"Avanzado",
file:"Archivo/URL",
list:"Lista",
size:"Dimensiones",
preview:"Vista Previa",
constrain_proportions:"Bloquear relaci\u00F3n de aspecto",
type:"Tipo",
id:"Id",
name:"Nombre",
class_name:"Clase",
vspace:"V-Space",
hspace:"H-Space",
play:"Comienzo Autom\u00E1tico",
loop:"Repetitivo",
menu:"Mostrar Men\u00FA",
quality:"Calidad",
scale:"Scale",
align:"Alineaci\u00F3n",
salign:"SAlign",
wmode:"WMode",
bgcolor:"Fondo",
base:"Base",
flashvars:"Flashvars",
liveconnect:"SWLiveConnect",
autohref:"AutoHREF",
cache:"Cach\u00E9",
hidden:"Hidden",
controller:"Controller",
kioskmode:"Kiosk mode",
playeveryframe:"Reproducir todo los frames",
targetcache:"Target cache",
correction:"Sin correci\u00F3n",
enablejavascript:"Habilitar JavaScript",
starttime:"Inicio",
endtime:"Fin",
href:"Href",
qtsrcchokespeed:"Vel. de choque",
target:"Target",
volume:"Volumen",
autostart:"Comienzo Autom\u00E1tico",
enabled:"Habilitado",
fullscreen:"Pantalla Completa",
invokeurls:"Invocar URLs",
mute:"Silencio",
stretchtofit:"Estirar para ajustar",
windowlessvideo:"Video sin ventana",
balance:"Balance",
baseurl:"URL Base",
captioningid:"Captioning id",
currentmarker:"Marcador actual",
currentposition:"Posici\u00F3n actual",
defaultframe:"Frame predet.",
playcount:"Cuantas reproducciones",
rate:"Ratio",
uimode:"Modo UI",
flash_options:"Opciones Flash",
qt_options:"Opciones Quicktime",
wmp_options:"Opciones Windows media player",
rmp_options:"Opciones Real media player",
shockwave_options:"Opciones Shockwave",
autogotourl:"Ir a URL autom\u00E1t.",
center:"Centrado",
imagestatus:"Estado de imagen",
maintainaspect:"Mantener aspecto",
nojava:"No java",
prefetch:"Preb\u00FAsqueda",
shuffle:"Aleatorio",
console:"Consola",
numloop:"N\u00FAm. repeticiones",
controls:"Controles",
scriptcallbacks:"Script callbacks",
swstretchstyle:"Estilo estiramiento",
swstretchhalign:"Alin. H. Estiramiento",
swstretchvalign:"Alin. V. Estiramiento",
sound:"Sonido",
progress:"Progreso",
qtsrc:"QT Src",
qt_stream_warn:"Los recursos rtsp de Streaming deber\u00EDan a\u00F1adirse en el campo QT Src de la pesta\u00F1a avanzada.\nAdem\u00E1s deber\u00EDa a\u00F1adir una versi\u00F3n no Streaming en el campo Src.",
align_top:"Arriba",
align_right:"Derecha",
align_bottom:"Debajo",
align_left:"Izquierda",
align_center:"Centrado",
align_top_left:"Arriba Izda.",
align_top_right:"Arriba Dcha.",
align_bottom_left:"Debajo Izda.",
align_bottom_right:"Debajo Dcha.",
flv_options:"Opciones Video Flash",
flv_scalemode:"Modo escalado",
flv_buffer:"Buffer",
flv_startimage:"Imagen inicio",
flv_starttime:"Tiempo inicio",
flv_defaultvolume:"Volumen predet.",
flv_hiddengui:"Ocultar GUI",
flv_autostart:"Inicio auto.",
flv_loop:"Repetitivo",
flv_showscalemodes:"Mostrar modos escala",
flv_smoothvideo:"Video suave",
flv_jscallback:"JS Callback"
});