tinyMCE.addI18n('de.table_dlg',{
general_tab:"Allgemein",
advanced_tab:"Erweitert",
general_props:"Allgemeine Einstellungen",
advanced_props:"Erweiterte Einstellungen",
rowtype:"Gruppierung",
title:"Tabelle einf\u00FCgen/bearbeiten",
width:"Breite",
height:"H\u00F6he",
cols:"Spalten",
rows:"Zeilen",
cellspacing:"Zellenabstand",
cellpadding:"Abstand innerhalb der Zellen",
border:"Rahmen",
align:"Ausrichtung",
align_default:"Standard",
align_left:"Links",
align_right:"Rechts",
align_middle:"Mittig",
row_title:"Eigenschaften der Zeile",
cell_title:"Eigenschaften der Zelle",
cell_type:"Zellentyp",
valign:"Vertikale Ausrichtung",
align_top:"Oben",
align_bottom:"Unten",
bordercolor:"Rahmenfarbe",
bgcolor:"Hintergrundfarbe",
merge_cells_title:"Zellen vereinen",
id:"ID",
style:"Format",
langdir:"Schriftrichtung",
langcode:"Sprachcode",
mime:"MIME-Type des Inhalts",
ltr:"Links nach rechts",
rtl:"Rechts nach links",
bgimage:"Hintergrundbild",
summary:"Zusammenfassung",
td:"Textzelle",
th:"\u00DCberschrift",
cell_cell:"Diese Zelle ver\u00E4ndern",
cell_row:"Alle Zellen in dieser Zeile ver\u00E4ndern",
cell_all:"Alle Zellen der Tabelle ver\u00E4ndern",
row_row:"Diese Zeile ver\u00E4ndern",
row_odd:"Ungerade Zeilen ver\u00E4ndern",
row_even:"Gerade Zeilen ver\u00E4ndern",
row_all:"Alle Zeilen ver\u00E4ndern",
thead:"Tabellenkopf",
tbody:"Tabelleninhalt",
tfoot:"Tabellenfu\u00DF",
scope:"Bezug",
rowgroup:"Vertikal gruppieren",
colgroup:"Horizontal gruppieren",
col_limit:"Sie haben die maximale Spaltenzahl von {$cols} \u00FCberschritten.",
row_limit:"Sie haben die maximale Zeilenzahl von {$rows} \u00FCberschritten.",
cell_limit:"Sie haben die maximale Zellenzahl von {$cells} \u00FCberschritten.",
missing_scope:"Wollen Sie wirklich keine Beziehung f\u00FCr diese \u00DCberschrift angeben? Benutzer mit k\u00F6rperlichen Einschr\u00E4nkungen k\u00F6nnten Schwierigkeiten haben, den Inhalt der Tabelle zu verstehen.",
caption:"Beschriftung der Tabelle",
frame:"Rahmen",
frame_none:"keine",
frame_groups:"zwischen Gruppen",
frame_rows:"zwischen Zeilen",
frame_cols:"zwischen Spalten",
frame_all:"zwischen allen Zellen",
rules:"Gitter",
rules_void:"keins",
rules_above:"nur oben",
rules_below:"nur unten",
rules_hsides:"oben und unten",
rules_lhs:"nur links",
rules_rhs:"nur rechts",
rules_vsides:"links und rechts",
rules_box:"alle 4 Seiten (Box)",
rules_border:"alle 4 Seiten (Border)"
});