tinyMCE.addI18n('sl.xhtmlxtras_dlg',{
attribute_label_title:"Naslov",
attribute_label_id:"Id",
attribute_label_class:"Razred",
attribute_label_style:"Slog",
attribute_label_cite:"Citat",
attribute_label_datetime:"Datum/ura",
attribute_label_langdir:"Smer pisave",
attribute_option_ltr:"Od leve proti desni",
attribute_option_rtl:"Od desne proti levi",
attribute_label_langcode:"Jezik",
attribute_label_tabindex:"Zap. \u0161t.",
attribute_label_accesskey:"Tipka dostopa",
attribute_events_tab:"Dogodki",
attribute_attrib_tab:"Atributi",
general_tab:"Splo\u0161no",
attrib_tab:"Atributi",
events_tab:"Dogodki",
fieldset_general_tab:"Splo\u0161ne nastavitve",
fieldset_attrib_tab:"Atributi elementa",
fieldset_events_tab:"Dogodki elementa",
title_ins_element:"Vstavljeno",
title_del_element:"Izbrisano",
title_acronym_element:"Kratica",
title_abbr_element:"Okraj\u0161ava",
title_cite_element:"Citat",
remove:"Odstrani",
insert_date:"Vstavi trenutni datum/\u010Das",
option_ltr:"Od leve proti desni",
option_rtl:"Od desne proti levi",
attribs_title:"Vstavi/uredi atribute"
});