tinyMCE.addI18n('zh.media_dlg',{
title:"\u63D2\u5165/\u7F16\u8F91\u591A\u5A92\u4F53",
general:"\u4E00\u822C",
advanced:"\u66F4\u591A\u8BBE\u5B9A",
file:"\u6863\u6848/\u7F51\u5740",
list:"\u5217\u8868",
size:"\u5C3A\u5BF8",
preview:"\u9884\u89C8",
constrain_proportions:"\u4FDD\u6301\u6BD4\u4F8B",
type:"\u7C7B\u578B",
id:"ID \u8BC6\u522B",
name:"\u540D\u7B31",
class_name:"\u7C7B\u578B",
vspace:"\u6C34\u51C6\u95F4\u8DDD",
hspace:"\u5782\u76F4\u95F4\u8DDD",
play:"\u81EA\u52A8\u64AD\u653E",
loop:"\u56DE\u5708\u64AD\u653E",
menu:"\u663E\u793A\u529F\u80FD\u8868",
quality:"\u54C1\u8D28",
scale:"\u6BD4\u4F8B",
align:"\u5BF9\u9F50",
salign:"SAlign",
wmode:"\u89C6\u7A97\u6A21\u5F0F",
bgcolor:"\u80CC\u666F\u8272",
base:"\u57FA\u5E95",
flashvars:"\u53C2\u6570",
liveconnect:"SWLive Connect",
autohref:"\u81EA\u52A8 Href",
cache:"\u6682\u5B58",
hidden:"\u9690\u85CF",
controller:"\u63A7\u5236\u5668",
kioskmode:"Kiosk \u6A21\u5F0F",
playeveryframe:"\u64AD\u653E\u6BCF\u4E00\u5F71\u683C",
targetcache:"\u76EE\u6807\u6682\u5B58",
correction:"\u5C1A\u672A\u4FEE\u6B63",
enablejavascript:"\u5F00\u542FJavaScript",
starttime:"\u5F00\u59CB\u65F6\u95F4",
endtime:"\u7ED3\u675F\u65F6\u95F4",
href:"\u8FDE\u7ED3",
qtsrcchokespeed:"\u963B\u585E\u901F\u5EA6",
target:"\u76EE\u6807",
volume:"\u97F3\u91CF",
autostart:"\u81EA\u52A8\u5F00\u59CB",
enabled:"\u542F\u7528",
fullscreen:"\u5168\u5C4F\u663E\u793A",
invokeurls:"\u76F8\u5173\u7F51\u5740",
mute:"\u9759\u97F3",
stretchtofit:"\u5EF6\u5C55",
windowlessvideo:"\u65E0\u8FB9\u6846",
balance:"\u5E73\u8861",
baseurl:"Base URL",
captioningid:"Captioning ID",
currentmarker:"\u6807\u8BB0\u76EE\u524D\u7684\u4F4D\u7F6E",
currentposition:"\u76EE\u524D\u4F4D\u7F6E",
defaultframe:"\u9884\u8BBE\u5E27",
playcount:"\u64AD\u653E\u6B21\u6570",
rate:"\u6BD4\u7279\u7387",
uimode:"\u5916\u89C2\u6A21\u5F0F",
flash_options:"Flash \u9009\u9879",
qt_options:"Quick Time \u9009\u9879",
wmp_options:"Windows Media Player \u9009\u9879",
rmp_options:"Real Media Player \u9009\u9879",
shockwave_options:"Shockwave \u9009\u9879",
autogotourl:"\u81EA\u52A8\u8F6C\u6362\u6210\u7F51\u5740",
center:"\u5C45\u4E2D",
imagestatus:"\u56FE\u7247\u72B6\u6001",
maintainaspect:"Maintain aspect",
nojava:"No java",
prefetch:"\u7F13\u51B2",
shuffle:"Shuffle",
console:"\u63A7\u5236\u53F0",
numloop:"\u64AD\u653E\u6B21\u6570",
controls:"\u63A7\u5236\u4ECB\u9762",
scriptcallbacks:"\u56DE\u8C03Script",
swstretchstyle:"\u7F29\u653E\u65B9\u5F0F",
swstretchhalign:"\u6C34\u51C6\u7F29\u653E",
swstretchvalign:"\u5782\u76F4\u7F29\u653E",
sound:"\u97F3\u91CF",
progress:"\u8FDB\u5EA6",
qtsrc:"QT Src",
qt_stream_warn:"\u7A0B\u5F0F\u9519\u8BEF\uFF0C\u53EF\u80FD\u8BBE\u5B9A\u6709\u8BEF\u3002 ",
align_top:"\u4E0A\u65B9",
align_right:"\u9760\u53F3",
align_bottom:"\u4E0B\u65B9",
align_left:"\u9760\u5DE6",
align_center:"\u4E2D\u95F4",
align_top_left:"\u5DE6\u4E0A",
align_top_right:"\u53F3\u4E0A",
align_bottom_left:"\u5DE6\u4E0B",
align_bottom_right:"\u53F3\u4E0B",
flv_options:"Flash \u9009\u9879",
flv_scalemode:"\u4FDD\u6301\u6BD4\u4F8B",
flv_buffer:"\u7F13\u51B2",
flv_startimage:"\u5F00\u59CB\u753B\u9762",
flv_starttime:"\u5F00\u59CB\u65F6\u95F4",
flv_defaultvolume:"\u9884\u8BBE\u97F3\u91CF",
flv_hiddengui:"\u9690\u85CF\u64AD\u653E\u4ECB\u9762",
flv_autostart:"\u81EA\u52A8\u64AD\u653E",
flv_loop:"\u91CD\u64AD",
flv_showscalemodes:"Show scale modes",
flv_smoothvideo:"\u5E73\u6ED1\u5316",
flv_jscallback:"\u56DE\u8C03Javascript"
});