tinyMCE.addI18n('vi.advanced_dlg',{
about_title:"Th\u00F4ng tin v\u1EC1 TinyMCE",
about_general:"Th\u00F4ng tin",
about_help:"Tr\u1EE3 gi\u00FAp",
about_license:"Gi\u1EA5y ph\u00E9p",
about_plugins:"Tr\u00ECnh g\u1EAFn k\u00E8m",
about_plugin:"Tr\u00ECnh g\u1EAFn k\u00E8m",
about_author:"T\u00E1c gi\u1EA3",
about_version:"Phi\u00EAn b\u1EA3n",
about_loaded:"Tr\u00ECnh g\u1EAFn k\u00E8m \u0111\u00E3 n\u1EA1p",
anchor_title:"Ch\u00E8n/s\u1EEDa m\u1ECF neo",
anchor_name:"T\u00EAn m\u1ECF neo",
code_title:"Tr\u00ECnh so\u1EA1n th\u1EA3o m\u00E3 ngu\u1ED3n HTML",
code_wordwrap:"Xu\u1ED1ng d\u00F2ng t\u1EF1 \u0111\u1ED9ng",
colorpicker_title:"Ch\u1ECDn m\u1ED9t m\u00E0u",
colorpicker_picker_tab:"B\u1ED9 ch\u1ECDn",
colorpicker_picker_title:"B\u1ED9 ch\u1ECDn m\u00E0u",
colorpicker_palette_tab:"B\u1EA3ng m\u00E0u",
colorpicker_palette_title:"B\u1EA3ng m\u00E0u",
colorpicker_named_tab:"T\u00EAn",
colorpicker_named_title:"M\u00E0u \u0111\u00E3 \u0111\u1EB7t t\u00EAn",
colorpicker_color:"M\u00E0u:",
colorpicker_name:"T\u00EAn:",
charmap_title:"Ch\u1ECDn k\u00FD t\u1EF1 t\u00F9y bi\u1EBFn",
image_title:"Ch\u00E8n/s\u1EEDa \u1EA3nh",
image_src:"URL \u1EA3nh",
image_alt:"M\u00F4 t\u1EA3 \u1EA3nh",
image_list:"Danh s\u00E1ch \u1EA3nh",
image_border:"Vi\u1EC1n",
image_dimensions:"K\u00EDch th\u01B0\u1EDBng",
image_vspace:"Kho\u1EA3ng c\u00E1ch d\u1ECDc",
image_hspace:"Kho\u1EA3ng c\u00E1ch ngang",
image_align:"Canh l\u1EC1n",
image_align_baseline:"\u0110\u01B0\u1EDDng c\u01A1 s\u1EDF",
image_align_top:"Tr\u00EAn c\u00F9ng",
image_align_middle:"Gi\u1EEFa",
image_align_bottom:"D\u01B0\u1EDBi c\u00F9ng",
image_align_texttop:"V\u0103n b\u1EA3n tr\u00EA",
image_align_textbottom:"V\u0103n b\u1EA3n d\u01B0\u1EDBi",
image_align_left:"Tr\u00E1i",
image_align_right:"Ph\u1EA3i",
link_title:"Th\u00EAm/S\u1EEDa Li\u00EAn k\u1EBFt",
link_url:"URL Li\u00EAn k\u1EBFt",
link_target:"\u0110\u00EDch",
link_target_same:"M\u1EDF li\u00EAn k\u1EBFt trong c\u00F9ng c\u1EEDa s\u1ED5",
link_target_blank:"M\u1EDF li\u00EAn k\u1EBFt trong c\u1EEDa s\u1ED5 m\u1EDBi",
link_titlefield:"Ti\u00EAu \u0111\u1EC1",
link_is_email:"URL b\u1EA1n \u0111\u00E3 nh\u1EADp c\u00F3 v\u1EBB l\u00E0 m\u1ED9t \u0111\u1ECBa ch\u1EC9 \u0111i\u1EC7n th\u01B0, B\u1EA1n c\u00F3 mu\u1ED1n th\u00EAm ti\u1EC1n t\u1ED1 mailto?",
link_is_external:"URL b\u1EA1n \u0111\u00E3 nh\u1EADp c\u00F3 v\u1EBB l\u00E0 m\u1ED9t li\u00EAn k\u1EBFt ngo\u00E0i, b\u1EA1n c\u00F3 mu\u1ED1n th\u00EAm ti\u1EC1n t\u1ED1 http://?",
link_list:"Danh s\u00E1ch li\u00EAn k\u1EBFt"
});