tinyMCE.addI18n('lb.emotions_dlg',{
title:"Smiley af\u00FCgen",
desc:"Smileyen",
cool:"Cool",
cry:"Kr\u00E4ischend",
embarassed:"Gen\u00E9iert",
foot_in_mouth:"Eragefall",
frown:"D'Stir ronzelend",
innocent:"Onsch\u00EBlleg",
kiss:"Kussend",
laughing:"Laachend",
money_mouth:"Suen",
sealed:"Verschlossen",
smile:"Laachend",
surprised:"Iwwerrascht",
tongue_out:"Zong eraus",
undecided:"Onentschloss",
wink:"Zwinkernd",
yell:"Br\u00EBllend"
});