tinyMCE.addI18n('id.advimage_dlg',{
tab_general:"Umum",
tab_appearance:"Tampilan",
tab_advanced:"Advanced",
general:"Umun",
title:"Judul",
preview:"Preview",
constrain_proportions:"Proporsi dibatasi",
langdir:"Bahasa",
langcode:"Kode bahasa",
long_desc:"Deskripsi panjang link",
style:"Style",
classes:"Classes",
ltr:"Kiri ke kanan",
rtl:"Kanan ke kiri",
id:"Id",
map:"Image map",
swap_image:"Swap image",
alt_image:"Alternatif gambar",
mouseover:"untuk mouse over",
mouseout:"untuk mouse out",
misc:"Rupa-rupa",
example_img:"Gambar pra-tampil",
missing_alt:"Yakin ingin melanjutkan tanpa menyertakan deskripsi gambar? Gambar mungkin tidak dapat diakses oleh beberapa pengguna yang yang memiliki keterbatasan, atau mereka yang menggunakan modus teks browser, atau berselancar di Web dengan gambar dimatikan.",
dialog_title:"sisipkan/Ubah Gambar",
src:"URL Gambar",
alt:"Deskripsi Gambar",
list:"Daftar Gambar",
border:"Border",
dimensions:"Dimensi",
vspace:"Vertical space",
hspace:"Horizontal space",
align:"Alignment",
align_baseline:"Baseline",
align_top:"Top",
align_middle:"Middle",
align_bottom:"Bottom",
align_texttop:"Text top",
align_textbottom:"Text bottom",
align_left:"Left",
align_right:"Right",
image_list:"Daftar Gambar"
});