tinyMCE.addI18n('ml.advanced',{
style_select:"\u0D30\u0D42\u0D2A\u0D2D\u0D02\u0D17\u0D3F",
font_size:"\u0D05\u0D15\u0D4D\u0D37\u0D30\u0D35\u0D32\u0D41\u0D2A\u0D4D\u0D2A\u0D02",
fontdefault:"\u0D05\u0D15\u0D4D\u0D37\u0D30\u0D15\u0D42\u0D1F\u0D4D\u0D1F\u0D02",
block:"\u0D18\u0D1F\u0D28",
paragraph:"\u0D16\u0D23\u0D4D\u0D21\u0D3F\u0D15",
div:"Div",
address:"\u0D35\u0D3F\u0D32\u0D3E\u0D38\u0D02",
pre:"Preformatted",
h1:"\u0D24\u0D32\u0D15\u0D4D\u0D15\u0D46\u0D1F\u0D4D\u0D1F\u0D41\u0D4D 1",
h2:"\u0D24\u0D32\u0D15\u0D4D\u0D15\u0D46\u0D1F\u0D4D\u0D1F\u0D41\u0D4D  2",
h3:"\u0D24\u0D32\u0D15\u0D4D\u0D15\u0D46\u0D1F\u0D4D\u0D1F\u0D41\u0D4D  3",
h4:"\u0D24\u0D32\u0D15\u0D4D\u0D15\u0D46\u0D1F\u0D4D\u0D1F\u0D41\u0D4D  4",
h5:"\u0D24\u0D32\u0D15\u0D4D\u0D15\u0D46\u0D1F\u0D4D\u0D1F\u0D41\u0D4D  5",
h6:"\u0D24\u0D32\u0D15\u0D4D\u0D15\u0D46\u0D1F\u0D4D\u0D1F\u0D41\u0D4D  6",
blockquote:"Blockquote",
code:"Code",
samp:"Code sample",
dt:"Definition term ",
dd:"Definition description",
bold_desc:"Bold (Ctrl+B)",
italic_desc:"Italic (Ctrl+I)",
underline_desc:"Underline (Ctrl+U)",
striketrough_desc:"Strikethrough",
justifyleft_desc:"Align left",
justifycenter_desc:"Align center",
justifyright_desc:"Align right",
justifyfull_desc:"Align full",
bullist_desc:"Unordered list",
numlist_desc:"Ordered list",
outdent_desc:"Outdent",
indent_desc:"Indent",
undo_desc:"Undo (Ctrl+Z)",
redo_desc:"Redo (Ctrl+Y)",
link_desc:"Insert/edit link",
unlink_desc:"\u0D35\u0D3F\u0D1A\u0D4D\u0D1B\u0D47\u0D26\u0D3F\u0D15\u0D4D\u0D15\u0D41\u0D15",
image_desc:"Insert/edit image",
cleanup_desc:"Cleanup messy code",
code_desc:"Edit HTML Source",
sub_desc:"Subscript",
sup_desc:"Superscript",
hr_desc:"Insert horizontal ruler",
removeformat_desc:"Remove formatting",
custom1_desc:"Your custom description here",
forecolor_desc:"Select text color",
backcolor_desc:"Select background color",
charmap_desc:"Insert custom character",
visualaid_desc:"Toggle guidelines/invisible elements",
anchor_desc:"Insert/edit anchor",
cut_desc:"\u0D2E\u0D41\u0D31\u0D3F\u0D15\u0D4D\u0D15\u0D41\u0D15",
copy_desc:"\u0D2A\u0D15\u0D30\u0D4D\u200D\u0D24\u0D4D\u0D24\u0D41\u0D15",
paste_desc:"\u0D12\u0D1F\u0D4D\u0D1F\u0D3F\u0D15\u0D4D\u0D15\u0D41\u0D15",
image_props_desc:"Image properties",
newdocument_desc:"New document",
help_desc:"Help",
blockquote_desc:"Blockquote",
clipboard_msg:"\u0D2E\u0D41\u0D31\u0D3F\u0D15\u0D4D\u0D15\u0D32\u0D4D\u200D/\u0D2A\u0D15\u0D30\u0D4D\u200D\u0D24\u0D4D\u0D24\u0D32\u0D4D\u200D/\u0D12\u0D1F\u0D4D\u0D1F\u0D3F\u0D15\u0D4D\u0D15\u0D32\u0D4D\u200D  \u0D0E\u0D28\u0D4D\u0D28\u0D3F\u0D35 '\u0D2E\u0D4B\u0D38\u0D3F\u0D32\u0D4D\u0D32'\u0D2F\u0D3F\u0D32\u0D41\u0D02 '\u0D2B\u0D2F\u0D30\u0D4D\u200D\u0D2B\u0D4B\u0D15\u0D4D\u0D38\u0D4D'\u0D32\u0D41\u0D02 \u0D32\u0D2D\u0D4D\u0D2F\u0D2E\u0D32\u0D4D\u0D32. \n\u0D24\u0D3E\u0D19\u0D4D\u0D15\u0D33\u0D4D\u200D\u0D15\u0D4D\u0D15\u0D41 \u0D07\u0D24\u0D3F\u0D28\u0D46 \u0D15\u0D41\u0D31\u0D3F\u0D1A\u0D4D\u0D1A\u0D41\u0D4D \u0D15\u0D42\u0D1F\u0D41\u0D24\u0D32\u0D4D\u200D \u0D05\u0D31\u0D3F\u0D2F\u0D23\u0D4B ?",
path:"Path",
newdocument:"Are you sure you want clear all contents?",
toolbar_focus:"Jump to tool buttons - Alt+Q, Jump to editor - Alt-Z, Jump to element path - Alt-X",
more_colors:"More colors"
});