tinyMCE.addI18n('tr.xhtmlxtras_dlg',{
attribute_label_title:"Ba\u015Fl\u0131k",
attribute_label_id:"ID",
attribute_label_class:"S\u0131n\u0131f",
attribute_label_style:"Stil",
attribute_label_cite:"Al\u0131nt\u0131 yapmak",
attribute_label_datetime:"Tarih/Saat",
attribute_label_langdir:"Metnin y\u00F6n\u00FC",
attribute_option_ltr:"Sa\u011Fdan sola",
attribute_option_rtl:"Soldan sa\u011Fa",
attribute_label_langcode:"Dil",
attribute_label_tabindex:"Sekme indeksi",
attribute_label_accesskey:"Eri\u015Fim Tu\u015Fu",
attribute_events_tab:"Olaylar",
attribute_attrib_tab:"Nitelikler",
general_tab:"Genel",
attrib_tab:"Nitelikler",
events_tab:"Olaylar",
fieldset_general_tab:"Genel Ayarlar",
fieldset_attrib_tab:"Nesne Nitelikleri",
fieldset_events_tab:"Nesne Olaylar\u0131",
title_ins_element:"Nesne Ekleme",
title_del_element:"Nesne Silme",
title_acronym_element:"Nense K\u0131sa ad\u0131",
title_abbr_element:"Nesne K\u0131saltmas\u0131",
title_cite_element:"Nesne Al\u0131nt\u0131s\u0131",
remove:"Sil",
insert_date:"\u015Euan ki tarih/saati ekle",
option_ltr:"Sa\u011Fdan sola",
option_rtl:"Soldan sa\u011Fa",
attribs_title:"Nitelik ekle/d\u00FCzenle"
});