tinyMCE.addI18n('ro.table_dlg',{
general_tab:"General",
advanced_tab:"Avansat",
general_props:"Propriet\u0103\u0163i generale",
advanced_props:"Propriet\u0103\u0163i avansate",
rowtype:"R\u0103nd \u00EEn tabel",
title:"Inserare/modificare tabel",
width:"L\u0103\u0163ime",
height:"\u00CEn\u0103l\u0163ime",
cols:"Coloane",
rows:"R\u00E2nduri",
cellspacing:"Spa\u0163iu \u00EEntre celule",
cellpadding:"Spa\u0163iu \u00EEn celule",
border:"Bordur\u0103",
align:"Aliniere",
align_default:"Implicit\u0103",
align_left:"St\u00E2nga",
align_right:"Dreapta",
align_middle:"Centru",
row_title:"Propriet\u0103\u0163i r\u00E2nd",
cell_title:"Propriet\u0103\u0163i celul\u0103",
cell_type:"Tip celul\u0103",
valign:"Aliniere vertical\u0103",
align_top:"Sus",
align_bottom:"Jos",
bordercolor:"Culoare bordur\u0103",
bgcolor:"Culoare fundal",
merge_cells_title:"Uni\u0163i celulele",
id:"Id",
style:"Stil",
langdir:"Direc\u0163ie limb\u0103",
langcode:"Cod limb\u0103",
mime:"MIME type \u0163int\u0103",
ltr:"De la st\u00E2nga la dreapta",
rtl:"De la dreapta la st\u00E2nga",
bgimage:"Imagine de fundal",
summary:"Sumar",
td:"Date",
th:"Antet",
cell_cell:"Actualizeaz\u0103 celula curent\u0103",
cell_row:"Actualizeaz\u0103 toate celulele din r\u00E2nd",
cell_all:"Actualizeaz\u0103 toate celulele din tabel",
row_row:"Actualizeaz\u0103 r\u00E2nd curent",
row_odd:"Actualizeaz\u0103 r\u00E2ndurile impare",
row_even:"Actualizeaz\u0103 r\u00E2ndurile pare",
row_all:"Actualizeaz\u0103 toate r\u00E2ndurile",
thead:"Antet tabel",
tbody:"Corp tabel",
tfoot:"Subsol tabel",
scope:"Scop",
rowgroup:"Grupeaz\u0103 r\u00E2nduri",
colgroup:"Grupeaz\u0103 celule",
col_limit:"A\u0163i dep\u0103\u015Fit num\u0103rul maxim de coloane: {$cols}.",
row_limit:"A\u0163i dep\u0103\u015Fit num\u0103rul maxim de r\u00E2nduri: {$rows}.",
cell_limit:"A\u0163i dep\u0103\u015Fit num\u0103rul maxim de celule: {$cells}.",
missing_scope:"Sigur dori\u0163i s\u0103 l\u0103sa\u0163i scopul necompletat? ",
caption:"Titlu tabel",
frame:"Frame",
frame_none:"niciuna",
frame_groups:"grupuri",
frame_rows:"r\u00E2nduri",
frame_cols:"coloane",
frame_all:"toate",
rules:"Reguli",
rules_void:"gol",
rules_above:"deasupra",
rules_below:"dedesubt",
rules_hsides:"hsides",
rules_lhs:"lhs",
rules_rhs:"rhs",
rules_vsides:"vsides",
rules_box:"box",
rules_border:"border"
});