tinyMCE.addI18n('tr.media_dlg',{
title:"T\u00FCmle\u015Fik medya ekle / d\u00FCzenle",
general:"Genel",
advanced:"Geli\u015Fmi\u015F",
file:"Dosya/URL",
list:"Listele",
size:"Boyutlar",
preview:"\u00D6nizleme",
constrain_proportions:"Oran\u0131 s\u0131n\u0131rla",
type:"Tip",
id:"Id",
name:"\u0130sim",
class_name:"S\u0131n\u0131f",
vspace:"Dikey bo\u015Fluk",
hspace:"Yatay bo\u015Fluk",
play:"Otomatik oynat",
loop:"D\u00F6nd\u00FCr",
menu:"Men\u00FCy\u00FC g\u00F6ster",
quality:"Kalite",
scale:"\u00D6l\u00E7ek",
align:"Hizala",
salign:"SHizala",
wmode:"WModu",
bgcolor:"Arkaplan",
base:"Taban",
flashvars:"Flash de\u011Fi\u015Fkeni",
liveconnect:"SWLiveConnect",
autohref:"AutoHREF",
cache:"\u00D6nbellek",
hidden:"Gizli",
controller:"Kontroller",
kioskmode:"Kiosk modu",
playeveryframe:"Her \u00E7er\u00E7eveyi oynat",
targetcache:"Hedef \u00F6nbellek",
correction:"D\u00FCzeltme yok",
enablejavascript:"Javascript Aktif",
starttime:"Ba\u015Flang\u0131\u00E7 zaman\u0131",
endtime:"Biti\u015F zaman\u0131",
href:"Href",
qtsrcchokespeed:"S\u0131k\u0131\u015Ft\u0131rma h\u0131z\u0131",
target:"Hedef",
volume:"Ses d\u00FCzeyi",
autostart:"Otomatik ba\u015Flat",
enabled:"Aktif",
fullscreen:"Tam ekran",
invokeurls:"Ba\u015Flatma URL'si",
mute:"Sessiz",
stretchtofit:"S\u0131\u011Facak \u015Fekilde boyutland\u0131r",
windowlessvideo:"Penceresiz video",
balance:"Denge",
baseurl:"Ge\u00E7erli URL",
captioningid:"Ba\u015Fl\u0131k id",
currentmarker:"Se\u00E7ili i\u015Faret\u00E7i",
currentposition:"Se\u00E7ili konum",
defaultframe:"Varsay\u0131lan \u00E7er\u00E7eve",
playcount:"Oynatma say\u0131s\u0131",
rate:"Oran",
uimode:"UI Modu",
flash_options:"Flash se\u00E7enekleri",
qt_options:"Quicktime se\u00E7enekleri",
wmp_options:"Windows media player se\u00E7enekleri",
rmp_options:"Real media player se\u00E7enekleri",
shockwave_options:"Shockware se\u00E7enekleri",
autogotourl:"URL'e otomatik git",
center:"Orta",
imagestatus:"Resim durumu",
maintainaspect:"Orant\u0131y\u0131 koru",
nojava:"Java yok",
prefetch:"\u00D6n belle\u011Fe al",
shuffle:"Kar\u0131\u015Ft\u0131r",
console:"Konsol",
numloop:"D\u00F6ng\u00FC say\u0131s\u0131",
controls:"Kontroller",
scriptcallbacks:"Script \u00E7a\u011F\u0131r",
swstretchstyle:"Esnetme stili",
swstretchhalign:"Esnetme Y-Hiza",
swstretchvalign:"Esnetme D-Hiza",
sound:"Ses",
progress:"\u0130lerle",
qtsrc:"QT Kay.",
qt_stream_warn:"Ak\u0131\u015F rtsp kaynaklar\u0131 geli\u015Fmi\u015F alt\u0131ndaki QT Kay. alan\u0131na girilmeli.\nKay. alan\u0131na ayr\u0131ca ak\u0131\u015Fkan olmayan eklenir.",
align_top:"\u00DCst",
align_right:"Sa\u011F",
align_bottom:"Bottom",
align_left:"Sol",
align_center:"Orta",
align_top_left:"Sol \u00FCst",
align_top_right:"Sa\u011F \u00FCst",
align_bottom_left:"Sol alt",
align_bottom_right:"Sa\u011F alt",
flv_options:"Flash video se\u00E7enekleri",
flv_scalemode:"\u00D6l\u00E7ek modu",
flv_buffer:"Tampon",
flv_startimage:"Resmi ba\u015Flat",
flv_starttime:"Ba\u015Flang\u0131\u00E7 zaman\u0131",
flv_defaultvolume:"Varsay\u0131lan ses d\u00FCzeyi",
flv_hiddengui:"Gizli GUI",
flv_autostart:"Otomatik ba\u015Flat",
flv_loop:"D\u00F6nd\u00FCr",
flv_showscalemodes:"\u00D6l\u00E7ek modunu g\u00F6ster",
flv_smoothvideo:"D\u00FCzg\u00FCn video",
flv_jscallback:"JS \u00C7e\u011F\u0131r"
});