tinyMCE.addI18n('nb.media_dlg',{
title:"Sett inn / rediger inkludert objekt",
general:"Generelt",
advanced:"Avansert",
file:"Fil/URL",
list:"Liste",
size:"St\u00F8rrelse",
preview:"Forh\u00E5ndsvisning",
constrain_proportions:"Behold st\u00F8rrelsesforhold",
type:"Type",
id:"Id",
name:"Navn",
class_name:"Klasse",
vspace:"Vertikal avstand",
hspace:"Horisontal avstand",
play:"Autostart",
loop:"L\u00F8kke",
menu:"Vis meny",
quality:"Kvalitet",
scale:"Skalering",
align:"Justering",
salign:"S-justering",
wmode:"W-modus",
bgcolor:"Bakgrunn",
base:"Base",
flashvars:"Flash-variabler",
liveconnect:"SWLiveConnect",
autohref:"AutoHREF",
cache:"Cache",
hidden:"Skjult",
controller:"Kontroller",
kioskmode:"Kiosk-modus",
playeveryframe:"Spill hver ramme",
targetcache:"M\u00E5l-cache",
correction:"Ingen korreksjon",
enablejavascript:"Tillat Javaskript",
starttime:"Starttid",
endtime:"Stopptid",
href:"Href",
qtsrcchokespeed:"Choke-fart",
target:"M\u00E5l",
volume:"Volum",
autostart:"Autostart",
enabled:"Kj\u00F8rbar",
fullscreen:"Fullskjerm",
invokeurls:"Aktiviser URL-er",
mute:"Demp",
stretchtofit:"Strekk for \u00E5 passe inn",
windowlessvideo:"Video uten vindu",
balance:"Balanse",
baseurl:"Base URL",
captioningid:"Fang opp id",
currentmarker:"Aktiv mark\u00F8r",
currentposition:"Aktiv posisjon",
defaultframe:"Standardramme",
playcount:"Teller",
rate:"Rate",
uimode:"UI-modus",
flash_options:"Flash-egenskaper",
qt_options:"Quicktime-innstillinger",
wmp_options:"Windows mediaplayer-innstillinger",
rmp_options:"Real mediaplayer-innstillinger",
shockwave_options:"Shockwave-innstillinger",
autogotourl:"Auto-g\u00E5-til-URL",
center:"Midtstill",
imagestatus:"Bildestatus",
maintainaspect:"Behold st\u00F8rrelsesforhold",
nojava:"Ikke Java",
prefetch:"Forh\u00E5ndsregistrer",
shuffle:"Miks",
console:"Konsoll",
numloop:"Antall gjennoml\u00F8p",
controls:"Kontroller",
scriptcallbacks:"Skript-referanser",
swstretchstyle:"Strekkstil",
swstretchhalign:"Strekk H-justering",
swstretchvalign:"Strekk V-justering",
sound:"Lyd",
progress:"Framdrift",
qtsrc:"QT Src",
qt_stream_warn:"Streamede rtsp-ressurser b\u00F8r legges til QT Src field i avansert-fanen.\nDu b\u00F8r ogs\u00E5 legge til en ikke-streamet versjon i src field",
align_top:"Topp",
align_right:"H\u00F8yre",
align_bottom:"Bunn",
align_left:"Venstre",
align_center:"Midt",
align_top_left:"Topp venstre",
align_top_right:"Topp h\u00F8yre",
align_bottom_left:"Bunn venstre",
align_bottom_right:"Bunn h\u00F8yre",
flv_options:"Flash video-valg",
flv_scalemode:"Skalering",
flv_buffer:"Buffer",
flv_startimage:"Startbilde",
flv_starttime:"Starttid",
flv_defaultvolume:"Standardvolum",
flv_hiddengui:"Skjult GUI",
flv_autostart:"Auto-start",
flv_loop:"L\u00F8kke",
flv_showscalemodes:"Vis skalering",
flv_smoothvideo:"Jevn video",
flv_jscallback:"JS Callback"
});