tinyMCE.addI18n('lv.advanced_dlg',{
about_title:"Par TinyMCE",
about_general:"Par",
about_help:"Pal\u012Bdz\u012Bba",
about_license:"Licence",
about_plugins:"Papildmodu\u013Ci",
about_plugin:"Papildmodulis",
about_author:"Autors",
about_version:"Versija",
about_loaded:"Iestat\u012Btie papildmodu\u013Ci",
anchor_title:"Ievietot/Redi\u0123\u0113t enkursaiti",
anchor_name:"Enkursaites nosaukums",
code_title:"HTML koda redaktors",
code_wordwrap:"V\u0101rdu p\u0101rne\u0161ana jaun\u0101 rind\u0101",
colorpicker_title:"Izv\u0113l\u0113ties kr\u0101su",
colorpicker_picker_tab:"Izv\u0113lnis",
colorpicker_picker_title:"Kr\u0101su izv\u0113lnis",
colorpicker_palette_tab:"Palete",
colorpicker_palette_title:"Kr\u0101su palete",
colorpicker_named_tab:"Nosaukts",
colorpicker_named_title:"Nosaukt\u0101s kr\u0101sas",
colorpicker_color:"Kr\u0101sa:",
colorpicker_name:"Nosaukums:",
charmap_title:"Izv\u0113lies simbolu",
image_title:"Ievietot/Redi\u0123\u0113t att\u0113lu",
image_src:"Att\u0113la URL",
image_alt:"Att\u0113la apraksts",
image_list:"Att\u0113lu saraksts",
image_border:"Apmale",
image_dimensions:"Izm\u0113ri",
image_vspace:"Vertik\u0101l\u0101 atstarpe",
image_hspace:"Horizont\u0101l\u0101 atstarpe",
image_align:"Novietojums",
image_align_baseline:"Pati apak\u0161a",
image_align_top:"Aug\u0161a",
image_align_middle:"Vidus",
image_align_bottom:"Apak\u0161a",
image_align_texttop:"Teksta aug\u0161a",
image_align_textbottom:"Teksta apak\u0161a",
image_align_left:"Pa kreisi",
image_align_right:"Pa labi",
link_title:"Ievietot/Redi\u0123\u0113t saiti",
link_url:"Saites URL",
link_target:"M\u0113r\u0137is",
link_target_same:"Atv\u0113rt saiti \u0161ai pa\u0161\u0101 log\u0101",
link_target_blank:"Atv\u0113rt saiti jaun\u0101 log\u0101",
link_titlefield:"Nosaukums",
link_is_email:"Ievad\u012Btais URL \u0161\u0137iet ir e-pasta adrese, vai tu v\u0113lies pirms t\u0101s pievienot mailto: pried\u0113kli? ",
link_is_external:"Ievad\u012Btais URL \u0161\u0137iet ir \u0101r\u0113j\u0101 saite, vai tu v\u0113lies pirms t\u0101s pievienot http:// pried\u0113kli?",
link_list:"Sai\u0161u saraksts"
});