tinyMCE.addI18n('hu.advanced',{
style_select:"St\u00EDlusok",
font_size:"Bet\u0171m\u00E9ret",
fontdefault:"Bet\u0171t\u00EDpus",
block:"Form\u00E1tum",
paragraph:"Bekezd\u00E9s",
div:"Div",
address:"C\u00EDm",
pre:"El\u0151form\u00E1zott",
h1:"C\u00EDmsor 1",
h2:"C\u00EDmsor 2",
h3:"C\u00EDmsor 3",
h4:"C\u00EDmsor 4",
h5:"C\u00EDmsor 5",
h6:"C\u00EDmsor 6",
blockquote:"Id\u00E9zet",
code:"K\u00F3d",
samp:"K\u00F3d minta",
dt:"Defini\u00E1lt kifejez\u00E9s a defin\u00EDci\u00F3s list\u00E1ban",
dd:"Defin\u00EDci\u00F3 a defin\u00EDci\u00F3s list\u00E1ban",
bold_desc:"F\u00E9lk\u00F6v\u00E9r (Ctrl+B)",
italic_desc:"D\u0151lt (Ctrl+I)",
underline_desc:"Al\u00E1h\u00FAzott (Ctrl+U)",
striketrough_desc:"\u00C1th\u00FAzott",
justifyleft_desc:"Balra z\u00E1rt",
justifycenter_desc:"K\u00F6z\u00E9pre z\u00E1rt",
justifyright_desc:"Jobbra z\u00E1rt",
justifyfull_desc:"Sorkiz\u00E1rt",
bullist_desc:"Rendezetlen lista",
numlist_desc:"Rendezett lista",
outdent_desc:"Beh\u00FAz\u00E1s cs\u00F6kkent\u00E9se",
indent_desc:"Beh\u00FAz\u00E1s n\u00F6vel\u00E9se",
undo_desc:"Visszavon\u00E1s (Ctrl+Z)",
redo_desc:"M\u00E9gis v\u00E9grehajt (Ctrl+Y)",
link_desc:"Link besz\u00FAr\u00E1sa/szerkeszt\u00E9se",
unlink_desc:"Link megsz\u00FCntet\u00E9se",
image_desc:"K\u00E9p besz\u00FAr\u00E1sa/szerkeszt\u00E9se",
cleanup_desc:"Rendetlen k\u00F3d takar\u00EDt\u00E1sa",
code_desc:"HTML forr\u00E1s szerkeszt\u00E9se",
sub_desc:"Als\u00F3 index",
sup_desc:"Fels\u0151 index",
hr_desc:"V\u00EDzszintes elv\u00E1laszt\u00F3 besz\u00FAr\u00E1sa",
removeformat_desc:"Form\u00E1z\u00E1s elt\u00E1vol\u00EDt\u00E1sa",
custom1_desc:"Az \u00F6n egyedi le\u00EDr\u00E1sa",
forecolor_desc:"Sz\u00F6vegsz\u00EDn v\u00E1laszt\u00E1sa",
backcolor_desc:"H\u00E1tt\u00E9rsz\u00EDn v\u00E1laszt\u00E1sa",
charmap_desc:"Speci\u00E1lis karakter besz\u00FAr\u00E1sa",
visualaid_desc:"Vezet\u0151vonalak/nem l\u00E1that\u00F3 elemek ki-/bekapcsol\u00E1sa",
anchor_desc:"Horgony besz\u00FAr\u00E1sa/szerkeszt\u00E9se",
cut_desc:"Kiv\u00E1g\u00E1s",
copy_desc:"M\u00E1sol\u00E1s",
paste_desc:"Besz\u00FAr\u00E1s",
image_props_desc:"K\u00E9p tulajdons\u00E1gai",
newdocument_desc:"\u00DAj dokumentum",
help_desc:"Seg\u00EDts\u00E9g",
blockquote_desc:"Id\u00E9zet",
clipboard_msg:"A M\u00E1sol\u00E1s/Kiv\u00E1g\u00E1s/Besz\u00FAr\u00E1s funkci\u00F3k nem \u00E9rhet\u0151ek el Mozilla \u00E9s Firefox alatt. K\u00EDv\u00E1n t\u00F6bbet tudni err\u0151l a t\u00E9m\u00E1r\u00F3l?",
path:"\u00DAtvonal",
newdocument:"Biztosan t\u00F6rli az eddigi tartalmat?",
toolbar_focus:"Eszk\u00F6zgombokra ugr\u00E1s - Alt+Q, Szerkeszt\u0151h\u00F6z ugr\u00E1s - Alt-Z, Elem\u00FAtvonalhoz ugr\u00E1s - Alt-X",
more_colors:"T\u00F6bb sz\u00EDn"
});