tinyMCE.addI18n('nl.xhtmlxtras_dlg',{
attribute_label_title:"Titel",
attribute_label_id:"ID",
attribute_label_class:"Klasse",
attribute_label_style:"Stijl",
attribute_label_cite:"Citaat",
attribute_label_datetime:"Datum/Tijd",
attribute_label_langdir:"Tekstrichting",
attribute_option_ltr:"Van links naar rechts",
attribute_option_rtl:"Van rechts naar links",
attribute_label_langcode:"Taal",
attribute_label_tabindex:"Tabvolgorde",
attribute_label_accesskey:"Toegangstoets",
attribute_events_tab:"Gebeurtenissen",
attribute_attrib_tab:"Attributen",
general_tab:"Algemeen",
attrib_tab:"Attributen",
events_tab:"Gebeurtenissen",
fieldset_general_tab:"Algemene instellingen",
fieldset_attrib_tab:"Elementattributen",
fieldset_events_tab:"Element Gebeurtenissen",
title_ins_element:"Invoegingselement",
title_del_element:"Verwijderingselement",
title_acronym_element:"Synoniem",
title_abbr_element:"Afkorting",
title_cite_element:"Citaat",
remove:"Verwijderen",
insert_date:"Huidige datum/tijd invoegen",
option_ltr:"Van links naar rechts",
option_rtl:"Van rechts naar links",
attribs_title:"Attributen Invoegen/bewerken"
});