tinyMCE.addI18n({az:{
common:{
edit_confirm:"Siz haz\u0131rki m\u0259tn sah\u0259si \u00FC\u00E7\u00FCn WYSIWYG rejimi istifad\u0259 etm\u0259k ist\u0259yirsiniz?",
apply:"T\u0259tbiq et",
insert:"\u018Flav\u0259 et",
update:"Yenil\u0259",
cancel:"L\u0259\u011Fv et",
close:"Ba\u011Fla",
browse:"G\u00F6zd\u0259n ke\u00E7ir",
class_name:"Sinif",
not_set:"-- M\u00FC\u0259yy\u0259n edilm\u0259yib --",
clipboard_msg:"Kopyalama/\u018Flav\u0259 et Mozilla v\u0259 Firefox-da i\u015Fl\u0259mir.\nN\u0259 ba\u015F verdiyi haqda daha \u0259trafl\u0131 \u00F6yr\u0259nm\u0259k ist\u0259yirsiniz?",
clipboard_no_support:"Hal-haz\u0131rda b\u0259l\u0259d\u00E7iniz t\u0259r\u0259find\u0259n d\u0259st\u0259kl\u0259nmir. Klaviatura q\u0131saldmas\u0131ndan istifad\u0259 edin.",
popup_blocked:"Ba\u011F\u0131\u015Flay\u0131n, lakin sizin \u00FCz\u0259 \u00E7\u0131xan p\u0259nc\u0259r\u0259l\u0259riniz funksiya p\u0259nc\u0259r\u0259sinin qar\u015F\u0131s\u0131n\u0131 ald\u0131. G\u0259r\u0259k \u00FCz\u0259 \u00E7\u0131xan p\u0259nc\u0259r\u0259l\u0259rin bloklama nizamlamas\u0131n\u0131 l\u0259\u011Fv ed\u0259siniz ki, al\u0259td\u0259n tam istifad\u0259 ed\u0259 bil\u0259siniz.",
invalid_data:"X\u0259ta: Q\u0131rm\u0131z\u0131 il\u0259 qeyd edilmi\u015Fl\u0259r s\u0259hv daxil edilib.",
more_colors:"Daha \u00E7ox r\u0259ng"
},
contextmenu:{
align:"Tarazla\u015Fd\u0131r",
left:"Sola",
center:"M\u0259rk\u0259z il\u0259",
right:"Sa\u011Fa",
full:"Tam"
},
insertdatetime:{
date_fmt:"%d-%m-%Y",
time_fmt:"%H:%M:%S",
insertdate_desc:"Tarix \u0259lav\u0259 et",
inserttime_desc:"Vaxt \u0259lav\u0259 et",
months_long:"Yanvar,Fevral,Mart,Aprel,May,\u0130yun,\u0130yul,Avqust,Sentyabr,Oktyabr,Noyabr,Dekabr",
months_short:"Yan,Fev,Mar,Apr,May,\u0130yu,\u0130yl,Avq,Sen,Okt,Noy,Dek",
day_long:"Bazar,Bazar ert\u0259si,\u00C7\u0259r\u015F\u0259nb\u0259 ax\u015Fam\u0131,\u00C7\u0259r\u015F\u0259nb\u0259,C\u00FCm\u0259 ax\u015Fam\u0131,C\u00FCm\u0259,\u015E\u0259nb\u0259,Bazar",
day_short:"B,Be,\u00C7a,\u00C7,Ca,C,\u015E,B"
},
print:{
print_desc:"\u00C7ap et"
},
preview:{
preview_desc:"\u0130lkin bax\u0131\u015F"
},
directionality:{
ltr_desc:"\u0130stiqam\u0259t soldan-sa\u011Fa",
rtl_desc:"\u0130stiqam\u0259t sa\u011Fdan-sola"
},
layer:{
insertlayer_desc:"Yeni qat \u0259lav\u0259 et",
forward_desc:"\u0130r\u0259li k\u00F6\u00E7\u00FCr",
backward_desc:"Geri k\u00F6\u00E7\u00FCr",
absolute_desc:"M\u00FCtl\u0259q m\u00F6vqeni yand\u0131r/s\u00F6nd\u00FCr",
content:"Yeni qat..."
},
save:{
save_desc:"Yadda saxla",
cancel_desc:"B\u00FCt\u00FCn d\u0259yi\u015Fiklikl\u0259ri l\u0259\u011Fv et"
},
nonbreaking:{
nonbreaking_desc:"Q\u0131r\u0131lmaz bo\u015Fluq \u0259lav\u0259 et"
},
iespell:{
iespell_desc:"Orfoqrafiyan\u0131 yoxla",
download:"ieSpell a\u015Fkar edilm\u0259yib. Y\u00FCkl\u0259nilsin?"
},
advhr:{
advhr_desc:"\u00DCf\u00FCqi x\u0259tt"
},
emotions:{
emotions_desc:"Smayllar"
},
searchreplace:{
search_desc:"Axtar",
replace_desc:"Axtar/D\u0259yi\u015F"
},
advimage:{
image_desc:"\u015E\u0259kli \u0259lav\u0259/redakt\u0259 et"
},
advlink:{
link_desc:"Ke\u00E7idi \u0259lav\u0259/redakt\u0259 et"
},
xhtmlxtras:{
cite_desc:"Sitat",
abbr_desc:"Abbreviatura",
acronym_desc:"Akronim",
del_desc:"Silinmi\u015F m\u0259tn",
ins_desc:"\u018Flav\u0259 edilmi\u015F m\u0259tn",
attribs_desc:"Atribut \u0259lav\u0259/redakt\u0259 et"
},
style:{
desc:"CSS stili redakt\u0259 et",
delta_width:"35"
},
paste:{
paste_text_desc:"Sad\u0259 m\u0259tn kimi \u0259lav\u0259 et",
paste_word_desc:"Word-d\u0259n \u0259lav\u0259 et",
selectall_desc:"Ham\u0131s\u0131n\u0131 se\u00E7",
plaintext_mode_sticky:"Paste is now in plain text mode. Click again to toggle back to regular paste mode. After you paste something you will be returned to regular paste mode.",
plaintext_mode:"Paste is now in plain text mode. Click again to toggle back to regular paste mode."
},
paste_dlg:{
text_title:"P\u0259nc\u0259r\u0259y\u0259 m\u0259tn \u0259lav\u0259 etm\u0259k \u00FC\u00E7\u00FCn CTRL+V klavi\u015F birl\u0259\u015Fm\u0259sini istifad\u0259 edin.",
text_linebreaks:"S\u0259tr s\u0131nmalar\u0131n\u0131 saxla",
word_title:"P\u0259nc\u0259r\u0259y\u0259 s\u00F6z \u0259lav\u0259 etm\u0259k \u00FC\u00E7\u00FCn CTRL+V klavi\u015F birl\u0259\u015Fm\u0259sini istifad\u0259 edin."
},
table:{
desc:"Yeni c\u0259dv\u0259l \u0259lav\u0259 et",
row_before_desc:"S\u0259tri \u0259vv\u0259l \u0259lav\u0259 et:",
row_after_desc:"S\u0259tri sonra \u0259vv\u0259l et:",
delete_row_desc:"S\u0259tri sil",
col_before_desc:"S\u00FCtunu \u0259vv\u0259l \u0259lav\u0259 et:",
col_after_desc:"S\u00FCtunu sonra \u0259lav\u0259 et:",
delete_col_desc:"S\u00FCtunu sil",
split_cells_desc:"S\u00FCz\u00FClm\u00FC\u015F \u00F6z\u0259kl\u0259ri ay\u0131r",
merge_cells_desc:"\u00D6z\u0259kl\u0259ri s\u00FCz",
row_desc:"S\u0259tr x\u00FCsusiyy\u0259tl\u0259ri",
cell_desc:"\u00D6z\u0259k x\u00FCsusiyy\u0259tl\u0259ri",
props_desc:"C\u0259dv\u0259l x\u00FCsusiyy\u0259tl\u0259ri",
paste_row_before_desc:"S\u0259tr c\u0259dv\u0259lini \u0259vv\u0259l \u0259lav\u0259 et:",
paste_row_after_desc:"S\u0259tr c\u0259dv\u0259lini sonra \u0259lav\u0259 et:",
cut_row_desc:"S\u0259tri k\u0259s",
copy_row_desc:"S\u0259tri kopyala",
del:"C\u0259dv\u0259li sil",
row:"S\u0259tr",
col:"S\u00FCtun",
cell:"\u00D6z\u0259k"
},
autosave:{
unload_msg:"\u018Fg\u0259r s\u0259hif\u0259d\u0259n gets\u0259niz b\u00FCt\u00FCn d\u0259yi\u015Fiklikl\u0259r itiril\u0259c\u0259k.",
restore_content:"Restore auto-saved content.",
warning_message:"If you restore the saved content, you will lose all the content that is currently in the editor.\n\nAre you sure you want to restore the saved content?."
},
fullscreen:{
desc:"Tamekran rejimini yand\u0131r/s\u00F6nd\u00FCr"
},
media:{
desc:"mediya-obyekti \u0259lav\u0259/redakt\u0259 et",
edit:"Mediya-obyekti redakt\u0259 et"
},
fullpage:{
desc:"S\u0259n\u0259d nizamlamalar\u0131"
},
template:{
desc:"\u018Fvv\u0259ld\u0259n m\u00FC\u0259yy\u0259n edil\u0259n \u015Fablon daxil et"
},
visualchars:{
desc:"Vizual idar\u0259 xarakterl\u0259rini yand\u0131r/s\u00F6nd\u00FCr."
},
spellchecker:{
desc:"Orfoqraf\u0131 yoxla",
menu:"Orfoqrafiya nizamlamas\u0131n\u0131",
ignore_word:"S\u00F6zl\u00FC iqnor et",
ignore_words:"H\u0259r \u015Feyi iqnor et",
langs:"Dill\u0259r",
wait:"Z\u0259hm\u0259t olmasa, g\u00F6zl\u0259yin...",
sug:"Variantlar",
no_sug:"Variantlar yoxdur",
no_mpell:"X\u0259ta a\u015Fkar edilm\u0259di."
},
pagebreak:{
desc:"S\u0259hif\u0259 b\u00F6l\u0259nini \u0259lav\u0259 et."
},
advlist:{
types:"Types",
def:"Default",
lower_alpha:"Lower alpha",
lower_greek:"Lower greek",
lower_roman:"Lower roman",
upper_alpha:"Upper alpha",
upper_roman:"Upper roman",
circle:"Circle",
disc:"Disc",
square:"Square"
}}});