tinyMCE.addI18n('fr.emotions_dlg',{
title:"Ins\u00E9rer une \u00E9motic\u00F4ne",
desc:"\u00C9motic\u00F4nes",
cool:"Cool",
cry:"En pleurs",
embarassed:"Embarrass\u00E9",
foot_in_mouth:"Pied de nez",
frown:"D\u00E9\u00E7u",
innocent:"Innocent",
kiss:"Bisou",
laughing:"Rigolant",
money_mouth:"Avare",
sealed:"Bouche cousue",
smile:"Sourire",
surprised:"Surpris",
tongue_out:"Langue tir\u00E9e",
undecided:"Incertain",
wink:"Clin d'\u0153il",
yell:"Criant"
});