tinyMCE.addI18n('lt.advimage_dlg',{
tab_general:"Bendra",
tab_appearance:"I\u0161vaizda",
tab_advanced:"I\u0161pl\u0117sta",
general:"Bendra",
title:"Pavadinimas",
preview:"Per\u017Ei\u016Bra",
constrain_proportions:"Priverstin\u0117s proporcijos",
langdir:"Kalbos teksto kryptis",
langcode:"Kalbos kodas",
long_desc:"Ilgo apra\u0161o nuoroda",
style:"Stilius",
classes:"Klas\u0117s",
ltr:"I\u0161 kair\u0117s \u012F de\u0161in\u0119",
rtl:"I\u0161 de\u0161in\u0117s \u012F kair\u0119",
id:"Id",
map:"Paveiksl\u0117lio planas",
swap_image:"Sukeisti paveiksl\u0117l\u012F",
alt_image:"Alternatyvus paveiksl\u0117lis",
mouseover:"u\u017Evedant pele",
mouseout:"nuvedant pel\u0119",
misc:"\u012Evair\u016Bs",
example_img:"I\u0161vaizdos per\u017Ei\u016Bros paveiksl\u0117lis",
missing_alt:"Ar norite t\u0119sti ne\u012Fved\u0119 paveiksl\u0117lio apra\u0161o? Be apra\u0161o jo neatpa\u017Eins \u017Emon\u0117s su negalia, tie kurie naudoja tekstines nar\u0161ykles, arba tie, kurie nar\u0161o internet\u0105 i\u0161jung\u0119 paveiksl\u0117li\u0173 rodym\u0105.",
dialog_title:"\u012Eterpti/redaguoti paveiksl\u0117l\u012F",
src:"Paveiksl\u0117lio URL adresas",
alt:"Paveiksl\u0117lio apra\u0161as",
list:"Paveiksl\u0117li\u0173 s\u0105ra\u0161as",
border:"R\u0117melis",
dimensions:"I\u0161matavimai",
vspace:"Vertikalus tarpas",
hspace:"Horizontalus tarpas",
align:"Lygiavimas",
align_baseline:"Pradiniame ta\u0161ke",
align_top:"Vir\u0161uje",
align_middle:"Viduryje",
align_bottom:"Apa\u010Dioje",
align_texttop:"Teksto vir\u0161uje",
align_textbottom:"Teksto apa\u010Dioje",
align_left:"Kair\u0117je",
align_right:"De\u0161in\u0117je",
image_list:"Paveiksl\u0117li\u0173 s\u0105ra\u0161as"
});