tinyMCE.addI18n('tr.advimage_dlg',{
tab_general:"Genel",
tab_appearance:"G\u00F6r\u00FCn\u00FCm",
tab_advanced:"Geli\u015Fmi\u015F",
general:"Genel",
title:"Ba\u015Fl\u0131k",
preview:"\u00D6nizleme",
constrain_proportions:"Oran\u0131 s\u0131n\u0131rla",
langdir:"Dil y\u00F6n\u00FC",
langcode:"Dil kodu",
long_desc:"Uzun a\u00E7\u0131klamal\u0131 ba\u011Flant\u0131",
style:"Stil",
classes:"S\u0131n\u0131fla",
ltr:"Soldan sa\u011Fa",
rtl:"Sa\u011Fdan sola",
id:"Id",
map:"Resim haritas\u0131",
swap_image:"Resmi takas et",
alt_image:"Alternatif resim",
mouseover:"Fare \u00FCzerindeyken",
mouseout:"Fare d\u0131\u015F\u0131ndayken",
misc:"\u00C7e\u015Fitli",
example_img:"Resim \u00F6nizleme g\u00F6r\u00FCn\u00FCm\u00FC",
missing_alt:"Resim a\u00E7\u0131klamas\u0131 girmeden devam etmek istedi\u011Finize emini misiniz? Bu olmadan taray\u0131c\u0131da resimleri kapatanlar, metin bazl\u0131 taray\u0131c\u0131lar veya resim baz\u0131 engelli kullan\u0131c\u0131lar g\u00F6remeyeceklerdir.",
dialog_title:"Resim ekle/d\u00FCzenle",
src:"Resmin URL'si",
alt:"Resim a\u00E7\u0131klamas\u0131",
list:"Resim listesi",
border:"Kenarl\u0131k",
dimensions:"Boyutlar",
vspace:"Dikey bo\u015Fluk",
hspace:"Yatay bo\u015Fluk",
align:"Hizalama",
align_baseline:"Taban hizas\u0131",
align_top:"\u00DCst",
align_middle:"Orta",
align_bottom:"Alt",
align_texttop:"Metin \u00FCstte",
align_textbottom:"Metin altta",
align_left:"Sol",
align_right:"Sa\u011F",
image_list:"Resim listesi"
});