tinyMCE.addI18n('tr.advlink_dlg',{
title:"Ba\u011Flant\u0131 ekle/d\u00FCzenle",
url:"Ba\u011Flant\u0131 URL'si",
target:"Hedef",
titlefield:"Ba\u015Fl\u0131k",
is_email:"Girdi\u011Finiz URL e-posta adresi gibi g\u00F6r\u00FCn\u00FCyor; gerekli olan mailto: \u00F6nekinin eklenmesini ister misiniz? prefix?",
is_external:"Girdi\u011Fiz URL d\u0131\u015F ba\u011Flant\u0131 gibi g\u00F6r\u00FCn\u00FCyor; gerekli olan http:// \u00F6nekinin eklenmesini ister misiniz?",
list:"Ba\u011Flant\u0131 listesi",
general_tab:"Genel",
popup_tab:"A\u00E7\u0131l\u0131r pencere",
events_tab:"Olaylar",
advanced_tab:"Geli\u015Fmi\u015F",
general_props:"Genel \u00F6zellikler",
popup_props:"A\u00E7\u0131l\u0131r pencere \u00F6zellikleri",
event_props:"Olaylar",
advanced_props:"Geli\u015Fmi\u015F \u00F6zellikler",
popup_opts:"Se\u00E7enekler",
anchor_names:"Nesne tutucular",
target_same:"Pencerede / \u00E7er\u00E7evede a\u00E7",
target_parent:"Ana pencerede / \u00E7er\u00E7evede a\u00E7",
target_top:"\u00DCst \u00E7er\u00E7evede a\u00E7 (t\u00FCm \u00E7er\u00E7eveleri de\u011Fi\u015Ftir) ",
target_blank:"Yeni pencerede a\u00E7",
popup:"Javascript a\u00E7\u0131l\u0131r pencere",
popup_url:"A\u00E7\u0131l\u0131r pencere URL'si",
popup_name:"Pencere ad\u0131",
popup_return:"Ekle 'return false'",
popup_scrollbars:"Kayd\u0131rma \u00E7ubuklar\u0131n\u0131 g\u00F6ster",
popup_statusbar:"Durum \u00E7ubu\u011Funu g\u00F6ster",
popup_toolbar:"Ara\u00E7 kutusunu g\u00F6ster",
popup_menubar:"Men\u00FC \u00E7ubu\u011Funu g\u00F6ster",
popup_location:"Aderes \u00E7ubu\u011Funu g\u00F6ster",
popup_resizable:"Pencereyi boyutland\u0131r\u0131labilir yap",
popup_dependent:"Ba\u011F\u0131ml\u0131 (Sadece Mozilla Firefox)",
popup_size:"Boyut",
popup_position:"Konum (X/Y)",
id:"Id",
style:"Stil",
classes:"S\u0131n\u0131fla",
target_name:"Hedef ad\u0131",
langdir:"Dil y\u00F6n\u00FC",
target_langcode:"Hedef dil",
langcode:"Dil kodu",
encoding:"Hedef karakter kodlama",
mime:"Hedef MIME tipi",
rel:"Hedeften sayfaya ili\u015Fki",
rev:"Sayfadan hedefe ili\u015Fki",
tabindex:"Sekme indeksi",
accesskey:"Eri\u015Fim tu\u015Fu",
ltr:"Soldan sa\u011Fa",
rtl:"Sa\u011Fdan sola",
link_list:"Ba\u011Flant\u0131 listesi"
});