tinyMCE.addI18n('sl.advlink_dlg',{
title:"Vstavi/uredi povezavo",
url:"Naslov URL",
target:"Cilj",
titlefield:"Naslov",
is_email:"Vneseni naslov verjetno prestavlja e-naslov, \u017Eelite da dodam zahtevano predpono \'mailto:\'?",
is_external:"Vneseni naslov verjetno predstavlja zunanjo povezavo, \u017Eelite da dodam zahtevano predpono",
list:"Seznam povezav",
general_tab:"Splo\u0161no",
popup_tab:"Dodatno okno",
events_tab:"Dogodki",
advanced_tab:"Napredno",
general_props:"Splo\u0161ne lastnosti",
popup_props:"Lastnosti okna",
event_props:"Dogodki",
advanced_props:"Napredne lastnosti",
popup_opts:"Mo\u017Enosti",
anchor_names:"Sidra",
target_same:"Odpri v tem oknu / okviru",
target_parent:"Odpri v nadrejenem oknu / okviru",
target_top:"Odpri v vrhnjem okviru (nadomesti vse okvire)",
target_blank:"Odpri v novem oknu",
popup:"Dodatno okno z javascriptom",
popup_url:"Naslov URL okna",
popup_name:"Ime okna",
popup_return:"Vstavi \'return false\'",
popup_scrollbars:"Prika\u017Ei drsnike",
popup_statusbar:"Prika\u017Ei vrstico stanja",
popup_toolbar:"Prika\u017Ei orodjarno",
popup_menubar:"Prika\u017Ei meni",
popup_location:"Prika\u017Ei vrstico naslova",
popup_resizable:"Omogo\u010Di pvoe\u010Devanje okna",
popup_dependent:"Odvisno (le za Mozillo/Firefox)",
popup_size:"Velikost",
popup_position:"Polo\u017Eaj (X/Y)",
id:"Id",
style:"Slog",
classes:"Razredi",
target_name:"Ime cilja",
langdir:"Smer pisave",
target_langcode:"Jezik cilja",
langcode:"Koda jezika",
encoding:"Kodiranje znakov cilja",
mime:"Tip MIME cilja",
rel:"Razmerje strani do cilja",
rev:"Razmerje cilja do strani",
tabindex:"Zap. \u0161t.",
accesskey:"Tipka dostopa",
ltr:"Od leve proti desni",
rtl:"Od desne proti levi",
link_list:"Seznam povezav"
});