tinyMCE.addI18n('cs.emotions_dlg',{
title:"Vlo\u017Eit emotikonu",
desc:"Emotikony",
cool:"\u00DA\u017Easn\u00FD",
cry:"Pla\u010D\u00EDc\u00ED",
embarassed:"Rozpa\u010Dit\u00FD",
foot_in_mouth:"\u0160l\u00E1pnul vedle",
frown:"Zamra\u010Den\u00FD",
innocent:"Nevinn\u00FD",
kiss:"L\u00EDbaj\u00EDc\u00ED",
laughing:"Sm\u011Bj\u00EDc\u00ED se",
money_mouth:"Je na prachy",
sealed:"Ml\u010D\u00EDc\u00ED",
smile:"Usm\u00EDvaj\u00EDc\u00ED se",
surprised:"P\u0159ekvapen\u00FD",
tongue_out:"S vyplazen\u00FDm jazykem",
undecided:"Nerozhodn\u00FD",
wink:"Mrkaj\u00EDc\u00ED",
yell:"K\u0159i\u010D\u00EDc\u00ED"
});