tinyMCE.addI18n('eu.advanced',{
style_select:"Estiloak",
font_size:"Letra-tamaina",
fontdefault:"Letra-tipoa",
block:"Formatua",
paragraph:"Parrafoa",
div:"Div",
address:"Helbidea",
pre:"Aurreformateatua",
h1:"1. goiburua",
h2:"2. goiburua",
h3:"3. goiburua",
h4:"4. goiburua",
h5:"5. goiburua",
h6:"6. goiburua",
blockquote:"Zita",
code:"Kodea",
samp:"Kode adibidea",
dt:"Definizio terminoa (dt) ",
dd:"Definizioa (dd)",
bold_desc:"Beltza (Ctrl+B)",
italic_desc:"Etzana (Ctrl+I)",
underline_desc:"Azpimarratua (Ctrl+U)",
striketrough_desc:"Gainetik marra duena",
justifyleft_desc:"Ezkerrean alineatu",
justifycenter_desc:"Erdian zentratu",
justifyright_desc:"Eskuinean alineatu",
justifyfull_desc:"Testua justifikatu",
bullist_desc:"Zerrenda",
numlist_desc:"Zerrenda ordenatua",
outdent_desc:"Koska kendu",
indent_desc:"Koska gehitu",
undo_desc:"Desegin (Ctrl+Z)",
redo_desc:"Berregin (Ctrl+Y)",
link_desc:"Lotura txertatu/editatu",
unlink_desc:"Lotura kendu",
image_desc:"Irudia txertatu/editatu",
cleanup_desc:"Kode zikina garbitu",
code_desc:"HTML kodea editatu",
sub_desc:"Azpi-indizea",
sup_desc:"Goi-indizea",
hr_desc:"Lerro horizontala gehitu",
removeformat_desc:"Formatua kendu",
custom1_desc:"Nahi duzun deskribapena hemen idatzi",
forecolor_desc:"Testuaren kolorea aukeratu",
backcolor_desc:"Atzeko kolorea aukeratu",
charmap_desc:"Karaktere berezia txertatu",
visualaid_desc:"Elementu ikustezinak ikustarazi/ezkutatu",
anchor_desc:"Aingura txertatu/editatu",
cut_desc:"Ebaki",
copy_desc:"Kopiatu",
paste_desc:"Itsatsi",
image_props_desc:"Irudiaren aukerak",
newdocument_desc:"Dokumentu berria",
help_desc:"Laguntza",
blockquote_desc:"Zita",
clipboard_msg:"Kopiatu/Ebaki/Itsatsi ez dago Mozilla eta Firefoxen.\nHonen inguruko informazioa nahi duzu??",
path:"Bidea",
newdocument:"Eduki guztia kendu nahi duzu?",
toolbar_focus:"Tresnaren botoietara joan - Alt+Q, Editorera joan - Alt-Z, Elementuaren bidera joan - Alt-X",
more_colors:"Kolore gehiago",
image_delta_width:"Irudiaren zabalera",
image_delta_height:"Irudiaren altuera",
link_delta_width:"Loturaren zabalera",
link_delta_height:"Loturaren altuera",
colorpicker_delta_width:"Kolore hautatzailearen zabalera",
colorpicker_delta_height:"Kolore hautatzailearen altuera",
charmap_delta_width:"Karaktere maparen zabalera",
charmap_delta_height:"Karaktere maparen altuera",
anchor_delta_width:"Ainguraren zabalera",
anchor_delta_height:"Ainguraren altuera"
});