tinyMCE.addI18n('lb.advanced_dlg',{
about_title:"Iwwer TinyMCE",
about_general:"Iwwer\u2026",
about_help:"H\u00EBllef",
about_license:"Lizenzbedingungen",
about_plugins:"Pluginen",
about_plugin:"Plugin",
about_author:"Auteur",
about_version:"Versioun",
about_loaded:"Geluede Pluginen",
anchor_title:"Anker af\u00FCgen/ver\u00E4nneren",
anchor_name:"Numm vum Anker",
code_title:"HTML-Quellcode beaarbechten",
code_wordwrap:"Automateschen Zeilen\u00EBmbroch",
colorpicker_title:"Fuerf",
colorpicker_picker_tab:"Fuerfselectioun",
colorpicker_picker_title:"Fuerfselectioun",
colorpicker_palette_tab:"Palette",
colorpicker_palette_title:"Fuerfpalette",
colorpicker_named_tab:"Benannte Fuerwen",
colorpicker_named_title:"Benannte Fuerwen",
colorpicker_color:"Fuerf:",
colorpicker_name:"Numm:",
charmap_title:"Sonnerzeechen",
image_title:"Bild af\u00FCgen/beaarbechten",
image_src:"Adress",
image_alt:"Alternativtext",
image_list:"Billerleescht",
image_border:"Rumm",
image_dimensions:"Ausmoossen",
image_vspace:"Vertikalen Ofstand",
image_hspace:"Horizontalen Ofstand",
image_align:"Ausriichtung",
image_align_baseline:"Zeil",
image_align_top:"Uewen",
image_align_middle:"M\u00EBtteg",
image_align_bottom:"\u00CBnnen",
image_align_texttop:"Uewen am Text",
image_align_textbottom:"\u00CBnnen am Text",
image_align_left:"L\u00E9nks",
image_align_right:"Riets",
link_title:"Link af\u00FCgen/beaarbechten",
link_url:"Adress",
link_target:"F\u00EBnster",
link_target_same:"An der selwechter F\u00EBnster opmaachen",
link_target_blank:"Nei F\u00EBnster opmaachen",
link_titlefield:"Titel",
link_is_email:"D\u00EBs Adress sch\u00E9ngt eng Email-Adress ze sinn. W\u00EBll Dir den dofir ben\u00E9idegt mailto: virdru stellen?",
link_is_external:"D\u00EBs Adress sch\u00E9ngt een externen Link ze sinn. W\u00EBll Dir den dofir ben\u00E9idegt http:// virdru stellen?",
link_list:"Linkl\u00EBscht"
});