tinyMCE.addI18n('ms.table_dlg',{
general_tab:"Am",
advanced_tab:"Lanjutan",
general_props:"Alatan am",
advanced_props:"Alatan lanjutan",
rowtype:"Row dalam jadual",
title:"Masuk/Ubah jadual",
width:"Lebar",
height:"Tinggi",
cols:"Kol",
rows:"Row",
cellspacing:"Ruang sel",
cellpadding:"Lapisan sel",
border:"Sempadan",
align:"Penyelarian",
align_default:"Asal",
align_left:"Kiri",
align_right:"Kanan",
align_middle:"Tengah",
row_title:"Alatan row jadual",
cell_title:"Alatan sel jadual",
cell_type:"Jenis sel",
valign:"Penjajaran tegak",
align_top:"Atas",
align_bottom:"Bawah",
bordercolor:"Warna sempadan",
bgcolor:"Warna latar",
merge_cells_title:"Gabung sel jadual",
id:"Id",
style:"Gaya",
langdir:"Arah bahasa",
langcode:"Kod bahasa",
mime:"Sasaran jenis MIME",
ltr:"Kiri ke kanan",
rtl:"Kanan ke kiri",
bgimage:"Imej latar",
summary:"Kesimpulan",
td:"Data",
th:"Kepala",
cell_cell:"Baharui sel ini",
cell_row:"Baharui semua sel dalam row",
cell_all:"Baharui semua sel dalam jadual",
row_row:"Baharui row semasa",
row_odd:"Baharui row ganjil dalam jadual",
row_even:"Baharui row genap dalam jadual",
row_all:"Baharui semua row dalam jadual",
thead:"Pembuka jadual",
tbody:"Isi jadual",
tfoot:"Penutup jadual Foot",
scope:"Skop",
rowgroup:"Kumpulan row",
colgroup:"Kumpulan kol",
col_limit:"Anda telah melebihi maxima kolum dibenarkan iaitu {$cols}.",
row_limit:"Anda telah melebihi maxima row dibenarkan iaitu {$rows}.",
cell_limit:"Anda telah melebihi maxima sel dibenarkan iaitu {$cells}.",
missing_scope:"Adakah anda pasti terhadap skop sel jadual ini. Ia mungkin memberi kesan kepada OKU memahami isi jadual.",
caption:"Tajuk jadual",
frame:"Bingkai",
frame_none:"tiada",
frame_groups:"kumpulan",
frame_rows:"row",
frame_cols:"kol",
frame_all:"semua",
rules:"Peraturan",
rules_void:"batal",
rules_above:"atas",
rules_below:"bawah",
rules_hsides:"tepian datar",
rules_lhs:"hs-kiri",
rules_rhs:"hs-kanan",
rules_vsides:"tepian tegak",
rules_box:"kotak",
rules_border:"sempadan"
});