tinyMCE.addI18n('et.table_dlg',{
general_tab:"\u00DCldine",
advanced_tab:"T\u00E4psustatud",
general_props:"\u00DCldised seaded",
advanced_props:"T\u00E4psustatud seaded",
rowtype:"Rida rea osas",
title:"Sisesta/muuda tabelit",
width:"Laius",
height:"K\u00F5rgus",
cols:"Veerge",
rows:"Ridu",
cellspacing:"Veeru laius",
cellpadding:"Veeru t\u00E4ide",
border:"Raam",
align:"Joondus",
align_default:"Vaikimisi",
align_left:"Vasak",
align_right:"Parem",
align_middle:"Keskel",
row_title:"Tabeli rea seaded",
cell_title:"Tabeli veeru seaded",
cell_type:"Veeru t\u00FC\u00FCp",
valign:"Vertikaalne joondus",
align_top:"\u00DCleval",
align_bottom:"All",
bordercolor:"Raami v\u00E4rv",
bgcolor:"Tausta v\u00E4rv",
merge_cells_title:"\u00DChenda lahtrid",
id:"ID",
style:"Stiil",
langdir:"Keele suund",
langcode:"Keele kood",
mime:"M\u00E4rgista MIME t\u00FC\u00FCp",
ltr:"Vasakult paremale",
rtl:"Paremalt vasakule",
bgimage:"Tausta pilt",
summary:"Kokkuv\u00F5te",
td:"Info",
th:"P\u00E4is",
cell_cell:"Uuenda antud lahtrit",
cell_row:"Uuenda k\u00F5iki lahtreid reas",
cell_all:"Uuenda k\u00F5iki lahtreid tabelis",
row_row:"Uuenda antud rida",
row_odd:"Uuenda paarituid ridu tabelis",
row_even:"Uuenda paaris ridu tabelis",
row_all:"Uuenda k\u00F5iki ridu tabelis",
thead:"Tabeli p\u00E4is",
tbody:"Tabeli sisu",
tfoot:"Tabeli jalus",
scope:"Ulatus",
rowgroup:"Rea grupp",
colgroup:"Veeru grupp",
col_limit:"Oled j\u00F5udnud maksemaalse arvu veegudeni.",
row_limit:"Oled j\u00F5udnud maksimaalse arvu ridadeni",
cell_limit:"Oled j\u00F5udnud maksimaalse arvu elementideni",
missing_scope:"Oled kindel, et soovid j\u00E4tkata t\u00E4psustamata antud tabeli p\u00E4ise nime?",
caption:"Tabeli seletus",
frame:"Raam",
frame_none:"mitte \u00FCkski",
frame_groups:"grupid",
frame_rows:"read",
frame_cols:"veerud",
frame_all:"k\u00F5ik",
rules:"Reeglid",
rules_void:"t\u00FChi",
rules_above:"\u00FCleval",
rules_below:"all",
rules_hsides:"hsides",
rules_lhs:"lhs",
rules_rhs:"rhs",
rules_vsides:"vsides",
rules_box:"kast",
rules_border:"raam"
});