tinyMCE.addI18n('bs.table_dlg',{
general_tab:"Osnovno",
advanced_tab:"Napredno",
general_props:"Osnovna svojstva",
advanced_props:"Napredna svojstva",
rowtype:"Row in table part",
title:"Umetni/uredi tablicu",
width:"\u0160irina",
height:"Visina",
cols:"Stupaca",
rows:"Redaka",
cellspacing:"Razmak \u0107elija",
cellpadding:"Dopuna \u0107elije",
border:"Obrub",
align:"Poravnavanje",
align_default:"Zadano",
align_left:"Lijevo",
align_right:"Desno",
align_middle:"Sredina",
row_title:"Svojstva retka",
cell_title:"Svojstva \u0107elije",
cell_type:"Tip \u0107elije",
valign:"Okomito poravnavanje",
align_top:"Vrh",
align_bottom:"Dno",
bordercolor:"Boja obruba",
bgcolor:"Background color",
merge_cells_title:"Spoji \u0107elije",
id:"Id",
style:"Stil",
langdir:"Smjer jezika",
langcode:"Kod jezika",
mime:"MIME tip",
ltr:"S lijeva na desno",
rtl:"S desna na lijevo",
bgimage:"Slika pozadine",
summary:"Sa\u017Eetak",
td:"Podatkovna",
th:"Zaglavlje",
cell_cell:"Primjeni na odabranu \u0107eliju",
cell_row:"Primjeni na sve \u0107elije u retku",
cell_all:"Primjeni na sve \u0107elije u tablici",
row_row:"Primjeni na odabrani redak",
row_odd:"Primjeni na neparne retke u tablici",
row_even:"Primjeni na parne retke u tablici",
row_all:"Primjeni na sve retke u tablici",
thead:"Zaglavlje tablice",
tbody:"Tijelo tablice",
tfoot:"Podno\u017Eje tablice",
scope:"Domet",
rowgroup:"Grupa redaka",
colgroup:"Grupa stupaca",
col_limit:"Prema\u0161ili ste maksimalni broj stupaca ({$cols}).",
row_limit:"Prema\u0161ili ste maksimalni broj redaka ({$rows}).",
cell_limit:"Prema\u0161ili ste maksimalni broj \u0107elija ({$cells}).",
missing_scope:"Are you sure you want to continue without specifying a scope for this table header cell. Without it, it may be difficult for some users with disabilities to understand the content or data displayed of the table.",
caption:"Opis tablice",
frame:"Frame",
frame_none:"none",
frame_groups:"groups",
frame_rows:"rows",
frame_cols:"cols",
frame_all:"all",
rules:"Rules",
rules_void:"void",
rules_above:"above",
rules_below:"below",
rules_hsides:"hsides",
rules_lhs:"lhs",
rules_rhs:"rhs",
rules_vsides:"vsides",
rules_box:"box",
rules_border:"border"
});