tinyMCE.addI18n('de.emotions_dlg',{
title:"Smiley einf\u00FCgen",
desc:"Smilies",
cool:"Cool",
cry:"Weinend",
embarassed:"Verlegen",
foot_in_mouth:"Reingefallen",
frown:"Stirnrunzelnd",
innocent:"Unschuldig",
kiss:"K\u00FCssend",
laughing:"Lachend",
money_mouth:"Geld",
sealed:"Verschlossen",
smile:"L\u00E4chelnd",
surprised:"\u00DCberrascht",
tongue_out:"Zunge raus",
undecided:"Unentschlossen",
wink:"Zwinkernd",
yell:"Br\u00FCllend"
});