tinyMCE.addI18n('zh.xhtmlxtras_dlg',{
attribute_label_title:"\u6807\u9898",
attribute_label_id:"ID \u8BC6\u522B",
attribute_label_class:"\u7C7B\u578B",
attribute_label_style:"\u6837\u5F0F",
attribute_label_cite:"\u5F15\u7528",
attribute_label_datetime:"\u65E5\u671F/\u65F6\u95F4",
attribute_label_langdir:"\u6587\u5B57\u6392\u5217\u65B9\u5F0F",
attribute_option_ltr:"\u7531\u5DE6\u5230\u53F3",
attribute_option_rtl:"\u7531\u53F3\u5230\u5DE6",
attribute_label_langcode:"\u8BED\u8A00",
attribute_label_tabindex:"Tab\u7D22\u5F15",
attribute_label_accesskey:"\u5FEB\u6377\u952E",
attribute_events_tab:"\u4E8B\u4EF6",
attribute_attrib_tab:"\u5C5E\u6027",
general_tab:"\u4E00\u822C",
attrib_tab:"\u5C5E\u6027",
events_tab:"\u4E8B\u4EF6",
fieldset_general_tab:"\u4E00\u822C",
fieldset_attrib_tab:"\u5143\u7D20\u5C5E\u6027",
fieldset_events_tab:"\u5143\u7D20\u4E8B\u4EF6",
title_ins_element:"\u63D2\u5165\u5143\u7D20",
title_del_element:"\u5220\u9664\u5143\u7D20",
title_acronym_element:"\u9996\u5B57\u6BCD\u7B80\u7565\u8BCD\u5143\u7D20",
title_abbr_element:"\u7F29\u5199\u8BCD\u5143\u7D20",
title_cite_element:"\u5F15\u7528\u5143\u7D20",
remove:"\u5220\u9664",
insert_date:"\u63D2\u5165\u73B0\u5728\u65E5\u671F/\u65F6\u95F4",
option_ltr:"\u7531\u5DE6\u5230\u53F3",
option_rtl:"\u7531\u53F3\u5230\u5DE6",
attribs_title:"\u63D2\u5165/\u7F16\u8F91\u5C5E\u6027"
});